/* Automatically @generated by tree-sitter v0.25.4 (726dcd1e872149d95de581589fc408fb8ea9cb0b) */

#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#ifdef _MSC_VER
#pragma optimize("", off)
#elif defined(__clang__)
#pragma clang optimize off
#elif defined(__GNUC__)
#pragma GCC optimize ("O0")
#endif

#define LANGUAGE_VERSION 14
#define STATE_COUNT 642
#define LARGE_STATE_COUNT 86
#define SYMBOL_COUNT 176
#define ALIAS_COUNT 1
#define TOKEN_COUNT 121
#define EXTERNAL_TOKEN_COUNT 8
#define FIELD_COUNT 11
#define MAX_ALIAS_SEQUENCE_LENGTH 9
#define MAX_RESERVED_WORD_SET_SIZE 0
#define PRODUCTION_ID_COUNT 33
#define SUPERTYPE_COUNT 0

enum ts_symbol_identifiers {
  anon_sym_COLONmanuscript_COLON = 1,
  anon_sym_COLON_COLON = 2,
  anon_sym_COLONparagraph_COLON = 3,
  aux_sym_section_token1 = 4,
  anon_sym_COLONsection_COLON = 5,
  aux_sym_subsection_token1 = 6,
  anon_sym_COLONsubsection_COLON = 7,
  aux_sym_subsubsection_token1 = 8,
  anon_sym_COLONsubsubsection_COLON = 9,
  anon_sym_COLONappendix_COLON = 10,
  aux_sym_mathblock_token1 = 11,
  anon_sym_COLONmathblock_COLON = 12,
  anon_sym_COLONbibliography_COLON = 13,
  anon_sym_COLONtoc_COLON = 14,
  aux_sym_specialblock_token1 = 15,
  anon_sym_COLONcodeblock_COLON = 16,
  anon_sym_COLONalgorithm_COLON = 17,
  anon_sym_COLONcaption_COLON = 18,
  anon_sym_COLONitem_COLON = 19,
  anon_sym_COLONprev_COLON = 20,
  anon_sym_COLONprev2_COLON = 21,
  anon_sym_COLONprev3_COLON = 22,
  aux_sym_specialinline_token1 = 23,
  aux_sym_specialinline_token2 = 24,
  anon_sym_COLONmath_COLON = 25,
  anon_sym_COLONcode_COLON = 26,
  aux_sym_specialinline_token3 = 27,
  anon_sym_STAR = 28,
  aux_sym_specialinline_token4 = 29,
  anon_sym_SLASH = 30,
  anon_sym_COLONref_COLON = 31,
  aux_sym_specialinline_token5 = 32,
  anon_sym_COMMA = 33,
  anon_sym_COLONprevious_COLON = 34,
  aux_sym_specialinline_token6 = 35,
  anon_sym_COLONurl_COLON = 36,
  aux_sym_specialinline_token7 = 37,
  anon_sym_COLONcite_COLON = 38,
  aux_sym_specialinline_token8 = 39,
  anon_sym_COLONqed_COLON = 40,
  anon_sym_LBRACE = 41,
  anon_sym_RBRACE = 42,
  aux_sym_metaval_any_token1 = 43,
  aux_sym_metaval_any_inline_token1 = 44,
  anon_sym_COLONtable_COLON = 45,
  anon_sym_COLONthead_COLON = 46,
  anon_sym_COLONtbody_COLON = 47,
  anon_sym_COLONtr_COLON = 48,
  anon_sym_COLON = 49,
  anon_sym_COLONtd_COLON = 50,
  anon_sym_COLONbibtex_COLON = 51,
  anon_sym_AT = 52,
  aux_sym_bibitem_token1 = 53,
  aux_sym_bibitem_token2 = 54,
  aux_sym_bibitempair_token1 = 55,
  anon_sym_EQ = 56,
  aux_sym_bibitempair_token2 = 57,
  anon_sym_COLONassume_COLON = 58,
  anon_sym_COLONsuppose_COLON = 59,
  anon_sym_COLONprove_COLON = 60,
  anon_sym_COLONthen_COLON = 61,
  anon_sym_COLONnew_COLON = 62,
  anon_sym_COLONlet_COLON = 63,
  anon_sym_COLONcase_COLON = 64,
  anon_sym_COLONdefine_COLON = 65,
  anon_sym_COLONwrite_COLON = 66,
  anon_sym_COLONwlog_COLON = 67,
  anon_sym_COLONsuffices_COLON = 68,
  anon_sym_COLONclaim_COLON = 69,
  anon_sym_COLON_PIPE_DASH_COLON = 70,
  anon_sym_COLONu22a2_COLON = 71,
  anon_sym_COLONpick_COLON = 72,
  anon_sym_COLONst_COLON = 73,
  anon_sym_COLONdraft_COLON = 74,
  anon_sym_COLONnote_COLON = 75,
  anon_sym_COLONspan_COLON = 76,
  anon_sym_COLONabstract_COLON = 77,
  anon_sym_COLONauthor_COLON = 78,
  anon_sym_COLONdefinition_COLON = 79,
  anon_sym_COLONcorollary_COLON = 80,
  anon_sym_COLONenumerate_COLON = 81,
  anon_sym_COLONexample_COLON = 82,
  anon_sym_COLONitemize_COLON = 83,
  anon_sym_COLONlemma_COLON = 84,
  anon_sym_COLONfigure_COLON = 85,
  anon_sym_COLONp_COLON = 86,
  anon_sym_COLONproof_COLON = 87,
  anon_sym_COLONproposition_COLON = 88,
  anon_sym_COLONremark_COLON = 89,
  anon_sym_COLONsketch_COLON = 90,
  anon_sym_COLONstep_COLON = 91,
  anon_sym_COLONtheorem_COLON = 92,
  anon_sym_COLONaffiliation_COLON = 93,
  anon_sym_COLONemail_COLON = 94,
  anon_sym_COLONlabel_COLON = 95,
  anon_sym_COLONname_COLON = 96,
  anon_sym_COLONreftext_COLON = 97,
  anon_sym_COLONtitle_COLON = 98,
  anon_sym_COLONgoal_COLON = 99,
  anon_sym_COLONlang_COLON = 100,
  anon_sym_COLONicon_COLON = 101,
  anon_sym_COLONnonum_COLON = 102,
  anon_sym_COLONstrong_COLON = 103,
  anon_sym_COLONemphas_COLON = 104,
  anon_sym_COLONisclaim_COLON = 105,
  anon_sym_COLONkeywords_COLON = 106,
  anon_sym_COLONmsc_COLON = 107,
  anon_sym_COLONtypes_COLON = 108,
  anon_sym_COLONdate_COLON = 109,
  anon_sym_COLONpath_COLON = 110,
  anon_sym_COLONscale_COLON = 111,
  sym_comment = 112,
  sym_upto_brace_or_comma_text = 113,
  sym_asis_dollar_text = 114,
  sym_asis_two_dollars_text = 115,
  sym_asis_backtick_text = 116,
  sym_asis_three_backticks_text = 117,
  sym_asis_halmos_text = 118,
  sym_text = 119,
  sym_paragraph_end = 120,
  sym_source_file = 121,
  sym_block = 122,
  sym_paragraph = 123,
  sym_inline = 124,
  sym_construct = 125,
  sym_section = 126,
  sym_subsection = 127,
  sym_subsubsection = 128,
  sym_appendix = 129,
  sym_mathblock = 130,
  sym_specialblock = 131,
  sym_caption = 132,
  sym_item = 133,
  sym_specialinline = 134,
  sym_specialconstruct = 135,
  sym_inlinemeta = 136,
  sym_blockmeta = 137,
  sym_inlinemetapair = 138,
  sym_pair = 139,
  sym_metaval_any = 140,
  sym_metaval_any_inline = 141,
  sym_metaval_text = 142,
  sym_metaval_text_inline = 143,
  sym_metaval_list = 144,
  sym_metaval_list_inline = 145,
  sym_table = 146,
  sym_thead = 147,
  sym_tbody = 148,
  sym_tr = 149,
  sym_trshort = 150,
  sym_td = 151,
  sym_tdcontent = 152,
  sym_bibtex = 153,
  sym_bibitem = 154,
  sym_bibitempair = 155,
  sym__paragraphcontent_no_special = 156,
  sym_metakey_text = 157,
  sym_metakey_bool = 158,
  sym_metakey_list = 159,
  sym_metakey_any = 160,
  aux_sym_source_file_repeat1 = 161,
  aux_sym_block_repeat1 = 162,
  aux_sym_paragraph_repeat1 = 163,
  aux_sym_inline_repeat1 = 164,
  aux_sym_section_repeat1 = 165,
  aux_sym_subsection_repeat1 = 166,
  aux_sym_subsubsection_repeat1 = 167,
  aux_sym_inlinemeta_repeat1 = 168,
  aux_sym_blockmeta_repeat1 = 169,
  aux_sym_metaval_list_repeat1 = 170,
  aux_sym_thead_repeat1 = 171,
  aux_sym_tr_repeat1 = 172,
  aux_sym_trshort_repeat1 = 173,
  aux_sym_bibtex_repeat1 = 174,
  aux_sym_bibitem_repeat1 = 175,
  anon_alias_sym_math = 176,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [anon_sym_COLONmanuscript_COLON] = "manuscript",
  [anon_sym_COLON_COLON] = "::",
  [anon_sym_COLONparagraph_COLON] = ":paragraph:",
  [aux_sym_section_token1] = "section",
  [anon_sym_COLONsection_COLON] = "section",
  [aux_sym_subsection_token1] = "subsection",
  [anon_sym_COLONsubsection_COLON] = "subsection",
  [aux_sym_subsubsection_token1] = "subsubsection",
  [anon_sym_COLONsubsubsection_COLON] = "subsubsection",
  [anon_sym_COLONappendix_COLON] = "appendix",
  [aux_sym_mathblock_token1] = "mathblock_token1",
  [anon_sym_COLONmathblock_COLON] = ":mathblock:",
  [anon_sym_COLONbibliography_COLON] = "bibliography",
  [anon_sym_COLONtoc_COLON] = "toc",
  [aux_sym_specialblock_token1] = "specialblock_token1",
  [anon_sym_COLONcodeblock_COLON] = "codeblock",
  [anon_sym_COLONalgorithm_COLON] = "algorithm",
  [anon_sym_COLONcaption_COLON] = ":caption:",
  [anon_sym_COLONitem_COLON] = ":item:",
  [anon_sym_COLONprev_COLON] = "prev",
  [anon_sym_COLONprev2_COLON] = "prev2",
  [anon_sym_COLONprev3_COLON] = "prev3",
  [aux_sym_specialinline_token1] = "math",
  [aux_sym_specialinline_token2] = "specialinline_token2",
  [anon_sym_COLONmath_COLON] = "math",
  [anon_sym_COLONcode_COLON] = "code",
  [aux_sym_specialinline_token3] = "spanstrong",
  [anon_sym_STAR] = "*",
  [aux_sym_specialinline_token4] = "spanemphas",
  [anon_sym_SLASH] = "/",
  [anon_sym_COLONref_COLON] = "ref",
  [aux_sym_specialinline_token5] = "text",
  [anon_sym_COMMA] = ",",
  [anon_sym_COLONprevious_COLON] = "previous",
  [aux_sym_specialinline_token6] = "text",
  [anon_sym_COLONurl_COLON] = "url",
  [aux_sym_specialinline_token7] = "text",
  [anon_sym_COLONcite_COLON] = "cite",
  [aux_sym_specialinline_token8] = "text",
  [anon_sym_COLONqed_COLON] = "qed",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [aux_sym_metaval_any_token1] = "text",
  [aux_sym_metaval_any_inline_token1] = "text",
  [anon_sym_COLONtable_COLON] = ":table:",
  [anon_sym_COLONthead_COLON] = ":thead:",
  [anon_sym_COLONtbody_COLON] = ":tbody:",
  [anon_sym_COLONtr_COLON] = ":tr:",
  [anon_sym_COLON] = ":",
  [anon_sym_COLONtd_COLON] = ":td:",
  [anon_sym_COLONbibtex_COLON] = ":bibtex:",
  [anon_sym_AT] = "@",
  [aux_sym_bibitem_token1] = "kind",
  [aux_sym_bibitem_token2] = "label",
  [aux_sym_bibitempair_token1] = "key",
  [anon_sym_EQ] = "=",
  [aux_sym_bibitempair_token2] = "value",
  [anon_sym_COLONassume_COLON] = "assume",
  [anon_sym_COLONsuppose_COLON] = "suppose",
  [anon_sym_COLONprove_COLON] = "prove",
  [anon_sym_COLONthen_COLON] = "then",
  [anon_sym_COLONnew_COLON] = "new",
  [anon_sym_COLONlet_COLON] = "let",
  [anon_sym_COLONcase_COLON] = "case",
  [anon_sym_COLONdefine_COLON] = "define",
  [anon_sym_COLONwrite_COLON] = "write",
  [anon_sym_COLONwlog_COLON] = "wlog",
  [anon_sym_COLONsuffices_COLON] = "suffices",
  [anon_sym_COLONclaim_COLON] = "claim",
  [anon_sym_COLON_PIPE_DASH_COLON] = "claim",
  [anon_sym_COLONu22a2_COLON] = "claim",
  [anon_sym_COLONpick_COLON] = "pick",
  [anon_sym_COLONst_COLON] = "st",
  [anon_sym_COLONdraft_COLON] = "draft",
  [anon_sym_COLONnote_COLON] = "note",
  [anon_sym_COLONspan_COLON] = "span",
  [anon_sym_COLONabstract_COLON] = "abstract",
  [anon_sym_COLONauthor_COLON] = "author",
  [anon_sym_COLONdefinition_COLON] = "definition",
  [anon_sym_COLONcorollary_COLON] = "corollary",
  [anon_sym_COLONenumerate_COLON] = "enumerate",
  [anon_sym_COLONexample_COLON] = "example",
  [anon_sym_COLONitemize_COLON] = "itemize",
  [anon_sym_COLONlemma_COLON] = "lemma",
  [anon_sym_COLONfigure_COLON] = "figure",
  [anon_sym_COLONp_COLON] = "subproof",
  [anon_sym_COLONproof_COLON] = "proof",
  [anon_sym_COLONproposition_COLON] = "proposition",
  [anon_sym_COLONremark_COLON] = "remark",
  [anon_sym_COLONsketch_COLON] = "sketch",
  [anon_sym_COLONstep_COLON] = "step",
  [anon_sym_COLONtheorem_COLON] = "theorem",
  [anon_sym_COLONaffiliation_COLON] = "affiliation",
  [anon_sym_COLONemail_COLON] = "email",
  [anon_sym_COLONlabel_COLON] = "label",
  [anon_sym_COLONname_COLON] = "name",
  [anon_sym_COLONreftext_COLON] = "reftext",
  [anon_sym_COLONtitle_COLON] = "title",
  [anon_sym_COLONgoal_COLON] = "goal",
  [anon_sym_COLONlang_COLON] = "lang",
  [anon_sym_COLONicon_COLON] = "icon",
  [anon_sym_COLONnonum_COLON] = "nonum",
  [anon_sym_COLONstrong_COLON] = "strong",
  [anon_sym_COLONemphas_COLON] = "emphas",
  [anon_sym_COLONisclaim_COLON] = "isclaim",
  [anon_sym_COLONkeywords_COLON] = "keywords",
  [anon_sym_COLONmsc_COLON] = "msc",
  [anon_sym_COLONtypes_COLON] = "types",
  [anon_sym_COLONdate_COLON] = "date",
  [anon_sym_COLONpath_COLON] = "path",
  [anon_sym_COLONscale_COLON] = "scale",
  [sym_comment] = "comment",
  [sym_upto_brace_or_comma_text] = "metaval_list_item",
  [sym_asis_dollar_text] = "asis_text",
  [sym_asis_two_dollars_text] = "asis_text",
  [sym_asis_backtick_text] = "asis_text",
  [sym_asis_three_backticks_text] = "asis_text",
  [sym_asis_halmos_text] = "asis_text",
  [sym_text] = "text",
  [sym_paragraph_end] = "paragraph_end",
  [sym_source_file] = "source_file",
  [sym_block] = "block",
  [sym_paragraph] = "paragraph",
  [sym_inline] = "inline",
  [sym_construct] = "construct",
  [sym_section] = "section",
  [sym_subsection] = "subsection",
  [sym_subsubsection] = "subsubsection",
  [sym_appendix] = "appendix",
  [sym_mathblock] = "mathblock",
  [sym_specialblock] = "specialblock",
  [sym_caption] = "caption",
  [sym_item] = "item",
  [sym_specialinline] = "specialinline",
  [sym_specialconstruct] = "specialconstruct",
  [sym_inlinemeta] = "inlinemeta",
  [sym_blockmeta] = "blockmeta",
  [sym_inlinemetapair] = "pair",
  [sym_pair] = "pair",
  [sym_metaval_any] = "metaval_any",
  [sym_metaval_any_inline] = "metaval_any",
  [sym_metaval_text] = "metaval_text",
  [sym_metaval_text_inline] = "metaval_text",
  [sym_metaval_list] = "metaval_list",
  [sym_metaval_list_inline] = "metaval_list",
  [sym_table] = "table",
  [sym_thead] = "thead",
  [sym_tbody] = "tbody",
  [sym_tr] = "tr",
  [sym_trshort] = "trshort",
  [sym_td] = "td",
  [sym_tdcontent] = "tdcontent",
  [sym_bibtex] = "bibtex",
  [sym_bibitem] = "bibitem",
  [sym_bibitempair] = "bibitempair",
  [sym__paragraphcontent_no_special] = "_paragraphcontent_no_special",
  [sym_metakey_text] = "metakey_text",
  [sym_metakey_bool] = "metakey_bool",
  [sym_metakey_list] = "metakey_list",
  [sym_metakey_any] = "metakey_any",
  [aux_sym_source_file_repeat1] = "source_file_repeat1",
  [aux_sym_block_repeat1] = "block_repeat1",
  [aux_sym_paragraph_repeat1] = "paragraph_repeat1",
  [aux_sym_inline_repeat1] = "inline_repeat1",
  [aux_sym_section_repeat1] = "section_repeat1",
  [aux_sym_subsection_repeat1] = "subsection_repeat1",
  [aux_sym_subsubsection_repeat1] = "subsubsection_repeat1",
  [aux_sym_inlinemeta_repeat1] = "inlinemeta_repeat1",
  [aux_sym_blockmeta_repeat1] = "blockmeta_repeat1",
  [aux_sym_metaval_list_repeat1] = "metaval_list_repeat1",
  [aux_sym_thead_repeat1] = "thead_repeat1",
  [aux_sym_tr_repeat1] = "tr_repeat1",
  [aux_sym_trshort_repeat1] = "trshort_repeat1",
  [aux_sym_bibtex_repeat1] = "bibtex_repeat1",
  [aux_sym_bibitem_repeat1] = "bibitem_repeat1",
  [anon_alias_sym_math] = "math",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [anon_sym_COLONmanuscript_COLON] = anon_sym_COLONmanuscript_COLON,
  [anon_sym_COLON_COLON] = anon_sym_COLON_COLON,
  [anon_sym_COLONparagraph_COLON] = anon_sym_COLONparagraph_COLON,
  [aux_sym_section_token1] = sym_section,
  [anon_sym_COLONsection_COLON] = sym_section,
  [aux_sym_subsection_token1] = sym_subsection,
  [anon_sym_COLONsubsection_COLON] = sym_subsection,
  [aux_sym_subsubsection_token1] = sym_subsubsection,
  [anon_sym_COLONsubsubsection_COLON] = sym_subsubsection,
  [anon_sym_COLONappendix_COLON] = sym_appendix,
  [aux_sym_mathblock_token1] = aux_sym_mathblock_token1,
  [anon_sym_COLONmathblock_COLON] = anon_sym_COLONmathblock_COLON,
  [anon_sym_COLONbibliography_COLON] = anon_sym_COLONbibliography_COLON,
  [anon_sym_COLONtoc_COLON] = anon_sym_COLONtoc_COLON,
  [aux_sym_specialblock_token1] = aux_sym_specialblock_token1,
  [anon_sym_COLONcodeblock_COLON] = anon_sym_COLONcodeblock_COLON,
  [anon_sym_COLONalgorithm_COLON] = anon_sym_COLONalgorithm_COLON,
  [anon_sym_COLONcaption_COLON] = anon_sym_COLONcaption_COLON,
  [anon_sym_COLONitem_COLON] = anon_sym_COLONitem_COLON,
  [anon_sym_COLONprev_COLON] = anon_sym_COLONprev_COLON,
  [anon_sym_COLONprev2_COLON] = anon_sym_COLONprev2_COLON,
  [anon_sym_COLONprev3_COLON] = anon_sym_COLONprev3_COLON,
  [aux_sym_specialinline_token1] = aux_sym_specialinline_token1,
  [aux_sym_specialinline_token2] = aux_sym_specialinline_token2,
  [anon_sym_COLONmath_COLON] = aux_sym_specialinline_token1,
  [anon_sym_COLONcode_COLON] = anon_sym_COLONcode_COLON,
  [aux_sym_specialinline_token3] = aux_sym_specialinline_token3,
  [anon_sym_STAR] = anon_sym_STAR,
  [aux_sym_specialinline_token4] = aux_sym_specialinline_token4,
  [anon_sym_SLASH] = anon_sym_SLASH,
  [anon_sym_COLONref_COLON] = anon_sym_COLONref_COLON,
  [aux_sym_specialinline_token5] = sym_text,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_COLONprevious_COLON] = anon_sym_COLONprevious_COLON,
  [aux_sym_specialinline_token6] = sym_text,
  [anon_sym_COLONurl_COLON] = anon_sym_COLONurl_COLON,
  [aux_sym_specialinline_token7] = sym_text,
  [anon_sym_COLONcite_COLON] = anon_sym_COLONcite_COLON,
  [aux_sym_specialinline_token8] = sym_text,
  [anon_sym_COLONqed_COLON] = anon_sym_COLONqed_COLON,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [aux_sym_metaval_any_token1] = aux_sym_metaval_any_token1,
  [aux_sym_metaval_any_inline_token1] = aux_sym_metaval_any_token1,
  [anon_sym_COLONtable_COLON] = anon_sym_COLONtable_COLON,
  [anon_sym_COLONthead_COLON] = anon_sym_COLONthead_COLON,
  [anon_sym_COLONtbody_COLON] = anon_sym_COLONtbody_COLON,
  [anon_sym_COLONtr_COLON] = anon_sym_COLONtr_COLON,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_COLONtd_COLON] = anon_sym_COLONtd_COLON,
  [anon_sym_COLONbibtex_COLON] = anon_sym_COLONbibtex_COLON,
  [anon_sym_AT] = anon_sym_AT,
  [aux_sym_bibitem_token1] = aux_sym_bibitem_token1,
  [aux_sym_bibitem_token2] = aux_sym_bibitem_token2,
  [aux_sym_bibitempair_token1] = aux_sym_bibitempair_token1,
  [anon_sym_EQ] = anon_sym_EQ,
  [aux_sym_bibitempair_token2] = aux_sym_bibitempair_token2,
  [anon_sym_COLONassume_COLON] = anon_sym_COLONassume_COLON,
  [anon_sym_COLONsuppose_COLON] = anon_sym_COLONsuppose_COLON,
  [anon_sym_COLONprove_COLON] = anon_sym_COLONprove_COLON,
  [anon_sym_COLONthen_COLON] = anon_sym_COLONthen_COLON,
  [anon_sym_COLONnew_COLON] = anon_sym_COLONnew_COLON,
  [anon_sym_COLONlet_COLON] = anon_sym_COLONlet_COLON,
  [anon_sym_COLONcase_COLON] = anon_sym_COLONcase_COLON,
  [anon_sym_COLONdefine_COLON] = anon_sym_COLONdefine_COLON,
  [anon_sym_COLONwrite_COLON] = anon_sym_COLONwrite_COLON,
  [anon_sym_COLONwlog_COLON] = anon_sym_COLONwlog_COLON,
  [anon_sym_COLONsuffices_COLON] = anon_sym_COLONsuffices_COLON,
  [anon_sym_COLONclaim_COLON] = anon_sym_COLONclaim_COLON,
  [anon_sym_COLON_PIPE_DASH_COLON] = anon_sym_COLONclaim_COLON,
  [anon_sym_COLONu22a2_COLON] = anon_sym_COLONclaim_COLON,
  [anon_sym_COLONpick_COLON] = anon_sym_COLONpick_COLON,
  [anon_sym_COLONst_COLON] = anon_sym_COLONst_COLON,
  [anon_sym_COLONdraft_COLON] = anon_sym_COLONdraft_COLON,
  [anon_sym_COLONnote_COLON] = anon_sym_COLONnote_COLON,
  [anon_sym_COLONspan_COLON] = anon_sym_COLONspan_COLON,
  [anon_sym_COLONabstract_COLON] = anon_sym_COLONabstract_COLON,
  [anon_sym_COLONauthor_COLON] = anon_sym_COLONauthor_COLON,
  [anon_sym_COLONdefinition_COLON] = anon_sym_COLONdefinition_COLON,
  [anon_sym_COLONcorollary_COLON] = anon_sym_COLONcorollary_COLON,
  [anon_sym_COLONenumerate_COLON] = anon_sym_COLONenumerate_COLON,
  [anon_sym_COLONexample_COLON] = anon_sym_COLONexample_COLON,
  [anon_sym_COLONitemize_COLON] = anon_sym_COLONitemize_COLON,
  [anon_sym_COLONlemma_COLON] = anon_sym_COLONlemma_COLON,
  [anon_sym_COLONfigure_COLON] = anon_sym_COLONfigure_COLON,
  [anon_sym_COLONp_COLON] = anon_sym_COLONp_COLON,
  [anon_sym_COLONproof_COLON] = anon_sym_COLONproof_COLON,
  [anon_sym_COLONproposition_COLON] = anon_sym_COLONproposition_COLON,
  [anon_sym_COLONremark_COLON] = anon_sym_COLONremark_COLON,
  [anon_sym_COLONsketch_COLON] = anon_sym_COLONsketch_COLON,
  [anon_sym_COLONstep_COLON] = anon_sym_COLONstep_COLON,
  [anon_sym_COLONtheorem_COLON] = anon_sym_COLONtheorem_COLON,
  [anon_sym_COLONaffiliation_COLON] = anon_sym_COLONaffiliation_COLON,
  [anon_sym_COLONemail_COLON] = anon_sym_COLONemail_COLON,
  [anon_sym_COLONlabel_COLON] = aux_sym_bibitem_token2,
  [anon_sym_COLONname_COLON] = anon_sym_COLONname_COLON,
  [anon_sym_COLONreftext_COLON] = anon_sym_COLONreftext_COLON,
  [anon_sym_COLONtitle_COLON] = anon_sym_COLONtitle_COLON,
  [anon_sym_COLONgoal_COLON] = anon_sym_COLONgoal_COLON,
  [anon_sym_COLONlang_COLON] = anon_sym_COLONlang_COLON,
  [anon_sym_COLONicon_COLON] = anon_sym_COLONicon_COLON,
  [anon_sym_COLONnonum_COLON] = anon_sym_COLONnonum_COLON,
  [anon_sym_COLONstrong_COLON] = anon_sym_COLONstrong_COLON,
  [anon_sym_COLONemphas_COLON] = anon_sym_COLONemphas_COLON,
  [anon_sym_COLONisclaim_COLON] = anon_sym_COLONisclaim_COLON,
  [anon_sym_COLONkeywords_COLON] = anon_sym_COLONkeywords_COLON,
  [anon_sym_COLONmsc_COLON] = anon_sym_COLONmsc_COLON,
  [anon_sym_COLONtypes_COLON] = anon_sym_COLONtypes_COLON,
  [anon_sym_COLONdate_COLON] = anon_sym_COLONdate_COLON,
  [anon_sym_COLONpath_COLON] = anon_sym_COLONpath_COLON,
  [anon_sym_COLONscale_COLON] = anon_sym_COLONscale_COLON,
  [sym_comment] = sym_comment,
  [sym_upto_brace_or_comma_text] = sym_upto_brace_or_comma_text,
  [sym_asis_dollar_text] = sym_asis_dollar_text,
  [sym_asis_two_dollars_text] = sym_asis_dollar_text,
  [sym_asis_backtick_text] = sym_asis_dollar_text,
  [sym_asis_three_backticks_text] = sym_asis_dollar_text,
  [sym_asis_halmos_text] = sym_asis_dollar_text,
  [sym_text] = sym_text,
  [sym_paragraph_end] = sym_paragraph_end,
  [sym_source_file] = sym_source_file,
  [sym_block] = sym_block,
  [sym_paragraph] = sym_paragraph,
  [sym_inline] = sym_inline,
  [sym_construct] = sym_construct,
  [sym_section] = sym_section,
  [sym_subsection] = sym_subsection,
  [sym_subsubsection] = sym_subsubsection,
  [sym_appendix] = sym_appendix,
  [sym_mathblock] = sym_mathblock,
  [sym_specialblock] = sym_specialblock,
  [sym_caption] = sym_caption,
  [sym_item] = sym_item,
  [sym_specialinline] = sym_specialinline,
  [sym_specialconstruct] = sym_specialconstruct,
  [sym_inlinemeta] = sym_inlinemeta,
  [sym_blockmeta] = sym_blockmeta,
  [sym_inlinemetapair] = sym_inlinemetapair,
  [sym_pair] = sym_inlinemetapair,
  [sym_metaval_any] = sym_metaval_any,
  [sym_metaval_any_inline] = sym_metaval_any,
  [sym_metaval_text] = sym_metaval_text,
  [sym_metaval_text_inline] = sym_metaval_text,
  [sym_metaval_list] = sym_metaval_list,
  [sym_metaval_list_inline] = sym_metaval_list,
  [sym_table] = sym_table,
  [sym_thead] = sym_thead,
  [sym_tbody] = sym_tbody,
  [sym_tr] = sym_tr,
  [sym_trshort] = sym_trshort,
  [sym_td] = sym_td,
  [sym_tdcontent] = sym_tdcontent,
  [sym_bibtex] = sym_bibtex,
  [sym_bibitem] = sym_bibitem,
  [sym_bibitempair] = sym_bibitempair,
  [sym__paragraphcontent_no_special] = sym__paragraphcontent_no_special,
  [sym_metakey_text] = sym_metakey_text,
  [sym_metakey_bool] = sym_metakey_bool,
  [sym_metakey_list] = sym_metakey_list,
  [sym_metakey_any] = sym_metakey_any,
  [aux_sym_source_file_repeat1] = aux_sym_source_file_repeat1,
  [aux_sym_block_repeat1] = aux_sym_block_repeat1,
  [aux_sym_paragraph_repeat1] = aux_sym_paragraph_repeat1,
  [aux_sym_inline_repeat1] = aux_sym_inline_repeat1,
  [aux_sym_section_repeat1] = aux_sym_section_repeat1,
  [aux_sym_subsection_repeat1] = aux_sym_subsection_repeat1,
  [aux_sym_subsubsection_repeat1] = aux_sym_subsubsection_repeat1,
  [aux_sym_inlinemeta_repeat1] = aux_sym_inlinemeta_repeat1,
  [aux_sym_blockmeta_repeat1] = aux_sym_blockmeta_repeat1,
  [aux_sym_metaval_list_repeat1] = aux_sym_metaval_list_repeat1,
  [aux_sym_thead_repeat1] = aux_sym_thead_repeat1,
  [aux_sym_tr_repeat1] = aux_sym_tr_repeat1,
  [aux_sym_trshort_repeat1] = aux_sym_trshort_repeat1,
  [aux_sym_bibtex_repeat1] = aux_sym_bibtex_repeat1,
  [aux_sym_bibitem_repeat1] = aux_sym_bibitem_repeat1,
  [anon_alias_sym_math] = anon_alias_sym_math,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [anon_sym_COLONmanuscript_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLON_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLONparagraph_COLON] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_section_token1] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONsection_COLON] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_subsection_token1] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONsubsection_COLON] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_subsubsection_token1] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONsubsubsection_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONappendix_COLON] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_mathblock_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_COLONmathblock_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLONbibliography_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONtoc_COLON] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_specialblock_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_COLONcodeblock_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONalgorithm_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONcaption_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLONitem_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLONprev_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONprev2_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONprev3_COLON] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_specialinline_token1] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_specialinline_token2] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_COLONmath_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONcode_COLON] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_specialinline_token3] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_specialinline_token4] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLONref_COLON] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_specialinline_token5] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLONprevious_COLON] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_specialinline_token6] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONurl_COLON] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_specialinline_token7] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONcite_COLON] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_specialinline_token8] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONqed_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_metaval_any_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_metaval_any_inline_token1] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLONtable_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLONthead_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLONtbody_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLONtr_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLONtd_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLONbibtex_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AT] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_bibitem_token1] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_bibitem_token2] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_bibitempair_token1] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_bibitempair_token2] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONassume_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONsuppose_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONprove_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONthen_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONnew_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONlet_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONcase_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONdefine_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONwrite_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONwlog_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONsuffices_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONclaim_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLON_PIPE_DASH_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONu22a2_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONpick_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONst_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONdraft_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONnote_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONspan_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONabstract_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONauthor_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONdefinition_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONcorollary_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONenumerate_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONexample_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONitemize_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONlemma_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONfigure_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONp_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONproof_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONproposition_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONremark_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONsketch_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONstep_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONtheorem_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONaffiliation_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONemail_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONlabel_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONname_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONreftext_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONtitle_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONgoal_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONlang_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONicon_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONnonum_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONstrong_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONemphas_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONisclaim_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONkeywords_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONmsc_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONtypes_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONdate_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONpath_COLON] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLONscale_COLON] = {
    .visible = true,
    .named = true,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_upto_brace_or_comma_text] = {
    .visible = true,
    .named = true,
  },
  [sym_asis_dollar_text] = {
    .visible = true,
    .named = true,
  },
  [sym_asis_two_dollars_text] = {
    .visible = true,
    .named = true,
  },
  [sym_asis_backtick_text] = {
    .visible = true,
    .named = true,
  },
  [sym_asis_three_backticks_text] = {
    .visible = true,
    .named = true,
  },
  [sym_asis_halmos_text] = {
    .visible = true,
    .named = true,
  },
  [sym_text] = {
    .visible = true,
    .named = true,
  },
  [sym_paragraph_end] = {
    .visible = true,
    .named = false,
  },
  [sym_source_file] = {
    .visible = true,
    .named = true,
  },
  [sym_block] = {
    .visible = true,
    .named = true,
  },
  [sym_paragraph] = {
    .visible = true,
    .named = true,
  },
  [sym_inline] = {
    .visible = true,
    .named = true,
  },
  [sym_construct] = {
    .visible = true,
    .named = true,
  },
  [sym_section] = {
    .visible = true,
    .named = true,
  },
  [sym_subsection] = {
    .visible = true,
    .named = true,
  },
  [sym_subsubsection] = {
    .visible = true,
    .named = true,
  },
  [sym_appendix] = {
    .visible = true,
    .named = true,
  },
  [sym_mathblock] = {
    .visible = true,
    .named = true,
  },
  [sym_specialblock] = {
    .visible = true,
    .named = true,
  },
  [sym_caption] = {
    .visible = true,
    .named = true,
  },
  [sym_item] = {
    .visible = true,
    .named = true,
  },
  [sym_specialinline] = {
    .visible = true,
    .named = true,
  },
  [sym_specialconstruct] = {
    .visible = true,
    .named = true,
  },
  [sym_inlinemeta] = {
    .visible = true,
    .named = true,
  },
  [sym_blockmeta] = {
    .visible = true,
    .named = true,
  },
  [sym_inlinemetapair] = {
    .visible = true,
    .named = true,
  },
  [sym_pair] = {
    .visible = true,
    .named = true,
  },
  [sym_metaval_any] = {
    .visible = true,
    .named = true,
  },
  [sym_metaval_any_inline] = {
    .visible = true,
    .named = true,
  },
  [sym_metaval_text] = {
    .visible = true,
    .named = true,
  },
  [sym_metaval_text_inline] = {
    .visible = true,
    .named = true,
  },
  [sym_metaval_list] = {
    .visible = true,
    .named = true,
  },
  [sym_metaval_list_inline] = {
    .visible = true,
    .named = true,
  },
  [sym_table] = {
    .visible = true,
    .named = true,
  },
  [sym_thead] = {
    .visible = true,
    .named = true,
  },
  [sym_tbody] = {
    .visible = true,
    .named = true,
  },
  [sym_tr] = {
    .visible = true,
    .named = true,
  },
  [sym_trshort] = {
    .visible = true,
    .named = true,
  },
  [sym_td] = {
    .visible = true,
    .named = true,
  },
  [sym_tdcontent] = {
    .visible = true,
    .named = true,
  },
  [sym_bibtex] = {
    .visible = true,
    .named = true,
  },
  [sym_bibitem] = {
    .visible = true,
    .named = true,
  },
  [sym_bibitempair] = {
    .visible = true,
    .named = true,
  },
  [sym__paragraphcontent_no_special] = {
    .visible = false,
    .named = true,
  },
  [sym_metakey_text] = {
    .visible = true,
    .named = true,
  },
  [sym_metakey_bool] = {
    .visible = true,
    .named = true,
  },
  [sym_metakey_list] = {
    .visible = true,
    .named = true,
  },
  [sym_metakey_any] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_source_file_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_block_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_paragraph_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_inline_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_section_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_subsection_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_subsubsection_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_inlinemeta_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_blockmeta_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_metaval_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_thead_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_tr_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_trshort_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_bibtex_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_bibitem_repeat1] = {
    .visible = false,
    .named = false,
  },
  [anon_alias_sym_math] = {
    .visible = true,
    .named = false,
  },
};

enum ts_field_identifiers {
  field_body = 1,
  field_caption = 2,
  field_head = 3,
  field_kind = 4,
  field_label = 5,
  field_meta = 6,
  field_reftext = 7,
  field_tag = 8,
  field_target = 9,
  field_targetlabels = 10,
  field_title = 11,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_body] = "body",
  [field_caption] = "caption",
  [field_head] = "head",
  [field_kind] = "kind",
  [field_label] = "label",
  [field_meta] = "meta",
  [field_reftext] = "reftext",
  [field_tag] = "tag",
  [field_target] = "target",
  [field_targetlabels] = "targetlabels",
  [field_title] = "title",
};

static const TSMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [1] = {.index = 0, .length = 1},
  [2] = {.index = 1, .length = 2},
  [3] = {.index = 3, .length = 2},
  [6] = {.index = 5, .length = 3},
  [7] = {.index = 0, .length = 1},
  [8] = {.index = 0, .length = 1},
  [9] = {.index = 0, .length = 1},
  [10] = {.index = 8, .length = 2},
  [11] = {.index = 10, .length = 2},
  [12] = {.index = 12, .length = 2},
  [13] = {.index = 14, .length = 2},
  [14] = {.index = 16, .length = 2},
  [15] = {.index = 18, .length = 1},
  [16] = {.index = 3, .length = 2},
  [17] = {.index = 3, .length = 2},
  [18] = {.index = 3, .length = 2},
  [19] = {.index = 19, .length = 3},
  [20] = {.index = 22, .length = 3},
  [21] = {.index = 25, .length = 3},
  [22] = {.index = 28, .length = 3},
  [23] = {.index = 31, .length = 3},
  [24] = {.index = 34, .length = 3},
  [25] = {.index = 37, .length = 3},
  [26] = {.index = 40, .length = 3},
  [27] = {.index = 43, .length = 4},
  [28] = {.index = 47, .length = 4},
  [29] = {.index = 51, .length = 4},
  [30] = {.index = 55, .length = 4},
  [31] = {.index = 59, .length = 5},
  [32] = {.index = 64, .length = 2},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_tag, 0},
  [1] =
    {field_tag, 0},
    {field_title, 1},
  [3] =
    {field_meta, 1},
    {field_tag, 0},
  [5] =
    {field_meta, 2},
    {field_tag, 0},
    {field_title, 1},
  [8] =
    {field_tag, 0},
    {field_target, 1},
  [10] =
    {field_tag, 0},
    {field_targetlabels, 1},
  [12] =
    {field_caption, 1},
    {field_tag, 0},
  [14] =
    {field_head, 1},
    {field_tag, 0},
  [16] =
    {field_body, 1},
    {field_tag, 0},
  [18] =
    {field_meta, 1},
  [19] =
    {field_caption, 2},
    {field_meta, 1},
    {field_tag, 0},
  [22] =
    {field_head, 2},
    {field_meta, 1},
    {field_tag, 0},
  [25] =
    {field_body, 2},
    {field_meta, 1},
    {field_tag, 0},
  [28] =
    {field_caption, 2},
    {field_head, 1},
    {field_tag, 0},
  [31] =
    {field_body, 2},
    {field_head, 1},
    {field_tag, 0},
  [34] =
    {field_body, 1},
    {field_caption, 2},
    {field_tag, 0},
  [37] =
    {field_reftext, 3},
    {field_tag, 0},
    {field_target, 1},
  [40] =
    {field_reftext, 3},
    {field_tag, 0},
    {field_targetlabels, 1},
  [43] =
    {field_caption, 3},
    {field_head, 2},
    {field_meta, 1},
    {field_tag, 0},
  [47] =
    {field_body, 3},
    {field_head, 2},
    {field_meta, 1},
    {field_tag, 0},
  [51] =
    {field_body, 2},
    {field_caption, 3},
    {field_meta, 1},
    {field_tag, 0},
  [55] =
    {field_body, 2},
    {field_caption, 3},
    {field_head, 1},
    {field_tag, 0},
  [59] =
    {field_body, 3},
    {field_caption, 4},
    {field_head, 2},
    {field_meta, 1},
    {field_tag, 0},
  [64] =
    {field_kind, 1},
    {field_label, 3},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [4] = {
    [0] = aux_sym_metaval_any_token1,
  },
  [5] = {
    [0] = sym_upto_brace_or_comma_text,
  },
  [7] = {
    [0] = anon_sym_COLONcodeblock_COLON,
  },
  [8] = {
    [2] = anon_alias_sym_math,
  },
  [9] = {
    [0] = anon_sym_COLONcode_COLON,
  },
  [16] = {
    [0] = anon_sym_COLONcodeblock_COLON,
  },
  [17] = {
    [3] = anon_alias_sym_math,
  },
  [18] = {
    [0] = anon_sym_COLONcode_COLON,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 3,
  [4] = 4,
  [5] = 5,
  [6] = 6,
  [7] = 7,
  [8] = 8,
  [9] = 9,
  [10] = 10,
  [11] = 11,
  [12] = 12,
  [13] = 13,
  [14] = 14,
  [15] = 15,
  [16] = 16,
  [17] = 17,
  [18] = 18,
  [19] = 19,
  [20] = 20,
  [21] = 21,
  [22] = 22,
  [23] = 23,
  [24] = 24,
  [25] = 25,
  [26] = 26,
  [27] = 27,
  [28] = 28,
  [29] = 29,
  [30] = 30,
  [31] = 31,
  [32] = 32,
  [33] = 33,
  [34] = 34,
  [35] = 35,
  [36] = 36,
  [37] = 37,
  [38] = 38,
  [39] = 39,
  [40] = 40,
  [41] = 41,
  [42] = 42,
  [43] = 43,
  [44] = 44,
  [45] = 45,
  [46] = 46,
  [47] = 47,
  [48] = 48,
  [49] = 49,
  [50] = 50,
  [51] = 51,
  [52] = 52,
  [53] = 53,
  [54] = 54,
  [55] = 55,
  [56] = 56,
  [57] = 57,
  [58] = 58,
  [59] = 59,
  [60] = 60,
  [61] = 61,
  [62] = 62,
  [63] = 63,
  [64] = 64,
  [65] = 65,
  [66] = 66,
  [67] = 67,
  [68] = 68,
  [69] = 69,
  [70] = 70,
  [71] = 71,
  [72] = 72,
  [73] = 73,
  [74] = 74,
  [75] = 75,
  [76] = 76,
  [77] = 77,
  [78] = 78,
  [79] = 79,
  [80] = 80,
  [81] = 81,
  [82] = 82,
  [83] = 83,
  [84] = 84,
  [85] = 85,
  [86] = 86,
  [87] = 87,
  [88] = 88,
  [89] = 88,
  [90] = 90,
  [91] = 91,
  [92] = 92,
  [93] = 93,
  [94] = 94,
  [95] = 95,
  [96] = 96,
  [97] = 97,
  [98] = 98,
  [99] = 93,
  [100] = 92,
  [101] = 101,
  [102] = 102,
  [103] = 103,
  [104] = 104,
  [105] = 105,
  [106] = 104,
  [107] = 104,
  [108] = 104,
  [109] = 105,
  [110] = 105,
  [111] = 104,
  [112] = 105,
  [113] = 105,
  [114] = 101,
  [115] = 115,
  [116] = 116,
  [117] = 117,
  [118] = 118,
  [119] = 119,
  [120] = 120,
  [121] = 118,
  [122] = 122,
  [123] = 123,
  [124] = 119,
  [125] = 125,
  [126] = 120,
  [127] = 127,
  [128] = 128,
  [129] = 118,
  [130] = 116,
  [131] = 118,
  [132] = 122,
  [133] = 123,
  [134] = 127,
  [135] = 128,
  [136] = 136,
  [137] = 137,
  [138] = 138,
  [139] = 119,
  [140] = 120,
  [141] = 122,
  [142] = 123,
  [143] = 127,
  [144] = 128,
  [145] = 136,
  [146] = 137,
  [147] = 147,
  [148] = 138,
  [149] = 119,
  [150] = 120,
  [151] = 122,
  [152] = 123,
  [153] = 136,
  [154] = 137,
  [155] = 127,
  [156] = 128,
  [157] = 136,
  [158] = 137,
  [159] = 147,
  [160] = 138,
  [161] = 120,
  [162] = 122,
  [163] = 123,
  [164] = 147,
  [165] = 138,
  [166] = 127,
  [167] = 128,
  [168] = 136,
  [169] = 137,
  [170] = 147,
  [171] = 138,
  [172] = 119,
  [173] = 147,
  [174] = 174,
  [175] = 175,
  [176] = 176,
  [177] = 177,
  [178] = 178,
  [179] = 179,
  [180] = 180,
  [181] = 181,
  [182] = 182,
  [183] = 183,
  [184] = 184,
  [185] = 185,
  [186] = 186,
  [187] = 187,
  [188] = 188,
  [189] = 189,
  [190] = 190,
  [191] = 191,
  [192] = 192,
  [193] = 193,
  [194] = 194,
  [195] = 195,
  [196] = 83,
  [197] = 197,
  [198] = 64,
  [199] = 176,
  [200] = 200,
  [201] = 175,
  [202] = 181,
  [203] = 193,
  [204] = 190,
  [205] = 185,
  [206] = 195,
  [207] = 187,
  [208] = 191,
  [209] = 194,
  [210] = 197,
  [211] = 182,
  [212] = 188,
  [213] = 189,
  [214] = 192,
  [215] = 177,
  [216] = 180,
  [217] = 183,
  [218] = 178,
  [219] = 179,
  [220] = 184,
  [221] = 186,
  [222] = 222,
  [223] = 195,
  [224] = 191,
  [225] = 194,
  [226] = 197,
  [227] = 176,
  [228] = 182,
  [229] = 188,
  [230] = 189,
  [231] = 192,
  [232] = 177,
  [233] = 180,
  [234] = 183,
  [235] = 178,
  [236] = 179,
  [237] = 184,
  [238] = 186,
  [239] = 190,
  [240] = 185,
  [241] = 175,
  [242] = 181,
  [243] = 193,
  [244] = 190,
  [245] = 185,
  [246] = 195,
  [247] = 187,
  [248] = 191,
  [249] = 194,
  [250] = 197,
  [251] = 176,
  [252] = 182,
  [253] = 188,
  [254] = 189,
  [255] = 192,
  [256] = 177,
  [257] = 193,
  [258] = 183,
  [259] = 178,
  [260] = 179,
  [261] = 184,
  [262] = 186,
  [263] = 222,
  [264] = 200,
  [265] = 175,
  [266] = 181,
  [267] = 193,
  [268] = 190,
  [269] = 185,
  [270] = 195,
  [271] = 187,
  [272] = 191,
  [273] = 194,
  [274] = 197,
  [275] = 176,
  [276] = 182,
  [277] = 188,
  [278] = 189,
  [279] = 192,
  [280] = 181,
  [281] = 177,
  [282] = 180,
  [283] = 183,
  [284] = 178,
  [285] = 179,
  [286] = 187,
  [287] = 184,
  [288] = 186,
  [289] = 175,
  [290] = 180,
  [291] = 291,
  [292] = 292,
  [293] = 11,
  [294] = 10,
  [295] = 295,
  [296] = 296,
  [297] = 297,
  [298] = 298,
  [299] = 299,
  [300] = 296,
  [301] = 295,
  [302] = 11,
  [303] = 10,
  [304] = 11,
  [305] = 10,
  [306] = 11,
  [307] = 10,
  [308] = 308,
  [309] = 308,
  [310] = 310,
  [311] = 310,
  [312] = 18,
  [313] = 313,
  [314] = 308,
  [315] = 310,
  [316] = 308,
  [317] = 310,
  [318] = 308,
  [319] = 310,
  [320] = 16,
  [321] = 15,
  [322] = 14,
  [323] = 13,
  [324] = 17,
  [325] = 12,
  [326] = 12,
  [327] = 12,
  [328] = 13,
  [329] = 16,
  [330] = 14,
  [331] = 15,
  [332] = 15,
  [333] = 18,
  [334] = 13,
  [335] = 17,
  [336] = 14,
  [337] = 18,
  [338] = 18,
  [339] = 15,
  [340] = 16,
  [341] = 12,
  [342] = 16,
  [343] = 14,
  [344] = 13,
  [345] = 17,
  [346] = 17,
  [347] = 347,
  [348] = 348,
  [349] = 349,
  [350] = 350,
  [351] = 351,
  [352] = 352,
  [353] = 353,
  [354] = 354,
  [355] = 355,
  [356] = 356,
  [357] = 357,
  [358] = 358,
  [359] = 359,
  [360] = 360,
  [361] = 361,
  [362] = 362,
  [363] = 363,
  [364] = 364,
  [365] = 365,
  [366] = 366,
  [367] = 367,
  [368] = 368,
  [369] = 369,
  [370] = 370,
  [371] = 371,
  [372] = 366,
  [373] = 373,
  [374] = 374,
  [375] = 366,
  [376] = 376,
  [377] = 366,
  [378] = 366,
  [379] = 379,
  [380] = 380,
  [381] = 369,
  [382] = 370,
  [383] = 373,
  [384] = 374,
  [385] = 369,
  [386] = 370,
  [387] = 373,
  [388] = 374,
  [389] = 374,
  [390] = 369,
  [391] = 370,
  [392] = 373,
  [393] = 374,
  [394] = 394,
  [395] = 369,
  [396] = 370,
  [397] = 373,
  [398] = 398,
  [399] = 399,
  [400] = 400,
  [401] = 401,
  [402] = 402,
  [403] = 403,
  [404] = 399,
  [405] = 405,
  [406] = 405,
  [407] = 399,
  [408] = 408,
  [409] = 409,
  [410] = 410,
  [411] = 411,
  [412] = 400,
  [413] = 401,
  [414] = 414,
  [415] = 415,
  [416] = 416,
  [417] = 415,
  [418] = 418,
  [419] = 405,
  [420] = 408,
  [421] = 409,
  [422] = 422,
  [423] = 410,
  [424] = 408,
  [425] = 425,
  [426] = 400,
  [427] = 401,
  [428] = 428,
  [429] = 429,
  [430] = 430,
  [431] = 431,
  [432] = 399,
  [433] = 433,
  [434] = 405,
  [435] = 400,
  [436] = 408,
  [437] = 409,
  [438] = 438,
  [439] = 439,
  [440] = 410,
  [441] = 441,
  [442] = 400,
  [443] = 401,
  [444] = 444,
  [445] = 445,
  [446] = 446,
  [447] = 409,
  [448] = 448,
  [449] = 449,
  [450] = 450,
  [451] = 416,
  [452] = 452,
  [453] = 453,
  [454] = 454,
  [455] = 455,
  [456] = 399,
  [457] = 416,
  [458] = 401,
  [459] = 405,
  [460] = 411,
  [461] = 408,
  [462] = 409,
  [463] = 416,
  [464] = 464,
  [465] = 410,
  [466] = 466,
  [467] = 467,
  [468] = 468,
  [469] = 416,
  [470] = 415,
  [471] = 415,
  [472] = 415,
  [473] = 410,
  [474] = 474,
  [475] = 475,
  [476] = 476,
  [477] = 477,
  [478] = 478,
  [479] = 479,
  [480] = 474,
  [481] = 481,
  [482] = 482,
  [483] = 483,
  [484] = 484,
  [485] = 49,
  [486] = 486,
  [487] = 487,
  [488] = 488,
  [489] = 489,
  [490] = 490,
  [491] = 491,
  [492] = 492,
  [493] = 493,
  [494] = 494,
  [495] = 495,
  [496] = 496,
  [497] = 483,
  [498] = 498,
  [499] = 499,
  [500] = 500,
  [501] = 501,
  [502] = 502,
  [503] = 503,
  [504] = 504,
  [505] = 505,
  [506] = 506,
  [507] = 507,
  [508] = 508,
  [509] = 509,
  [510] = 500,
  [511] = 481,
  [512] = 482,
  [513] = 483,
  [514] = 514,
  [515] = 515,
  [516] = 516,
  [517] = 517,
  [518] = 518,
  [519] = 67,
  [520] = 481,
  [521] = 521,
  [522] = 522,
  [523] = 493,
  [524] = 494,
  [525] = 495,
  [526] = 496,
  [527] = 527,
  [528] = 528,
  [529] = 222,
  [530] = 500,
  [531] = 501,
  [532] = 532,
  [533] = 533,
  [534] = 534,
  [535] = 535,
  [536] = 536,
  [537] = 200,
  [538] = 538,
  [539] = 539,
  [540] = 474,
  [541] = 481,
  [542] = 482,
  [543] = 483,
  [544] = 544,
  [545] = 545,
  [546] = 493,
  [547] = 200,
  [548] = 548,
  [549] = 549,
  [550] = 550,
  [551] = 551,
  [552] = 552,
  [553] = 493,
  [554] = 494,
  [555] = 495,
  [556] = 496,
  [557] = 494,
  [558] = 482,
  [559] = 495,
  [560] = 500,
  [561] = 501,
  [562] = 501,
  [563] = 490,
  [564] = 475,
  [565] = 474,
  [566] = 481,
  [567] = 482,
  [568] = 483,
  [569] = 569,
  [570] = 504,
  [571] = 536,
  [572] = 486,
  [573] = 499,
  [574] = 574,
  [575] = 489,
  [576] = 491,
  [577] = 577,
  [578] = 533,
  [579] = 516,
  [580] = 580,
  [581] = 503,
  [582] = 582,
  [583] = 477,
  [584] = 484,
  [585] = 222,
  [586] = 496,
  [587] = 587,
  [588] = 588,
  [589] = 589,
  [590] = 504,
  [591] = 536,
  [592] = 486,
  [593] = 499,
  [594] = 588,
  [595] = 533,
  [596] = 516,
  [597] = 580,
  [598] = 503,
  [599] = 599,
  [600] = 477,
  [601] = 484,
  [602] = 602,
  [603] = 222,
  [604] = 532,
  [605] = 538,
  [606] = 606,
  [607] = 504,
  [608] = 536,
  [609] = 486,
  [610] = 499,
  [611] = 611,
  [612] = 533,
  [613] = 516,
  [614] = 580,
  [615] = 503,
  [616] = 493,
  [617] = 477,
  [618] = 484,
  [619] = 494,
  [620] = 495,
  [621] = 496,
  [622] = 200,
  [623] = 623,
  [624] = 504,
  [625] = 536,
  [626] = 486,
  [627] = 499,
  [628] = 628,
  [629] = 533,
  [630] = 516,
  [631] = 580,
  [632] = 503,
  [633] = 474,
  [634] = 477,
  [635] = 484,
  [636] = 500,
  [637] = 501,
  [638] = 638,
  [639] = 639,
  [640] = 580,
  [641] = 488,
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(474);
      ADVANCE_MAP(
        '#', 7,
        '$', 498,
        '%', 608,
        '*', 504,
        ',', 511,
        '/', 506,
        ':', 537,
        '=', 548,
        '@', 542,
        '`', 500,
        'a', 386,
        'b', 359,
        'd', 353,
        'e', 177,
        'j', 350,
        'n', 449,
        'p', 450,
        's', 345,
        't', 259,
        'u', 387,
        'v', 348,
        'y', 180,
        '{', 527,
        '}', 528,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(0);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(513);
      END_STATE();
    case 1:
      if (lookahead == '\n') SKIP(1);
      if (lookahead == '\r') ADVANCE(2);
      if (lookahead == '%') ADVANCE(606);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') ADVANCE(2);
      if (lookahead != 0) ADVANCE(3);
      END_STATE();
    case 2:
      if (lookahead == '\n') ADVANCE(530);
      if (lookahead == '\r') ADVANCE(2);
      if (lookahead == '%') ADVANCE(606);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') ADVANCE(2);
      if (lookahead != 0) ADVANCE(3);
      END_STATE();
    case 3:
      if (lookahead == '\n') ADVANCE(529);
      if (lookahead != 0) ADVANCE(3);
      END_STATE();
    case 4:
      if (lookahead == '\n') SKIP(4);
      if (lookahead == '\r') ADVANCE(5);
      if (lookahead == '%') ADVANCE(607);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') ADVANCE(5);
      if (lookahead != 0 &&
          lookahead != ',' &&
          lookahead != '}') ADVANCE(6);
      END_STATE();
    case 5:
      if (lookahead == '\n') ADVANCE(532);
      if (lookahead == '\r') ADVANCE(5);
      if (lookahead == '%') ADVANCE(607);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') ADVANCE(5);
      if (lookahead != 0 &&
          lookahead != ',' &&
          lookahead != '}') ADVANCE(6);
      END_STATE();
    case 6:
      if (lookahead == '\n') ADVANCE(531);
      if (lookahead != 0 &&
          lookahead != ',' &&
          lookahead != '}') ADVANCE(6);
      END_STATE();
    case 7:
      if (lookahead == ' ') ADVANCE(478);
      if (lookahead == '#') ADVANCE(8);
      END_STATE();
    case 8:
      if (lookahead == ' ') ADVANCE(480);
      if (lookahead == '#') ADVANCE(9);
      END_STATE();
    case 9:
      if (lookahead == ' ') ADVANCE(482);
      END_STATE();
    case 10:
      if (lookahead == '$') ADVANCE(498);
      if (lookahead == '%') ADVANCE(608);
      if (lookahead == '*') ADVANCE(503);
      if (lookahead == '/') ADVANCE(505);
      if (lookahead == ':') ADVANCE(129);
      if (lookahead == '`') ADVANCE(499);
      if (lookahead == '{') ADVANCE(527);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(10);
      END_STATE();
    case 11:
      if (lookahead == '$') ADVANCE(497);
      if (lookahead == '%') ADVANCE(608);
      if (lookahead == '*') ADVANCE(504);
      if (lookahead == '/') ADVANCE(505);
      if (lookahead == ':') ADVANCE(539);
      if (lookahead == '`') ADVANCE(499);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(11);
      END_STATE();
    case 12:
      if (lookahead == '$') ADVANCE(497);
      if (lookahead == '%') ADVANCE(608);
      if (lookahead == '*') ADVANCE(503);
      if (lookahead == '/') ADVANCE(506);
      if (lookahead == ':') ADVANCE(128);
      if (lookahead == '`') ADVANCE(499);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(12);
      END_STATE();
    case 13:
      if (lookahead == '$') ADVANCE(497);
      if (lookahead == '%') ADVANCE(608);
      if (lookahead == '*') ADVANCE(503);
      if (lookahead == '/') ADVANCE(505);
      if (lookahead == ':') ADVANCE(26);
      if (lookahead == '`') ADVANCE(499);
      if (lookahead == '{') ADVANCE(527);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(13);
      END_STATE();
    case 14:
      if (lookahead == '$') ADVANCE(497);
      if (lookahead == '%') ADVANCE(608);
      if (lookahead == '*') ADVANCE(503);
      if (lookahead == '/') ADVANCE(505);
      if (lookahead == ':') ADVANCE(538);
      if (lookahead == '`') ADVANCE(499);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(14);
      END_STATE();
    case 15:
      if (lookahead == '$') ADVANCE(497);
      if (lookahead == '%') ADVANCE(608);
      if (lookahead == '*') ADVANCE(503);
      if (lookahead == '/') ADVANCE(505);
      if (lookahead == ':') ADVANCE(539);
      if (lookahead == '`') ADVANCE(499);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(15);
      END_STATE();
    case 16:
      if (lookahead == '%') ADVANCE(520);
      if (lookahead == 'h') ADVANCE(519);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(16);
      if (lookahead != 0 &&
          lookahead != ',' &&
          lookahead != ':') ADVANCE(521);
      END_STATE();
    case 17:
      if (lookahead == '%') ADVANCE(523);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(524);
      if (lookahead != 0 &&
          lookahead != ':') ADVANCE(525);
      END_STATE();
    case 18:
      if (lookahead == '%') ADVANCE(508);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(509);
      if (lookahead != 0 &&
          lookahead != ',' &&
          lookahead != ':') ADVANCE(510);
      END_STATE();
    case 19:
      if (lookahead == '%') ADVANCE(544);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(545);
      if (lookahead != 0 &&
          lookahead != ',') ADVANCE(546);
      END_STATE();
    case 20:
      if (lookahead == '%') ADVANCE(549);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(550);
      if (lookahead != 0 &&
          lookahead != '}') ADVANCE(551);
      END_STATE();
    case 21:
      if (lookahead == '-') ADVANCE(33);
      END_STATE();
    case 22:
      if (lookahead == '/') ADVANCE(472);
      END_STATE();
    case 23:
      if (lookahead == '/') ADVANCE(22);
      END_STATE();
    case 24:
      if (lookahead == '2') ADVANCE(67);
      if (lookahead == '3') ADVANCE(68);
      if (lookahead == ':') ADVANCE(494);
      if (lookahead == 'i') ADVANCE(357);
      END_STATE();
    case 25:
      ADVANCE_MAP(
        ':', 476,
        'a', 147,
        'b', 257,
        'c', 115,
        'd', 143,
        'e', 312,
        'f', 258,
        'g', 355,
        'i', 159,
        'k', 181,
        'l', 116,
        'm', 117,
        'n', 118,
        'p', 27,
        'q', 191,
        'r', 183,
        's', 158,
        't', 134,
        'u', 390,
        'w', 293,
        '|', 21,
        0x22a2, 28,
      );
      END_STATE();
    case 26:
      ADVANCE_MAP(
        ':', 476,
        'a', 406,
        'c', 144,
        'd', 220,
        'l', 198,
        'm', 131,
        'n', 182,
        'p', 260,
        'q', 191,
        'r', 218,
        's', 376,
        't', 171,
        'u', 390,
        'w', 293,
        '|', 21,
        0x22a2, 28,
      );
      END_STATE();
    case 27:
      if (lookahead == ':') ADVANCE(580);
      if (lookahead == 'a') ADVANCE(392);
      if (lookahead == 'i') ADVANCE(155);
      if (lookahead == 'r') ADVANCE(185);
      END_STATE();
    case 28:
      if (lookahead == ':') ADVANCE(565);
      END_STATE();
    case 29:
      if (lookahead == ':') ADVANCE(567);
      END_STATE();
    case 30:
      if (lookahead == ':') ADVANCE(567);
      if (lookahead == 'e') ADVANCE(381);
      if (lookahead == 'r') ADVANCE(356);
      END_STATE();
    case 31:
      if (lookahead == ':') ADVANCE(540);
      END_STATE();
    case 32:
      if (lookahead == ':') ADVANCE(536);
      END_STATE();
    case 33:
      if (lookahead == ':') ADVANCE(564);
      END_STATE();
    case 34:
      if (lookahead == ':') ADVANCE(557);
      END_STATE();
    case 35:
      if (lookahead == ':') ADVANCE(601);
      END_STATE();
    case 36:
      if (lookahead == ':') ADVANCE(556);
      END_STATE();
    case 37:
      if (lookahead == ':') ADVANCE(526);
      END_STATE();
    case 38:
      if (lookahead == ':') ADVANCE(507);
      END_STATE();
    case 39:
      if (lookahead == ':') ADVANCE(507);
      if (lookahead == 't') ADVANCE(192);
      END_STATE();
    case 40:
      if (lookahead == ':') ADVANCE(488);
      END_STATE();
    case 41:
      if (lookahead == ':') ADVANCE(514);
      END_STATE();
    case 42:
      if (lookahead == ':') ADVANCE(558);
      END_STATE();
    case 43:
      if (lookahead == ':') ADVANCE(522);
      END_STATE();
    case 44:
      if (lookahead == ':') ADVANCE(502);
      END_STATE();
    case 45:
      if (lookahead == ':') ADVANCE(502);
      if (lookahead == 'b') ADVANCE(300);
      END_STATE();
    case 46:
      if (lookahead == ':') ADVANCE(603);
      END_STATE();
    case 47:
      if (lookahead == ':') ADVANCE(593);
      END_STATE();
    case 48:
      if (lookahead == ':') ADVANCE(595);
      END_STATE();
    case 49:
      if (lookahead == ':') ADVANCE(493);
      if (lookahead == 'i') ADVANCE(471);
      END_STATE();
    case 50:
      if (lookahead == ':') ADVANCE(594);
      END_STATE();
    case 51:
      if (lookahead == ':') ADVANCE(501);
      END_STATE();
    case 52:
      if (lookahead == ':') ADVANCE(501);
      if (lookahead == 'b') ADVANCE(311);
      END_STATE();
    case 53:
      if (lookahead == ':') ADVANCE(590);
      END_STATE();
    case 54:
      if (lookahead == ':') ADVANCE(569);
      END_STATE();
    case 55:
      if (lookahead == ':') ADVANCE(604);
      END_STATE();
    case 56:
      if (lookahead == ':') ADVANCE(566);
      END_STATE();
    case 57:
      if (lookahead == ':') ADVANCE(570);
      END_STATE();
    case 58:
      if (lookahead == ':') ADVANCE(585);
      END_STATE();
    case 59:
      if (lookahead == ':') ADVANCE(555);
      END_STATE();
    case 60:
      if (lookahead == ':') ADVANCE(561);
      END_STATE();
    case 61:
      if (lookahead == ':') ADVANCE(563);
      END_STATE();
    case 62:
      if (lookahead == ':') ADVANCE(568);
      END_STATE();
    case 63:
      if (lookahead == ':') ADVANCE(588);
      END_STATE();
    case 64:
      if (lookahead == ':') ADVANCE(589);
      END_STATE();
    case 65:
      if (lookahead == ':') ADVANCE(578);
      END_STATE();
    case 66:
      if (lookahead == ':') ADVANCE(596);
      END_STATE();
    case 67:
      if (lookahead == ':') ADVANCE(495);
      END_STATE();
    case 68:
      if (lookahead == ':') ADVANCE(496);
      END_STATE();
    case 69:
      if (lookahead == ':') ADVANCE(581);
      END_STATE();
    case 70:
      if (lookahead == ':') ADVANCE(554);
      END_STATE();
    case 71:
      if (lookahead == ':') ADVANCE(605);
      END_STATE();
    case 72:
      if (lookahead == ':') ADVANCE(533);
      END_STATE();
    case 73:
      if (lookahead == ':') ADVANCE(535);
      END_STATE();
    case 74:
      if (lookahead == ':') ADVANCE(534);
      END_STATE();
    case 75:
      if (lookahead == ':') ADVANCE(592);
      END_STATE();
    case 76:
      if (lookahead == ':') ADVANCE(602);
      END_STATE();
    case 77:
      if (lookahead == ':') ADVANCE(560);
      END_STATE();
    case 78:
      if (lookahead == ':') ADVANCE(552);
      END_STATE();
    case 79:
      if (lookahead == ':') ADVANCE(572);
      END_STATE();
    case 80:
      if (lookahead == ':') ADVANCE(541);
      END_STATE();
    case 81:
      if (lookahead == ':') ADVANCE(559);
      END_STATE();
    case 82:
      if (lookahead == ':') ADVANCE(598);
      END_STATE();
    case 83:
      if (lookahead == ':') ADVANCE(579);
      END_STATE();
    case 84:
      if (lookahead == ':') ADVANCE(583);
      END_STATE();
    case 85:
      if (lookahead == ':') ADVANCE(584);
      END_STATE();
    case 86:
      if (lookahead == ':') ADVANCE(597);
      END_STATE();
    case 87:
      if (lookahead == ':') ADVANCE(492);
      END_STATE();
    case 88:
      if (lookahead == ':') ADVANCE(576);
      END_STATE();
    case 89:
      if (lookahead == ':') ADVANCE(599);
      END_STATE();
    case 90:
      if (lookahead == ':') ADVANCE(577);
      END_STATE();
    case 91:
      if (lookahead == ':') ADVANCE(591);
      END_STATE();
    case 92:
      if (lookahead == ':') ADVANCE(479);
      END_STATE();
    case 93:
      if (lookahead == ':') ADVANCE(553);
      END_STATE();
    case 94:
      if (lookahead == ':') ADVANCE(586);
      END_STATE();
    case 95:
      if (lookahead == ':') ADVANCE(571);
      END_STATE();
    case 96:
      if (lookahead == ':') ADVANCE(484);
      END_STATE();
    case 97:
      if (lookahead == ':') ADVANCE(600);
      END_STATE();
    case 98:
      if (lookahead == ':') ADVANCE(512);
      END_STATE();
    case 99:
      if (lookahead == ':') ADVANCE(562);
      END_STATE();
    case 100:
      if (lookahead == ':') ADVANCE(491);
      END_STATE();
    case 101:
      if (lookahead == ':') ADVANCE(490);
      END_STATE();
    case 102:
      if (lookahead == ':') ADVANCE(574);
      END_STATE();
    case 103:
      if (lookahead == ':') ADVANCE(575);
      END_STATE();
    case 104:
      if (lookahead == ':') ADVANCE(486);
      END_STATE();
    case 105:
      if (lookahead == ':') ADVANCE(477);
      END_STATE();
    case 106:
      if (lookahead == ':') ADVANCE(573);
      END_STATE();
    case 107:
      if (lookahead == ':') ADVANCE(475);
      END_STATE();
    case 108:
      if (lookahead == ':') ADVANCE(481);
      END_STATE();
    case 109:
      if (lookahead == ':') ADVANCE(587);
      END_STATE();
    case 110:
      if (lookahead == ':') ADVANCE(582);
      END_STATE();
    case 111:
      if (lookahead == ':') ADVANCE(487);
      END_STATE();
    case 112:
      if (lookahead == ':') ADVANCE(483);
      END_STATE();
    case 113:
      if (lookahead == '`') ADVANCE(489);
      END_STATE();
    case 114:
      if (lookahead == 'a') ADVANCE(291);
      END_STATE();
    case 115:
      if (lookahead == 'a') ADVANCE(382);
      if (lookahead == 'i') ADVANCE(436);
      if (lookahead == 'l') ADVANCE(123);
      if (lookahead == 'o') ADVANCE(174);
      END_STATE();
    case 116:
      if (lookahead == 'a') ADVANCE(151);
      if (lookahead == 'e') ADVANCE(316);
      END_STATE();
    case 117:
      if (lookahead == 'a') ADVANCE(329);
      if (lookahead == 's') ADVANCE(156);
      END_STATE();
    case 118:
      if (lookahead == 'a') ADVANCE(325);
      if (lookahead == 'e') ADVANCE(461);
      if (lookahead == 'o') ADVANCE(343);
      END_STATE();
    case 119:
      if (lookahead == 'a') ADVANCE(388);
      END_STATE();
    case 120:
      if (lookahead == 'a') ADVANCE(315);
      END_STATE();
    case 121:
      if (lookahead == 'a') ADVANCE(242);
      END_STATE();
    case 122:
      if (lookahead == 'a') ADVANCE(383);
      END_STATE();
    case 123:
      if (lookahead == 'a') ADVANCE(262);
      END_STATE();
    case 124:
      if (lookahead == 'a') ADVANCE(402);
      END_STATE();
    case 125:
      if (lookahead == 'a') ADVANCE(377);
      END_STATE();
    case 126:
      if (lookahead == 'a') ADVANCE(166);
      END_STATE();
    case 127:
      if (lookahead == 'a') ADVANCE(276);
      if (lookahead == 'p') ADVANCE(245);
      END_STATE();
    case 128:
      ADVANCE_MAP(
        'a', 406,
        'c', 144,
        'd', 220,
        'l', 198,
        'm', 131,
        'n', 182,
        'p', 260,
        'q', 191,
        'r', 218,
        's', 376,
        't', 250,
        'u', 390,
        'w', 293,
        '|', 21,
        0x22a2, 28,
      );
      END_STATE();
    case 129:
      ADVANCE_MAP(
        'a', 406,
        'c', 144,
        'd', 220,
        'l', 198,
        'm', 132,
        'n', 182,
        'p', 260,
        'q', 191,
        'r', 218,
        's', 376,
        't', 250,
        'u', 390,
        'w', 293,
        '|', 21,
        0x22a2, 28,
      );
      END_STATE();
    case 130:
      if (lookahead == 'a') ADVANCE(401);
      END_STATE();
    case 131:
      if (lookahead == 'a') ADVANCE(438);
      END_STATE();
    case 132:
      if (lookahead == 'a') ADVANCE(422);
      END_STATE();
    case 133:
      if (lookahead == 'a') ADVANCE(65);
      END_STATE();
    case 134:
      ADVANCE_MAP(
        'a', 154,
        'b', 349,
        'd', 31,
        'h', 187,
        'i', 442,
        'o', 160,
        'r', 32,
        'y', 379,
      );
      END_STATE();
    case 135:
      if (lookahead == 'a') ADVANCE(231);
      END_STATE();
    case 136:
      if (lookahead == 'a') ADVANCE(332);
      END_STATE();
    case 137:
      if (lookahead == 'a') ADVANCE(176);
      if (lookahead == 'n') ADVANCE(59);
      if (lookahead == 'o') ADVANCE(398);
      END_STATE();
    case 138:
      if (lookahead == 'a') ADVANCE(298);
      END_STATE();
    case 139:
      if (lookahead == 'a') ADVANCE(305);
      END_STATE();
    case 140:
      if (lookahead == 'a') ADVANCE(413);
      END_STATE();
    case 141:
      if (lookahead == 'a') ADVANCE(277);
      END_STATE();
    case 142:
      if (lookahead == 'a') ADVANCE(399);
      END_STATE();
    case 143:
      if (lookahead == 'a') ADVANCE(437);
      if (lookahead == 'e') ADVANCE(230);
      if (lookahead == 'r') ADVANCE(135);
      END_STATE();
    case 144:
      if (lookahead == 'a') ADVANCE(410);
      if (lookahead == 'i') ADVANCE(436);
      if (lookahead == 'l') ADVANCE(123);
      if (lookahead == 'o') ADVANCE(179);
      END_STATE();
    case 145:
      if (lookahead == 'a') ADVANCE(441);
      END_STATE();
    case 146:
      if (lookahead == 'a') ADVANCE(446);
      END_STATE();
    case 147:
      if (lookahead == 'b') ADVANCE(408);
      if (lookahead == 'f') ADVANCE(229);
      if (lookahead == 'l') ADVANCE(238);
      if (lookahead == 'p') ADVANCE(378);
      if (lookahead == 's') ADVANCE(417);
      if (lookahead == 'u') ADVANCE(435);
      END_STATE();
    case 148:
      if (lookahead == 'b') ADVANCE(303);
      END_STATE();
    case 149:
      if (lookahead == 'b') ADVANCE(405);
      if (lookahead == 'f') ADVANCE(232);
      if (lookahead == 'p') ADVANCE(380);
      END_STATE();
    case 150:
      if (lookahead == 'b') ADVANCE(295);
      END_STATE();
    case 151:
      if (lookahead == 'b') ADVANCE(221);
      if (lookahead == 'n') ADVANCE(239);
      END_STATE();
    case 152:
      if (lookahead == 'b') ADVANCE(193);
      END_STATE();
    case 153:
      if (lookahead == 'b') ADVANCE(411);
      END_STATE();
    case 154:
      if (lookahead == 'b') ADVANCE(306);
      END_STATE();
    case 155:
      if (lookahead == 'c') ADVANCE(287);
      END_STATE();
    case 156:
      if (lookahead == 'c') ADVANCE(35);
      END_STATE();
    case 157:
      if (lookahead == 'c') ADVANCE(309);
      END_STATE();
    case 158:
      if (lookahead == 'c') ADVANCE(139);
      if (lookahead == 'e') ADVANCE(168);
      if (lookahead == 'k') ADVANCE(197);
      if (lookahead == 'p') ADVANCE(136);
      if (lookahead == 't') ADVANCE(30);
      if (lookahead == 'u') ADVANCE(149);
      END_STATE();
    case 159:
      if (lookahead == 'c') ADVANCE(347);
      if (lookahead == 's') ADVANCE(157);
      if (lookahead == 't') ADVANCE(195);
      END_STATE();
    case 160:
      if (lookahead == 'c') ADVANCE(40);
      END_STATE();
    case 161:
      if (lookahead == 'c') ADVANCE(396);
      END_STATE();
    case 162:
      if (lookahead == 'c') ADVANCE(251);
      END_STATE();
    case 163:
      if (lookahead == 'c') ADVANCE(223);
      END_STATE();
    case 164:
      if (lookahead == 'c') ADVANCE(289);
      END_STATE();
    case 165:
      if (lookahead == 'c') ADVANCE(299);
      END_STATE();
    case 166:
      if (lookahead == 'c') ADVANCE(433);
      END_STATE();
    case 167:
      if (lookahead == 'c') ADVANCE(290);
      END_STATE();
    case 168:
      if (lookahead == 'c') ADVANCE(443);
      END_STATE();
    case 169:
      if (lookahead == 'c') ADVANCE(445);
      END_STATE();
    case 170:
      if (lookahead == 'c') ADVANCE(448);
      END_STATE();
    case 171:
      if (lookahead == 'd') ADVANCE(31);
      if (lookahead == 'h') ADVANCE(224);
      END_STATE();
    case 172:
      if (lookahead == 'd') ADVANCE(468);
      END_STATE();
    case 173:
      if (lookahead == 'd') ADVANCE(37);
      END_STATE();
    case 174:
      if (lookahead == 'd') ADVANCE(189);
      if (lookahead == 'r') ADVANCE(360);
      END_STATE();
    case 175:
      if (lookahead == 'd') ADVANCE(273);
      END_STATE();
    case 176:
      if (lookahead == 'd') ADVANCE(74);
      END_STATE();
    case 177:
      if (lookahead == 'd') ADVANCE(271);
      END_STATE();
    case 178:
      if (lookahead == 'd') ADVANCE(414);
      END_STATE();
    case 179:
      if (lookahead == 'd') ADVANCE(217);
      END_STATE();
    case 180:
      if (lookahead == 'e') ADVANCE(119);
      END_STATE();
    case 181:
      if (lookahead == 'e') ADVANCE(467);
      END_STATE();
    case 182:
      if (lookahead == 'e') ADVANCE(461);
      if (lookahead == 'o') ADVANCE(439);
      END_STATE();
    case 183:
      if (lookahead == 'e') ADVANCE(227);
      END_STATE();
    case 184:
      if (lookahead == 'e') ADVANCE(547);
      END_STATE();
    case 185:
      if (lookahead == 'e') ADVANCE(459);
      if (lookahead == 'o') ADVANCE(352);
      END_STATE();
    case 186:
      if (lookahead == 'e') ADVANCE(459);
      if (lookahead == 'o') ADVANCE(460);
      END_STATE();
    case 187:
      if (lookahead == 'e') ADVANCE(137);
      END_STATE();
    case 188:
      if (lookahead == 'e') ADVANCE(543);
      END_STATE();
    case 189:
      if (lookahead == 'e') ADVANCE(45);
      END_STATE();
    case 190:
      if (lookahead == 'e') ADVANCE(464);
      END_STATE();
    case 191:
      if (lookahead == 'e') ADVANCE(173);
      END_STATE();
    case 192:
      if (lookahead == 'e') ADVANCE(466);
      END_STATE();
    case 193:
      if (lookahead == 'e') ADVANCE(388);
      END_STATE();
    case 194:
      if (lookahead == 'e') ADVANCE(341);
      END_STATE();
    case 195:
      if (lookahead == 'e') ADVANCE(313);
      END_STATE();
    case 196:
      if (lookahead == 'e') ADVANCE(412);
      END_STATE();
    case 197:
      if (lookahead == 'e') ADVANCE(427);
      END_STATE();
    case 198:
      if (lookahead == 'e') ADVANCE(425);
      END_STATE();
    case 199:
      if (lookahead == 'e') ADVANCE(42);
      END_STATE();
    case 200:
      if (lookahead == 'e') ADVANCE(43);
      END_STATE();
    case 201:
      if (lookahead == 'e') ADVANCE(46);
      END_STATE();
    case 202:
      if (lookahead == 'e') ADVANCE(53);
      END_STATE();
    case 203:
      if (lookahead == 'e') ADVANCE(54);
      END_STATE();
    case 204:
      if (lookahead == 'e') ADVANCE(70);
      END_STATE();
    case 205:
      if (lookahead == 'e') ADVANCE(71);
      END_STATE();
    case 206:
      if (lookahead == 'e') ADVANCE(72);
      END_STATE();
    case 207:
      if (lookahead == 'e') ADVANCE(75);
      END_STATE();
    case 208:
      if (lookahead == 'e') ADVANCE(77);
      END_STATE();
    case 209:
      if (lookahead == 'e') ADVANCE(78);
      END_STATE();
    case 210:
      if (lookahead == 'e') ADVANCE(81);
      END_STATE();
    case 211:
      if (lookahead == 'e') ADVANCE(81);
      if (lookahead == 'i') ADVANCE(444);
      END_STATE();
    case 212:
      if (lookahead == 'e') ADVANCE(83);
      END_STATE();
    case 213:
      if (lookahead == 'e') ADVANCE(88);
      END_STATE();
    case 214:
      if (lookahead == 'e') ADVANCE(90);
      END_STATE();
    case 215:
      if (lookahead == 'e') ADVANCE(93);
      END_STATE();
    case 216:
      if (lookahead == 'e') ADVANCE(103);
      END_STATE();
    case 217:
      if (lookahead == 'e') ADVANCE(44);
      END_STATE();
    case 218:
      if (lookahead == 'e') ADVANCE(235);
      END_STATE();
    case 219:
      if (lookahead == 'e') ADVANCE(394);
      END_STATE();
    case 220:
      if (lookahead == 'e') ADVANCE(233);
      if (lookahead == 'r') ADVANCE(135);
      END_STATE();
    case 221:
      if (lookahead == 'e') ADVANCE(302);
      END_STATE();
    case 222:
      if (lookahead == 'e') ADVANCE(323);
      END_STATE();
    case 223:
      if (lookahead == 'e') ADVANCE(416);
      END_STATE();
    case 224:
      if (lookahead == 'e') ADVANCE(333);
      END_STATE();
    case 225:
      if (lookahead == 'e') ADVANCE(169);
      if (lookahead == 'u') ADVANCE(153);
      END_STATE();
    case 226:
      if (lookahead == 'e') ADVANCE(170);
      END_STATE();
    case 227:
      if (lookahead == 'f') ADVANCE(39);
      if (lookahead == 'm') ADVANCE(124);
      END_STATE();
    case 228:
      if (lookahead == 'f') ADVANCE(421);
      END_STATE();
    case 229:
      if (lookahead == 'f') ADVANCE(274);
      END_STATE();
    case 230:
      if (lookahead == 'f') ADVANCE(261);
      END_STATE();
    case 231:
      if (lookahead == 'f') ADVANCE(431);
      END_STATE();
    case 232:
      if (lookahead == 'f') ADVANCE(265);
      END_STATE();
    case 233:
      if (lookahead == 'f') ADVANCE(266);
      END_STATE();
    case 234:
      if (lookahead == 'f') ADVANCE(69);
      END_STATE();
    case 235:
      if (lookahead == 'f') ADVANCE(38);
      END_STATE();
    case 236:
      if (lookahead == 'f') ADVANCE(232);
      if (lookahead == 'p') ADVANCE(380);
      END_STATE();
    case 237:
      if (lookahead == 'g') ADVANCE(453);
      END_STATE();
    case 238:
      if (lookahead == 'g') ADVANCE(354);
      END_STATE();
    case 239:
      if (lookahead == 'g') ADVANCE(50);
      END_STATE();
    case 240:
      if (lookahead == 'g') ADVANCE(60);
      END_STATE();
    case 241:
      if (lookahead == 'g') ADVANCE(86);
      END_STATE();
    case 242:
      if (lookahead == 'g') ADVANCE(395);
      END_STATE();
    case 243:
      if (lookahead == 'g') ADVANCE(397);
      END_STATE();
    case 244:
      if (lookahead == 'h') ADVANCE(52);
      END_STATE();
    case 245:
      if (lookahead == 'h') ADVANCE(140);
      END_STATE();
    case 246:
      if (lookahead == 'h') ADVANCE(193);
      END_STATE();
    case 247:
      if (lookahead == 'h') ADVANCE(351);
      END_STATE();
    case 248:
      if (lookahead == 'h') ADVANCE(362);
      END_STATE();
    case 249:
      if (lookahead == 'h') ADVANCE(55);
      END_STATE();
    case 250:
      if (lookahead == 'h') ADVANCE(224);
      END_STATE();
    case 251:
      if (lookahead == 'h') ADVANCE(85);
      END_STATE();
    case 252:
      if (lookahead == 'h') ADVANCE(105);
      END_STATE();
    case 253:
      if (lookahead == 'h') ADVANCE(51);
      END_STATE();
    case 254:
      if (lookahead == 'h') ADVANCE(470);
      END_STATE();
    case 255:
      if (lookahead == 'h') ADVANCE(324);
      END_STATE();
    case 256:
      if (lookahead == 'i') ADVANCE(547);
      END_STATE();
    case 257:
      if (lookahead == 'i') ADVANCE(148);
      END_STATE();
    case 258:
      if (lookahead == 'i') ADVANCE(237);
      END_STATE();
    case 259:
      if (lookahead == 'i') ADVANCE(426);
      END_STATE();
    case 260:
      if (lookahead == 'i') ADVANCE(155);
      if (lookahead == 'r') ADVANCE(186);
      END_STATE();
    case 261:
      if (lookahead == 'i') ADVANCE(328);
      END_STATE();
    case 262:
      if (lookahead == 'i') ADVANCE(320);
      END_STATE();
    case 263:
      if (lookahead == 'i') ADVANCE(407);
      END_STATE();
    case 264:
      if (lookahead == 'i') ADVANCE(384);
      END_STATE();
    case 265:
      if (lookahead == 'i') ADVANCE(163);
      END_STATE();
    case 266:
      if (lookahead == 'i') ADVANCE(344);
      END_STATE();
    case 267:
      if (lookahead == 'i') ADVANCE(428);
      END_STATE();
    case 268:
      if (lookahead == 'i') ADVANCE(146);
      END_STATE();
    case 269:
      if (lookahead == 'i') ADVANCE(358);
      END_STATE();
    case 270:
      if (lookahead == 'i') ADVANCE(374);
      END_STATE();
    case 271:
      if (lookahead == 'i') ADVANCE(429);
      END_STATE();
    case 272:
      if (lookahead == 'i') ADVANCE(165);
      END_STATE();
    case 273:
      if (lookahead == 'i') ADVANCE(465);
      END_STATE();
    case 274:
      if (lookahead == 'i') ADVANCE(296);
      END_STATE();
    case 275:
      if (lookahead == 'i') ADVANCE(367);
      END_STATE();
    case 276:
      if (lookahead == 'i') ADVANCE(301);
      END_STATE();
    case 277:
      if (lookahead == 'i') ADVANCE(322);
      END_STATE();
    case 278:
      if (lookahead == 'i') ADVANCE(368);
      END_STATE();
    case 279:
      if (lookahead == 'i') ADVANCE(440);
      END_STATE();
    case 280:
      if (lookahead == 'i') ADVANCE(369);
      END_STATE();
    case 281:
      if (lookahead == 'i') ADVANCE(370);
      END_STATE();
    case 282:
      if (lookahead == 'i') ADVANCE(371);
      END_STATE();
    case 283:
      if (lookahead == 'i') ADVANCE(372);
      END_STATE();
    case 284:
      if (lookahead == 'i') ADVANCE(373);
      END_STATE();
    case 285:
      if (lookahead == 'i') ADVANCE(447);
      END_STATE();
    case 286:
      if (lookahead == 'k') ADVANCE(543);
      END_STATE();
    case 287:
      if (lookahead == 'k') ADVANCE(56);
      END_STATE();
    case 288:
      if (lookahead == 'k') ADVANCE(84);
      END_STATE();
    case 289:
      if (lookahead == 'k') ADVANCE(101);
      END_STATE();
    case 290:
      if (lookahead == 'k') ADVANCE(104);
      END_STATE();
    case 291:
      if (lookahead == 'l') ADVANCE(547);
      END_STATE();
    case 292:
      if (lookahead == 'l') ADVANCE(304);
      END_STATE();
    case 293:
      if (lookahead == 'l') ADVANCE(365);
      if (lookahead == 'r') ADVANCE(279);
      END_STATE();
    case 294:
      if (lookahead == 'l') ADVANCE(41);
      END_STATE();
    case 295:
      if (lookahead == 'l') ADVANCE(263);
      END_STATE();
    case 296:
      if (lookahead == 'l') ADVANCE(268);
      END_STATE();
    case 297:
      if (lookahead == 'l') ADVANCE(184);
      END_STATE();
    case 298:
      if (lookahead == 'l') ADVANCE(47);
      END_STATE();
    case 299:
      if (lookahead == 'l') ADVANCE(188);
      END_STATE();
    case 300:
      if (lookahead == 'l') ADVANCE(366);
      END_STATE();
    case 301:
      if (lookahead == 'l') ADVANCE(63);
      END_STATE();
    case 302:
      if (lookahead == 'l') ADVANCE(64);
      END_STATE();
    case 303:
      if (lookahead == 'l') ADVANCE(270);
      if (lookahead == 't') ADVANCE(190);
      END_STATE();
    case 304:
      if (lookahead == 'l') ADVANCE(130);
      END_STATE();
    case 305:
      if (lookahead == 'l') ADVANCE(205);
      END_STATE();
    case 306:
      if (lookahead == 'l') ADVANCE(206);
      END_STATE();
    case 307:
      if (lookahead == 'l') ADVANCE(207);
      END_STATE();
    case 308:
      if (lookahead == 'l') ADVANCE(213);
      END_STATE();
    case 309:
      if (lookahead == 'l') ADVANCE(141);
      END_STATE();
    case 310:
      if (lookahead == 'l') ADVANCE(456);
      END_STATE();
    case 311:
      if (lookahead == 'l') ADVANCE(375);
      END_STATE();
    case 312:
      if (lookahead == 'm') ADVANCE(127);
      if (lookahead == 'n') ADVANCE(454);
      if (lookahead == 'x') ADVANCE(120);
      END_STATE();
    case 313:
      if (lookahead == 'm') ADVANCE(49);
      END_STATE();
    case 314:
      if (lookahead == 'm') ADVANCE(152);
      END_STATE();
    case 315:
      if (lookahead == 'm') ADVANCE(385);
      END_STATE();
    case 316:
      if (lookahead == 'm') ADVANCE(317);
      if (lookahead == 't') ADVANCE(34);
      END_STATE();
    case 317:
      if (lookahead == 'm') ADVANCE(133);
      END_STATE();
    case 318:
      if (lookahead == 'm') ADVANCE(184);
      END_STATE();
    case 319:
      if (lookahead == 'm') ADVANCE(219);
      END_STATE();
    case 320:
      if (lookahead == 'm') ADVANCE(61);
      END_STATE();
    case 321:
      if (lookahead == 'm') ADVANCE(66);
      END_STATE();
    case 322:
      if (lookahead == 'm') ADVANCE(89);
      END_STATE();
    case 323:
      if (lookahead == 'm') ADVANCE(94);
      END_STATE();
    case 324:
      if (lookahead == 'm') ADVANCE(100);
      END_STATE();
    case 325:
      if (lookahead == 'm') ADVANCE(202);
      END_STATE();
    case 326:
      if (lookahead == 'm') ADVANCE(209);
      END_STATE();
    case 327:
      if (lookahead == 'n') ADVANCE(547);
      END_STATE();
    case 328:
      if (lookahead == 'n') ADVANCE(211);
      END_STATE();
    case 329:
      if (lookahead == 'n') ADVANCE(452);
      if (lookahead == 't') ADVANCE(244);
      END_STATE();
    case 330:
      if (lookahead == 'n') ADVANCE(114);
      END_STATE();
    case 331:
      if (lookahead == 'n') ADVANCE(48);
      END_STATE();
    case 332:
      if (lookahead == 'n') ADVANCE(57);
      END_STATE();
    case 333:
      if (lookahead == 'n') ADVANCE(59);
      END_STATE();
    case 334:
      if (lookahead == 'n') ADVANCE(87);
      END_STATE();
    case 335:
      if (lookahead == 'n') ADVANCE(92);
      END_STATE();
    case 336:
      if (lookahead == 'n') ADVANCE(106);
      END_STATE();
    case 337:
      if (lookahead == 'n') ADVANCE(108);
      END_STATE();
    case 338:
      if (lookahead == 'n') ADVANCE(109);
      END_STATE();
    case 339:
      if (lookahead == 'n') ADVANCE(110);
      END_STATE();
    case 340:
      if (lookahead == 'n') ADVANCE(112);
      END_STATE();
    case 341:
      if (lookahead == 'n') ADVANCE(175);
      END_STATE();
    case 342:
      if (lookahead == 'n') ADVANCE(241);
      END_STATE();
    case 343:
      if (lookahead == 'n') ADVANCE(455);
      if (lookahead == 't') ADVANCE(203);
      END_STATE();
    case 344:
      if (lookahead == 'n') ADVANCE(210);
      END_STATE();
    case 345:
      if (lookahead == 'o') ADVANCE(228);
      END_STATE();
    case 346:
      if (lookahead == 'o') ADVANCE(286);
      END_STATE();
    case 347:
      if (lookahead == 'o') ADVANCE(331);
      END_STATE();
    case 348:
      if (lookahead == 'o') ADVANCE(310);
      END_STATE();
    case 349:
      if (lookahead == 'o') ADVANCE(172);
      END_STATE();
    case 350:
      if (lookahead == 'o') ADVANCE(451);
      END_STATE();
    case 351:
      if (lookahead == 'o') ADVANCE(388);
      END_STATE();
    case 352:
      if (lookahead == 'o') ADVANCE(234);
      if (lookahead == 'p') ADVANCE(361);
      if (lookahead == 'v') ADVANCE(204);
      END_STATE();
    case 353:
      if (lookahead == 'o') ADVANCE(256);
      END_STATE();
    case 354:
      if (lookahead == 'o') ADVANCE(403);
      END_STATE();
    case 355:
      if (lookahead == 'o') ADVANCE(138);
      END_STATE();
    case 356:
      if (lookahead == 'o') ADVANCE(342);
      END_STATE();
    case 357:
      if (lookahead == 'o') ADVANCE(457);
      END_STATE();
    case 358:
      if (lookahead == 'o') ADVANCE(327);
      END_STATE();
    case 359:
      if (lookahead == 'o') ADVANCE(346);
      END_STATE();
    case 360:
      if (lookahead == 'o') ADVANCE(292);
      END_STATE();
    case 361:
      if (lookahead == 'o') ADVANCE(419);
      END_STATE();
    case 362:
      if (lookahead == 'o') ADVANCE(400);
      END_STATE();
    case 363:
      if (lookahead == 'o') ADVANCE(418);
      END_STATE();
    case 364:
      if (lookahead == 'o') ADVANCE(391);
      END_STATE();
    case 365:
      if (lookahead == 'o') ADVANCE(240);
      END_STATE();
    case 366:
      if (lookahead == 'o') ADVANCE(164);
      END_STATE();
    case 367:
      if (lookahead == 'o') ADVANCE(334);
      END_STATE();
    case 368:
      if (lookahead == 'o') ADVANCE(335);
      END_STATE();
    case 369:
      if (lookahead == 'o') ADVANCE(336);
      END_STATE();
    case 370:
      if (lookahead == 'o') ADVANCE(337);
      END_STATE();
    case 371:
      if (lookahead == 'o') ADVANCE(338);
      END_STATE();
    case 372:
      if (lookahead == 'o') ADVANCE(339);
      END_STATE();
    case 373:
      if (lookahead == 'o') ADVANCE(340);
      END_STATE();
    case 374:
      if (lookahead == 'o') ADVANCE(243);
      END_STATE();
    case 375:
      if (lookahead == 'o') ADVANCE(167);
      END_STATE();
    case 376:
      if (lookahead == 'p') ADVANCE(136);
      if (lookahead == 't') ADVANCE(29);
      if (lookahead == 'u') ADVANCE(236);
      END_STATE();
    case 377:
      if (lookahead == 'p') ADVANCE(254);
      END_STATE();
    case 378:
      if (lookahead == 'p') ADVANCE(194);
      END_STATE();
    case 379:
      if (lookahead == 'p') ADVANCE(196);
      END_STATE();
    case 380:
      if (lookahead == 'p') ADVANCE(363);
      END_STATE();
    case 381:
      if (lookahead == 'p') ADVANCE(58);
      END_STATE();
    case 382:
      if (lookahead == 'p') ADVANCE(430);
      if (lookahead == 's') ADVANCE(199);
      END_STATE();
    case 383:
      if (lookahead == 'p') ADVANCE(252);
      END_STATE();
    case 384:
      if (lookahead == 'p') ADVANCE(434);
      END_STATE();
    case 385:
      if (lookahead == 'p') ADVANCE(308);
      END_STATE();
    case 386:
      if (lookahead == 'r') ADVANCE(424);
      if (lookahead == 'u') ADVANCE(420);
      END_STATE();
    case 387:
      if (lookahead == 'r') ADVANCE(291);
      END_STATE();
    case 388:
      if (lookahead == 'r') ADVANCE(547);
      END_STATE();
    case 389:
      if (lookahead == 'r') ADVANCE(330);
      END_STATE();
    case 390:
      if (lookahead == 'r') ADVANCE(294);
      END_STATE();
    case 391:
      if (lookahead == 'r') ADVANCE(178);
      END_STATE();
    case 392:
      if (lookahead == 'r') ADVANCE(121);
      if (lookahead == 't') ADVANCE(249);
      END_STATE();
    case 393:
      if (lookahead == 'r') ADVANCE(126);
      END_STATE();
    case 394:
      if (lookahead == 'r') ADVANCE(145);
      END_STATE();
    case 395:
      if (lookahead == 'r') ADVANCE(122);
      END_STATE();
    case 396:
      if (lookahead == 'r') ADVANCE(264);
      END_STATE();
    case 397:
      if (lookahead == 'r') ADVANCE(125);
      END_STATE();
    case 398:
      if (lookahead == 'r') ADVANCE(222);
      END_STATE();
    case 399:
      if (lookahead == 'r') ADVANCE(188);
      END_STATE();
    case 400:
      if (lookahead == 'r') ADVANCE(79);
      END_STATE();
    case 401:
      if (lookahead == 'r') ADVANCE(469);
      END_STATE();
    case 402:
      if (lookahead == 'r') ADVANCE(288);
      END_STATE();
    case 403:
      if (lookahead == 'r') ADVANCE(267);
      END_STATE();
    case 404:
      if (lookahead == 'r') ADVANCE(212);
      END_STATE();
    case 405:
      if (lookahead == 's') ADVANCE(225);
      END_STATE();
    case 406:
      if (lookahead == 's') ADVANCE(417);
      END_STATE();
    case 407:
      if (lookahead == 's') ADVANCE(246);
      END_STATE();
    case 408:
      if (lookahead == 's') ADVANCE(423);
      END_STATE();
    case 409:
      if (lookahead == 's') ADVANCE(161);
      END_STATE();
    case 410:
      if (lookahead == 's') ADVANCE(199);
      END_STATE();
    case 411:
      if (lookahead == 's') ADVANCE(226);
      END_STATE();
    case 412:
      if (lookahead == 's') ADVANCE(76);
      END_STATE();
    case 413:
      if (lookahead == 's') ADVANCE(82);
      END_STATE();
    case 414:
      if (lookahead == 's') ADVANCE(97);
      END_STATE();
    case 415:
      if (lookahead == 's') ADVANCE(98);
      END_STATE();
    case 416:
      if (lookahead == 's') ADVANCE(99);
      END_STATE();
    case 417:
      if (lookahead == 's') ADVANCE(458);
      END_STATE();
    case 418:
      if (lookahead == 's') ADVANCE(215);
      END_STATE();
    case 419:
      if (lookahead == 's') ADVANCE(285);
      END_STATE();
    case 420:
      if (lookahead == 't') ADVANCE(247);
      END_STATE();
    case 421:
      if (lookahead == 't') ADVANCE(463);
      END_STATE();
    case 422:
      if (lookahead == 't') ADVANCE(244);
      END_STATE();
    case 423:
      if (lookahead == 't') ADVANCE(393);
      END_STATE();
    case 424:
      if (lookahead == 't') ADVANCE(272);
      END_STATE();
    case 425:
      if (lookahead == 't') ADVANCE(34);
      END_STATE();
    case 426:
      if (lookahead == 't') ADVANCE(297);
      END_STATE();
    case 427:
      if (lookahead == 't') ADVANCE(162);
      END_STATE();
    case 428:
      if (lookahead == 't') ADVANCE(255);
      END_STATE();
    case 429:
      if (lookahead == 't') ADVANCE(269);
      END_STATE();
    case 430:
      if (lookahead == 't') ADVANCE(275);
      END_STATE();
    case 431:
      if (lookahead == 't') ADVANCE(62);
      END_STATE();
    case 432:
      if (lookahead == 't') ADVANCE(91);
      END_STATE();
    case 433:
      if (lookahead == 't') ADVANCE(95);
      END_STATE();
    case 434:
      if (lookahead == 't') ADVANCE(107);
      END_STATE();
    case 435:
      if (lookahead == 't') ADVANCE(248);
      END_STATE();
    case 436:
      if (lookahead == 't') ADVANCE(200);
      END_STATE();
    case 437:
      if (lookahead == 't') ADVANCE(201);
      END_STATE();
    case 438:
      if (lookahead == 't') ADVANCE(253);
      END_STATE();
    case 439:
      if (lookahead == 't') ADVANCE(203);
      END_STATE();
    case 440:
      if (lookahead == 't') ADVANCE(208);
      END_STATE();
    case 441:
      if (lookahead == 't') ADVANCE(216);
      END_STATE();
    case 442:
      if (lookahead == 't') ADVANCE(307);
      END_STATE();
    case 443:
      if (lookahead == 't') ADVANCE(278);
      END_STATE();
    case 444:
      if (lookahead == 't') ADVANCE(280);
      END_STATE();
    case 445:
      if (lookahead == 't') ADVANCE(281);
      END_STATE();
    case 446:
      if (lookahead == 't') ADVANCE(282);
      END_STATE();
    case 447:
      if (lookahead == 't') ADVANCE(283);
      END_STATE();
    case 448:
      if (lookahead == 't') ADVANCE(284);
      END_STATE();
    case 449:
      if (lookahead == 'u') ADVANCE(314);
      END_STATE();
    case 450:
      if (lookahead == 'u') ADVANCE(150);
      END_STATE();
    case 451:
      if (lookahead == 'u') ADVANCE(389);
      END_STATE();
    case 452:
      if (lookahead == 'u') ADVANCE(409);
      END_STATE();
    case 453:
      if (lookahead == 'u') ADVANCE(404);
      END_STATE();
    case 454:
      if (lookahead == 'u') ADVANCE(319);
      END_STATE();
    case 455:
      if (lookahead == 'u') ADVANCE(321);
      END_STATE();
    case 456:
      if (lookahead == 'u') ADVANCE(318);
      END_STATE();
    case 457:
      if (lookahead == 'u') ADVANCE(415);
      END_STATE();
    case 458:
      if (lookahead == 'u') ADVANCE(326);
      END_STATE();
    case 459:
      if (lookahead == 'v') ADVANCE(24);
      END_STATE();
    case 460:
      if (lookahead == 'v') ADVANCE(204);
      END_STATE();
    case 461:
      if (lookahead == 'w') ADVANCE(36);
      END_STATE();
    case 462:
      if (lookahead == 'w') ADVANCE(364);
      END_STATE();
    case 463:
      if (lookahead == 'w') ADVANCE(142);
      END_STATE();
    case 464:
      if (lookahead == 'x') ADVANCE(80);
      END_STATE();
    case 465:
      if (lookahead == 'x') ADVANCE(96);
      END_STATE();
    case 466:
      if (lookahead == 'x') ADVANCE(432);
      END_STATE();
    case 467:
      if (lookahead == 'y') ADVANCE(462);
      END_STATE();
    case 468:
      if (lookahead == 'y') ADVANCE(73);
      END_STATE();
    case 469:
      if (lookahead == 'y') ADVANCE(102);
      END_STATE();
    case 470:
      if (lookahead == 'y') ADVANCE(111);
      END_STATE();
    case 471:
      if (lookahead == 'z') ADVANCE(214);
      END_STATE();
    case 472:
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ' &&
          lookahead != ',' &&
          lookahead != ':') ADVANCE(521);
      END_STATE();
    case 473:
      if (eof) ADVANCE(474);
      ADVANCE_MAP(
        '#', 7,
        '$', 498,
        '%', 608,
        '*', 503,
        ',', 511,
        '/', 505,
        ':', 25,
        '`', 500,
        '}', 528,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(473);
      END_STATE();
    case 474:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 475:
      ACCEPT_TOKEN(anon_sym_COLONmanuscript_COLON);
      END_STATE();
    case 476:
      ACCEPT_TOKEN(anon_sym_COLON_COLON);
      END_STATE();
    case 477:
      ACCEPT_TOKEN(anon_sym_COLONparagraph_COLON);
      END_STATE();
    case 478:
      ACCEPT_TOKEN(aux_sym_section_token1);
      END_STATE();
    case 479:
      ACCEPT_TOKEN(anon_sym_COLONsection_COLON);
      END_STATE();
    case 480:
      ACCEPT_TOKEN(aux_sym_subsection_token1);
      END_STATE();
    case 481:
      ACCEPT_TOKEN(anon_sym_COLONsubsection_COLON);
      END_STATE();
    case 482:
      ACCEPT_TOKEN(aux_sym_subsubsection_token1);
      END_STATE();
    case 483:
      ACCEPT_TOKEN(anon_sym_COLONsubsubsection_COLON);
      END_STATE();
    case 484:
      ACCEPT_TOKEN(anon_sym_COLONappendix_COLON);
      END_STATE();
    case 485:
      ACCEPT_TOKEN(aux_sym_mathblock_token1);
      END_STATE();
    case 486:
      ACCEPT_TOKEN(anon_sym_COLONmathblock_COLON);
      END_STATE();
    case 487:
      ACCEPT_TOKEN(anon_sym_COLONbibliography_COLON);
      END_STATE();
    case 488:
      ACCEPT_TOKEN(anon_sym_COLONtoc_COLON);
      END_STATE();
    case 489:
      ACCEPT_TOKEN(aux_sym_specialblock_token1);
      END_STATE();
    case 490:
      ACCEPT_TOKEN(anon_sym_COLONcodeblock_COLON);
      END_STATE();
    case 491:
      ACCEPT_TOKEN(anon_sym_COLONalgorithm_COLON);
      END_STATE();
    case 492:
      ACCEPT_TOKEN(anon_sym_COLONcaption_COLON);
      END_STATE();
    case 493:
      ACCEPT_TOKEN(anon_sym_COLONitem_COLON);
      END_STATE();
    case 494:
      ACCEPT_TOKEN(anon_sym_COLONprev_COLON);
      END_STATE();
    case 495:
      ACCEPT_TOKEN(anon_sym_COLONprev2_COLON);
      END_STATE();
    case 496:
      ACCEPT_TOKEN(anon_sym_COLONprev3_COLON);
      END_STATE();
    case 497:
      ACCEPT_TOKEN(aux_sym_specialinline_token1);
      END_STATE();
    case 498:
      ACCEPT_TOKEN(aux_sym_specialinline_token1);
      if (lookahead == '$') ADVANCE(485);
      END_STATE();
    case 499:
      ACCEPT_TOKEN(aux_sym_specialinline_token2);
      END_STATE();
    case 500:
      ACCEPT_TOKEN(aux_sym_specialinline_token2);
      if (lookahead == '`') ADVANCE(113);
      END_STATE();
    case 501:
      ACCEPT_TOKEN(anon_sym_COLONmath_COLON);
      END_STATE();
    case 502:
      ACCEPT_TOKEN(anon_sym_COLONcode_COLON);
      END_STATE();
    case 503:
      ACCEPT_TOKEN(aux_sym_specialinline_token3);
      END_STATE();
    case 504:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 505:
      ACCEPT_TOKEN(aux_sym_specialinline_token4);
      END_STATE();
    case 506:
      ACCEPT_TOKEN(anon_sym_SLASH);
      END_STATE();
    case 507:
      ACCEPT_TOKEN(anon_sym_COLONref_COLON);
      END_STATE();
    case 508:
      ACCEPT_TOKEN(aux_sym_specialinline_token5);
      if (lookahead == '\n') ADVANCE(510);
      if (lookahead == ',' ||
          lookahead == ':') ADVANCE(608);
      if (lookahead != 0) ADVANCE(508);
      END_STATE();
    case 509:
      ACCEPT_TOKEN(aux_sym_specialinline_token5);
      if (lookahead == '%') ADVANCE(508);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(509);
      if (lookahead != 0 &&
          lookahead != ',' &&
          lookahead != ':') ADVANCE(510);
      END_STATE();
    case 510:
      ACCEPT_TOKEN(aux_sym_specialinline_token5);
      if (lookahead != 0 &&
          lookahead != ',' &&
          lookahead != ':') ADVANCE(510);
      END_STATE();
    case 511:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 512:
      ACCEPT_TOKEN(anon_sym_COLONprevious_COLON);
      END_STATE();
    case 513:
      ACCEPT_TOKEN(aux_sym_specialinline_token6);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(513);
      END_STATE();
    case 514:
      ACCEPT_TOKEN(anon_sym_COLONurl_COLON);
      END_STATE();
    case 515:
      ACCEPT_TOKEN(aux_sym_specialinline_token7);
      if (lookahead == ':') ADVANCE(23);
      if (lookahead == 's') ADVANCE(516);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(521);
      END_STATE();
    case 516:
      ACCEPT_TOKEN(aux_sym_specialinline_token7);
      if (lookahead == ':') ADVANCE(23);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(521);
      END_STATE();
    case 517:
      ACCEPT_TOKEN(aux_sym_specialinline_token7);
      if (lookahead == 'p') ADVANCE(515);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ' &&
          lookahead != ',' &&
          lookahead != ':') ADVANCE(521);
      END_STATE();
    case 518:
      ACCEPT_TOKEN(aux_sym_specialinline_token7);
      if (lookahead == 't') ADVANCE(517);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ' &&
          lookahead != ',' &&
          lookahead != ':') ADVANCE(521);
      END_STATE();
    case 519:
      ACCEPT_TOKEN(aux_sym_specialinline_token7);
      if (lookahead == 't') ADVANCE(518);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ' &&
          lookahead != ',' &&
          lookahead != ':') ADVANCE(521);
      END_STATE();
    case 520:
      ACCEPT_TOKEN(aux_sym_specialinline_token7);
      if (lookahead == '\t' ||
          (0x0b <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == ',' ||
          lookahead == ':') ADVANCE(608);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(520);
      END_STATE();
    case 521:
      ACCEPT_TOKEN(aux_sym_specialinline_token7);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ' &&
          lookahead != ',' &&
          lookahead != ':') ADVANCE(521);
      END_STATE();
    case 522:
      ACCEPT_TOKEN(anon_sym_COLONcite_COLON);
      END_STATE();
    case 523:
      ACCEPT_TOKEN(aux_sym_specialinline_token8);
      if (lookahead == '\n') ADVANCE(525);
      if (lookahead == ':') ADVANCE(608);
      if (lookahead != 0) ADVANCE(523);
      END_STATE();
    case 524:
      ACCEPT_TOKEN(aux_sym_specialinline_token8);
      if (lookahead == '%') ADVANCE(523);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(524);
      if (lookahead != 0 &&
          lookahead != ':') ADVANCE(525);
      END_STATE();
    case 525:
      ACCEPT_TOKEN(aux_sym_specialinline_token8);
      if (lookahead != 0 &&
          lookahead != ':') ADVANCE(525);
      END_STATE();
    case 526:
      ACCEPT_TOKEN(anon_sym_COLONqed_COLON);
      END_STATE();
    case 527:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 528:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 529:
      ACCEPT_TOKEN(aux_sym_metaval_any_token1);
      END_STATE();
    case 530:
      ACCEPT_TOKEN(aux_sym_metaval_any_token1);
      if (lookahead == '\r') ADVANCE(2);
      if (lookahead == '%') ADVANCE(606);
      if (lookahead == '\t' ||
          lookahead == 0x0b ||
          lookahead == '\f' ||
          lookahead == ' ') ADVANCE(2);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(3);
      END_STATE();
    case 531:
      ACCEPT_TOKEN(aux_sym_metaval_any_inline_token1);
      END_STATE();
    case 532:
      ACCEPT_TOKEN(aux_sym_metaval_any_inline_token1);
      if (lookahead == '\r') ADVANCE(5);
      if (lookahead == '%') ADVANCE(607);
      if (lookahead == '\t' ||
          lookahead == 0x0b ||
          lookahead == '\f' ||
          lookahead == ' ') ADVANCE(5);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ',' &&
          lookahead != '}') ADVANCE(6);
      END_STATE();
    case 533:
      ACCEPT_TOKEN(anon_sym_COLONtable_COLON);
      END_STATE();
    case 534:
      ACCEPT_TOKEN(anon_sym_COLONthead_COLON);
      END_STATE();
    case 535:
      ACCEPT_TOKEN(anon_sym_COLONtbody_COLON);
      END_STATE();
    case 536:
      ACCEPT_TOKEN(anon_sym_COLONtr_COLON);
      END_STATE();
    case 537:
      ACCEPT_TOKEN(anon_sym_COLON);
      ADVANCE_MAP(
        ':', 476,
        'a', 147,
        'b', 257,
        'c', 115,
        'd', 143,
        'e', 312,
        'f', 258,
        'g', 355,
        'i', 159,
        'k', 181,
        'l', 116,
        'm', 117,
        'n', 118,
        'p', 27,
        'q', 191,
        'r', 183,
        's', 158,
        't', 134,
        'u', 390,
        'w', 293,
        '|', 21,
        0x22a2, 28,
      );
      END_STATE();
    case 538:
      ACCEPT_TOKEN(anon_sym_COLON);
      ADVANCE_MAP(
        ':', 476,
        'a', 406,
        'c', 144,
        'd', 220,
        'l', 198,
        'm', 131,
        'n', 182,
        'p', 260,
        'q', 191,
        'r', 218,
        's', 376,
        't', 250,
        'u', 390,
        'w', 293,
        '|', 21,
        0x22a2, 28,
      );
      END_STATE();
    case 539:
      ACCEPT_TOKEN(anon_sym_COLON);
      ADVANCE_MAP(
        'a', 406,
        'c', 144,
        'd', 220,
        'l', 198,
        'm', 131,
        'n', 182,
        'p', 260,
        'q', 191,
        'r', 218,
        's', 376,
        't', 250,
        'u', 390,
        'w', 293,
        '|', 21,
        0x22a2, 28,
      );
      END_STATE();
    case 540:
      ACCEPT_TOKEN(anon_sym_COLONtd_COLON);
      END_STATE();
    case 541:
      ACCEPT_TOKEN(anon_sym_COLONbibtex_COLON);
      END_STATE();
    case 542:
      ACCEPT_TOKEN(anon_sym_AT);
      END_STATE();
    case 543:
      ACCEPT_TOKEN(aux_sym_bibitem_token1);
      END_STATE();
    case 544:
      ACCEPT_TOKEN(aux_sym_bibitem_token2);
      if (lookahead == '\n') ADVANCE(546);
      if (lookahead == ',') ADVANCE(608);
      if (lookahead != 0) ADVANCE(544);
      END_STATE();
    case 545:
      ACCEPT_TOKEN(aux_sym_bibitem_token2);
      if (lookahead == '%') ADVANCE(544);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(545);
      if (lookahead != 0 &&
          lookahead != ',') ADVANCE(546);
      END_STATE();
    case 546:
      ACCEPT_TOKEN(aux_sym_bibitem_token2);
      if (lookahead != 0 &&
          lookahead != ',') ADVANCE(546);
      END_STATE();
    case 547:
      ACCEPT_TOKEN(aux_sym_bibitempair_token1);
      END_STATE();
    case 548:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 549:
      ACCEPT_TOKEN(aux_sym_bibitempair_token2);
      if (lookahead == '\n') ADVANCE(551);
      if (lookahead == '}') ADVANCE(608);
      if (lookahead != 0) ADVANCE(549);
      END_STATE();
    case 550:
      ACCEPT_TOKEN(aux_sym_bibitempair_token2);
      if (lookahead == '%') ADVANCE(549);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(550);
      if (lookahead != 0 &&
          lookahead != '}') ADVANCE(551);
      END_STATE();
    case 551:
      ACCEPT_TOKEN(aux_sym_bibitempair_token2);
      if (lookahead != 0 &&
          lookahead != '}') ADVANCE(551);
      END_STATE();
    case 552:
      ACCEPT_TOKEN(anon_sym_COLONassume_COLON);
      END_STATE();
    case 553:
      ACCEPT_TOKEN(anon_sym_COLONsuppose_COLON);
      END_STATE();
    case 554:
      ACCEPT_TOKEN(anon_sym_COLONprove_COLON);
      END_STATE();
    case 555:
      ACCEPT_TOKEN(anon_sym_COLONthen_COLON);
      END_STATE();
    case 556:
      ACCEPT_TOKEN(anon_sym_COLONnew_COLON);
      END_STATE();
    case 557:
      ACCEPT_TOKEN(anon_sym_COLONlet_COLON);
      END_STATE();
    case 558:
      ACCEPT_TOKEN(anon_sym_COLONcase_COLON);
      END_STATE();
    case 559:
      ACCEPT_TOKEN(anon_sym_COLONdefine_COLON);
      END_STATE();
    case 560:
      ACCEPT_TOKEN(anon_sym_COLONwrite_COLON);
      END_STATE();
    case 561:
      ACCEPT_TOKEN(anon_sym_COLONwlog_COLON);
      END_STATE();
    case 562:
      ACCEPT_TOKEN(anon_sym_COLONsuffices_COLON);
      END_STATE();
    case 563:
      ACCEPT_TOKEN(anon_sym_COLONclaim_COLON);
      END_STATE();
    case 564:
      ACCEPT_TOKEN(anon_sym_COLON_PIPE_DASH_COLON);
      END_STATE();
    case 565:
      ACCEPT_TOKEN(anon_sym_COLONu22a2_COLON);
      END_STATE();
    case 566:
      ACCEPT_TOKEN(anon_sym_COLONpick_COLON);
      END_STATE();
    case 567:
      ACCEPT_TOKEN(anon_sym_COLONst_COLON);
      END_STATE();
    case 568:
      ACCEPT_TOKEN(anon_sym_COLONdraft_COLON);
      END_STATE();
    case 569:
      ACCEPT_TOKEN(anon_sym_COLONnote_COLON);
      END_STATE();
    case 570:
      ACCEPT_TOKEN(anon_sym_COLONspan_COLON);
      END_STATE();
    case 571:
      ACCEPT_TOKEN(anon_sym_COLONabstract_COLON);
      END_STATE();
    case 572:
      ACCEPT_TOKEN(anon_sym_COLONauthor_COLON);
      END_STATE();
    case 573:
      ACCEPT_TOKEN(anon_sym_COLONdefinition_COLON);
      END_STATE();
    case 574:
      ACCEPT_TOKEN(anon_sym_COLONcorollary_COLON);
      END_STATE();
    case 575:
      ACCEPT_TOKEN(anon_sym_COLONenumerate_COLON);
      END_STATE();
    case 576:
      ACCEPT_TOKEN(anon_sym_COLONexample_COLON);
      END_STATE();
    case 577:
      ACCEPT_TOKEN(anon_sym_COLONitemize_COLON);
      END_STATE();
    case 578:
      ACCEPT_TOKEN(anon_sym_COLONlemma_COLON);
      END_STATE();
    case 579:
      ACCEPT_TOKEN(anon_sym_COLONfigure_COLON);
      END_STATE();
    case 580:
      ACCEPT_TOKEN(anon_sym_COLONp_COLON);
      END_STATE();
    case 581:
      ACCEPT_TOKEN(anon_sym_COLONproof_COLON);
      END_STATE();
    case 582:
      ACCEPT_TOKEN(anon_sym_COLONproposition_COLON);
      END_STATE();
    case 583:
      ACCEPT_TOKEN(anon_sym_COLONremark_COLON);
      END_STATE();
    case 584:
      ACCEPT_TOKEN(anon_sym_COLONsketch_COLON);
      END_STATE();
    case 585:
      ACCEPT_TOKEN(anon_sym_COLONstep_COLON);
      END_STATE();
    case 586:
      ACCEPT_TOKEN(anon_sym_COLONtheorem_COLON);
      END_STATE();
    case 587:
      ACCEPT_TOKEN(anon_sym_COLONaffiliation_COLON);
      END_STATE();
    case 588:
      ACCEPT_TOKEN(anon_sym_COLONemail_COLON);
      END_STATE();
    case 589:
      ACCEPT_TOKEN(anon_sym_COLONlabel_COLON);
      END_STATE();
    case 590:
      ACCEPT_TOKEN(anon_sym_COLONname_COLON);
      END_STATE();
    case 591:
      ACCEPT_TOKEN(anon_sym_COLONreftext_COLON);
      END_STATE();
    case 592:
      ACCEPT_TOKEN(anon_sym_COLONtitle_COLON);
      END_STATE();
    case 593:
      ACCEPT_TOKEN(anon_sym_COLONgoal_COLON);
      END_STATE();
    case 594:
      ACCEPT_TOKEN(anon_sym_COLONlang_COLON);
      END_STATE();
    case 595:
      ACCEPT_TOKEN(anon_sym_COLONicon_COLON);
      END_STATE();
    case 596:
      ACCEPT_TOKEN(anon_sym_COLONnonum_COLON);
      END_STATE();
    case 597:
      ACCEPT_TOKEN(anon_sym_COLONstrong_COLON);
      END_STATE();
    case 598:
      ACCEPT_TOKEN(anon_sym_COLONemphas_COLON);
      END_STATE();
    case 599:
      ACCEPT_TOKEN(anon_sym_COLONisclaim_COLON);
      END_STATE();
    case 600:
      ACCEPT_TOKEN(anon_sym_COLONkeywords_COLON);
      END_STATE();
    case 601:
      ACCEPT_TOKEN(anon_sym_COLONmsc_COLON);
      END_STATE();
    case 602:
      ACCEPT_TOKEN(anon_sym_COLONtypes_COLON);
      END_STATE();
    case 603:
      ACCEPT_TOKEN(anon_sym_COLONdate_COLON);
      END_STATE();
    case 604:
      ACCEPT_TOKEN(anon_sym_COLONpath_COLON);
      END_STATE();
    case 605:
      ACCEPT_TOKEN(anon_sym_COLONscale_COLON);
      END_STATE();
    case 606:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '\n') ADVANCE(529);
      if (lookahead != 0) ADVANCE(606);
      END_STATE();
    case 607:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '\n') ADVANCE(531);
      if (lookahead == ',' ||
          lookahead == '}') ADVANCE(608);
      if (lookahead != 0) ADVANCE(607);
      END_STATE();
    case 608:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(608);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0, .external_lex_state = 1},
  [1] = {.lex_state = 473},
  [2] = {.lex_state = 473, .external_lex_state = 2},
  [3] = {.lex_state = 473, .external_lex_state = 2},
  [4] = {.lex_state = 473, .external_lex_state = 2},
  [5] = {.lex_state = 473, .external_lex_state = 2},
  [6] = {.lex_state = 473, .external_lex_state = 2},
  [7] = {.lex_state = 473, .external_lex_state = 2},
  [8] = {.lex_state = 473, .external_lex_state = 2},
  [9] = {.lex_state = 473, .external_lex_state = 2},
  [10] = {.lex_state = 473, .external_lex_state = 2},
  [11] = {.lex_state = 473, .external_lex_state = 2},
  [12] = {.lex_state = 473, .external_lex_state = 2},
  [13] = {.lex_state = 473, .external_lex_state = 2},
  [14] = {.lex_state = 473, .external_lex_state = 2},
  [15] = {.lex_state = 473, .external_lex_state = 2},
  [16] = {.lex_state = 473, .external_lex_state = 2},
  [17] = {.lex_state = 473, .external_lex_state = 2},
  [18] = {.lex_state = 473, .external_lex_state = 2},
  [19] = {.lex_state = 473, .external_lex_state = 2},
  [20] = {.lex_state = 473, .external_lex_state = 2},
  [21] = {.lex_state = 473, .external_lex_state = 2},
  [22] = {.lex_state = 473, .external_lex_state = 2},
  [23] = {.lex_state = 473, .external_lex_state = 2},
  [24] = {.lex_state = 473, .external_lex_state = 2},
  [25] = {.lex_state = 473, .external_lex_state = 2},
  [26] = {.lex_state = 473, .external_lex_state = 2},
  [27] = {.lex_state = 473, .external_lex_state = 2},
  [28] = {.lex_state = 473, .external_lex_state = 2},
  [29] = {.lex_state = 473, .external_lex_state = 2},
  [30] = {.lex_state = 473, .external_lex_state = 2},
  [31] = {.lex_state = 473, .external_lex_state = 2},
  [32] = {.lex_state = 473, .external_lex_state = 2},
  [33] = {.lex_state = 473, .external_lex_state = 2},
  [34] = {.lex_state = 473, .external_lex_state = 2},
  [35] = {.lex_state = 473, .external_lex_state = 2},
  [36] = {.lex_state = 473, .external_lex_state = 2},
  [37] = {.lex_state = 473, .external_lex_state = 2},
  [38] = {.lex_state = 473, .external_lex_state = 2},
  [39] = {.lex_state = 473, .external_lex_state = 2},
  [40] = {.lex_state = 473, .external_lex_state = 2},
  [41] = {.lex_state = 473, .external_lex_state = 2},
  [42] = {.lex_state = 473, .external_lex_state = 2},
  [43] = {.lex_state = 473, .external_lex_state = 2},
  [44] = {.lex_state = 473, .external_lex_state = 2},
  [45] = {.lex_state = 473, .external_lex_state = 2},
  [46] = {.lex_state = 473, .external_lex_state = 2},
  [47] = {.lex_state = 473, .external_lex_state = 2},
  [48] = {.lex_state = 473, .external_lex_state = 2},
  [49] = {.lex_state = 473, .external_lex_state = 2},
  [50] = {.lex_state = 473, .external_lex_state = 2},
  [51] = {.lex_state = 473, .external_lex_state = 2},
  [52] = {.lex_state = 473, .external_lex_state = 2},
  [53] = {.lex_state = 473, .external_lex_state = 2},
  [54] = {.lex_state = 473, .external_lex_state = 2},
  [55] = {.lex_state = 473, .external_lex_state = 2},
  [56] = {.lex_state = 473, .external_lex_state = 2},
  [57] = {.lex_state = 473, .external_lex_state = 2},
  [58] = {.lex_state = 473, .external_lex_state = 2},
  [59] = {.lex_state = 473, .external_lex_state = 2},
  [60] = {.lex_state = 473, .external_lex_state = 2},
  [61] = {.lex_state = 473, .external_lex_state = 2},
  [62] = {.lex_state = 473, .external_lex_state = 2},
  [63] = {.lex_state = 473, .external_lex_state = 2},
  [64] = {.lex_state = 473, .external_lex_state = 2},
  [65] = {.lex_state = 473, .external_lex_state = 2},
  [66] = {.lex_state = 473, .external_lex_state = 2},
  [67] = {.lex_state = 473, .external_lex_state = 2},
  [68] = {.lex_state = 473, .external_lex_state = 2},
  [69] = {.lex_state = 473, .external_lex_state = 2},
  [70] = {.lex_state = 473, .external_lex_state = 2},
  [71] = {.lex_state = 473, .external_lex_state = 2},
  [72] = {.lex_state = 473, .external_lex_state = 2},
  [73] = {.lex_state = 473, .external_lex_state = 2},
  [74] = {.lex_state = 473, .external_lex_state = 2},
  [75] = {.lex_state = 473, .external_lex_state = 2},
  [76] = {.lex_state = 473, .external_lex_state = 2},
  [77] = {.lex_state = 473, .external_lex_state = 2},
  [78] = {.lex_state = 473, .external_lex_state = 2},
  [79] = {.lex_state = 473, .external_lex_state = 2},
  [80] = {.lex_state = 473, .external_lex_state = 2},
  [81] = {.lex_state = 473, .external_lex_state = 2},
  [82] = {.lex_state = 473, .external_lex_state = 2},
  [83] = {.lex_state = 473, .external_lex_state = 2},
  [84] = {.lex_state = 473, .external_lex_state = 2},
  [85] = {.lex_state = 473, .external_lex_state = 2},
  [86] = {.lex_state = 13, .external_lex_state = 2},
  [87] = {.lex_state = 10, .external_lex_state = 2},
  [88] = {.lex_state = 10, .external_lex_state = 2},
  [89] = {.lex_state = 10, .external_lex_state = 2},
  [90] = {.lex_state = 10, .external_lex_state = 3},
  [91] = {.lex_state = 10, .external_lex_state = 3},
  [92] = {.lex_state = 10, .external_lex_state = 3},
  [93] = {.lex_state = 10, .external_lex_state = 3},
  [94] = {.lex_state = 10, .external_lex_state = 3},
  [95] = {.lex_state = 10, .external_lex_state = 3},
  [96] = {.lex_state = 10, .external_lex_state = 3},
  [97] = {.lex_state = 10, .external_lex_state = 3},
  [98] = {.lex_state = 10, .external_lex_state = 3},
  [99] = {.lex_state = 10, .external_lex_state = 3},
  [100] = {.lex_state = 10, .external_lex_state = 3},
  [101] = {.lex_state = 10, .external_lex_state = 2},
  [102] = {.lex_state = 10, .external_lex_state = 2},
  [103] = {.lex_state = 13, .external_lex_state = 2},
  [104] = {.lex_state = 13, .external_lex_state = 2},
  [105] = {.lex_state = 13, .external_lex_state = 2},
  [106] = {.lex_state = 13, .external_lex_state = 2},
  [107] = {.lex_state = 13, .external_lex_state = 2},
  [108] = {.lex_state = 13, .external_lex_state = 2},
  [109] = {.lex_state = 13, .external_lex_state = 2},
  [110] = {.lex_state = 13, .external_lex_state = 2},
  [111] = {.lex_state = 13, .external_lex_state = 2},
  [112] = {.lex_state = 13, .external_lex_state = 2},
  [113] = {.lex_state = 13, .external_lex_state = 2},
  [114] = {.lex_state = 10, .external_lex_state = 2},
  [115] = {.lex_state = 13, .external_lex_state = 2},
  [116] = {.lex_state = 14, .external_lex_state = 2},
  [117] = {.lex_state = 13, .external_lex_state = 2},
  [118] = {.lex_state = 14, .external_lex_state = 2},
  [119] = {.lex_state = 13, .external_lex_state = 2},
  [120] = {.lex_state = 13, .external_lex_state = 2},
  [121] = {.lex_state = 11, .external_lex_state = 2},
  [122] = {.lex_state = 11, .external_lex_state = 2},
  [123] = {.lex_state = 12, .external_lex_state = 2},
  [124] = {.lex_state = 13, .external_lex_state = 2},
  [125] = {.lex_state = 13, .external_lex_state = 2},
  [126] = {.lex_state = 13, .external_lex_state = 2},
  [127] = {.lex_state = 11, .external_lex_state = 2},
  [128] = {.lex_state = 12, .external_lex_state = 2},
  [129] = {.lex_state = 12, .external_lex_state = 2},
  [130] = {.lex_state = 15, .external_lex_state = 2},
  [131] = {.lex_state = 15, .external_lex_state = 2},
  [132] = {.lex_state = 11, .external_lex_state = 2},
  [133] = {.lex_state = 12, .external_lex_state = 2},
  [134] = {.lex_state = 11, .external_lex_state = 2},
  [135] = {.lex_state = 12, .external_lex_state = 2},
  [136] = {.lex_state = 13, .external_lex_state = 2},
  [137] = {.lex_state = 13, .external_lex_state = 2},
  [138] = {.lex_state = 13, .external_lex_state = 2},
  [139] = {.lex_state = 13, .external_lex_state = 2},
  [140] = {.lex_state = 13, .external_lex_state = 2},
  [141] = {.lex_state = 11, .external_lex_state = 2},
  [142] = {.lex_state = 12, .external_lex_state = 2},
  [143] = {.lex_state = 11, .external_lex_state = 2},
  [144] = {.lex_state = 12, .external_lex_state = 2},
  [145] = {.lex_state = 13, .external_lex_state = 2},
  [146] = {.lex_state = 13, .external_lex_state = 2},
  [147] = {.lex_state = 13, .external_lex_state = 2},
  [148] = {.lex_state = 13, .external_lex_state = 2},
  [149] = {.lex_state = 13, .external_lex_state = 2},
  [150] = {.lex_state = 13, .external_lex_state = 2},
  [151] = {.lex_state = 11, .external_lex_state = 2},
  [152] = {.lex_state = 12, .external_lex_state = 2},
  [153] = {.lex_state = 13, .external_lex_state = 2},
  [154] = {.lex_state = 13, .external_lex_state = 2},
  [155] = {.lex_state = 11, .external_lex_state = 2},
  [156] = {.lex_state = 12, .external_lex_state = 2},
  [157] = {.lex_state = 13, .external_lex_state = 2},
  [158] = {.lex_state = 13, .external_lex_state = 2},
  [159] = {.lex_state = 13, .external_lex_state = 2},
  [160] = {.lex_state = 13, .external_lex_state = 2},
  [161] = {.lex_state = 13, .external_lex_state = 2},
  [162] = {.lex_state = 11, .external_lex_state = 2},
  [163] = {.lex_state = 12, .external_lex_state = 2},
  [164] = {.lex_state = 13, .external_lex_state = 2},
  [165] = {.lex_state = 13, .external_lex_state = 2},
  [166] = {.lex_state = 11, .external_lex_state = 2},
  [167] = {.lex_state = 12, .external_lex_state = 2},
  [168] = {.lex_state = 13, .external_lex_state = 2},
  [169] = {.lex_state = 13, .external_lex_state = 2},
  [170] = {.lex_state = 13, .external_lex_state = 2},
  [171] = {.lex_state = 13, .external_lex_state = 2},
  [172] = {.lex_state = 13, .external_lex_state = 2},
  [173] = {.lex_state = 13, .external_lex_state = 2},
  [174] = {.lex_state = 13, .external_lex_state = 2},
  [175] = {.lex_state = 10, .external_lex_state = 3},
  [176] = {.lex_state = 10, .external_lex_state = 3},
  [177] = {.lex_state = 10, .external_lex_state = 3},
  [178] = {.lex_state = 10, .external_lex_state = 3},
  [179] = {.lex_state = 10, .external_lex_state = 3},
  [180] = {.lex_state = 10, .external_lex_state = 3},
  [181] = {.lex_state = 10, .external_lex_state = 3},
  [182] = {.lex_state = 10, .external_lex_state = 3},
  [183] = {.lex_state = 10, .external_lex_state = 3},
  [184] = {.lex_state = 10, .external_lex_state = 3},
  [185] = {.lex_state = 10, .external_lex_state = 3},
  [186] = {.lex_state = 10, .external_lex_state = 3},
  [187] = {.lex_state = 10, .external_lex_state = 3},
  [188] = {.lex_state = 10, .external_lex_state = 3},
  [189] = {.lex_state = 10, .external_lex_state = 3},
  [190] = {.lex_state = 10, .external_lex_state = 3},
  [191] = {.lex_state = 10, .external_lex_state = 3},
  [192] = {.lex_state = 10, .external_lex_state = 3},
  [193] = {.lex_state = 10, .external_lex_state = 3},
  [194] = {.lex_state = 10, .external_lex_state = 3},
  [195] = {.lex_state = 10, .external_lex_state = 3},
  [196] = {.lex_state = 10, .external_lex_state = 3},
  [197] = {.lex_state = 10, .external_lex_state = 3},
  [198] = {.lex_state = 10, .external_lex_state = 3},
  [199] = {.lex_state = 14, .external_lex_state = 2},
  [200] = {.lex_state = 10, .external_lex_state = 2},
  [201] = {.lex_state = 14, .external_lex_state = 2},
  [202] = {.lex_state = 14, .external_lex_state = 2},
  [203] = {.lex_state = 14, .external_lex_state = 2},
  [204] = {.lex_state = 14, .external_lex_state = 2},
  [205] = {.lex_state = 14, .external_lex_state = 2},
  [206] = {.lex_state = 14, .external_lex_state = 2},
  [207] = {.lex_state = 14, .external_lex_state = 2},
  [208] = {.lex_state = 14, .external_lex_state = 2},
  [209] = {.lex_state = 14, .external_lex_state = 2},
  [210] = {.lex_state = 14, .external_lex_state = 2},
  [211] = {.lex_state = 14, .external_lex_state = 2},
  [212] = {.lex_state = 14, .external_lex_state = 2},
  [213] = {.lex_state = 14, .external_lex_state = 2},
  [214] = {.lex_state = 14, .external_lex_state = 2},
  [215] = {.lex_state = 14, .external_lex_state = 2},
  [216] = {.lex_state = 14, .external_lex_state = 2},
  [217] = {.lex_state = 14, .external_lex_state = 2},
  [218] = {.lex_state = 14, .external_lex_state = 2},
  [219] = {.lex_state = 14, .external_lex_state = 2},
  [220] = {.lex_state = 14, .external_lex_state = 2},
  [221] = {.lex_state = 14, .external_lex_state = 2},
  [222] = {.lex_state = 10, .external_lex_state = 2},
  [223] = {.lex_state = 12, .external_lex_state = 2},
  [224] = {.lex_state = 12, .external_lex_state = 2},
  [225] = {.lex_state = 12, .external_lex_state = 2},
  [226] = {.lex_state = 12, .external_lex_state = 2},
  [227] = {.lex_state = 12, .external_lex_state = 2},
  [228] = {.lex_state = 12, .external_lex_state = 2},
  [229] = {.lex_state = 12, .external_lex_state = 2},
  [230] = {.lex_state = 12, .external_lex_state = 2},
  [231] = {.lex_state = 12, .external_lex_state = 2},
  [232] = {.lex_state = 12, .external_lex_state = 2},
  [233] = {.lex_state = 12, .external_lex_state = 2},
  [234] = {.lex_state = 12, .external_lex_state = 2},
  [235] = {.lex_state = 12, .external_lex_state = 2},
  [236] = {.lex_state = 12, .external_lex_state = 2},
  [237] = {.lex_state = 12, .external_lex_state = 2},
  [238] = {.lex_state = 12, .external_lex_state = 2},
  [239] = {.lex_state = 12, .external_lex_state = 2},
  [240] = {.lex_state = 12, .external_lex_state = 2},
  [241] = {.lex_state = 15, .external_lex_state = 2},
  [242] = {.lex_state = 15, .external_lex_state = 2},
  [243] = {.lex_state = 15, .external_lex_state = 2},
  [244] = {.lex_state = 15, .external_lex_state = 2},
  [245] = {.lex_state = 15, .external_lex_state = 2},
  [246] = {.lex_state = 15, .external_lex_state = 2},
  [247] = {.lex_state = 15, .external_lex_state = 2},
  [248] = {.lex_state = 15, .external_lex_state = 2},
  [249] = {.lex_state = 15, .external_lex_state = 2},
  [250] = {.lex_state = 15, .external_lex_state = 2},
  [251] = {.lex_state = 15, .external_lex_state = 2},
  [252] = {.lex_state = 15, .external_lex_state = 2},
  [253] = {.lex_state = 15, .external_lex_state = 2},
  [254] = {.lex_state = 15, .external_lex_state = 2},
  [255] = {.lex_state = 15, .external_lex_state = 2},
  [256] = {.lex_state = 15, .external_lex_state = 2},
  [257] = {.lex_state = 12, .external_lex_state = 2},
  [258] = {.lex_state = 15, .external_lex_state = 2},
  [259] = {.lex_state = 15, .external_lex_state = 2},
  [260] = {.lex_state = 15, .external_lex_state = 2},
  [261] = {.lex_state = 15, .external_lex_state = 2},
  [262] = {.lex_state = 15, .external_lex_state = 2},
  [263] = {.lex_state = 13, .external_lex_state = 2},
  [264] = {.lex_state = 13, .external_lex_state = 2},
  [265] = {.lex_state = 11, .external_lex_state = 2},
  [266] = {.lex_state = 11, .external_lex_state = 2},
  [267] = {.lex_state = 11, .external_lex_state = 2},
  [268] = {.lex_state = 11, .external_lex_state = 2},
  [269] = {.lex_state = 11, .external_lex_state = 2},
  [270] = {.lex_state = 11, .external_lex_state = 2},
  [271] = {.lex_state = 11, .external_lex_state = 2},
  [272] = {.lex_state = 11, .external_lex_state = 2},
  [273] = {.lex_state = 11, .external_lex_state = 2},
  [274] = {.lex_state = 11, .external_lex_state = 2},
  [275] = {.lex_state = 11, .external_lex_state = 2},
  [276] = {.lex_state = 11, .external_lex_state = 2},
  [277] = {.lex_state = 11, .external_lex_state = 2},
  [278] = {.lex_state = 11, .external_lex_state = 2},
  [279] = {.lex_state = 11, .external_lex_state = 2},
  [280] = {.lex_state = 12, .external_lex_state = 2},
  [281] = {.lex_state = 11, .external_lex_state = 2},
  [282] = {.lex_state = 11, .external_lex_state = 2},
  [283] = {.lex_state = 11, .external_lex_state = 2},
  [284] = {.lex_state = 11, .external_lex_state = 2},
  [285] = {.lex_state = 11, .external_lex_state = 2},
  [286] = {.lex_state = 12, .external_lex_state = 2},
  [287] = {.lex_state = 11, .external_lex_state = 2},
  [288] = {.lex_state = 11, .external_lex_state = 2},
  [289] = {.lex_state = 12, .external_lex_state = 2},
  [290] = {.lex_state = 15, .external_lex_state = 2},
  [291] = {.lex_state = 13, .external_lex_state = 2},
  [292] = {.lex_state = 473},
  [293] = {.lex_state = 473},
  [294] = {.lex_state = 473},
  [295] = {.lex_state = 473, .external_lex_state = 4},
  [296] = {.lex_state = 473, .external_lex_state = 5},
  [297] = {.lex_state = 473, .external_lex_state = 5},
  [298] = {.lex_state = 473, .external_lex_state = 5},
  [299] = {.lex_state = 473, .external_lex_state = 6},
  [300] = {.lex_state = 473, .external_lex_state = 5},
  [301] = {.lex_state = 473, .external_lex_state = 4},
  [302] = {.lex_state = 473, .external_lex_state = 5},
  [303] = {.lex_state = 473, .external_lex_state = 5},
  [304] = {.lex_state = 473, .external_lex_state = 4},
  [305] = {.lex_state = 473, .external_lex_state = 4},
  [306] = {.lex_state = 473, .external_lex_state = 6},
  [307] = {.lex_state = 473, .external_lex_state = 6},
  [308] = {.lex_state = 473},
  [309] = {.lex_state = 473},
  [310] = {.lex_state = 473},
  [311] = {.lex_state = 473},
  [312] = {.lex_state = 473},
  [313] = {.lex_state = 473},
  [314] = {.lex_state = 473},
  [315] = {.lex_state = 473},
  [316] = {.lex_state = 473},
  [317] = {.lex_state = 473},
  [318] = {.lex_state = 473},
  [319] = {.lex_state = 473},
  [320] = {.lex_state = 473},
  [321] = {.lex_state = 473},
  [322] = {.lex_state = 473},
  [323] = {.lex_state = 473},
  [324] = {.lex_state = 473},
  [325] = {.lex_state = 473},
  [326] = {.lex_state = 473, .external_lex_state = 5},
  [327] = {.lex_state = 473, .external_lex_state = 4},
  [328] = {.lex_state = 473, .external_lex_state = 5},
  [329] = {.lex_state = 473, .external_lex_state = 4},
  [330] = {.lex_state = 473, .external_lex_state = 4},
  [331] = {.lex_state = 473, .external_lex_state = 4},
  [332] = {.lex_state = 473, .external_lex_state = 5},
  [333] = {.lex_state = 473, .external_lex_state = 6},
  [334] = {.lex_state = 473, .external_lex_state = 4},
  [335] = {.lex_state = 473, .external_lex_state = 4},
  [336] = {.lex_state = 473, .external_lex_state = 5},
  [337] = {.lex_state = 473, .external_lex_state = 5},
  [338] = {.lex_state = 473, .external_lex_state = 4},
  [339] = {.lex_state = 473, .external_lex_state = 6},
  [340] = {.lex_state = 473, .external_lex_state = 6},
  [341] = {.lex_state = 473, .external_lex_state = 6},
  [342] = {.lex_state = 473, .external_lex_state = 5},
  [343] = {.lex_state = 473, .external_lex_state = 6},
  [344] = {.lex_state = 473, .external_lex_state = 6},
  [345] = {.lex_state = 473, .external_lex_state = 6},
  [346] = {.lex_state = 473, .external_lex_state = 5},
  [347] = {.lex_state = 473},
  [348] = {.lex_state = 473},
  [349] = {.lex_state = 473},
  [350] = {.lex_state = 473},
  [351] = {.lex_state = 473},
  [352] = {.lex_state = 473},
  [353] = {.lex_state = 473},
  [354] = {.lex_state = 0},
  [355] = {.lex_state = 473},
  [356] = {.lex_state = 473},
  [357] = {.lex_state = 473},
  [358] = {.lex_state = 473},
  [359] = {.lex_state = 0},
  [360] = {.lex_state = 0},
  [361] = {.lex_state = 473},
  [362] = {.lex_state = 473},
  [363] = {.lex_state = 0},
  [364] = {.lex_state = 0},
  [365] = {.lex_state = 0},
  [366] = {.lex_state = 0, .external_lex_state = 2},
  [367] = {.lex_state = 473},
  [368] = {.lex_state = 473},
  [369] = {.lex_state = 0, .external_lex_state = 7},
  [370] = {.lex_state = 0, .external_lex_state = 8},
  [371] = {.lex_state = 473},
  [372] = {.lex_state = 0, .external_lex_state = 2},
  [373] = {.lex_state = 0, .external_lex_state = 5},
  [374] = {.lex_state = 0, .external_lex_state = 5},
  [375] = {.lex_state = 0, .external_lex_state = 2},
  [376] = {.lex_state = 473},
  [377] = {.lex_state = 0, .external_lex_state = 2},
  [378] = {.lex_state = 0, .external_lex_state = 2},
  [379] = {.lex_state = 473},
  [380] = {.lex_state = 0, .external_lex_state = 9},
  [381] = {.lex_state = 0, .external_lex_state = 7},
  [382] = {.lex_state = 0, .external_lex_state = 8},
  [383] = {.lex_state = 0, .external_lex_state = 5},
  [384] = {.lex_state = 0, .external_lex_state = 5},
  [385] = {.lex_state = 0, .external_lex_state = 7},
  [386] = {.lex_state = 0, .external_lex_state = 8},
  [387] = {.lex_state = 0, .external_lex_state = 5},
  [388] = {.lex_state = 0, .external_lex_state = 5},
  [389] = {.lex_state = 0, .external_lex_state = 5},
  [390] = {.lex_state = 0, .external_lex_state = 7},
  [391] = {.lex_state = 0, .external_lex_state = 8},
  [392] = {.lex_state = 0, .external_lex_state = 5},
  [393] = {.lex_state = 0, .external_lex_state = 5},
  [394] = {.lex_state = 473},
  [395] = {.lex_state = 0, .external_lex_state = 7},
  [396] = {.lex_state = 0, .external_lex_state = 8},
  [397] = {.lex_state = 0, .external_lex_state = 5},
  [398] = {.lex_state = 473},
  [399] = {.lex_state = 0, .external_lex_state = 2},
  [400] = {.lex_state = 0},
  [401] = {.lex_state = 0},
  [402] = {.lex_state = 0, .external_lex_state = 9},
  [403] = {.lex_state = 14},
  [404] = {.lex_state = 0, .external_lex_state = 2},
  [405] = {.lex_state = 1},
  [406] = {.lex_state = 1},
  [407] = {.lex_state = 0, .external_lex_state = 2},
  [408] = {.lex_state = 0},
  [409] = {.lex_state = 0},
  [410] = {.lex_state = 0},
  [411] = {.lex_state = 0, .external_lex_state = 2},
  [412] = {.lex_state = 0},
  [413] = {.lex_state = 0},
  [414] = {.lex_state = 0},
  [415] = {.lex_state = 0, .external_lex_state = 9},
  [416] = {.lex_state = 0, .external_lex_state = 9},
  [417] = {.lex_state = 0, .external_lex_state = 9},
  [418] = {.lex_state = 473},
  [419] = {.lex_state = 1},
  [420] = {.lex_state = 0},
  [421] = {.lex_state = 0},
  [422] = {.lex_state = 473},
  [423] = {.lex_state = 0},
  [424] = {.lex_state = 0},
  [425] = {.lex_state = 0},
  [426] = {.lex_state = 0},
  [427] = {.lex_state = 0},
  [428] = {.lex_state = 0},
  [429] = {.lex_state = 0},
  [430] = {.lex_state = 0, .external_lex_state = 9},
  [431] = {.lex_state = 0},
  [432] = {.lex_state = 0, .external_lex_state = 2},
  [433] = {.lex_state = 0},
  [434] = {.lex_state = 1},
  [435] = {.lex_state = 0},
  [436] = {.lex_state = 0},
  [437] = {.lex_state = 0},
  [438] = {.lex_state = 473},
  [439] = {.lex_state = 14},
  [440] = {.lex_state = 0},
  [441] = {.lex_state = 0, .external_lex_state = 9},
  [442] = {.lex_state = 0},
  [443] = {.lex_state = 0},
  [444] = {.lex_state = 0},
  [445] = {.lex_state = 0},
  [446] = {.lex_state = 4},
  [447] = {.lex_state = 0},
  [448] = {.lex_state = 0},
  [449] = {.lex_state = 0},
  [450] = {.lex_state = 473},
  [451] = {.lex_state = 0, .external_lex_state = 9},
  [452] = {.lex_state = 0},
  [453] = {.lex_state = 0},
  [454] = {.lex_state = 0},
  [455] = {.lex_state = 0},
  [456] = {.lex_state = 0, .external_lex_state = 2},
  [457] = {.lex_state = 0, .external_lex_state = 9},
  [458] = {.lex_state = 0},
  [459] = {.lex_state = 1},
  [460] = {.lex_state = 0, .external_lex_state = 9},
  [461] = {.lex_state = 0},
  [462] = {.lex_state = 0},
  [463] = {.lex_state = 0, .external_lex_state = 9},
  [464] = {.lex_state = 473},
  [465] = {.lex_state = 0},
  [466] = {.lex_state = 0, .external_lex_state = 9},
  [467] = {.lex_state = 473},
  [468] = {.lex_state = 0},
  [469] = {.lex_state = 0, .external_lex_state = 9},
  [470] = {.lex_state = 0, .external_lex_state = 9},
  [471] = {.lex_state = 0, .external_lex_state = 9},
  [472] = {.lex_state = 0, .external_lex_state = 9},
  [473] = {.lex_state = 0},
  [474] = {.lex_state = 13},
  [475] = {.lex_state = 0, .external_lex_state = 2},
  [476] = {.lex_state = 0},
  [477] = {.lex_state = 0, .external_lex_state = 2},
  [478] = {.lex_state = 0},
  [479] = {.lex_state = 0},
  [480] = {.lex_state = 13},
  [481] = {.lex_state = 13},
  [482] = {.lex_state = 0},
  [483] = {.lex_state = 0},
  [484] = {.lex_state = 0, .external_lex_state = 2},
  [485] = {.lex_state = 0},
  [486] = {.lex_state = 16},
  [487] = {.lex_state = 0},
  [488] = {.lex_state = 0},
  [489] = {.lex_state = 0, .external_lex_state = 4},
  [490] = {.lex_state = 0},
  [491] = {.lex_state = 0, .external_lex_state = 5},
  [492] = {.lex_state = 0},
  [493] = {.lex_state = 13},
  [494] = {.lex_state = 13},
  [495] = {.lex_state = 0},
  [496] = {.lex_state = 0},
  [497] = {.lex_state = 0},
  [498] = {.lex_state = 0},
  [499] = {.lex_state = 17},
  [500] = {.lex_state = 0},
  [501] = {.lex_state = 0},
  [502] = {.lex_state = 0},
  [503] = {.lex_state = 0, .external_lex_state = 5},
  [504] = {.lex_state = 18},
  [505] = {.lex_state = 0},
  [506] = {.lex_state = 11},
  [507] = {.lex_state = 0, .external_lex_state = 2},
  [508] = {.lex_state = 0},
  [509] = {.lex_state = 0, .external_lex_state = 9},
  [510] = {.lex_state = 0},
  [511] = {.lex_state = 13},
  [512] = {.lex_state = 0},
  [513] = {.lex_state = 0},
  [514] = {.lex_state = 0},
  [515] = {.lex_state = 0},
  [516] = {.lex_state = 0, .external_lex_state = 8},
  [517] = {.lex_state = 0},
  [518] = {.lex_state = 0},
  [519] = {.lex_state = 0},
  [520] = {.lex_state = 13},
  [521] = {.lex_state = 0},
  [522] = {.lex_state = 19},
  [523] = {.lex_state = 13},
  [524] = {.lex_state = 13},
  [525] = {.lex_state = 0},
  [526] = {.lex_state = 0},
  [527] = {.lex_state = 0},
  [528] = {.lex_state = 0},
  [529] = {.lex_state = 0, .external_lex_state = 5},
  [530] = {.lex_state = 0},
  [531] = {.lex_state = 0},
  [532] = {.lex_state = 0},
  [533] = {.lex_state = 0, .external_lex_state = 7},
  [534] = {.lex_state = 0},
  [535] = {.lex_state = 20},
  [536] = {.lex_state = 0},
  [537] = {.lex_state = 0, .external_lex_state = 5},
  [538] = {.lex_state = 0},
  [539] = {.lex_state = 0},
  [540] = {.lex_state = 13},
  [541] = {.lex_state = 13},
  [542] = {.lex_state = 0},
  [543] = {.lex_state = 0},
  [544] = {.lex_state = 0},
  [545] = {.lex_state = 0, .external_lex_state = 6},
  [546] = {.lex_state = 13},
  [547] = {.lex_state = 0, .external_lex_state = 7},
  [548] = {.lex_state = 0},
  [549] = {.lex_state = 0},
  [550] = {.lex_state = 0},
  [551] = {.lex_state = 0},
  [552] = {.lex_state = 0},
  [553] = {.lex_state = 13},
  [554] = {.lex_state = 13},
  [555] = {.lex_state = 0},
  [556] = {.lex_state = 0},
  [557] = {.lex_state = 13},
  [558] = {.lex_state = 0},
  [559] = {.lex_state = 0},
  [560] = {.lex_state = 0},
  [561] = {.lex_state = 0},
  [562] = {.lex_state = 0},
  [563] = {.lex_state = 0},
  [564] = {.lex_state = 0, .external_lex_state = 9},
  [565] = {.lex_state = 13},
  [566] = {.lex_state = 13},
  [567] = {.lex_state = 0},
  [568] = {.lex_state = 0},
  [569] = {.lex_state = 0},
  [570] = {.lex_state = 18},
  [571] = {.lex_state = 0},
  [572] = {.lex_state = 16},
  [573] = {.lex_state = 17},
  [574] = {.lex_state = 0, .external_lex_state = 5},
  [575] = {.lex_state = 0, .external_lex_state = 4},
  [576] = {.lex_state = 0, .external_lex_state = 5},
  [577] = {.lex_state = 0},
  [578] = {.lex_state = 0, .external_lex_state = 7},
  [579] = {.lex_state = 0, .external_lex_state = 8},
  [580] = {.lex_state = 0, .external_lex_state = 5},
  [581] = {.lex_state = 0, .external_lex_state = 5},
  [582] = {.lex_state = 0, .external_lex_state = 5},
  [583] = {.lex_state = 0, .external_lex_state = 2},
  [584] = {.lex_state = 0, .external_lex_state = 2},
  [585] = {.lex_state = 0, .external_lex_state = 8},
  [586] = {.lex_state = 0},
  [587] = {.lex_state = 0},
  [588] = {.lex_state = 4},
  [589] = {.lex_state = 0},
  [590] = {.lex_state = 18},
  [591] = {.lex_state = 0},
  [592] = {.lex_state = 16},
  [593] = {.lex_state = 17},
  [594] = {.lex_state = 1},
  [595] = {.lex_state = 0, .external_lex_state = 7},
  [596] = {.lex_state = 0, .external_lex_state = 8},
  [597] = {.lex_state = 0, .external_lex_state = 5},
  [598] = {.lex_state = 0, .external_lex_state = 5},
  [599] = {.lex_state = 0},
  [600] = {.lex_state = 0, .external_lex_state = 2},
  [601] = {.lex_state = 0, .external_lex_state = 2},
  [602] = {.lex_state = 0},
  [603] = {.lex_state = 0, .external_lex_state = 7},
  [604] = {.lex_state = 0},
  [605] = {.lex_state = 0},
  [606] = {.lex_state = 0},
  [607] = {.lex_state = 18},
  [608] = {.lex_state = 0},
  [609] = {.lex_state = 16},
  [610] = {.lex_state = 17},
  [611] = {.lex_state = 0, .external_lex_state = 2},
  [612] = {.lex_state = 0, .external_lex_state = 7},
  [613] = {.lex_state = 0, .external_lex_state = 8},
  [614] = {.lex_state = 0, .external_lex_state = 5},
  [615] = {.lex_state = 0, .external_lex_state = 5},
  [616] = {.lex_state = 13},
  [617] = {.lex_state = 0, .external_lex_state = 2},
  [618] = {.lex_state = 0, .external_lex_state = 2},
  [619] = {.lex_state = 13},
  [620] = {.lex_state = 0},
  [621] = {.lex_state = 0},
  [622] = {.lex_state = 0, .external_lex_state = 8},
  [623] = {.lex_state = 0},
  [624] = {.lex_state = 18},
  [625] = {.lex_state = 0},
  [626] = {.lex_state = 16},
  [627] = {.lex_state = 17},
  [628] = {.lex_state = 0},
  [629] = {.lex_state = 0, .external_lex_state = 7},
  [630] = {.lex_state = 0, .external_lex_state = 8},
  [631] = {.lex_state = 0, .external_lex_state = 5},
  [632] = {.lex_state = 0, .external_lex_state = 5},
  [633] = {.lex_state = 13},
  [634] = {.lex_state = 0, .external_lex_state = 2},
  [635] = {.lex_state = 0, .external_lex_state = 2},
  [636] = {.lex_state = 0},
  [637] = {.lex_state = 0},
  [638] = {.lex_state = 0},
  [639] = {.lex_state = 0, .external_lex_state = 2},
  [640] = {.lex_state = 0, .external_lex_state = 5},
  [641] = {.lex_state = 0},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [STATE(0)] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [anon_sym_COLONmanuscript_COLON] = ACTIONS(1),
    [anon_sym_COLON_COLON] = ACTIONS(1),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(1),
    [aux_sym_section_token1] = ACTIONS(1),
    [anon_sym_COLONsection_COLON] = ACTIONS(1),
    [aux_sym_subsection_token1] = ACTIONS(1),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(1),
    [aux_sym_subsubsection_token1] = ACTIONS(1),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(1),
    [anon_sym_COLONappendix_COLON] = ACTIONS(1),
    [aux_sym_mathblock_token1] = ACTIONS(1),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(1),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(1),
    [anon_sym_COLONtoc_COLON] = ACTIONS(1),
    [aux_sym_specialblock_token1] = ACTIONS(1),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(1),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(1),
    [anon_sym_COLONcaption_COLON] = ACTIONS(1),
    [anon_sym_COLONitem_COLON] = ACTIONS(1),
    [anon_sym_COLONprev_COLON] = ACTIONS(1),
    [anon_sym_COLONprev2_COLON] = ACTIONS(1),
    [anon_sym_COLONprev3_COLON] = ACTIONS(1),
    [aux_sym_specialinline_token1] = ACTIONS(1),
    [aux_sym_specialinline_token2] = ACTIONS(1),
    [anon_sym_COLONmath_COLON] = ACTIONS(1),
    [anon_sym_COLONcode_COLON] = ACTIONS(1),
    [aux_sym_specialinline_token3] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [aux_sym_specialinline_token4] = ACTIONS(1),
    [anon_sym_SLASH] = ACTIONS(1),
    [anon_sym_COLONref_COLON] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_COLONprevious_COLON] = ACTIONS(1),
    [aux_sym_specialinline_token6] = ACTIONS(1),
    [anon_sym_COLONurl_COLON] = ACTIONS(1),
    [anon_sym_COLONcite_COLON] = ACTIONS(1),
    [anon_sym_COLONqed_COLON] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_COLONtable_COLON] = ACTIONS(1),
    [anon_sym_COLONthead_COLON] = ACTIONS(1),
    [anon_sym_COLONtbody_COLON] = ACTIONS(1),
    [anon_sym_COLONtr_COLON] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_COLONtd_COLON] = ACTIONS(1),
    [anon_sym_COLONbibtex_COLON] = ACTIONS(1),
    [anon_sym_AT] = ACTIONS(1),
    [aux_sym_bibitem_token1] = ACTIONS(1),
    [aux_sym_bibitempair_token1] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_COLONassume_COLON] = ACTIONS(1),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(1),
    [anon_sym_COLONprove_COLON] = ACTIONS(1),
    [anon_sym_COLONthen_COLON] = ACTIONS(1),
    [anon_sym_COLONnew_COLON] = ACTIONS(1),
    [anon_sym_COLONlet_COLON] = ACTIONS(1),
    [anon_sym_COLONcase_COLON] = ACTIONS(1),
    [anon_sym_COLONdefine_COLON] = ACTIONS(1),
    [anon_sym_COLONwrite_COLON] = ACTIONS(1),
    [anon_sym_COLONwlog_COLON] = ACTIONS(1),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(1),
    [anon_sym_COLONclaim_COLON] = ACTIONS(1),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(1),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(1),
    [anon_sym_COLONpick_COLON] = ACTIONS(1),
    [anon_sym_COLONst_COLON] = ACTIONS(1),
    [anon_sym_COLONdraft_COLON] = ACTIONS(1),
    [anon_sym_COLONnote_COLON] = ACTIONS(1),
    [anon_sym_COLONspan_COLON] = ACTIONS(1),
    [anon_sym_COLONabstract_COLON] = ACTIONS(1),
    [anon_sym_COLONauthor_COLON] = ACTIONS(1),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(1),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(1),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(1),
    [anon_sym_COLONexample_COLON] = ACTIONS(1),
    [anon_sym_COLONitemize_COLON] = ACTIONS(1),
    [anon_sym_COLONlemma_COLON] = ACTIONS(1),
    [anon_sym_COLONfigure_COLON] = ACTIONS(1),
    [anon_sym_COLONp_COLON] = ACTIONS(1),
    [anon_sym_COLONproof_COLON] = ACTIONS(1),
    [anon_sym_COLONproposition_COLON] = ACTIONS(1),
    [anon_sym_COLONremark_COLON] = ACTIONS(1),
    [anon_sym_COLONsketch_COLON] = ACTIONS(1),
    [anon_sym_COLONstep_COLON] = ACTIONS(1),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(1),
    [anon_sym_COLONaffiliation_COLON] = ACTIONS(1),
    [anon_sym_COLONemail_COLON] = ACTIONS(1),
    [anon_sym_COLONlabel_COLON] = ACTIONS(1),
    [anon_sym_COLONname_COLON] = ACTIONS(1),
    [anon_sym_COLONreftext_COLON] = ACTIONS(1),
    [anon_sym_COLONtitle_COLON] = ACTIONS(1),
    [anon_sym_COLONgoal_COLON] = ACTIONS(1),
    [anon_sym_COLONlang_COLON] = ACTIONS(1),
    [anon_sym_COLONicon_COLON] = ACTIONS(1),
    [anon_sym_COLONnonum_COLON] = ACTIONS(1),
    [anon_sym_COLONstrong_COLON] = ACTIONS(1),
    [anon_sym_COLONemphas_COLON] = ACTIONS(1),
    [anon_sym_COLONisclaim_COLON] = ACTIONS(1),
    [anon_sym_COLONkeywords_COLON] = ACTIONS(1),
    [anon_sym_COLONmsc_COLON] = ACTIONS(1),
    [anon_sym_COLONtypes_COLON] = ACTIONS(1),
    [anon_sym_COLONdate_COLON] = ACTIONS(1),
    [anon_sym_COLONpath_COLON] = ACTIONS(1),
    [anon_sym_COLONscale_COLON] = ACTIONS(1),
    [sym_comment] = ACTIONS(3),
    [sym_upto_brace_or_comma_text] = ACTIONS(1),
    [sym_asis_dollar_text] = ACTIONS(1),
    [sym_asis_two_dollars_text] = ACTIONS(1),
    [sym_asis_backtick_text] = ACTIONS(1),
    [sym_asis_three_backticks_text] = ACTIONS(1),
    [sym_asis_halmos_text] = ACTIONS(1),
    [sym_text] = ACTIONS(1),
    [sym_paragraph_end] = ACTIONS(1),
  },
  [STATE(1)] = {
    [sym_source_file] = STATE(599),
    [anon_sym_COLONmanuscript_COLON] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
  },
  [STATE(2)] = {
    [sym_block] = STATE(20),
    [sym_paragraph] = STATE(20),
    [sym_inline] = STATE(98),
    [sym_construct] = STATE(98),
    [sym_subsubsection] = STATE(20),
    [sym_mathblock] = STATE(20),
    [sym_specialblock] = STATE(20),
    [sym_caption] = STATE(61),
    [sym_item] = STATE(61),
    [sym_specialinline] = STATE(98),
    [sym_specialconstruct] = STATE(98),
    [sym_blockmeta] = STATE(19),
    [sym_pair] = STATE(11),
    [sym_table] = STATE(62),
    [sym__paragraphcontent_no_special] = STATE(98),
    [sym_metakey_text] = STATE(407),
    [sym_metakey_bool] = STATE(16),
    [sym_metakey_list] = STATE(377),
    [sym_metakey_any] = STATE(405),
    [aux_sym_subsection_repeat1] = STATE(20),
    [aux_sym_blockmeta_repeat1] = STATE(11),
    [anon_sym_COLON_COLON] = ACTIONS(7),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(7),
    [anon_sym_COLONsection_COLON] = ACTIONS(7),
    [aux_sym_subsection_token1] = ACTIONS(7),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(7),
    [aux_sym_subsubsection_token1] = ACTIONS(11),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(13),
    [anon_sym_COLONappendix_COLON] = ACTIONS(7),
    [aux_sym_mathblock_token1] = ACTIONS(15),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(17),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(19),
    [aux_sym_specialblock_token1] = ACTIONS(21),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(23),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(25),
    [anon_sym_COLONcaption_COLON] = ACTIONS(27),
    [anon_sym_COLONitem_COLON] = ACTIONS(29),
    [anon_sym_COLONprev_COLON] = ACTIONS(31),
    [anon_sym_COLONprev2_COLON] = ACTIONS(31),
    [anon_sym_COLONprev3_COLON] = ACTIONS(31),
    [aux_sym_specialinline_token1] = ACTIONS(33),
    [aux_sym_specialinline_token2] = ACTIONS(35),
    [anon_sym_COLONmath_COLON] = ACTIONS(37),
    [anon_sym_COLONcode_COLON] = ACTIONS(39),
    [aux_sym_specialinline_token3] = ACTIONS(41),
    [aux_sym_specialinline_token4] = ACTIONS(43),
    [anon_sym_COLONref_COLON] = ACTIONS(45),
    [anon_sym_COLONprevious_COLON] = ACTIONS(47),
    [anon_sym_COLONurl_COLON] = ACTIONS(49),
    [anon_sym_COLONcite_COLON] = ACTIONS(51),
    [anon_sym_COLONqed_COLON] = ACTIONS(53),
    [anon_sym_COLONtable_COLON] = ACTIONS(55),
    [anon_sym_COLONassume_COLON] = ACTIONS(57),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(57),
    [anon_sym_COLONprove_COLON] = ACTIONS(57),
    [anon_sym_COLONthen_COLON] = ACTIONS(57),
    [anon_sym_COLONnew_COLON] = ACTIONS(57),
    [anon_sym_COLONlet_COLON] = ACTIONS(57),
    [anon_sym_COLONcase_COLON] = ACTIONS(57),
    [anon_sym_COLONdefine_COLON] = ACTIONS(57),
    [anon_sym_COLONwrite_COLON] = ACTIONS(57),
    [anon_sym_COLONwlog_COLON] = ACTIONS(57),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(57),
    [anon_sym_COLONclaim_COLON] = ACTIONS(57),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(57),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(57),
    [anon_sym_COLONpick_COLON] = ACTIONS(57),
    [anon_sym_COLONst_COLON] = ACTIONS(57),
    [anon_sym_COLONdraft_COLON] = ACTIONS(59),
    [anon_sym_COLONnote_COLON] = ACTIONS(59),
    [anon_sym_COLONspan_COLON] = ACTIONS(59),
    [anon_sym_COLONabstract_COLON] = ACTIONS(61),
    [anon_sym_COLONauthor_COLON] = ACTIONS(61),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(61),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(61),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(61),
    [anon_sym_COLONexample_COLON] = ACTIONS(61),
    [anon_sym_COLONitemize_COLON] = ACTIONS(61),
    [anon_sym_COLONlemma_COLON] = ACTIONS(61),
    [anon_sym_COLONfigure_COLON] = ACTIONS(61),
    [anon_sym_COLONp_COLON] = ACTIONS(61),
    [anon_sym_COLONproof_COLON] = ACTIONS(61),
    [anon_sym_COLONproposition_COLON] = ACTIONS(61),
    [anon_sym_COLONremark_COLON] = ACTIONS(61),
    [anon_sym_COLONsketch_COLON] = ACTIONS(61),
    [anon_sym_COLONstep_COLON] = ACTIONS(61),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(61),
    [anon_sym_COLONaffiliation_COLON] = ACTIONS(63),
    [anon_sym_COLONemail_COLON] = ACTIONS(63),
    [anon_sym_COLONlabel_COLON] = ACTIONS(63),
    [anon_sym_COLONname_COLON] = ACTIONS(63),
    [anon_sym_COLONreftext_COLON] = ACTIONS(63),
    [anon_sym_COLONtitle_COLON] = ACTIONS(63),
    [anon_sym_COLONgoal_COLON] = ACTIONS(63),
    [anon_sym_COLONlang_COLON] = ACTIONS(63),
    [anon_sym_COLONicon_COLON] = ACTIONS(63),
    [anon_sym_COLONnonum_COLON] = ACTIONS(65),
    [anon_sym_COLONstrong_COLON] = ACTIONS(65),
    [anon_sym_COLONemphas_COLON] = ACTIONS(65),
    [anon_sym_COLONisclaim_COLON] = ACTIONS(65),
    [anon_sym_COLONkeywords_COLON] = ACTIONS(67),
    [anon_sym_COLONmsc_COLON] = ACTIONS(67),
    [anon_sym_COLONtypes_COLON] = ACTIONS(67),
    [anon_sym_COLONdate_COLON] = ACTIONS(69),
    [anon_sym_COLONpath_COLON] = ACTIONS(69),
    [anon_sym_COLONscale_COLON] = ACTIONS(69),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(71),
  },
  [STATE(3)] = {
    [sym_block] = STATE(24),
    [sym_paragraph] = STATE(24),
    [sym_inline] = STATE(98),
    [sym_construct] = STATE(98),
    [sym_subsubsection] = STATE(24),
    [sym_mathblock] = STATE(24),
    [sym_specialblock] = STATE(24),
    [sym_caption] = STATE(61),
    [sym_item] = STATE(61),
    [sym_specialinline] = STATE(98),
    [sym_specialconstruct] = STATE(98),
    [sym_blockmeta] = STATE(21),
    [sym_pair] = STATE(11),
    [sym_table] = STATE(62),
    [sym__paragraphcontent_no_special] = STATE(98),
    [sym_metakey_text] = STATE(407),
    [sym_metakey_bool] = STATE(16),
    [sym_metakey_list] = STATE(377),
    [sym_metakey_any] = STATE(405),
    [aux_sym_subsection_repeat1] = STATE(24),
    [aux_sym_blockmeta_repeat1] = STATE(11),
    [anon_sym_COLON_COLON] = ACTIONS(73),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(73),
    [anon_sym_COLONsection_COLON] = ACTIONS(73),
    [aux_sym_subsection_token1] = ACTIONS(73),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(73),
    [aux_sym_subsubsection_token1] = ACTIONS(11),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(13),
    [anon_sym_COLONappendix_COLON] = ACTIONS(73),
    [aux_sym_mathblock_token1] = ACTIONS(15),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(17),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(19),
    [aux_sym_specialblock_token1] = ACTIONS(21),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(23),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(25),
    [anon_sym_COLONcaption_COLON] = ACTIONS(27),
    [anon_sym_COLONitem_COLON] = ACTIONS(29),
    [anon_sym_COLONprev_COLON] = ACTIONS(31),
    [anon_sym_COLONprev2_COLON] = ACTIONS(31),
    [anon_sym_COLONprev3_COLON] = ACTIONS(31),
    [aux_sym_specialinline_token1] = ACTIONS(33),
    [aux_sym_specialinline_token2] = ACTIONS(35),
    [anon_sym_COLONmath_COLON] = ACTIONS(37),
    [anon_sym_COLONcode_COLON] = ACTIONS(39),
    [aux_sym_specialinline_token3] = ACTIONS(41),
    [aux_sym_specialinline_token4] = ACTIONS(43),
    [anon_sym_COLONref_COLON] = ACTIONS(45),
    [anon_sym_COLONprevious_COLON] = ACTIONS(47),
    [anon_sym_COLONurl_COLON] = ACTIONS(49),
    [anon_sym_COLONcite_COLON] = ACTIONS(51),
    [anon_sym_COLONqed_COLON] = ACTIONS(53),
    [anon_sym_COLONtable_COLON] = ACTIONS(55),
    [anon_sym_COLONassume_COLON] = ACTIONS(57),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(57),
    [anon_sym_COLONprove_COLON] = ACTIONS(57),
    [anon_sym_COLONthen_COLON] = ACTIONS(57),
    [anon_sym_COLONnew_COLON] = ACTIONS(57),
    [anon_sym_COLONlet_COLON] = ACTIONS(57),
    [anon_sym_COLONcase_COLON] = ACTIONS(57),
    [anon_sym_COLONdefine_COLON] = ACTIONS(57),
    [anon_sym_COLONwrite_COLON] = ACTIONS(57),
    [anon_sym_COLONwlog_COLON] = ACTIONS(57),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(57),
    [anon_sym_COLONclaim_COLON] = ACTIONS(57),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(57),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(57),
    [anon_sym_COLONpick_COLON] = ACTIONS(57),
    [anon_sym_COLONst_COLON] = ACTIONS(57),
    [anon_sym_COLONdraft_COLON] = ACTIONS(59),
    [anon_sym_COLONnote_COLON] = ACTIONS(59),
    [anon_sym_COLONspan_COLON] = ACTIONS(59),
    [anon_sym_COLONabstract_COLON] = ACTIONS(61),
    [anon_sym_COLONauthor_COLON] = ACTIONS(61),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(61),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(61),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(61),
    [anon_sym_COLONexample_COLON] = ACTIONS(61),
    [anon_sym_COLONitemize_COLON] = ACTIONS(61),
    [anon_sym_COLONlemma_COLON] = ACTIONS(61),
    [anon_sym_COLONfigure_COLON] = ACTIONS(61),
    [anon_sym_COLONp_COLON] = ACTIONS(61),
    [anon_sym_COLONproof_COLON] = ACTIONS(61),
    [anon_sym_COLONproposition_COLON] = ACTIONS(61),
    [anon_sym_COLONremark_COLON] = ACTIONS(61),
    [anon_sym_COLONsketch_COLON] = ACTIONS(61),
    [anon_sym_COLONstep_COLON] = ACTIONS(61),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(61),
    [anon_sym_COLONaffiliation_COLON] = ACTIONS(63),
    [anon_sym_COLONemail_COLON] = ACTIONS(63),
    [anon_sym_COLONlabel_COLON] = ACTIONS(63),
    [anon_sym_COLONname_COLON] = ACTIONS(63),
    [anon_sym_COLONreftext_COLON] = ACTIONS(63),
    [anon_sym_COLONtitle_COLON] = ACTIONS(63),
    [anon_sym_COLONgoal_COLON] = ACTIONS(63),
    [anon_sym_COLONlang_COLON] = ACTIONS(63),
    [anon_sym_COLONicon_COLON] = ACTIONS(63),
    [anon_sym_COLONnonum_COLON] = ACTIONS(65),
    [anon_sym_COLONstrong_COLON] = ACTIONS(65),
    [anon_sym_COLONemphas_COLON] = ACTIONS(65),
    [anon_sym_COLONisclaim_COLON] = ACTIONS(65),
    [anon_sym_COLONkeywords_COLON] = ACTIONS(67),
    [anon_sym_COLONmsc_COLON] = ACTIONS(67),
    [anon_sym_COLONtypes_COLON] = ACTIONS(67),
    [anon_sym_COLONdate_COLON] = ACTIONS(69),
    [anon_sym_COLONpath_COLON] = ACTIONS(69),
    [anon_sym_COLONscale_COLON] = ACTIONS(69),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(71),
  },
  [STATE(4)] = {
    [sym_block] = STATE(28),
    [sym_paragraph] = STATE(28),
    [sym_inline] = STATE(98),
    [sym_construct] = STATE(98),
    [sym_mathblock] = STATE(28),
    [sym_specialblock] = STATE(28),
    [sym_caption] = STATE(61),
    [sym_item] = STATE(61),
    [sym_specialinline] = STATE(98),
    [sym_specialconstruct] = STATE(98),
    [sym_blockmeta] = STATE(27),
    [sym_pair] = STATE(11),
    [sym_table] = STATE(62),
    [sym__paragraphcontent_no_special] = STATE(98),
    [sym_metakey_text] = STATE(407),
    [sym_metakey_bool] = STATE(16),
    [sym_metakey_list] = STATE(377),
    [sym_metakey_any] = STATE(405),
    [aux_sym_subsubsection_repeat1] = STATE(28),
    [aux_sym_blockmeta_repeat1] = STATE(11),
    [anon_sym_COLON_COLON] = ACTIONS(75),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(75),
    [anon_sym_COLONsection_COLON] = ACTIONS(75),
    [aux_sym_subsection_token1] = ACTIONS(75),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(75),
    [aux_sym_subsubsection_token1] = ACTIONS(75),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(75),
    [anon_sym_COLONappendix_COLON] = ACTIONS(75),
    [aux_sym_mathblock_token1] = ACTIONS(15),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(17),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(19),
    [aux_sym_specialblock_token1] = ACTIONS(21),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(23),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(25),
    [anon_sym_COLONcaption_COLON] = ACTIONS(27),
    [anon_sym_COLONitem_COLON] = ACTIONS(29),
    [anon_sym_COLONprev_COLON] = ACTIONS(31),
    [anon_sym_COLONprev2_COLON] = ACTIONS(31),
    [anon_sym_COLONprev3_COLON] = ACTIONS(31),
    [aux_sym_specialinline_token1] = ACTIONS(33),
    [aux_sym_specialinline_token2] = ACTIONS(35),
    [anon_sym_COLONmath_COLON] = ACTIONS(37),
    [anon_sym_COLONcode_COLON] = ACTIONS(39),
    [aux_sym_specialinline_token3] = ACTIONS(41),
    [aux_sym_specialinline_token4] = ACTIONS(43),
    [anon_sym_COLONref_COLON] = ACTIONS(45),
    [anon_sym_COLONprevious_COLON] = ACTIONS(47),
    [anon_sym_COLONurl_COLON] = ACTIONS(49),
    [anon_sym_COLONcite_COLON] = ACTIONS(51),
    [anon_sym_COLONqed_COLON] = ACTIONS(53),
    [anon_sym_COLONtable_COLON] = ACTIONS(55),
    [anon_sym_COLONassume_COLON] = ACTIONS(57),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(57),
    [anon_sym_COLONprove_COLON] = ACTIONS(57),
    [anon_sym_COLONthen_COLON] = ACTIONS(57),
    [anon_sym_COLONnew_COLON] = ACTIONS(57),
    [anon_sym_COLONlet_COLON] = ACTIONS(57),
    [anon_sym_COLONcase_COLON] = ACTIONS(57),
    [anon_sym_COLONdefine_COLON] = ACTIONS(57),
    [anon_sym_COLONwrite_COLON] = ACTIONS(57),
    [anon_sym_COLONwlog_COLON] = ACTIONS(57),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(57),
    [anon_sym_COLONclaim_COLON] = ACTIONS(57),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(57),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(57),
    [anon_sym_COLONpick_COLON] = ACTIONS(57),
    [anon_sym_COLONst_COLON] = ACTIONS(57),
    [anon_sym_COLONdraft_COLON] = ACTIONS(59),
    [anon_sym_COLONnote_COLON] = ACTIONS(59),
    [anon_sym_COLONspan_COLON] = ACTIONS(59),
    [anon_sym_COLONabstract_COLON] = ACTIONS(61),
    [anon_sym_COLONauthor_COLON] = ACTIONS(61),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(61),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(61),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(61),
    [anon_sym_COLONexample_COLON] = ACTIONS(61),
    [anon_sym_COLONitemize_COLON] = ACTIONS(61),
    [anon_sym_COLONlemma_COLON] = ACTIONS(61),
    [anon_sym_COLONfigure_COLON] = ACTIONS(61),
    [anon_sym_COLONp_COLON] = ACTIONS(61),
    [anon_sym_COLONproof_COLON] = ACTIONS(61),
    [anon_sym_COLONproposition_COLON] = ACTIONS(61),
    [anon_sym_COLONremark_COLON] = ACTIONS(61),
    [anon_sym_COLONsketch_COLON] = ACTIONS(61),
    [anon_sym_COLONstep_COLON] = ACTIONS(61),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(61),
    [anon_sym_COLONaffiliation_COLON] = ACTIONS(63),
    [anon_sym_COLONemail_COLON] = ACTIONS(63),
    [anon_sym_COLONlabel_COLON] = ACTIONS(63),
    [anon_sym_COLONname_COLON] = ACTIONS(63),
    [anon_sym_COLONreftext_COLON] = ACTIONS(63),
    [anon_sym_COLONtitle_COLON] = ACTIONS(63),
    [anon_sym_COLONgoal_COLON] = ACTIONS(63),
    [anon_sym_COLONlang_COLON] = ACTIONS(63),
    [anon_sym_COLONicon_COLON] = ACTIONS(63),
    [anon_sym_COLONnonum_COLON] = ACTIONS(65),
    [anon_sym_COLONstrong_COLON] = ACTIONS(65),
    [anon_sym_COLONemphas_COLON] = ACTIONS(65),
    [anon_sym_COLONisclaim_COLON] = ACTIONS(65),
    [anon_sym_COLONkeywords_COLON] = ACTIONS(67),
    [anon_sym_COLONmsc_COLON] = ACTIONS(67),
    [anon_sym_COLONtypes_COLON] = ACTIONS(67),
    [anon_sym_COLONdate_COLON] = ACTIONS(69),
    [anon_sym_COLONpath_COLON] = ACTIONS(69),
    [anon_sym_COLONscale_COLON] = ACTIONS(69),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(71),
  },
  [STATE(5)] = {
    [sym_block] = STATE(31),
    [sym_paragraph] = STATE(31),
    [sym_inline] = STATE(98),
    [sym_construct] = STATE(98),
    [sym_mathblock] = STATE(31),
    [sym_specialblock] = STATE(31),
    [sym_caption] = STATE(61),
    [sym_item] = STATE(61),
    [sym_specialinline] = STATE(98),
    [sym_specialconstruct] = STATE(98),
    [sym_blockmeta] = STATE(29),
    [sym_pair] = STATE(11),
    [sym_table] = STATE(62),
    [sym__paragraphcontent_no_special] = STATE(98),
    [sym_metakey_text] = STATE(407),
    [sym_metakey_bool] = STATE(16),
    [sym_metakey_list] = STATE(377),
    [sym_metakey_any] = STATE(405),
    [aux_sym_subsubsection_repeat1] = STATE(31),
    [aux_sym_blockmeta_repeat1] = STATE(11),
    [anon_sym_COLON_COLON] = ACTIONS(77),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(77),
    [anon_sym_COLONsection_COLON] = ACTIONS(77),
    [aux_sym_subsection_token1] = ACTIONS(77),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(77),
    [aux_sym_subsubsection_token1] = ACTIONS(77),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(77),
    [anon_sym_COLONappendix_COLON] = ACTIONS(77),
    [aux_sym_mathblock_token1] = ACTIONS(15),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(17),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(19),
    [aux_sym_specialblock_token1] = ACTIONS(21),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(23),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(25),
    [anon_sym_COLONcaption_COLON] = ACTIONS(27),
    [anon_sym_COLONitem_COLON] = ACTIONS(29),
    [anon_sym_COLONprev_COLON] = ACTIONS(31),
    [anon_sym_COLONprev2_COLON] = ACTIONS(31),
    [anon_sym_COLONprev3_COLON] = ACTIONS(31),
    [aux_sym_specialinline_token1] = ACTIONS(33),
    [aux_sym_specialinline_token2] = ACTIONS(35),
    [anon_sym_COLONmath_COLON] = ACTIONS(37),
    [anon_sym_COLONcode_COLON] = ACTIONS(39),
    [aux_sym_specialinline_token3] = ACTIONS(41),
    [aux_sym_specialinline_token4] = ACTIONS(43),
    [anon_sym_COLONref_COLON] = ACTIONS(45),
    [anon_sym_COLONprevious_COLON] = ACTIONS(47),
    [anon_sym_COLONurl_COLON] = ACTIONS(49),
    [anon_sym_COLONcite_COLON] = ACTIONS(51),
    [anon_sym_COLONqed_COLON] = ACTIONS(53),
    [anon_sym_COLONtable_COLON] = ACTIONS(55),
    [anon_sym_COLONassume_COLON] = ACTIONS(57),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(57),
    [anon_sym_COLONprove_COLON] = ACTIONS(57),
    [anon_sym_COLONthen_COLON] = ACTIONS(57),
    [anon_sym_COLONnew_COLON] = ACTIONS(57),
    [anon_sym_COLONlet_COLON] = ACTIONS(57),
    [anon_sym_COLONcase_COLON] = ACTIONS(57),
    [anon_sym_COLONdefine_COLON] = ACTIONS(57),
    [anon_sym_COLONwrite_COLON] = ACTIONS(57),
    [anon_sym_COLONwlog_COLON] = ACTIONS(57),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(57),
    [anon_sym_COLONclaim_COLON] = ACTIONS(57),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(57),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(57),
    [anon_sym_COLONpick_COLON] = ACTIONS(57),
    [anon_sym_COLONst_COLON] = ACTIONS(57),
    [anon_sym_COLONdraft_COLON] = ACTIONS(59),
    [anon_sym_COLONnote_COLON] = ACTIONS(59),
    [anon_sym_COLONspan_COLON] = ACTIONS(59),
    [anon_sym_COLONabstract_COLON] = ACTIONS(61),
    [anon_sym_COLONauthor_COLON] = ACTIONS(61),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(61),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(61),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(61),
    [anon_sym_COLONexample_COLON] = ACTIONS(61),
    [anon_sym_COLONitemize_COLON] = ACTIONS(61),
    [anon_sym_COLONlemma_COLON] = ACTIONS(61),
    [anon_sym_COLONfigure_COLON] = ACTIONS(61),
    [anon_sym_COLONp_COLON] = ACTIONS(61),
    [anon_sym_COLONproof_COLON] = ACTIONS(61),
    [anon_sym_COLONproposition_COLON] = ACTIONS(61),
    [anon_sym_COLONremark_COLON] = ACTIONS(61),
    [anon_sym_COLONsketch_COLON] = ACTIONS(61),
    [anon_sym_COLONstep_COLON] = ACTIONS(61),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(61),
    [anon_sym_COLONaffiliation_COLON] = ACTIONS(63),
    [anon_sym_COLONemail_COLON] = ACTIONS(63),
    [anon_sym_COLONlabel_COLON] = ACTIONS(63),
    [anon_sym_COLONname_COLON] = ACTIONS(63),
    [anon_sym_COLONreftext_COLON] = ACTIONS(63),
    [anon_sym_COLONtitle_COLON] = ACTIONS(63),
    [anon_sym_COLONgoal_COLON] = ACTIONS(63),
    [anon_sym_COLONlang_COLON] = ACTIONS(63),
    [anon_sym_COLONicon_COLON] = ACTIONS(63),
    [anon_sym_COLONnonum_COLON] = ACTIONS(65),
    [anon_sym_COLONstrong_COLON] = ACTIONS(65),
    [anon_sym_COLONemphas_COLON] = ACTIONS(65),
    [anon_sym_COLONisclaim_COLON] = ACTIONS(65),
    [anon_sym_COLONkeywords_COLON] = ACTIONS(67),
    [anon_sym_COLONmsc_COLON] = ACTIONS(67),
    [anon_sym_COLONtypes_COLON] = ACTIONS(67),
    [anon_sym_COLONdate_COLON] = ACTIONS(69),
    [anon_sym_COLONpath_COLON] = ACTIONS(69),
    [anon_sym_COLONscale_COLON] = ACTIONS(69),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(71),
  },
  [STATE(6)] = {
    [sym_block] = STATE(36),
    [sym_paragraph] = STATE(36),
    [sym_inline] = STATE(98),
    [sym_construct] = STATE(98),
    [sym_subsection] = STATE(36),
    [sym_mathblock] = STATE(36),
    [sym_specialblock] = STATE(36),
    [sym_caption] = STATE(61),
    [sym_item] = STATE(61),
    [sym_specialinline] = STATE(98),
    [sym_specialconstruct] = STATE(98),
    [sym_blockmeta] = STATE(39),
    [sym_pair] = STATE(11),
    [sym_table] = STATE(62),
    [sym__paragraphcontent_no_special] = STATE(98),
    [sym_metakey_text] = STATE(407),
    [sym_metakey_bool] = STATE(16),
    [sym_metakey_list] = STATE(377),
    [sym_metakey_any] = STATE(405),
    [aux_sym_section_repeat1] = STATE(36),
    [aux_sym_blockmeta_repeat1] = STATE(11),
    [anon_sym_COLON_COLON] = ACTIONS(79),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(79),
    [anon_sym_COLONsection_COLON] = ACTIONS(79),
    [aux_sym_subsection_token1] = ACTIONS(81),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(83),
    [anon_sym_COLONappendix_COLON] = ACTIONS(79),
    [aux_sym_mathblock_token1] = ACTIONS(15),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(17),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(19),
    [aux_sym_specialblock_token1] = ACTIONS(21),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(23),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(25),
    [anon_sym_COLONcaption_COLON] = ACTIONS(27),
    [anon_sym_COLONitem_COLON] = ACTIONS(29),
    [anon_sym_COLONprev_COLON] = ACTIONS(31),
    [anon_sym_COLONprev2_COLON] = ACTIONS(31),
    [anon_sym_COLONprev3_COLON] = ACTIONS(31),
    [aux_sym_specialinline_token1] = ACTIONS(33),
    [aux_sym_specialinline_token2] = ACTIONS(35),
    [anon_sym_COLONmath_COLON] = ACTIONS(37),
    [anon_sym_COLONcode_COLON] = ACTIONS(39),
    [aux_sym_specialinline_token3] = ACTIONS(41),
    [aux_sym_specialinline_token4] = ACTIONS(43),
    [anon_sym_COLONref_COLON] = ACTIONS(45),
    [anon_sym_COLONprevious_COLON] = ACTIONS(47),
    [anon_sym_COLONurl_COLON] = ACTIONS(49),
    [anon_sym_COLONcite_COLON] = ACTIONS(51),
    [anon_sym_COLONqed_COLON] = ACTIONS(53),
    [anon_sym_COLONtable_COLON] = ACTIONS(55),
    [anon_sym_COLONassume_COLON] = ACTIONS(57),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(57),
    [anon_sym_COLONprove_COLON] = ACTIONS(57),
    [anon_sym_COLONthen_COLON] = ACTIONS(57),
    [anon_sym_COLONnew_COLON] = ACTIONS(57),
    [anon_sym_COLONlet_COLON] = ACTIONS(57),
    [anon_sym_COLONcase_COLON] = ACTIONS(57),
    [anon_sym_COLONdefine_COLON] = ACTIONS(57),
    [anon_sym_COLONwrite_COLON] = ACTIONS(57),
    [anon_sym_COLONwlog_COLON] = ACTIONS(57),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(57),
    [anon_sym_COLONclaim_COLON] = ACTIONS(57),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(57),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(57),
    [anon_sym_COLONpick_COLON] = ACTIONS(57),
    [anon_sym_COLONst_COLON] = ACTIONS(57),
    [anon_sym_COLONdraft_COLON] = ACTIONS(59),
    [anon_sym_COLONnote_COLON] = ACTIONS(59),
    [anon_sym_COLONspan_COLON] = ACTIONS(59),
    [anon_sym_COLONabstract_COLON] = ACTIONS(61),
    [anon_sym_COLONauthor_COLON] = ACTIONS(61),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(61),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(61),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(61),
    [anon_sym_COLONexample_COLON] = ACTIONS(61),
    [anon_sym_COLONitemize_COLON] = ACTIONS(61),
    [anon_sym_COLONlemma_COLON] = ACTIONS(61),
    [anon_sym_COLONfigure_COLON] = ACTIONS(61),
    [anon_sym_COLONp_COLON] = ACTIONS(61),
    [anon_sym_COLONproof_COLON] = ACTIONS(61),
    [anon_sym_COLONproposition_COLON] = ACTIONS(61),
    [anon_sym_COLONremark_COLON] = ACTIONS(61),
    [anon_sym_COLONsketch_COLON] = ACTIONS(61),
    [anon_sym_COLONstep_COLON] = ACTIONS(61),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(61),
    [anon_sym_COLONaffiliation_COLON] = ACTIONS(63),
    [anon_sym_COLONemail_COLON] = ACTIONS(63),
    [anon_sym_COLONlabel_COLON] = ACTIONS(63),
    [anon_sym_COLONname_COLON] = ACTIONS(63),
    [anon_sym_COLONreftext_COLON] = ACTIONS(63),
    [anon_sym_COLONtitle_COLON] = ACTIONS(63),
    [anon_sym_COLONgoal_COLON] = ACTIONS(63),
    [anon_sym_COLONlang_COLON] = ACTIONS(63),
    [anon_sym_COLONicon_COLON] = ACTIONS(63),
    [anon_sym_COLONnonum_COLON] = ACTIONS(65),
    [anon_sym_COLONstrong_COLON] = ACTIONS(65),
    [anon_sym_COLONemphas_COLON] = ACTIONS(65),
    [anon_sym_COLONisclaim_COLON] = ACTIONS(65),
    [anon_sym_COLONkeywords_COLON] = ACTIONS(67),
    [anon_sym_COLONmsc_COLON] = ACTIONS(67),
    [anon_sym_COLONtypes_COLON] = ACTIONS(67),
    [anon_sym_COLONdate_COLON] = ACTIONS(69),
    [anon_sym_COLONpath_COLON] = ACTIONS(69),
    [anon_sym_COLONscale_COLON] = ACTIONS(69),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(71),
  },
  [STATE(7)] = {
    [sym_block] = STATE(37),
    [sym_paragraph] = STATE(37),
    [sym_inline] = STATE(98),
    [sym_construct] = STATE(98),
    [sym_subsection] = STATE(37),
    [sym_mathblock] = STATE(37),
    [sym_specialblock] = STATE(37),
    [sym_caption] = STATE(61),
    [sym_item] = STATE(61),
    [sym_specialinline] = STATE(98),
    [sym_specialconstruct] = STATE(98),
    [sym_blockmeta] = STATE(38),
    [sym_pair] = STATE(11),
    [sym_table] = STATE(62),
    [sym__paragraphcontent_no_special] = STATE(98),
    [sym_metakey_text] = STATE(407),
    [sym_metakey_bool] = STATE(16),
    [sym_metakey_list] = STATE(377),
    [sym_metakey_any] = STATE(405),
    [aux_sym_section_repeat1] = STATE(37),
    [aux_sym_blockmeta_repeat1] = STATE(11),
    [anon_sym_COLON_COLON] = ACTIONS(85),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(85),
    [anon_sym_COLONsection_COLON] = ACTIONS(85),
    [aux_sym_subsection_token1] = ACTIONS(81),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(83),
    [anon_sym_COLONappendix_COLON] = ACTIONS(85),
    [aux_sym_mathblock_token1] = ACTIONS(15),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(17),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(19),
    [aux_sym_specialblock_token1] = ACTIONS(21),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(23),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(25),
    [anon_sym_COLONcaption_COLON] = ACTIONS(27),
    [anon_sym_COLONitem_COLON] = ACTIONS(29),
    [anon_sym_COLONprev_COLON] = ACTIONS(31),
    [anon_sym_COLONprev2_COLON] = ACTIONS(31),
    [anon_sym_COLONprev3_COLON] = ACTIONS(31),
    [aux_sym_specialinline_token1] = ACTIONS(33),
    [aux_sym_specialinline_token2] = ACTIONS(35),
    [anon_sym_COLONmath_COLON] = ACTIONS(37),
    [anon_sym_COLONcode_COLON] = ACTIONS(39),
    [aux_sym_specialinline_token3] = ACTIONS(41),
    [aux_sym_specialinline_token4] = ACTIONS(43),
    [anon_sym_COLONref_COLON] = ACTIONS(45),
    [anon_sym_COLONprevious_COLON] = ACTIONS(47),
    [anon_sym_COLONurl_COLON] = ACTIONS(49),
    [anon_sym_COLONcite_COLON] = ACTIONS(51),
    [anon_sym_COLONqed_COLON] = ACTIONS(53),
    [anon_sym_COLONtable_COLON] = ACTIONS(55),
    [anon_sym_COLONassume_COLON] = ACTIONS(57),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(57),
    [anon_sym_COLONprove_COLON] = ACTIONS(57),
    [anon_sym_COLONthen_COLON] = ACTIONS(57),
    [anon_sym_COLONnew_COLON] = ACTIONS(57),
    [anon_sym_COLONlet_COLON] = ACTIONS(57),
    [anon_sym_COLONcase_COLON] = ACTIONS(57),
    [anon_sym_COLONdefine_COLON] = ACTIONS(57),
    [anon_sym_COLONwrite_COLON] = ACTIONS(57),
    [anon_sym_COLONwlog_COLON] = ACTIONS(57),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(57),
    [anon_sym_COLONclaim_COLON] = ACTIONS(57),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(57),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(57),
    [anon_sym_COLONpick_COLON] = ACTIONS(57),
    [anon_sym_COLONst_COLON] = ACTIONS(57),
    [anon_sym_COLONdraft_COLON] = ACTIONS(59),
    [anon_sym_COLONnote_COLON] = ACTIONS(59),
    [anon_sym_COLONspan_COLON] = ACTIONS(59),
    [anon_sym_COLONabstract_COLON] = ACTIONS(61),
    [anon_sym_COLONauthor_COLON] = ACTIONS(61),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(61),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(61),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(61),
    [anon_sym_COLONexample_COLON] = ACTIONS(61),
    [anon_sym_COLONitemize_COLON] = ACTIONS(61),
    [anon_sym_COLONlemma_COLON] = ACTIONS(61),
    [anon_sym_COLONfigure_COLON] = ACTIONS(61),
    [anon_sym_COLONp_COLON] = ACTIONS(61),
    [anon_sym_COLONproof_COLON] = ACTIONS(61),
    [anon_sym_COLONproposition_COLON] = ACTIONS(61),
    [anon_sym_COLONremark_COLON] = ACTIONS(61),
    [anon_sym_COLONsketch_COLON] = ACTIONS(61),
    [anon_sym_COLONstep_COLON] = ACTIONS(61),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(61),
    [anon_sym_COLONaffiliation_COLON] = ACTIONS(63),
    [anon_sym_COLONemail_COLON] = ACTIONS(63),
    [anon_sym_COLONlabel_COLON] = ACTIONS(63),
    [anon_sym_COLONname_COLON] = ACTIONS(63),
    [anon_sym_COLONreftext_COLON] = ACTIONS(63),
    [anon_sym_COLONtitle_COLON] = ACTIONS(63),
    [anon_sym_COLONgoal_COLON] = ACTIONS(63),
    [anon_sym_COLONlang_COLON] = ACTIONS(63),
    [anon_sym_COLONicon_COLON] = ACTIONS(63),
    [anon_sym_COLONnonum_COLON] = ACTIONS(65),
    [anon_sym_COLONstrong_COLON] = ACTIONS(65),
    [anon_sym_COLONemphas_COLON] = ACTIONS(65),
    [anon_sym_COLONisclaim_COLON] = ACTIONS(65),
    [anon_sym_COLONkeywords_COLON] = ACTIONS(67),
    [anon_sym_COLONmsc_COLON] = ACTIONS(67),
    [anon_sym_COLONtypes_COLON] = ACTIONS(67),
    [anon_sym_COLONdate_COLON] = ACTIONS(69),
    [anon_sym_COLONpath_COLON] = ACTIONS(69),
    [anon_sym_COLONscale_COLON] = ACTIONS(69),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(71),
  },
  [STATE(8)] = {
    [sym_block] = STATE(43),
    [sym_paragraph] = STATE(43),
    [sym_inline] = STATE(98),
    [sym_construct] = STATE(98),
    [sym_section] = STATE(43),
    [sym_appendix] = STATE(43),
    [sym_mathblock] = STATE(43),
    [sym_specialblock] = STATE(43),
    [sym_caption] = STATE(61),
    [sym_item] = STATE(61),
    [sym_specialinline] = STATE(98),
    [sym_specialconstruct] = STATE(98),
    [sym_blockmeta] = STATE(41),
    [sym_pair] = STATE(11),
    [sym_table] = STATE(62),
    [sym__paragraphcontent_no_special] = STATE(98),
    [sym_metakey_text] = STATE(407),
    [sym_metakey_bool] = STATE(16),
    [sym_metakey_list] = STATE(377),
    [sym_metakey_any] = STATE(405),
    [aux_sym_source_file_repeat1] = STATE(43),
    [aux_sym_blockmeta_repeat1] = STATE(11),
    [anon_sym_COLON_COLON] = ACTIONS(87),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(89),
    [anon_sym_COLONsection_COLON] = ACTIONS(91),
    [anon_sym_COLONappendix_COLON] = ACTIONS(93),
    [aux_sym_mathblock_token1] = ACTIONS(15),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(17),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(19),
    [aux_sym_specialblock_token1] = ACTIONS(21),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(23),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(25),
    [anon_sym_COLONcaption_COLON] = ACTIONS(27),
    [anon_sym_COLONitem_COLON] = ACTIONS(29),
    [anon_sym_COLONprev_COLON] = ACTIONS(31),
    [anon_sym_COLONprev2_COLON] = ACTIONS(31),
    [anon_sym_COLONprev3_COLON] = ACTIONS(31),
    [aux_sym_specialinline_token1] = ACTIONS(33),
    [aux_sym_specialinline_token2] = ACTIONS(35),
    [anon_sym_COLONmath_COLON] = ACTIONS(37),
    [anon_sym_COLONcode_COLON] = ACTIONS(39),
    [aux_sym_specialinline_token3] = ACTIONS(41),
    [aux_sym_specialinline_token4] = ACTIONS(43),
    [anon_sym_COLONref_COLON] = ACTIONS(45),
    [anon_sym_COLONprevious_COLON] = ACTIONS(47),
    [anon_sym_COLONurl_COLON] = ACTIONS(49),
    [anon_sym_COLONcite_COLON] = ACTIONS(51),
    [anon_sym_COLONqed_COLON] = ACTIONS(53),
    [anon_sym_COLONtable_COLON] = ACTIONS(55),
    [anon_sym_COLONassume_COLON] = ACTIONS(57),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(57),
    [anon_sym_COLONprove_COLON] = ACTIONS(57),
    [anon_sym_COLONthen_COLON] = ACTIONS(57),
    [anon_sym_COLONnew_COLON] = ACTIONS(57),
    [anon_sym_COLONlet_COLON] = ACTIONS(57),
    [anon_sym_COLONcase_COLON] = ACTIONS(57),
    [anon_sym_COLONdefine_COLON] = ACTIONS(57),
    [anon_sym_COLONwrite_COLON] = ACTIONS(57),
    [anon_sym_COLONwlog_COLON] = ACTIONS(57),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(57),
    [anon_sym_COLONclaim_COLON] = ACTIONS(57),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(57),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(57),
    [anon_sym_COLONpick_COLON] = ACTIONS(57),
    [anon_sym_COLONst_COLON] = ACTIONS(57),
    [anon_sym_COLONdraft_COLON] = ACTIONS(59),
    [anon_sym_COLONnote_COLON] = ACTIONS(59),
    [anon_sym_COLONspan_COLON] = ACTIONS(59),
    [anon_sym_COLONabstract_COLON] = ACTIONS(61),
    [anon_sym_COLONauthor_COLON] = ACTIONS(61),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(61),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(61),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(61),
    [anon_sym_COLONexample_COLON] = ACTIONS(61),
    [anon_sym_COLONitemize_COLON] = ACTIONS(61),
    [anon_sym_COLONlemma_COLON] = ACTIONS(61),
    [anon_sym_COLONfigure_COLON] = ACTIONS(61),
    [anon_sym_COLONp_COLON] = ACTIONS(61),
    [anon_sym_COLONproof_COLON] = ACTIONS(61),
    [anon_sym_COLONproposition_COLON] = ACTIONS(61),
    [anon_sym_COLONremark_COLON] = ACTIONS(61),
    [anon_sym_COLONsketch_COLON] = ACTIONS(61),
    [anon_sym_COLONstep_COLON] = ACTIONS(61),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(61),
    [anon_sym_COLONaffiliation_COLON] = ACTIONS(63),
    [anon_sym_COLONemail_COLON] = ACTIONS(63),
    [anon_sym_COLONlabel_COLON] = ACTIONS(63),
    [anon_sym_COLONname_COLON] = ACTIONS(63),
    [anon_sym_COLONreftext_COLON] = ACTIONS(63),
    [anon_sym_COLONtitle_COLON] = ACTIONS(63),
    [anon_sym_COLONgoal_COLON] = ACTIONS(63),
    [anon_sym_COLONlang_COLON] = ACTIONS(63),
    [anon_sym_COLONicon_COLON] = ACTIONS(63),
    [anon_sym_COLONnonum_COLON] = ACTIONS(65),
    [anon_sym_COLONstrong_COLON] = ACTIONS(65),
    [anon_sym_COLONemphas_COLON] = ACTIONS(65),
    [anon_sym_COLONisclaim_COLON] = ACTIONS(65),
    [anon_sym_COLONkeywords_COLON] = ACTIONS(67),
    [anon_sym_COLONmsc_COLON] = ACTIONS(67),
    [anon_sym_COLONtypes_COLON] = ACTIONS(67),
    [anon_sym_COLONdate_COLON] = ACTIONS(69),
    [anon_sym_COLONpath_COLON] = ACTIONS(69),
    [anon_sym_COLONscale_COLON] = ACTIONS(69),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(71),
  },
  [STATE(9)] = {
    [sym_block] = STATE(47),
    [sym_paragraph] = STATE(47),
    [sym_inline] = STATE(98),
    [sym_construct] = STATE(98),
    [sym_mathblock] = STATE(47),
    [sym_specialblock] = STATE(47),
    [sym_caption] = STATE(61),
    [sym_item] = STATE(61),
    [sym_specialinline] = STATE(98),
    [sym_specialconstruct] = STATE(98),
    [sym_blockmeta] = STATE(44),
    [sym_pair] = STATE(11),
    [sym_table] = STATE(62),
    [sym__paragraphcontent_no_special] = STATE(98),
    [sym_metakey_text] = STATE(407),
    [sym_metakey_bool] = STATE(16),
    [sym_metakey_list] = STATE(377),
    [sym_metakey_any] = STATE(405),
    [aux_sym_block_repeat1] = STATE(47),
    [aux_sym_blockmeta_repeat1] = STATE(11),
    [anon_sym_COLON_COLON] = ACTIONS(95),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_mathblock_token1] = ACTIONS(15),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(17),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(19),
    [aux_sym_specialblock_token1] = ACTIONS(21),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(23),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(25),
    [anon_sym_COLONcaption_COLON] = ACTIONS(27),
    [anon_sym_COLONitem_COLON] = ACTIONS(29),
    [anon_sym_COLONprev_COLON] = ACTIONS(31),
    [anon_sym_COLONprev2_COLON] = ACTIONS(31),
    [anon_sym_COLONprev3_COLON] = ACTIONS(31),
    [aux_sym_specialinline_token1] = ACTIONS(33),
    [aux_sym_specialinline_token2] = ACTIONS(35),
    [anon_sym_COLONmath_COLON] = ACTIONS(37),
    [anon_sym_COLONcode_COLON] = ACTIONS(39),
    [aux_sym_specialinline_token3] = ACTIONS(41),
    [aux_sym_specialinline_token4] = ACTIONS(43),
    [anon_sym_COLONref_COLON] = ACTIONS(45),
    [anon_sym_COLONprevious_COLON] = ACTIONS(47),
    [anon_sym_COLONurl_COLON] = ACTIONS(49),
    [anon_sym_COLONcite_COLON] = ACTIONS(51),
    [anon_sym_COLONqed_COLON] = ACTIONS(53),
    [anon_sym_COLONtable_COLON] = ACTIONS(55),
    [anon_sym_COLONassume_COLON] = ACTIONS(57),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(57),
    [anon_sym_COLONprove_COLON] = ACTIONS(57),
    [anon_sym_COLONthen_COLON] = ACTIONS(57),
    [anon_sym_COLONnew_COLON] = ACTIONS(57),
    [anon_sym_COLONlet_COLON] = ACTIONS(57),
    [anon_sym_COLONcase_COLON] = ACTIONS(57),
    [anon_sym_COLONdefine_COLON] = ACTIONS(57),
    [anon_sym_COLONwrite_COLON] = ACTIONS(57),
    [anon_sym_COLONwlog_COLON] = ACTIONS(57),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(57),
    [anon_sym_COLONclaim_COLON] = ACTIONS(57),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(57),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(57),
    [anon_sym_COLONpick_COLON] = ACTIONS(57),
    [anon_sym_COLONst_COLON] = ACTIONS(57),
    [anon_sym_COLONdraft_COLON] = ACTIONS(59),
    [anon_sym_COLONnote_COLON] = ACTIONS(59),
    [anon_sym_COLONspan_COLON] = ACTIONS(59),
    [anon_sym_COLONabstract_COLON] = ACTIONS(61),
    [anon_sym_COLONauthor_COLON] = ACTIONS(61),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(61),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(61),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(61),
    [anon_sym_COLONexample_COLON] = ACTIONS(61),
    [anon_sym_COLONitemize_COLON] = ACTIONS(61),
    [anon_sym_COLONlemma_COLON] = ACTIONS(61),
    [anon_sym_COLONfigure_COLON] = ACTIONS(61),
    [anon_sym_COLONp_COLON] = ACTIONS(61),
    [anon_sym_COLONproof_COLON] = ACTIONS(61),
    [anon_sym_COLONproposition_COLON] = ACTIONS(61),
    [anon_sym_COLONremark_COLON] = ACTIONS(61),
    [anon_sym_COLONsketch_COLON] = ACTIONS(61),
    [anon_sym_COLONstep_COLON] = ACTIONS(61),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(61),
    [anon_sym_COLONaffiliation_COLON] = ACTIONS(63),
    [anon_sym_COLONemail_COLON] = ACTIONS(63),
    [anon_sym_COLONlabel_COLON] = ACTIONS(63),
    [anon_sym_COLONname_COLON] = ACTIONS(63),
    [anon_sym_COLONreftext_COLON] = ACTIONS(63),
    [anon_sym_COLONtitle_COLON] = ACTIONS(63),
    [anon_sym_COLONgoal_COLON] = ACTIONS(63),
    [anon_sym_COLONlang_COLON] = ACTIONS(63),
    [anon_sym_COLONicon_COLON] = ACTIONS(63),
    [anon_sym_COLONnonum_COLON] = ACTIONS(65),
    [anon_sym_COLONstrong_COLON] = ACTIONS(65),
    [anon_sym_COLONemphas_COLON] = ACTIONS(65),
    [anon_sym_COLONisclaim_COLON] = ACTIONS(65),
    [anon_sym_COLONkeywords_COLON] = ACTIONS(67),
    [anon_sym_COLONmsc_COLON] = ACTIONS(67),
    [anon_sym_COLONtypes_COLON] = ACTIONS(67),
    [anon_sym_COLONdate_COLON] = ACTIONS(69),
    [anon_sym_COLONpath_COLON] = ACTIONS(69),
    [anon_sym_COLONscale_COLON] = ACTIONS(69),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(71),
  },
  [STATE(10)] = {
    [sym_pair] = STATE(10),
    [sym_metakey_text] = STATE(407),
    [sym_metakey_bool] = STATE(16),
    [sym_metakey_list] = STATE(377),
    [sym_metakey_any] = STATE(405),
    [aux_sym_blockmeta_repeat1] = STATE(10),
    [anon_sym_COLON_COLON] = ACTIONS(97),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(97),
    [aux_sym_section_token1] = ACTIONS(97),
    [anon_sym_COLONsection_COLON] = ACTIONS(97),
    [aux_sym_subsection_token1] = ACTIONS(97),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(97),
    [aux_sym_subsubsection_token1] = ACTIONS(97),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(97),
    [anon_sym_COLONappendix_COLON] = ACTIONS(97),
    [aux_sym_mathblock_token1] = ACTIONS(97),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(97),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(97),
    [anon_sym_COLONtoc_COLON] = ACTIONS(97),
    [aux_sym_specialblock_token1] = ACTIONS(97),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(97),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(97),
    [anon_sym_COLONcaption_COLON] = ACTIONS(97),
    [anon_sym_COLONitem_COLON] = ACTIONS(97),
    [anon_sym_COLONprev_COLON] = ACTIONS(97),
    [anon_sym_COLONprev2_COLON] = ACTIONS(97),
    [anon_sym_COLONprev3_COLON] = ACTIONS(97),
    [aux_sym_specialinline_token1] = ACTIONS(99),
    [aux_sym_specialinline_token2] = ACTIONS(99),
    [anon_sym_COLONmath_COLON] = ACTIONS(97),
    [anon_sym_COLONcode_COLON] = ACTIONS(97),
    [aux_sym_specialinline_token3] = ACTIONS(97),
    [aux_sym_specialinline_token4] = ACTIONS(97),
    [anon_sym_COLONref_COLON] = ACTIONS(97),
    [anon_sym_COLONprevious_COLON] = ACTIONS(97),
    [anon_sym_COLONurl_COLON] = ACTIONS(97),
    [anon_sym_COLONcite_COLON] = ACTIONS(97),
    [anon_sym_COLONqed_COLON] = ACTIONS(97),
    [anon_sym_COLONtable_COLON] = ACTIONS(97),
    [anon_sym_COLONassume_COLON] = ACTIONS(97),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(97),
    [anon_sym_COLONprove_COLON] = ACTIONS(97),
    [anon_sym_COLONthen_COLON] = ACTIONS(97),
    [anon_sym_COLONnew_COLON] = ACTIONS(97),
    [anon_sym_COLONlet_COLON] = ACTIONS(97),
    [anon_sym_COLONcase_COLON] = ACTIONS(97),
    [anon_sym_COLONdefine_COLON] = ACTIONS(97),
    [anon_sym_COLONwrite_COLON] = ACTIONS(97),
    [anon_sym_COLONwlog_COLON] = ACTIONS(97),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(97),
    [anon_sym_COLONclaim_COLON] = ACTIONS(97),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(97),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(97),
    [anon_sym_COLONpick_COLON] = ACTIONS(97),
    [anon_sym_COLONst_COLON] = ACTIONS(97),
    [anon_sym_COLONdraft_COLON] = ACTIONS(97),
    [anon_sym_COLONnote_COLON] = ACTIONS(97),
    [anon_sym_COLONspan_COLON] = ACTIONS(97),
    [anon_sym_COLONabstract_COLON] = ACTIONS(97),
    [anon_sym_COLONauthor_COLON] = ACTIONS(97),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(97),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(97),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(97),
    [anon_sym_COLONexample_COLON] = ACTIONS(97),
    [anon_sym_COLONitemize_COLON] = ACTIONS(97),
    [anon_sym_COLONlemma_COLON] = ACTIONS(97),
    [anon_sym_COLONfigure_COLON] = ACTIONS(97),
    [anon_sym_COLONp_COLON] = ACTIONS(97),
    [anon_sym_COLONproof_COLON] = ACTIONS(97),
    [anon_sym_COLONproposition_COLON] = ACTIONS(97),
    [anon_sym_COLONremark_COLON] = ACTIONS(97),
    [anon_sym_COLONsketch_COLON] = ACTIONS(97),
    [anon_sym_COLONstep_COLON] = ACTIONS(97),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(97),
    [anon_sym_COLONaffiliation_COLON] = ACTIONS(101),
    [anon_sym_COLONemail_COLON] = ACTIONS(101),
    [anon_sym_COLONlabel_COLON] = ACTIONS(101),
    [anon_sym_COLONname_COLON] = ACTIONS(101),
    [anon_sym_COLONreftext_COLON] = ACTIONS(101),
    [anon_sym_COLONtitle_COLON] = ACTIONS(101),
    [anon_sym_COLONgoal_COLON] = ACTIONS(101),
    [anon_sym_COLONlang_COLON] = ACTIONS(101),
    [anon_sym_COLONicon_COLON] = ACTIONS(101),
    [anon_sym_COLONnonum_COLON] = ACTIONS(104),
    [anon_sym_COLONstrong_COLON] = ACTIONS(104),
    [anon_sym_COLONemphas_COLON] = ACTIONS(104),
    [anon_sym_COLONisclaim_COLON] = ACTIONS(104),
    [anon_sym_COLONkeywords_COLON] = ACTIONS(107),
    [anon_sym_COLONmsc_COLON] = ACTIONS(107),
    [anon_sym_COLONtypes_COLON] = ACTIONS(107),
    [anon_sym_COLONdate_COLON] = ACTIONS(110),
    [anon_sym_COLONpath_COLON] = ACTIONS(110),
    [anon_sym_COLONscale_COLON] = ACTIONS(110),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(97),
  },
  [STATE(11)] = {
    [sym_pair] = STATE(10),
    [sym_metakey_text] = STATE(407),
    [sym_metakey_bool] = STATE(16),
    [sym_metakey_list] = STATE(377),
    [sym_metakey_any] = STATE(405),
    [aux_sym_blockmeta_repeat1] = STATE(10),
    [anon_sym_COLON_COLON] = ACTIONS(113),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(113),
    [aux_sym_section_token1] = ACTIONS(113),
    [anon_sym_COLONsection_COLON] = ACTIONS(113),
    [aux_sym_subsection_token1] = ACTIONS(113),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(113),
    [aux_sym_subsubsection_token1] = ACTIONS(113),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(113),
    [anon_sym_COLONappendix_COLON] = ACTIONS(113),
    [aux_sym_mathblock_token1] = ACTIONS(113),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(113),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(113),
    [anon_sym_COLONtoc_COLON] = ACTIONS(113),
    [aux_sym_specialblock_token1] = ACTIONS(113),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(113),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(113),
    [anon_sym_COLONcaption_COLON] = ACTIONS(113),
    [anon_sym_COLONitem_COLON] = ACTIONS(113),
    [anon_sym_COLONprev_COLON] = ACTIONS(113),
    [anon_sym_COLONprev2_COLON] = ACTIONS(113),
    [anon_sym_COLONprev3_COLON] = ACTIONS(113),
    [aux_sym_specialinline_token1] = ACTIONS(115),
    [aux_sym_specialinline_token2] = ACTIONS(115),
    [anon_sym_COLONmath_COLON] = ACTIONS(113),
    [anon_sym_COLONcode_COLON] = ACTIONS(113),
    [aux_sym_specialinline_token3] = ACTIONS(113),
    [aux_sym_specialinline_token4] = ACTIONS(113),
    [anon_sym_COLONref_COLON] = ACTIONS(113),
    [anon_sym_COLONprevious_COLON] = ACTIONS(113),
    [anon_sym_COLONurl_COLON] = ACTIONS(113),
    [anon_sym_COLONcite_COLON] = ACTIONS(113),
    [anon_sym_COLONqed_COLON] = ACTIONS(113),
    [anon_sym_COLONtable_COLON] = ACTIONS(113),
    [anon_sym_COLONassume_COLON] = ACTIONS(113),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(113),
    [anon_sym_COLONprove_COLON] = ACTIONS(113),
    [anon_sym_COLONthen_COLON] = ACTIONS(113),
    [anon_sym_COLONnew_COLON] = ACTIONS(113),
    [anon_sym_COLONlet_COLON] = ACTIONS(113),
    [anon_sym_COLONcase_COLON] = ACTIONS(113),
    [anon_sym_COLONdefine_COLON] = ACTIONS(113),
    [anon_sym_COLONwrite_COLON] = ACTIONS(113),
    [anon_sym_COLONwlog_COLON] = ACTIONS(113),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(113),
    [anon_sym_COLONclaim_COLON] = ACTIONS(113),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(113),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(113),
    [anon_sym_COLONpick_COLON] = ACTIONS(113),
    [anon_sym_COLONst_COLON] = ACTIONS(113),
    [anon_sym_COLONdraft_COLON] = ACTIONS(113),
    [anon_sym_COLONnote_COLON] = ACTIONS(113),
    [anon_sym_COLONspan_COLON] = ACTIONS(113),
    [anon_sym_COLONabstract_COLON] = ACTIONS(113),
    [anon_sym_COLONauthor_COLON] = ACTIONS(113),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(113),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(113),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(113),
    [anon_sym_COLONexample_COLON] = ACTIONS(113),
    [anon_sym_COLONitemize_COLON] = ACTIONS(113),
    [anon_sym_COLONlemma_COLON] = ACTIONS(113),
    [anon_sym_COLONfigure_COLON] = ACTIONS(113),
    [anon_sym_COLONp_COLON] = ACTIONS(113),
    [anon_sym_COLONproof_COLON] = ACTIONS(113),
    [anon_sym_COLONproposition_COLON] = ACTIONS(113),
    [anon_sym_COLONremark_COLON] = ACTIONS(113),
    [anon_sym_COLONsketch_COLON] = ACTIONS(113),
    [anon_sym_COLONstep_COLON] = ACTIONS(113),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(113),
    [anon_sym_COLONaffiliation_COLON] = ACTIONS(63),
    [anon_sym_COLONemail_COLON] = ACTIONS(63),
    [anon_sym_COLONlabel_COLON] = ACTIONS(63),
    [anon_sym_COLONname_COLON] = ACTIONS(63),
    [anon_sym_COLONreftext_COLON] = ACTIONS(63),
    [anon_sym_COLONtitle_COLON] = ACTIONS(63),
    [anon_sym_COLONgoal_COLON] = ACTIONS(63),
    [anon_sym_COLONlang_COLON] = ACTIONS(63),
    [anon_sym_COLONicon_COLON] = ACTIONS(63),
    [anon_sym_COLONnonum_COLON] = ACTIONS(65),
    [anon_sym_COLONstrong_COLON] = ACTIONS(65),
    [anon_sym_COLONemphas_COLON] = ACTIONS(65),
    [anon_sym_COLONisclaim_COLON] = ACTIONS(65),
    [anon_sym_COLONkeywords_COLON] = ACTIONS(67),
    [anon_sym_COLONmsc_COLON] = ACTIONS(67),
    [anon_sym_COLONtypes_COLON] = ACTIONS(67),
    [anon_sym_COLONdate_COLON] = ACTIONS(69),
    [anon_sym_COLONpath_COLON] = ACTIONS(69),
    [anon_sym_COLONscale_COLON] = ACTIONS(69),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(113),
  },
  [STATE(12)] = {
    [anon_sym_COLON_COLON] = ACTIONS(117),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(117),
    [aux_sym_section_token1] = ACTIONS(117),
    [anon_sym_COLONsection_COLON] = ACTIONS(117),
    [aux_sym_subsection_token1] = ACTIONS(117),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(117),
    [aux_sym_subsubsection_token1] = ACTIONS(117),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(117),
    [anon_sym_COLONappendix_COLON] = ACTIONS(117),
    [aux_sym_mathblock_token1] = ACTIONS(117),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(117),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(117),
    [anon_sym_COLONtoc_COLON] = ACTIONS(117),
    [aux_sym_specialblock_token1] = ACTIONS(117),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(117),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(117),
    [anon_sym_COLONcaption_COLON] = ACTIONS(117),
    [anon_sym_COLONitem_COLON] = ACTIONS(117),
    [anon_sym_COLONprev_COLON] = ACTIONS(117),
    [anon_sym_COLONprev2_COLON] = ACTIONS(117),
    [anon_sym_COLONprev3_COLON] = ACTIONS(117),
    [aux_sym_specialinline_token1] = ACTIONS(119),
    [aux_sym_specialinline_token2] = ACTIONS(119),
    [anon_sym_COLONmath_COLON] = ACTIONS(117),
    [anon_sym_COLONcode_COLON] = ACTIONS(117),
    [aux_sym_specialinline_token3] = ACTIONS(117),
    [aux_sym_specialinline_token4] = ACTIONS(117),
    [anon_sym_COLONref_COLON] = ACTIONS(117),
    [anon_sym_COLONprevious_COLON] = ACTIONS(117),
    [anon_sym_COLONurl_COLON] = ACTIONS(117),
    [anon_sym_COLONcite_COLON] = ACTIONS(117),
    [anon_sym_COLONqed_COLON] = ACTIONS(117),
    [anon_sym_COLONtable_COLON] = ACTIONS(117),
    [anon_sym_COLONassume_COLON] = ACTIONS(117),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(117),
    [anon_sym_COLONprove_COLON] = ACTIONS(117),
    [anon_sym_COLONthen_COLON] = ACTIONS(117),
    [anon_sym_COLONnew_COLON] = ACTIONS(117),
    [anon_sym_COLONlet_COLON] = ACTIONS(117),
    [anon_sym_COLONcase_COLON] = ACTIONS(117),
    [anon_sym_COLONdefine_COLON] = ACTIONS(117),
    [anon_sym_COLONwrite_COLON] = ACTIONS(117),
    [anon_sym_COLONwlog_COLON] = ACTIONS(117),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(117),
    [anon_sym_COLONclaim_COLON] = ACTIONS(117),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(117),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(117),
    [anon_sym_COLONpick_COLON] = ACTIONS(117),
    [anon_sym_COLONst_COLON] = ACTIONS(117),
    [anon_sym_COLONdraft_COLON] = ACTIONS(117),
    [anon_sym_COLONnote_COLON] = ACTIONS(117),
    [anon_sym_COLONspan_COLON] = ACTIONS(117),
    [anon_sym_COLONabstract_COLON] = ACTIONS(117),
    [anon_sym_COLONauthor_COLON] = ACTIONS(117),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(117),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(117),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(117),
    [anon_sym_COLONexample_COLON] = ACTIONS(117),
    [anon_sym_COLONitemize_COLON] = ACTIONS(117),
    [anon_sym_COLONlemma_COLON] = ACTIONS(117),
    [anon_sym_COLONfigure_COLON] = ACTIONS(117),
    [anon_sym_COLONp_COLON] = ACTIONS(117),
    [anon_sym_COLONproof_COLON] = ACTIONS(117),
    [anon_sym_COLONproposition_COLON] = ACTIONS(117),
    [anon_sym_COLONremark_COLON] = ACTIONS(117),
    [anon_sym_COLONsketch_COLON] = ACTIONS(117),
    [anon_sym_COLONstep_COLON] = ACTIONS(117),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(117),
    [anon_sym_COLONaffiliation_COLON] = ACTIONS(117),
    [anon_sym_COLONemail_COLON] = ACTIONS(117),
    [anon_sym_COLONlabel_COLON] = ACTIONS(117),
    [anon_sym_COLONname_COLON] = ACTIONS(117),
    [anon_sym_COLONreftext_COLON] = ACTIONS(117),
    [anon_sym_COLONtitle_COLON] = ACTIONS(117),
    [anon_sym_COLONgoal_COLON] = ACTIONS(117),
    [anon_sym_COLONlang_COLON] = ACTIONS(117),
    [anon_sym_COLONicon_COLON] = ACTIONS(117),
    [anon_sym_COLONnonum_COLON] = ACTIONS(117),
    [anon_sym_COLONstrong_COLON] = ACTIONS(117),
    [anon_sym_COLONemphas_COLON] = ACTIONS(117),
    [anon_sym_COLONisclaim_COLON] = ACTIONS(117),
    [anon_sym_COLONkeywords_COLON] = ACTIONS(117),
    [anon_sym_COLONmsc_COLON] = ACTIONS(117),
    [anon_sym_COLONtypes_COLON] = ACTIONS(117),
    [anon_sym_COLONdate_COLON] = ACTIONS(117),
    [anon_sym_COLONpath_COLON] = ACTIONS(117),
    [anon_sym_COLONscale_COLON] = ACTIONS(117),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(117),
  },
  [STATE(13)] = {
    [anon_sym_COLON_COLON] = ACTIONS(121),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(121),
    [aux_sym_section_token1] = ACTIONS(121),
    [anon_sym_COLONsection_COLON] = ACTIONS(121),
    [aux_sym_subsection_token1] = ACTIONS(121),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(121),
    [aux_sym_subsubsection_token1] = ACTIONS(121),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(121),
    [anon_sym_COLONappendix_COLON] = ACTIONS(121),
    [aux_sym_mathblock_token1] = ACTIONS(121),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(121),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(121),
    [anon_sym_COLONtoc_COLON] = ACTIONS(121),
    [aux_sym_specialblock_token1] = ACTIONS(121),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(121),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(121),
    [anon_sym_COLONcaption_COLON] = ACTIONS(121),
    [anon_sym_COLONitem_COLON] = ACTIONS(121),
    [anon_sym_COLONprev_COLON] = ACTIONS(121),
    [anon_sym_COLONprev2_COLON] = ACTIONS(121),
    [anon_sym_COLONprev3_COLON] = ACTIONS(121),
    [aux_sym_specialinline_token1] = ACTIONS(123),
    [aux_sym_specialinline_token2] = ACTIONS(123),
    [anon_sym_COLONmath_COLON] = ACTIONS(121),
    [anon_sym_COLONcode_COLON] = ACTIONS(121),
    [aux_sym_specialinline_token3] = ACTIONS(121),
    [aux_sym_specialinline_token4] = ACTIONS(121),
    [anon_sym_COLONref_COLON] = ACTIONS(121),
    [anon_sym_COLONprevious_COLON] = ACTIONS(121),
    [anon_sym_COLONurl_COLON] = ACTIONS(121),
    [anon_sym_COLONcite_COLON] = ACTIONS(121),
    [anon_sym_COLONqed_COLON] = ACTIONS(121),
    [anon_sym_COLONtable_COLON] = ACTIONS(121),
    [anon_sym_COLONassume_COLON] = ACTIONS(121),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(121),
    [anon_sym_COLONprove_COLON] = ACTIONS(121),
    [anon_sym_COLONthen_COLON] = ACTIONS(121),
    [anon_sym_COLONnew_COLON] = ACTIONS(121),
    [anon_sym_COLONlet_COLON] = ACTIONS(121),
    [anon_sym_COLONcase_COLON] = ACTIONS(121),
    [anon_sym_COLONdefine_COLON] = ACTIONS(121),
    [anon_sym_COLONwrite_COLON] = ACTIONS(121),
    [anon_sym_COLONwlog_COLON] = ACTIONS(121),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(121),
    [anon_sym_COLONclaim_COLON] = ACTIONS(121),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(121),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(121),
    [anon_sym_COLONpick_COLON] = ACTIONS(121),
    [anon_sym_COLONst_COLON] = ACTIONS(121),
    [anon_sym_COLONdraft_COLON] = ACTIONS(121),
    [anon_sym_COLONnote_COLON] = ACTIONS(121),
    [anon_sym_COLONspan_COLON] = ACTIONS(121),
    [anon_sym_COLONabstract_COLON] = ACTIONS(121),
    [anon_sym_COLONauthor_COLON] = ACTIONS(121),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(121),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(121),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(121),
    [anon_sym_COLONexample_COLON] = ACTIONS(121),
    [anon_sym_COLONitemize_COLON] = ACTIONS(121),
    [anon_sym_COLONlemma_COLON] = ACTIONS(121),
    [anon_sym_COLONfigure_COLON] = ACTIONS(121),
    [anon_sym_COLONp_COLON] = ACTIONS(121),
    [anon_sym_COLONproof_COLON] = ACTIONS(121),
    [anon_sym_COLONproposition_COLON] = ACTIONS(121),
    [anon_sym_COLONremark_COLON] = ACTIONS(121),
    [anon_sym_COLONsketch_COLON] = ACTIONS(121),
    [anon_sym_COLONstep_COLON] = ACTIONS(121),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(121),
    [anon_sym_COLONaffiliation_COLON] = ACTIONS(121),
    [anon_sym_COLONemail_COLON] = ACTIONS(121),
    [anon_sym_COLONlabel_COLON] = ACTIONS(121),
    [anon_sym_COLONname_COLON] = ACTIONS(121),
    [anon_sym_COLONreftext_COLON] = ACTIONS(121),
    [anon_sym_COLONtitle_COLON] = ACTIONS(121),
    [anon_sym_COLONgoal_COLON] = ACTIONS(121),
    [anon_sym_COLONlang_COLON] = ACTIONS(121),
    [anon_sym_COLONicon_COLON] = ACTIONS(121),
    [anon_sym_COLONnonum_COLON] = ACTIONS(121),
    [anon_sym_COLONstrong_COLON] = ACTIONS(121),
    [anon_sym_COLONemphas_COLON] = ACTIONS(121),
    [anon_sym_COLONisclaim_COLON] = ACTIONS(121),
    [anon_sym_COLONkeywords_COLON] = ACTIONS(121),
    [anon_sym_COLONmsc_COLON] = ACTIONS(121),
    [anon_sym_COLONtypes_COLON] = ACTIONS(121),
    [anon_sym_COLONdate_COLON] = ACTIONS(121),
    [anon_sym_COLONpath_COLON] = ACTIONS(121),
    [anon_sym_COLONscale_COLON] = ACTIONS(121),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(121),
  },
  [STATE(14)] = {
    [anon_sym_COLON_COLON] = ACTIONS(125),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(125),
    [aux_sym_section_token1] = ACTIONS(125),
    [anon_sym_COLONsection_COLON] = ACTIONS(125),
    [aux_sym_subsection_token1] = ACTIONS(125),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(125),
    [aux_sym_subsubsection_token1] = ACTIONS(125),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(125),
    [anon_sym_COLONappendix_COLON] = ACTIONS(125),
    [aux_sym_mathblock_token1] = ACTIONS(125),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(125),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(125),
    [anon_sym_COLONtoc_COLON] = ACTIONS(125),
    [aux_sym_specialblock_token1] = ACTIONS(125),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(125),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(125),
    [anon_sym_COLONcaption_COLON] = ACTIONS(125),
    [anon_sym_COLONitem_COLON] = ACTIONS(125),
    [anon_sym_COLONprev_COLON] = ACTIONS(125),
    [anon_sym_COLONprev2_COLON] = ACTIONS(125),
    [anon_sym_COLONprev3_COLON] = ACTIONS(125),
    [aux_sym_specialinline_token1] = ACTIONS(127),
    [aux_sym_specialinline_token2] = ACTIONS(127),
    [anon_sym_COLONmath_COLON] = ACTIONS(125),
    [anon_sym_COLONcode_COLON] = ACTIONS(125),
    [aux_sym_specialinline_token3] = ACTIONS(125),
    [aux_sym_specialinline_token4] = ACTIONS(125),
    [anon_sym_COLONref_COLON] = ACTIONS(125),
    [anon_sym_COLONprevious_COLON] = ACTIONS(125),
    [anon_sym_COLONurl_COLON] = ACTIONS(125),
    [anon_sym_COLONcite_COLON] = ACTIONS(125),
    [anon_sym_COLONqed_COLON] = ACTIONS(125),
    [anon_sym_COLONtable_COLON] = ACTIONS(125),
    [anon_sym_COLONassume_COLON] = ACTIONS(125),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(125),
    [anon_sym_COLONprove_COLON] = ACTIONS(125),
    [anon_sym_COLONthen_COLON] = ACTIONS(125),
    [anon_sym_COLONnew_COLON] = ACTIONS(125),
    [anon_sym_COLONlet_COLON] = ACTIONS(125),
    [anon_sym_COLONcase_COLON] = ACTIONS(125),
    [anon_sym_COLONdefine_COLON] = ACTIONS(125),
    [anon_sym_COLONwrite_COLON] = ACTIONS(125),
    [anon_sym_COLONwlog_COLON] = ACTIONS(125),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(125),
    [anon_sym_COLONclaim_COLON] = ACTIONS(125),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(125),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(125),
    [anon_sym_COLONpick_COLON] = ACTIONS(125),
    [anon_sym_COLONst_COLON] = ACTIONS(125),
    [anon_sym_COLONdraft_COLON] = ACTIONS(125),
    [anon_sym_COLONnote_COLON] = ACTIONS(125),
    [anon_sym_COLONspan_COLON] = ACTIONS(125),
    [anon_sym_COLONabstract_COLON] = ACTIONS(125),
    [anon_sym_COLONauthor_COLON] = ACTIONS(125),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(125),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(125),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(125),
    [anon_sym_COLONexample_COLON] = ACTIONS(125),
    [anon_sym_COLONitemize_COLON] = ACTIONS(125),
    [anon_sym_COLONlemma_COLON] = ACTIONS(125),
    [anon_sym_COLONfigure_COLON] = ACTIONS(125),
    [anon_sym_COLONp_COLON] = ACTIONS(125),
    [anon_sym_COLONproof_COLON] = ACTIONS(125),
    [anon_sym_COLONproposition_COLON] = ACTIONS(125),
    [anon_sym_COLONremark_COLON] = ACTIONS(125),
    [anon_sym_COLONsketch_COLON] = ACTIONS(125),
    [anon_sym_COLONstep_COLON] = ACTIONS(125),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(125),
    [anon_sym_COLONaffiliation_COLON] = ACTIONS(125),
    [anon_sym_COLONemail_COLON] = ACTIONS(125),
    [anon_sym_COLONlabel_COLON] = ACTIONS(125),
    [anon_sym_COLONname_COLON] = ACTIONS(125),
    [anon_sym_COLONreftext_COLON] = ACTIONS(125),
    [anon_sym_COLONtitle_COLON] = ACTIONS(125),
    [anon_sym_COLONgoal_COLON] = ACTIONS(125),
    [anon_sym_COLONlang_COLON] = ACTIONS(125),
    [anon_sym_COLONicon_COLON] = ACTIONS(125),
    [anon_sym_COLONnonum_COLON] = ACTIONS(125),
    [anon_sym_COLONstrong_COLON] = ACTIONS(125),
    [anon_sym_COLONemphas_COLON] = ACTIONS(125),
    [anon_sym_COLONisclaim_COLON] = ACTIONS(125),
    [anon_sym_COLONkeywords_COLON] = ACTIONS(125),
    [anon_sym_COLONmsc_COLON] = ACTIONS(125),
    [anon_sym_COLONtypes_COLON] = ACTIONS(125),
    [anon_sym_COLONdate_COLON] = ACTIONS(125),
    [anon_sym_COLONpath_COLON] = ACTIONS(125),
    [anon_sym_COLONscale_COLON] = ACTIONS(125),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(125),
  },
  [STATE(15)] = {
    [anon_sym_COLON_COLON] = ACTIONS(129),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(129),
    [aux_sym_section_token1] = ACTIONS(129),
    [anon_sym_COLONsection_COLON] = ACTIONS(129),
    [aux_sym_subsection_token1] = ACTIONS(129),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(129),
    [aux_sym_subsubsection_token1] = ACTIONS(129),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(129),
    [anon_sym_COLONappendix_COLON] = ACTIONS(129),
    [aux_sym_mathblock_token1] = ACTIONS(129),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(129),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(129),
    [anon_sym_COLONtoc_COLON] = ACTIONS(129),
    [aux_sym_specialblock_token1] = ACTIONS(129),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(129),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(129),
    [anon_sym_COLONcaption_COLON] = ACTIONS(129),
    [anon_sym_COLONitem_COLON] = ACTIONS(129),
    [anon_sym_COLONprev_COLON] = ACTIONS(129),
    [anon_sym_COLONprev2_COLON] = ACTIONS(129),
    [anon_sym_COLONprev3_COLON] = ACTIONS(129),
    [aux_sym_specialinline_token1] = ACTIONS(131),
    [aux_sym_specialinline_token2] = ACTIONS(131),
    [anon_sym_COLONmath_COLON] = ACTIONS(129),
    [anon_sym_COLONcode_COLON] = ACTIONS(129),
    [aux_sym_specialinline_token3] = ACTIONS(129),
    [aux_sym_specialinline_token4] = ACTIONS(129),
    [anon_sym_COLONref_COLON] = ACTIONS(129),
    [anon_sym_COLONprevious_COLON] = ACTIONS(129),
    [anon_sym_COLONurl_COLON] = ACTIONS(129),
    [anon_sym_COLONcite_COLON] = ACTIONS(129),
    [anon_sym_COLONqed_COLON] = ACTIONS(129),
    [anon_sym_COLONtable_COLON] = ACTIONS(129),
    [anon_sym_COLONassume_COLON] = ACTIONS(129),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(129),
    [anon_sym_COLONprove_COLON] = ACTIONS(129),
    [anon_sym_COLONthen_COLON] = ACTIONS(129),
    [anon_sym_COLONnew_COLON] = ACTIONS(129),
    [anon_sym_COLONlet_COLON] = ACTIONS(129),
    [anon_sym_COLONcase_COLON] = ACTIONS(129),
    [anon_sym_COLONdefine_COLON] = ACTIONS(129),
    [anon_sym_COLONwrite_COLON] = ACTIONS(129),
    [anon_sym_COLONwlog_COLON] = ACTIONS(129),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(129),
    [anon_sym_COLONclaim_COLON] = ACTIONS(129),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(129),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(129),
    [anon_sym_COLONpick_COLON] = ACTIONS(129),
    [anon_sym_COLONst_COLON] = ACTIONS(129),
    [anon_sym_COLONdraft_COLON] = ACTIONS(129),
    [anon_sym_COLONnote_COLON] = ACTIONS(129),
    [anon_sym_COLONspan_COLON] = ACTIONS(129),
    [anon_sym_COLONabstract_COLON] = ACTIONS(129),
    [anon_sym_COLONauthor_COLON] = ACTIONS(129),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(129),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(129),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(129),
    [anon_sym_COLONexample_COLON] = ACTIONS(129),
    [anon_sym_COLONitemize_COLON] = ACTIONS(129),
    [anon_sym_COLONlemma_COLON] = ACTIONS(129),
    [anon_sym_COLONfigure_COLON] = ACTIONS(129),
    [anon_sym_COLONp_COLON] = ACTIONS(129),
    [anon_sym_COLONproof_COLON] = ACTIONS(129),
    [anon_sym_COLONproposition_COLON] = ACTIONS(129),
    [anon_sym_COLONremark_COLON] = ACTIONS(129),
    [anon_sym_COLONsketch_COLON] = ACTIONS(129),
    [anon_sym_COLONstep_COLON] = ACTIONS(129),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(129),
    [anon_sym_COLONaffiliation_COLON] = ACTIONS(129),
    [anon_sym_COLONemail_COLON] = ACTIONS(129),
    [anon_sym_COLONlabel_COLON] = ACTIONS(129),
    [anon_sym_COLONname_COLON] = ACTIONS(129),
    [anon_sym_COLONreftext_COLON] = ACTIONS(129),
    [anon_sym_COLONtitle_COLON] = ACTIONS(129),
    [anon_sym_COLONgoal_COLON] = ACTIONS(129),
    [anon_sym_COLONlang_COLON] = ACTIONS(129),
    [anon_sym_COLONicon_COLON] = ACTIONS(129),
    [anon_sym_COLONnonum_COLON] = ACTIONS(129),
    [anon_sym_COLONstrong_COLON] = ACTIONS(129),
    [anon_sym_COLONemphas_COLON] = ACTIONS(129),
    [anon_sym_COLONisclaim_COLON] = ACTIONS(129),
    [anon_sym_COLONkeywords_COLON] = ACTIONS(129),
    [anon_sym_COLONmsc_COLON] = ACTIONS(129),
    [anon_sym_COLONtypes_COLON] = ACTIONS(129),
    [anon_sym_COLONdate_COLON] = ACTIONS(129),
    [anon_sym_COLONpath_COLON] = ACTIONS(129),
    [anon_sym_COLONscale_COLON] = ACTIONS(129),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(129),
  },
  [STATE(16)] = {
    [anon_sym_COLON_COLON] = ACTIONS(133),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(133),
    [aux_sym_section_token1] = ACTIONS(133),
    [anon_sym_COLONsection_COLON] = ACTIONS(133),
    [aux_sym_subsection_token1] = ACTIONS(133),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(133),
    [aux_sym_subsubsection_token1] = ACTIONS(133),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(133),
    [anon_sym_COLONappendix_COLON] = ACTIONS(133),
    [aux_sym_mathblock_token1] = ACTIONS(133),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(133),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(133),
    [anon_sym_COLONtoc_COLON] = ACTIONS(133),
    [aux_sym_specialblock_token1] = ACTIONS(133),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(133),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(133),
    [anon_sym_COLONcaption_COLON] = ACTIONS(133),
    [anon_sym_COLONitem_COLON] = ACTIONS(133),
    [anon_sym_COLONprev_COLON] = ACTIONS(133),
    [anon_sym_COLONprev2_COLON] = ACTIONS(133),
    [anon_sym_COLONprev3_COLON] = ACTIONS(133),
    [aux_sym_specialinline_token1] = ACTIONS(135),
    [aux_sym_specialinline_token2] = ACTIONS(135),
    [anon_sym_COLONmath_COLON] = ACTIONS(133),
    [anon_sym_COLONcode_COLON] = ACTIONS(133),
    [aux_sym_specialinline_token3] = ACTIONS(133),
    [aux_sym_specialinline_token4] = ACTIONS(133),
    [anon_sym_COLONref_COLON] = ACTIONS(133),
    [anon_sym_COLONprevious_COLON] = ACTIONS(133),
    [anon_sym_COLONurl_COLON] = ACTIONS(133),
    [anon_sym_COLONcite_COLON] = ACTIONS(133),
    [anon_sym_COLONqed_COLON] = ACTIONS(133),
    [anon_sym_COLONtable_COLON] = ACTIONS(133),
    [anon_sym_COLONassume_COLON] = ACTIONS(133),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(133),
    [anon_sym_COLONprove_COLON] = ACTIONS(133),
    [anon_sym_COLONthen_COLON] = ACTIONS(133),
    [anon_sym_COLONnew_COLON] = ACTIONS(133),
    [anon_sym_COLONlet_COLON] = ACTIONS(133),
    [anon_sym_COLONcase_COLON] = ACTIONS(133),
    [anon_sym_COLONdefine_COLON] = ACTIONS(133),
    [anon_sym_COLONwrite_COLON] = ACTIONS(133),
    [anon_sym_COLONwlog_COLON] = ACTIONS(133),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(133),
    [anon_sym_COLONclaim_COLON] = ACTIONS(133),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(133),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(133),
    [anon_sym_COLONpick_COLON] = ACTIONS(133),
    [anon_sym_COLONst_COLON] = ACTIONS(133),
    [anon_sym_COLONdraft_COLON] = ACTIONS(133),
    [anon_sym_COLONnote_COLON] = ACTIONS(133),
    [anon_sym_COLONspan_COLON] = ACTIONS(133),
    [anon_sym_COLONabstract_COLON] = ACTIONS(133),
    [anon_sym_COLONauthor_COLON] = ACTIONS(133),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(133),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(133),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(133),
    [anon_sym_COLONexample_COLON] = ACTIONS(133),
    [anon_sym_COLONitemize_COLON] = ACTIONS(133),
    [anon_sym_COLONlemma_COLON] = ACTIONS(133),
    [anon_sym_COLONfigure_COLON] = ACTIONS(133),
    [anon_sym_COLONp_COLON] = ACTIONS(133),
    [anon_sym_COLONproof_COLON] = ACTIONS(133),
    [anon_sym_COLONproposition_COLON] = ACTIONS(133),
    [anon_sym_COLONremark_COLON] = ACTIONS(133),
    [anon_sym_COLONsketch_COLON] = ACTIONS(133),
    [anon_sym_COLONstep_COLON] = ACTIONS(133),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(133),
    [anon_sym_COLONaffiliation_COLON] = ACTIONS(133),
    [anon_sym_COLONemail_COLON] = ACTIONS(133),
    [anon_sym_COLONlabel_COLON] = ACTIONS(133),
    [anon_sym_COLONname_COLON] = ACTIONS(133),
    [anon_sym_COLONreftext_COLON] = ACTIONS(133),
    [anon_sym_COLONtitle_COLON] = ACTIONS(133),
    [anon_sym_COLONgoal_COLON] = ACTIONS(133),
    [anon_sym_COLONlang_COLON] = ACTIONS(133),
    [anon_sym_COLONicon_COLON] = ACTIONS(133),
    [anon_sym_COLONnonum_COLON] = ACTIONS(133),
    [anon_sym_COLONstrong_COLON] = ACTIONS(133),
    [anon_sym_COLONemphas_COLON] = ACTIONS(133),
    [anon_sym_COLONisclaim_COLON] = ACTIONS(133),
    [anon_sym_COLONkeywords_COLON] = ACTIONS(133),
    [anon_sym_COLONmsc_COLON] = ACTIONS(133),
    [anon_sym_COLONtypes_COLON] = ACTIONS(133),
    [anon_sym_COLONdate_COLON] = ACTIONS(133),
    [anon_sym_COLONpath_COLON] = ACTIONS(133),
    [anon_sym_COLONscale_COLON] = ACTIONS(133),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(133),
  },
  [STATE(17)] = {
    [anon_sym_COLON_COLON] = ACTIONS(137),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(137),
    [aux_sym_section_token1] = ACTIONS(137),
    [anon_sym_COLONsection_COLON] = ACTIONS(137),
    [aux_sym_subsection_token1] = ACTIONS(137),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(137),
    [aux_sym_subsubsection_token1] = ACTIONS(137),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(137),
    [anon_sym_COLONappendix_COLON] = ACTIONS(137),
    [aux_sym_mathblock_token1] = ACTIONS(137),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(137),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(137),
    [anon_sym_COLONtoc_COLON] = ACTIONS(137),
    [aux_sym_specialblock_token1] = ACTIONS(137),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(137),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(137),
    [anon_sym_COLONcaption_COLON] = ACTIONS(137),
    [anon_sym_COLONitem_COLON] = ACTIONS(137),
    [anon_sym_COLONprev_COLON] = ACTIONS(137),
    [anon_sym_COLONprev2_COLON] = ACTIONS(137),
    [anon_sym_COLONprev3_COLON] = ACTIONS(137),
    [aux_sym_specialinline_token1] = ACTIONS(139),
    [aux_sym_specialinline_token2] = ACTIONS(139),
    [anon_sym_COLONmath_COLON] = ACTIONS(137),
    [anon_sym_COLONcode_COLON] = ACTIONS(137),
    [aux_sym_specialinline_token3] = ACTIONS(137),
    [aux_sym_specialinline_token4] = ACTIONS(137),
    [anon_sym_COLONref_COLON] = ACTIONS(137),
    [anon_sym_COLONprevious_COLON] = ACTIONS(137),
    [anon_sym_COLONurl_COLON] = ACTIONS(137),
    [anon_sym_COLONcite_COLON] = ACTIONS(137),
    [anon_sym_COLONqed_COLON] = ACTIONS(137),
    [anon_sym_COLONtable_COLON] = ACTIONS(137),
    [anon_sym_COLONassume_COLON] = ACTIONS(137),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(137),
    [anon_sym_COLONprove_COLON] = ACTIONS(137),
    [anon_sym_COLONthen_COLON] = ACTIONS(137),
    [anon_sym_COLONnew_COLON] = ACTIONS(137),
    [anon_sym_COLONlet_COLON] = ACTIONS(137),
    [anon_sym_COLONcase_COLON] = ACTIONS(137),
    [anon_sym_COLONdefine_COLON] = ACTIONS(137),
    [anon_sym_COLONwrite_COLON] = ACTIONS(137),
    [anon_sym_COLONwlog_COLON] = ACTIONS(137),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(137),
    [anon_sym_COLONclaim_COLON] = ACTIONS(137),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(137),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(137),
    [anon_sym_COLONpick_COLON] = ACTIONS(137),
    [anon_sym_COLONst_COLON] = ACTIONS(137),
    [anon_sym_COLONdraft_COLON] = ACTIONS(137),
    [anon_sym_COLONnote_COLON] = ACTIONS(137),
    [anon_sym_COLONspan_COLON] = ACTIONS(137),
    [anon_sym_COLONabstract_COLON] = ACTIONS(137),
    [anon_sym_COLONauthor_COLON] = ACTIONS(137),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(137),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(137),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(137),
    [anon_sym_COLONexample_COLON] = ACTIONS(137),
    [anon_sym_COLONitemize_COLON] = ACTIONS(137),
    [anon_sym_COLONlemma_COLON] = ACTIONS(137),
    [anon_sym_COLONfigure_COLON] = ACTIONS(137),
    [anon_sym_COLONp_COLON] = ACTIONS(137),
    [anon_sym_COLONproof_COLON] = ACTIONS(137),
    [anon_sym_COLONproposition_COLON] = ACTIONS(137),
    [anon_sym_COLONremark_COLON] = ACTIONS(137),
    [anon_sym_COLONsketch_COLON] = ACTIONS(137),
    [anon_sym_COLONstep_COLON] = ACTIONS(137),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(137),
    [anon_sym_COLONaffiliation_COLON] = ACTIONS(137),
    [anon_sym_COLONemail_COLON] = ACTIONS(137),
    [anon_sym_COLONlabel_COLON] = ACTIONS(137),
    [anon_sym_COLONname_COLON] = ACTIONS(137),
    [anon_sym_COLONreftext_COLON] = ACTIONS(137),
    [anon_sym_COLONtitle_COLON] = ACTIONS(137),
    [anon_sym_COLONgoal_COLON] = ACTIONS(137),
    [anon_sym_COLONlang_COLON] = ACTIONS(137),
    [anon_sym_COLONicon_COLON] = ACTIONS(137),
    [anon_sym_COLONnonum_COLON] = ACTIONS(137),
    [anon_sym_COLONstrong_COLON] = ACTIONS(137),
    [anon_sym_COLONemphas_COLON] = ACTIONS(137),
    [anon_sym_COLONisclaim_COLON] = ACTIONS(137),
    [anon_sym_COLONkeywords_COLON] = ACTIONS(137),
    [anon_sym_COLONmsc_COLON] = ACTIONS(137),
    [anon_sym_COLONtypes_COLON] = ACTIONS(137),
    [anon_sym_COLONdate_COLON] = ACTIONS(137),
    [anon_sym_COLONpath_COLON] = ACTIONS(137),
    [anon_sym_COLONscale_COLON] = ACTIONS(137),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(137),
  },
  [STATE(18)] = {
    [anon_sym_COLON_COLON] = ACTIONS(141),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(141),
    [aux_sym_section_token1] = ACTIONS(141),
    [anon_sym_COLONsection_COLON] = ACTIONS(141),
    [aux_sym_subsection_token1] = ACTIONS(141),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(141),
    [aux_sym_subsubsection_token1] = ACTIONS(141),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(141),
    [anon_sym_COLONappendix_COLON] = ACTIONS(141),
    [aux_sym_mathblock_token1] = ACTIONS(141),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(141),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(141),
    [anon_sym_COLONtoc_COLON] = ACTIONS(141),
    [aux_sym_specialblock_token1] = ACTIONS(141),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(141),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(141),
    [anon_sym_COLONcaption_COLON] = ACTIONS(141),
    [anon_sym_COLONitem_COLON] = ACTIONS(141),
    [anon_sym_COLONprev_COLON] = ACTIONS(141),
    [anon_sym_COLONprev2_COLON] = ACTIONS(141),
    [anon_sym_COLONprev3_COLON] = ACTIONS(141),
    [aux_sym_specialinline_token1] = ACTIONS(143),
    [aux_sym_specialinline_token2] = ACTIONS(143),
    [anon_sym_COLONmath_COLON] = ACTIONS(141),
    [anon_sym_COLONcode_COLON] = ACTIONS(141),
    [aux_sym_specialinline_token3] = ACTIONS(141),
    [aux_sym_specialinline_token4] = ACTIONS(141),
    [anon_sym_COLONref_COLON] = ACTIONS(141),
    [anon_sym_COLONprevious_COLON] = ACTIONS(141),
    [anon_sym_COLONurl_COLON] = ACTIONS(141),
    [anon_sym_COLONcite_COLON] = ACTIONS(141),
    [anon_sym_COLONqed_COLON] = ACTIONS(141),
    [anon_sym_COLONtable_COLON] = ACTIONS(141),
    [anon_sym_COLONassume_COLON] = ACTIONS(141),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(141),
    [anon_sym_COLONprove_COLON] = ACTIONS(141),
    [anon_sym_COLONthen_COLON] = ACTIONS(141),
    [anon_sym_COLONnew_COLON] = ACTIONS(141),
    [anon_sym_COLONlet_COLON] = ACTIONS(141),
    [anon_sym_COLONcase_COLON] = ACTIONS(141),
    [anon_sym_COLONdefine_COLON] = ACTIONS(141),
    [anon_sym_COLONwrite_COLON] = ACTIONS(141),
    [anon_sym_COLONwlog_COLON] = ACTIONS(141),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(141),
    [anon_sym_COLONclaim_COLON] = ACTIONS(141),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(141),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(141),
    [anon_sym_COLONpick_COLON] = ACTIONS(141),
    [anon_sym_COLONst_COLON] = ACTIONS(141),
    [anon_sym_COLONdraft_COLON] = ACTIONS(141),
    [anon_sym_COLONnote_COLON] = ACTIONS(141),
    [anon_sym_COLONspan_COLON] = ACTIONS(141),
    [anon_sym_COLONabstract_COLON] = ACTIONS(141),
    [anon_sym_COLONauthor_COLON] = ACTIONS(141),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(141),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(141),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(141),
    [anon_sym_COLONexample_COLON] = ACTIONS(141),
    [anon_sym_COLONitemize_COLON] = ACTIONS(141),
    [anon_sym_COLONlemma_COLON] = ACTIONS(141),
    [anon_sym_COLONfigure_COLON] = ACTIONS(141),
    [anon_sym_COLONp_COLON] = ACTIONS(141),
    [anon_sym_COLONproof_COLON] = ACTIONS(141),
    [anon_sym_COLONproposition_COLON] = ACTIONS(141),
    [anon_sym_COLONremark_COLON] = ACTIONS(141),
    [anon_sym_COLONsketch_COLON] = ACTIONS(141),
    [anon_sym_COLONstep_COLON] = ACTIONS(141),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(141),
    [anon_sym_COLONaffiliation_COLON] = ACTIONS(141),
    [anon_sym_COLONemail_COLON] = ACTIONS(141),
    [anon_sym_COLONlabel_COLON] = ACTIONS(141),
    [anon_sym_COLONname_COLON] = ACTIONS(141),
    [anon_sym_COLONreftext_COLON] = ACTIONS(141),
    [anon_sym_COLONtitle_COLON] = ACTIONS(141),
    [anon_sym_COLONgoal_COLON] = ACTIONS(141),
    [anon_sym_COLONlang_COLON] = ACTIONS(141),
    [anon_sym_COLONicon_COLON] = ACTIONS(141),
    [anon_sym_COLONnonum_COLON] = ACTIONS(141),
    [anon_sym_COLONstrong_COLON] = ACTIONS(141),
    [anon_sym_COLONemphas_COLON] = ACTIONS(141),
    [anon_sym_COLONisclaim_COLON] = ACTIONS(141),
    [anon_sym_COLONkeywords_COLON] = ACTIONS(141),
    [anon_sym_COLONmsc_COLON] = ACTIONS(141),
    [anon_sym_COLONtypes_COLON] = ACTIONS(141),
    [anon_sym_COLONdate_COLON] = ACTIONS(141),
    [anon_sym_COLONpath_COLON] = ACTIONS(141),
    [anon_sym_COLONscale_COLON] = ACTIONS(141),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(141),
  },
  [STATE(19)] = {
    [sym_block] = STATE(22),
    [sym_paragraph] = STATE(22),
    [sym_inline] = STATE(98),
    [sym_construct] = STATE(98),
    [sym_subsubsection] = STATE(22),
    [sym_mathblock] = STATE(22),
    [sym_specialblock] = STATE(22),
    [sym_caption] = STATE(61),
    [sym_item] = STATE(61),
    [sym_specialinline] = STATE(98),
    [sym_specialconstruct] = STATE(98),
    [sym_table] = STATE(62),
    [sym__paragraphcontent_no_special] = STATE(98),
    [aux_sym_subsection_repeat1] = STATE(22),
    [anon_sym_COLON_COLON] = ACTIONS(145),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(145),
    [anon_sym_COLONsection_COLON] = ACTIONS(145),
    [aux_sym_subsection_token1] = ACTIONS(145),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(145),
    [aux_sym_subsubsection_token1] = ACTIONS(11),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(13),
    [anon_sym_COLONappendix_COLON] = ACTIONS(145),
    [aux_sym_mathblock_token1] = ACTIONS(15),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(17),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(19),
    [aux_sym_specialblock_token1] = ACTIONS(21),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(23),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(25),
    [anon_sym_COLONcaption_COLON] = ACTIONS(27),
    [anon_sym_COLONitem_COLON] = ACTIONS(29),
    [anon_sym_COLONprev_COLON] = ACTIONS(31),
    [anon_sym_COLONprev2_COLON] = ACTIONS(31),
    [anon_sym_COLONprev3_COLON] = ACTIONS(31),
    [aux_sym_specialinline_token1] = ACTIONS(33),
    [aux_sym_specialinline_token2] = ACTIONS(35),
    [anon_sym_COLONmath_COLON] = ACTIONS(37),
    [anon_sym_COLONcode_COLON] = ACTIONS(39),
    [aux_sym_specialinline_token3] = ACTIONS(41),
    [aux_sym_specialinline_token4] = ACTIONS(43),
    [anon_sym_COLONref_COLON] = ACTIONS(45),
    [anon_sym_COLONprevious_COLON] = ACTIONS(47),
    [anon_sym_COLONurl_COLON] = ACTIONS(49),
    [anon_sym_COLONcite_COLON] = ACTIONS(51),
    [anon_sym_COLONqed_COLON] = ACTIONS(53),
    [anon_sym_COLONtable_COLON] = ACTIONS(55),
    [anon_sym_COLONassume_COLON] = ACTIONS(57),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(57),
    [anon_sym_COLONprove_COLON] = ACTIONS(57),
    [anon_sym_COLONthen_COLON] = ACTIONS(57),
    [anon_sym_COLONnew_COLON] = ACTIONS(57),
    [anon_sym_COLONlet_COLON] = ACTIONS(57),
    [anon_sym_COLONcase_COLON] = ACTIONS(57),
    [anon_sym_COLONdefine_COLON] = ACTIONS(57),
    [anon_sym_COLONwrite_COLON] = ACTIONS(57),
    [anon_sym_COLONwlog_COLON] = ACTIONS(57),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(57),
    [anon_sym_COLONclaim_COLON] = ACTIONS(57),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(57),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(57),
    [anon_sym_COLONpick_COLON] = ACTIONS(57),
    [anon_sym_COLONst_COLON] = ACTIONS(57),
    [anon_sym_COLONdraft_COLON] = ACTIONS(59),
    [anon_sym_COLONnote_COLON] = ACTIONS(59),
    [anon_sym_COLONspan_COLON] = ACTIONS(59),
    [anon_sym_COLONabstract_COLON] = ACTIONS(61),
    [anon_sym_COLONauthor_COLON] = ACTIONS(61),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(61),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(61),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(61),
    [anon_sym_COLONexample_COLON] = ACTIONS(61),
    [anon_sym_COLONitemize_COLON] = ACTIONS(61),
    [anon_sym_COLONlemma_COLON] = ACTIONS(61),
    [anon_sym_COLONfigure_COLON] = ACTIONS(61),
    [anon_sym_COLONp_COLON] = ACTIONS(61),
    [anon_sym_COLONproof_COLON] = ACTIONS(61),
    [anon_sym_COLONproposition_COLON] = ACTIONS(61),
    [anon_sym_COLONremark_COLON] = ACTIONS(61),
    [anon_sym_COLONsketch_COLON] = ACTIONS(61),
    [anon_sym_COLONstep_COLON] = ACTIONS(61),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(71),
  },
  [STATE(20)] = {
    [sym_block] = STATE(25),
    [sym_paragraph] = STATE(25),
    [sym_inline] = STATE(98),
    [sym_construct] = STATE(98),
    [sym_subsubsection] = STATE(25),
    [sym_mathblock] = STATE(25),
    [sym_specialblock] = STATE(25),
    [sym_caption] = STATE(61),
    [sym_item] = STATE(61),
    [sym_specialinline] = STATE(98),
    [sym_specialconstruct] = STATE(98),
    [sym_table] = STATE(62),
    [sym__paragraphcontent_no_special] = STATE(98),
    [aux_sym_subsection_repeat1] = STATE(25),
    [anon_sym_COLON_COLON] = ACTIONS(147),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(147),
    [anon_sym_COLONsection_COLON] = ACTIONS(147),
    [aux_sym_subsection_token1] = ACTIONS(147),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(147),
    [aux_sym_subsubsection_token1] = ACTIONS(11),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(13),
    [anon_sym_COLONappendix_COLON] = ACTIONS(147),
    [aux_sym_mathblock_token1] = ACTIONS(15),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(17),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(19),
    [aux_sym_specialblock_token1] = ACTIONS(21),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(23),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(25),
    [anon_sym_COLONcaption_COLON] = ACTIONS(27),
    [anon_sym_COLONitem_COLON] = ACTIONS(29),
    [anon_sym_COLONprev_COLON] = ACTIONS(31),
    [anon_sym_COLONprev2_COLON] = ACTIONS(31),
    [anon_sym_COLONprev3_COLON] = ACTIONS(31),
    [aux_sym_specialinline_token1] = ACTIONS(33),
    [aux_sym_specialinline_token2] = ACTIONS(35),
    [anon_sym_COLONmath_COLON] = ACTIONS(37),
    [anon_sym_COLONcode_COLON] = ACTIONS(39),
    [aux_sym_specialinline_token3] = ACTIONS(41),
    [aux_sym_specialinline_token4] = ACTIONS(43),
    [anon_sym_COLONref_COLON] = ACTIONS(45),
    [anon_sym_COLONprevious_COLON] = ACTIONS(47),
    [anon_sym_COLONurl_COLON] = ACTIONS(49),
    [anon_sym_COLONcite_COLON] = ACTIONS(51),
    [anon_sym_COLONqed_COLON] = ACTIONS(53),
    [anon_sym_COLONtable_COLON] = ACTIONS(55),
    [anon_sym_COLONassume_COLON] = ACTIONS(57),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(57),
    [anon_sym_COLONprove_COLON] = ACTIONS(57),
    [anon_sym_COLONthen_COLON] = ACTIONS(57),
    [anon_sym_COLONnew_COLON] = ACTIONS(57),
    [anon_sym_COLONlet_COLON] = ACTIONS(57),
    [anon_sym_COLONcase_COLON] = ACTIONS(57),
    [anon_sym_COLONdefine_COLON] = ACTIONS(57),
    [anon_sym_COLONwrite_COLON] = ACTIONS(57),
    [anon_sym_COLONwlog_COLON] = ACTIONS(57),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(57),
    [anon_sym_COLONclaim_COLON] = ACTIONS(57),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(57),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(57),
    [anon_sym_COLONpick_COLON] = ACTIONS(57),
    [anon_sym_COLONst_COLON] = ACTIONS(57),
    [anon_sym_COLONdraft_COLON] = ACTIONS(59),
    [anon_sym_COLONnote_COLON] = ACTIONS(59),
    [anon_sym_COLONspan_COLON] = ACTIONS(59),
    [anon_sym_COLONabstract_COLON] = ACTIONS(61),
    [anon_sym_COLONauthor_COLON] = ACTIONS(61),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(61),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(61),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(61),
    [anon_sym_COLONexample_COLON] = ACTIONS(61),
    [anon_sym_COLONitemize_COLON] = ACTIONS(61),
    [anon_sym_COLONlemma_COLON] = ACTIONS(61),
    [anon_sym_COLONfigure_COLON] = ACTIONS(61),
    [anon_sym_COLONp_COLON] = ACTIONS(61),
    [anon_sym_COLONproof_COLON] = ACTIONS(61),
    [anon_sym_COLONproposition_COLON] = ACTIONS(61),
    [anon_sym_COLONremark_COLON] = ACTIONS(61),
    [anon_sym_COLONsketch_COLON] = ACTIONS(61),
    [anon_sym_COLONstep_COLON] = ACTIONS(61),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(71),
  },
  [STATE(21)] = {
    [sym_block] = STATE(23),
    [sym_paragraph] = STATE(23),
    [sym_inline] = STATE(98),
    [sym_construct] = STATE(98),
    [sym_subsubsection] = STATE(23),
    [sym_mathblock] = STATE(23),
    [sym_specialblock] = STATE(23),
    [sym_caption] = STATE(61),
    [sym_item] = STATE(61),
    [sym_specialinline] = STATE(98),
    [sym_specialconstruct] = STATE(98),
    [sym_table] = STATE(62),
    [sym__paragraphcontent_no_special] = STATE(98),
    [aux_sym_subsection_repeat1] = STATE(23),
    [anon_sym_COLON_COLON] = ACTIONS(149),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(149),
    [anon_sym_COLONsection_COLON] = ACTIONS(149),
    [aux_sym_subsection_token1] = ACTIONS(149),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(149),
    [aux_sym_subsubsection_token1] = ACTIONS(11),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(13),
    [anon_sym_COLONappendix_COLON] = ACTIONS(149),
    [aux_sym_mathblock_token1] = ACTIONS(15),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(17),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(19),
    [aux_sym_specialblock_token1] = ACTIONS(21),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(23),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(25),
    [anon_sym_COLONcaption_COLON] = ACTIONS(27),
    [anon_sym_COLONitem_COLON] = ACTIONS(29),
    [anon_sym_COLONprev_COLON] = ACTIONS(31),
    [anon_sym_COLONprev2_COLON] = ACTIONS(31),
    [anon_sym_COLONprev3_COLON] = ACTIONS(31),
    [aux_sym_specialinline_token1] = ACTIONS(33),
    [aux_sym_specialinline_token2] = ACTIONS(35),
    [anon_sym_COLONmath_COLON] = ACTIONS(37),
    [anon_sym_COLONcode_COLON] = ACTIONS(39),
    [aux_sym_specialinline_token3] = ACTIONS(41),
    [aux_sym_specialinline_token4] = ACTIONS(43),
    [anon_sym_COLONref_COLON] = ACTIONS(45),
    [anon_sym_COLONprevious_COLON] = ACTIONS(47),
    [anon_sym_COLONurl_COLON] = ACTIONS(49),
    [anon_sym_COLONcite_COLON] = ACTIONS(51),
    [anon_sym_COLONqed_COLON] = ACTIONS(53),
    [anon_sym_COLONtable_COLON] = ACTIONS(55),
    [anon_sym_COLONassume_COLON] = ACTIONS(57),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(57),
    [anon_sym_COLONprove_COLON] = ACTIONS(57),
    [anon_sym_COLONthen_COLON] = ACTIONS(57),
    [anon_sym_COLONnew_COLON] = ACTIONS(57),
    [anon_sym_COLONlet_COLON] = ACTIONS(57),
    [anon_sym_COLONcase_COLON] = ACTIONS(57),
    [anon_sym_COLONdefine_COLON] = ACTIONS(57),
    [anon_sym_COLONwrite_COLON] = ACTIONS(57),
    [anon_sym_COLONwlog_COLON] = ACTIONS(57),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(57),
    [anon_sym_COLONclaim_COLON] = ACTIONS(57),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(57),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(57),
    [anon_sym_COLONpick_COLON] = ACTIONS(57),
    [anon_sym_COLONst_COLON] = ACTIONS(57),
    [anon_sym_COLONdraft_COLON] = ACTIONS(59),
    [anon_sym_COLONnote_COLON] = ACTIONS(59),
    [anon_sym_COLONspan_COLON] = ACTIONS(59),
    [anon_sym_COLONabstract_COLON] = ACTIONS(61),
    [anon_sym_COLONauthor_COLON] = ACTIONS(61),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(61),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(61),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(61),
    [anon_sym_COLONexample_COLON] = ACTIONS(61),
    [anon_sym_COLONitemize_COLON] = ACTIONS(61),
    [anon_sym_COLONlemma_COLON] = ACTIONS(61),
    [anon_sym_COLONfigure_COLON] = ACTIONS(61),
    [anon_sym_COLONp_COLON] = ACTIONS(61),
    [anon_sym_COLONproof_COLON] = ACTIONS(61),
    [anon_sym_COLONproposition_COLON] = ACTIONS(61),
    [anon_sym_COLONremark_COLON] = ACTIONS(61),
    [anon_sym_COLONsketch_COLON] = ACTIONS(61),
    [anon_sym_COLONstep_COLON] = ACTIONS(61),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(71),
  },
  [STATE(22)] = {
    [sym_block] = STATE(25),
    [sym_paragraph] = STATE(25),
    [sym_inline] = STATE(98),
    [sym_construct] = STATE(98),
    [sym_subsubsection] = STATE(25),
    [sym_mathblock] = STATE(25),
    [sym_specialblock] = STATE(25),
    [sym_caption] = STATE(61),
    [sym_item] = STATE(61),
    [sym_specialinline] = STATE(98),
    [sym_specialconstruct] = STATE(98),
    [sym_table] = STATE(62),
    [sym__paragraphcontent_no_special] = STATE(98),
    [aux_sym_subsection_repeat1] = STATE(25),
    [anon_sym_COLON_COLON] = ACTIONS(151),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(151),
    [anon_sym_COLONsection_COLON] = ACTIONS(151),
    [aux_sym_subsection_token1] = ACTIONS(151),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(151),
    [aux_sym_subsubsection_token1] = ACTIONS(11),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(13),
    [anon_sym_COLONappendix_COLON] = ACTIONS(151),
    [aux_sym_mathblock_token1] = ACTIONS(15),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(17),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(19),
    [aux_sym_specialblock_token1] = ACTIONS(21),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(23),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(25),
    [anon_sym_COLONcaption_COLON] = ACTIONS(27),
    [anon_sym_COLONitem_COLON] = ACTIONS(29),
    [anon_sym_COLONprev_COLON] = ACTIONS(31),
    [anon_sym_COLONprev2_COLON] = ACTIONS(31),
    [anon_sym_COLONprev3_COLON] = ACTIONS(31),
    [aux_sym_specialinline_token1] = ACTIONS(33),
    [aux_sym_specialinline_token2] = ACTIONS(35),
    [anon_sym_COLONmath_COLON] = ACTIONS(37),
    [anon_sym_COLONcode_COLON] = ACTIONS(39),
    [aux_sym_specialinline_token3] = ACTIONS(41),
    [aux_sym_specialinline_token4] = ACTIONS(43),
    [anon_sym_COLONref_COLON] = ACTIONS(45),
    [anon_sym_COLONprevious_COLON] = ACTIONS(47),
    [anon_sym_COLONurl_COLON] = ACTIONS(49),
    [anon_sym_COLONcite_COLON] = ACTIONS(51),
    [anon_sym_COLONqed_COLON] = ACTIONS(53),
    [anon_sym_COLONtable_COLON] = ACTIONS(55),
    [anon_sym_COLONassume_COLON] = ACTIONS(57),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(57),
    [anon_sym_COLONprove_COLON] = ACTIONS(57),
    [anon_sym_COLONthen_COLON] = ACTIONS(57),
    [anon_sym_COLONnew_COLON] = ACTIONS(57),
    [anon_sym_COLONlet_COLON] = ACTIONS(57),
    [anon_sym_COLONcase_COLON] = ACTIONS(57),
    [anon_sym_COLONdefine_COLON] = ACTIONS(57),
    [anon_sym_COLONwrite_COLON] = ACTIONS(57),
    [anon_sym_COLONwlog_COLON] = ACTIONS(57),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(57),
    [anon_sym_COLONclaim_COLON] = ACTIONS(57),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(57),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(57),
    [anon_sym_COLONpick_COLON] = ACTIONS(57),
    [anon_sym_COLONst_COLON] = ACTIONS(57),
    [anon_sym_COLONdraft_COLON] = ACTIONS(59),
    [anon_sym_COLONnote_COLON] = ACTIONS(59),
    [anon_sym_COLONspan_COLON] = ACTIONS(59),
    [anon_sym_COLONabstract_COLON] = ACTIONS(61),
    [anon_sym_COLONauthor_COLON] = ACTIONS(61),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(61),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(61),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(61),
    [anon_sym_COLONexample_COLON] = ACTIONS(61),
    [anon_sym_COLONitemize_COLON] = ACTIONS(61),
    [anon_sym_COLONlemma_COLON] = ACTIONS(61),
    [anon_sym_COLONfigure_COLON] = ACTIONS(61),
    [anon_sym_COLONp_COLON] = ACTIONS(61),
    [anon_sym_COLONproof_COLON] = ACTIONS(61),
    [anon_sym_COLONproposition_COLON] = ACTIONS(61),
    [anon_sym_COLONremark_COLON] = ACTIONS(61),
    [anon_sym_COLONsketch_COLON] = ACTIONS(61),
    [anon_sym_COLONstep_COLON] = ACTIONS(61),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(71),
  },
  [STATE(23)] = {
    [sym_block] = STATE(25),
    [sym_paragraph] = STATE(25),
    [sym_inline] = STATE(98),
    [sym_construct] = STATE(98),
    [sym_subsubsection] = STATE(25),
    [sym_mathblock] = STATE(25),
    [sym_specialblock] = STATE(25),
    [sym_caption] = STATE(61),
    [sym_item] = STATE(61),
    [sym_specialinline] = STATE(98),
    [sym_specialconstruct] = STATE(98),
    [sym_table] = STATE(62),
    [sym__paragraphcontent_no_special] = STATE(98),
    [aux_sym_subsection_repeat1] = STATE(25),
    [anon_sym_COLON_COLON] = ACTIONS(153),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(153),
    [anon_sym_COLONsection_COLON] = ACTIONS(153),
    [aux_sym_subsection_token1] = ACTIONS(153),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(153),
    [aux_sym_subsubsection_token1] = ACTIONS(11),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(13),
    [anon_sym_COLONappendix_COLON] = ACTIONS(153),
    [aux_sym_mathblock_token1] = ACTIONS(15),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(17),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(19),
    [aux_sym_specialblock_token1] = ACTIONS(21),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(23),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(25),
    [anon_sym_COLONcaption_COLON] = ACTIONS(27),
    [anon_sym_COLONitem_COLON] = ACTIONS(29),
    [anon_sym_COLONprev_COLON] = ACTIONS(31),
    [anon_sym_COLONprev2_COLON] = ACTIONS(31),
    [anon_sym_COLONprev3_COLON] = ACTIONS(31),
    [aux_sym_specialinline_token1] = ACTIONS(33),
    [aux_sym_specialinline_token2] = ACTIONS(35),
    [anon_sym_COLONmath_COLON] = ACTIONS(37),
    [anon_sym_COLONcode_COLON] = ACTIONS(39),
    [aux_sym_specialinline_token3] = ACTIONS(41),
    [aux_sym_specialinline_token4] = ACTIONS(43),
    [anon_sym_COLONref_COLON] = ACTIONS(45),
    [anon_sym_COLONprevious_COLON] = ACTIONS(47),
    [anon_sym_COLONurl_COLON] = ACTIONS(49),
    [anon_sym_COLONcite_COLON] = ACTIONS(51),
    [anon_sym_COLONqed_COLON] = ACTIONS(53),
    [anon_sym_COLONtable_COLON] = ACTIONS(55),
    [anon_sym_COLONassume_COLON] = ACTIONS(57),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(57),
    [anon_sym_COLONprove_COLON] = ACTIONS(57),
    [anon_sym_COLONthen_COLON] = ACTIONS(57),
    [anon_sym_COLONnew_COLON] = ACTIONS(57),
    [anon_sym_COLONlet_COLON] = ACTIONS(57),
    [anon_sym_COLONcase_COLON] = ACTIONS(57),
    [anon_sym_COLONdefine_COLON] = ACTIONS(57),
    [anon_sym_COLONwrite_COLON] = ACTIONS(57),
    [anon_sym_COLONwlog_COLON] = ACTIONS(57),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(57),
    [anon_sym_COLONclaim_COLON] = ACTIONS(57),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(57),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(57),
    [anon_sym_COLONpick_COLON] = ACTIONS(57),
    [anon_sym_COLONst_COLON] = ACTIONS(57),
    [anon_sym_COLONdraft_COLON] = ACTIONS(59),
    [anon_sym_COLONnote_COLON] = ACTIONS(59),
    [anon_sym_COLONspan_COLON] = ACTIONS(59),
    [anon_sym_COLONabstract_COLON] = ACTIONS(61),
    [anon_sym_COLONauthor_COLON] = ACTIONS(61),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(61),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(61),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(61),
    [anon_sym_COLONexample_COLON] = ACTIONS(61),
    [anon_sym_COLONitemize_COLON] = ACTIONS(61),
    [anon_sym_COLONlemma_COLON] = ACTIONS(61),
    [anon_sym_COLONfigure_COLON] = ACTIONS(61),
    [anon_sym_COLONp_COLON] = ACTIONS(61),
    [anon_sym_COLONproof_COLON] = ACTIONS(61),
    [anon_sym_COLONproposition_COLON] = ACTIONS(61),
    [anon_sym_COLONremark_COLON] = ACTIONS(61),
    [anon_sym_COLONsketch_COLON] = ACTIONS(61),
    [anon_sym_COLONstep_COLON] = ACTIONS(61),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(71),
  },
  [STATE(24)] = {
    [sym_block] = STATE(25),
    [sym_paragraph] = STATE(25),
    [sym_inline] = STATE(98),
    [sym_construct] = STATE(98),
    [sym_subsubsection] = STATE(25),
    [sym_mathblock] = STATE(25),
    [sym_specialblock] = STATE(25),
    [sym_caption] = STATE(61),
    [sym_item] = STATE(61),
    [sym_specialinline] = STATE(98),
    [sym_specialconstruct] = STATE(98),
    [sym_table] = STATE(62),
    [sym__paragraphcontent_no_special] = STATE(98),
    [aux_sym_subsection_repeat1] = STATE(25),
    [anon_sym_COLON_COLON] = ACTIONS(155),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(155),
    [anon_sym_COLONsection_COLON] = ACTIONS(155),
    [aux_sym_subsection_token1] = ACTIONS(155),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(155),
    [aux_sym_subsubsection_token1] = ACTIONS(11),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(13),
    [anon_sym_COLONappendix_COLON] = ACTIONS(155),
    [aux_sym_mathblock_token1] = ACTIONS(15),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(17),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(19),
    [aux_sym_specialblock_token1] = ACTIONS(21),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(23),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(25),
    [anon_sym_COLONcaption_COLON] = ACTIONS(27),
    [anon_sym_COLONitem_COLON] = ACTIONS(29),
    [anon_sym_COLONprev_COLON] = ACTIONS(31),
    [anon_sym_COLONprev2_COLON] = ACTIONS(31),
    [anon_sym_COLONprev3_COLON] = ACTIONS(31),
    [aux_sym_specialinline_token1] = ACTIONS(33),
    [aux_sym_specialinline_token2] = ACTIONS(35),
    [anon_sym_COLONmath_COLON] = ACTIONS(37),
    [anon_sym_COLONcode_COLON] = ACTIONS(39),
    [aux_sym_specialinline_token3] = ACTIONS(41),
    [aux_sym_specialinline_token4] = ACTIONS(43),
    [anon_sym_COLONref_COLON] = ACTIONS(45),
    [anon_sym_COLONprevious_COLON] = ACTIONS(47),
    [anon_sym_COLONurl_COLON] = ACTIONS(49),
    [anon_sym_COLONcite_COLON] = ACTIONS(51),
    [anon_sym_COLONqed_COLON] = ACTIONS(53),
    [anon_sym_COLONtable_COLON] = ACTIONS(55),
    [anon_sym_COLONassume_COLON] = ACTIONS(57),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(57),
    [anon_sym_COLONprove_COLON] = ACTIONS(57),
    [anon_sym_COLONthen_COLON] = ACTIONS(57),
    [anon_sym_COLONnew_COLON] = ACTIONS(57),
    [anon_sym_COLONlet_COLON] = ACTIONS(57),
    [anon_sym_COLONcase_COLON] = ACTIONS(57),
    [anon_sym_COLONdefine_COLON] = ACTIONS(57),
    [anon_sym_COLONwrite_COLON] = ACTIONS(57),
    [anon_sym_COLONwlog_COLON] = ACTIONS(57),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(57),
    [anon_sym_COLONclaim_COLON] = ACTIONS(57),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(57),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(57),
    [anon_sym_COLONpick_COLON] = ACTIONS(57),
    [anon_sym_COLONst_COLON] = ACTIONS(57),
    [anon_sym_COLONdraft_COLON] = ACTIONS(59),
    [anon_sym_COLONnote_COLON] = ACTIONS(59),
    [anon_sym_COLONspan_COLON] = ACTIONS(59),
    [anon_sym_COLONabstract_COLON] = ACTIONS(61),
    [anon_sym_COLONauthor_COLON] = ACTIONS(61),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(61),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(61),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(61),
    [anon_sym_COLONexample_COLON] = ACTIONS(61),
    [anon_sym_COLONitemize_COLON] = ACTIONS(61),
    [anon_sym_COLONlemma_COLON] = ACTIONS(61),
    [anon_sym_COLONfigure_COLON] = ACTIONS(61),
    [anon_sym_COLONp_COLON] = ACTIONS(61),
    [anon_sym_COLONproof_COLON] = ACTIONS(61),
    [anon_sym_COLONproposition_COLON] = ACTIONS(61),
    [anon_sym_COLONremark_COLON] = ACTIONS(61),
    [anon_sym_COLONsketch_COLON] = ACTIONS(61),
    [anon_sym_COLONstep_COLON] = ACTIONS(61),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(71),
  },
  [STATE(25)] = {
    [sym_block] = STATE(25),
    [sym_paragraph] = STATE(25),
    [sym_inline] = STATE(98),
    [sym_construct] = STATE(98),
    [sym_subsubsection] = STATE(25),
    [sym_mathblock] = STATE(25),
    [sym_specialblock] = STATE(25),
    [sym_caption] = STATE(61),
    [sym_item] = STATE(61),
    [sym_specialinline] = STATE(98),
    [sym_specialconstruct] = STATE(98),
    [sym_table] = STATE(62),
    [sym__paragraphcontent_no_special] = STATE(98),
    [aux_sym_subsection_repeat1] = STATE(25),
    [anon_sym_COLON_COLON] = ACTIONS(157),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(159),
    [aux_sym_section_token1] = ACTIONS(157),
    [anon_sym_COLONsection_COLON] = ACTIONS(157),
    [aux_sym_subsection_token1] = ACTIONS(157),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(157),
    [aux_sym_subsubsection_token1] = ACTIONS(162),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(165),
    [anon_sym_COLONappendix_COLON] = ACTIONS(157),
    [aux_sym_mathblock_token1] = ACTIONS(168),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(171),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(174),
    [anon_sym_COLONtoc_COLON] = ACTIONS(174),
    [aux_sym_specialblock_token1] = ACTIONS(177),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(180),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(183),
    [anon_sym_COLONcaption_COLON] = ACTIONS(186),
    [anon_sym_COLONitem_COLON] = ACTIONS(189),
    [anon_sym_COLONprev_COLON] = ACTIONS(192),
    [anon_sym_COLONprev2_COLON] = ACTIONS(192),
    [anon_sym_COLONprev3_COLON] = ACTIONS(192),
    [aux_sym_specialinline_token1] = ACTIONS(195),
    [aux_sym_specialinline_token2] = ACTIONS(198),
    [anon_sym_COLONmath_COLON] = ACTIONS(201),
    [anon_sym_COLONcode_COLON] = ACTIONS(204),
    [aux_sym_specialinline_token3] = ACTIONS(207),
    [aux_sym_specialinline_token4] = ACTIONS(210),
    [anon_sym_COLONref_COLON] = ACTIONS(213),
    [anon_sym_COLONprevious_COLON] = ACTIONS(216),
    [anon_sym_COLONurl_COLON] = ACTIONS(219),
    [anon_sym_COLONcite_COLON] = ACTIONS(222),
    [anon_sym_COLONqed_COLON] = ACTIONS(225),
    [anon_sym_COLONtable_COLON] = ACTIONS(228),
    [anon_sym_COLONassume_COLON] = ACTIONS(231),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(231),
    [anon_sym_COLONprove_COLON] = ACTIONS(231),
    [anon_sym_COLONthen_COLON] = ACTIONS(231),
    [anon_sym_COLONnew_COLON] = ACTIONS(231),
    [anon_sym_COLONlet_COLON] = ACTIONS(231),
    [anon_sym_COLONcase_COLON] = ACTIONS(231),
    [anon_sym_COLONdefine_COLON] = ACTIONS(231),
    [anon_sym_COLONwrite_COLON] = ACTIONS(231),
    [anon_sym_COLONwlog_COLON] = ACTIONS(231),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(231),
    [anon_sym_COLONclaim_COLON] = ACTIONS(231),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(231),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(231),
    [anon_sym_COLONpick_COLON] = ACTIONS(231),
    [anon_sym_COLONst_COLON] = ACTIONS(231),
    [anon_sym_COLONdraft_COLON] = ACTIONS(234),
    [anon_sym_COLONnote_COLON] = ACTIONS(234),
    [anon_sym_COLONspan_COLON] = ACTIONS(234),
    [anon_sym_COLONabstract_COLON] = ACTIONS(237),
    [anon_sym_COLONauthor_COLON] = ACTIONS(237),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(237),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(237),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(237),
    [anon_sym_COLONexample_COLON] = ACTIONS(237),
    [anon_sym_COLONitemize_COLON] = ACTIONS(237),
    [anon_sym_COLONlemma_COLON] = ACTIONS(237),
    [anon_sym_COLONfigure_COLON] = ACTIONS(237),
    [anon_sym_COLONp_COLON] = ACTIONS(237),
    [anon_sym_COLONproof_COLON] = ACTIONS(237),
    [anon_sym_COLONproposition_COLON] = ACTIONS(237),
    [anon_sym_COLONremark_COLON] = ACTIONS(237),
    [anon_sym_COLONsketch_COLON] = ACTIONS(237),
    [anon_sym_COLONstep_COLON] = ACTIONS(237),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(237),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(240),
  },
  [STATE(26)] = {
    [sym_block] = STATE(30),
    [sym_paragraph] = STATE(30),
    [sym_inline] = STATE(98),
    [sym_construct] = STATE(98),
    [sym_mathblock] = STATE(30),
    [sym_specialblock] = STATE(30),
    [sym_caption] = STATE(61),
    [sym_item] = STATE(61),
    [sym_specialinline] = STATE(98),
    [sym_specialconstruct] = STATE(98),
    [sym_table] = STATE(62),
    [sym__paragraphcontent_no_special] = STATE(98),
    [aux_sym_subsubsection_repeat1] = STATE(30),
    [anon_sym_COLON_COLON] = ACTIONS(243),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(243),
    [anon_sym_COLONsection_COLON] = ACTIONS(243),
    [aux_sym_subsection_token1] = ACTIONS(243),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(243),
    [aux_sym_subsubsection_token1] = ACTIONS(243),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(243),
    [anon_sym_COLONappendix_COLON] = ACTIONS(243),
    [aux_sym_mathblock_token1] = ACTIONS(15),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(17),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(19),
    [aux_sym_specialblock_token1] = ACTIONS(21),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(23),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(25),
    [anon_sym_COLONcaption_COLON] = ACTIONS(27),
    [anon_sym_COLONitem_COLON] = ACTIONS(29),
    [anon_sym_COLONprev_COLON] = ACTIONS(31),
    [anon_sym_COLONprev2_COLON] = ACTIONS(31),
    [anon_sym_COLONprev3_COLON] = ACTIONS(31),
    [aux_sym_specialinline_token1] = ACTIONS(33),
    [aux_sym_specialinline_token2] = ACTIONS(35),
    [anon_sym_COLONmath_COLON] = ACTIONS(37),
    [anon_sym_COLONcode_COLON] = ACTIONS(39),
    [aux_sym_specialinline_token3] = ACTIONS(41),
    [aux_sym_specialinline_token4] = ACTIONS(43),
    [anon_sym_COLONref_COLON] = ACTIONS(45),
    [anon_sym_COLONprevious_COLON] = ACTIONS(47),
    [anon_sym_COLONurl_COLON] = ACTIONS(49),
    [anon_sym_COLONcite_COLON] = ACTIONS(51),
    [anon_sym_COLONqed_COLON] = ACTIONS(53),
    [anon_sym_COLONtable_COLON] = ACTIONS(55),
    [anon_sym_COLONassume_COLON] = ACTIONS(57),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(57),
    [anon_sym_COLONprove_COLON] = ACTIONS(57),
    [anon_sym_COLONthen_COLON] = ACTIONS(57),
    [anon_sym_COLONnew_COLON] = ACTIONS(57),
    [anon_sym_COLONlet_COLON] = ACTIONS(57),
    [anon_sym_COLONcase_COLON] = ACTIONS(57),
    [anon_sym_COLONdefine_COLON] = ACTIONS(57),
    [anon_sym_COLONwrite_COLON] = ACTIONS(57),
    [anon_sym_COLONwlog_COLON] = ACTIONS(57),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(57),
    [anon_sym_COLONclaim_COLON] = ACTIONS(57),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(57),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(57),
    [anon_sym_COLONpick_COLON] = ACTIONS(57),
    [anon_sym_COLONst_COLON] = ACTIONS(57),
    [anon_sym_COLONdraft_COLON] = ACTIONS(59),
    [anon_sym_COLONnote_COLON] = ACTIONS(59),
    [anon_sym_COLONspan_COLON] = ACTIONS(59),
    [anon_sym_COLONabstract_COLON] = ACTIONS(61),
    [anon_sym_COLONauthor_COLON] = ACTIONS(61),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(61),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(61),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(61),
    [anon_sym_COLONexample_COLON] = ACTIONS(61),
    [anon_sym_COLONitemize_COLON] = ACTIONS(61),
    [anon_sym_COLONlemma_COLON] = ACTIONS(61),
    [anon_sym_COLONfigure_COLON] = ACTIONS(61),
    [anon_sym_COLONp_COLON] = ACTIONS(61),
    [anon_sym_COLONproof_COLON] = ACTIONS(61),
    [anon_sym_COLONproposition_COLON] = ACTIONS(61),
    [anon_sym_COLONremark_COLON] = ACTIONS(61),
    [anon_sym_COLONsketch_COLON] = ACTIONS(61),
    [anon_sym_COLONstep_COLON] = ACTIONS(61),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(71),
  },
  [STATE(27)] = {
    [sym_block] = STATE(26),
    [sym_paragraph] = STATE(26),
    [sym_inline] = STATE(98),
    [sym_construct] = STATE(98),
    [sym_mathblock] = STATE(26),
    [sym_specialblock] = STATE(26),
    [sym_caption] = STATE(61),
    [sym_item] = STATE(61),
    [sym_specialinline] = STATE(98),
    [sym_specialconstruct] = STATE(98),
    [sym_table] = STATE(62),
    [sym__paragraphcontent_no_special] = STATE(98),
    [aux_sym_subsubsection_repeat1] = STATE(26),
    [anon_sym_COLON_COLON] = ACTIONS(245),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(245),
    [anon_sym_COLONsection_COLON] = ACTIONS(245),
    [aux_sym_subsection_token1] = ACTIONS(245),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(245),
    [aux_sym_subsubsection_token1] = ACTIONS(245),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(245),
    [anon_sym_COLONappendix_COLON] = ACTIONS(245),
    [aux_sym_mathblock_token1] = ACTIONS(15),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(17),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(19),
    [aux_sym_specialblock_token1] = ACTIONS(21),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(23),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(25),
    [anon_sym_COLONcaption_COLON] = ACTIONS(27),
    [anon_sym_COLONitem_COLON] = ACTIONS(29),
    [anon_sym_COLONprev_COLON] = ACTIONS(31),
    [anon_sym_COLONprev2_COLON] = ACTIONS(31),
    [anon_sym_COLONprev3_COLON] = ACTIONS(31),
    [aux_sym_specialinline_token1] = ACTIONS(33),
    [aux_sym_specialinline_token2] = ACTIONS(35),
    [anon_sym_COLONmath_COLON] = ACTIONS(37),
    [anon_sym_COLONcode_COLON] = ACTIONS(39),
    [aux_sym_specialinline_token3] = ACTIONS(41),
    [aux_sym_specialinline_token4] = ACTIONS(43),
    [anon_sym_COLONref_COLON] = ACTIONS(45),
    [anon_sym_COLONprevious_COLON] = ACTIONS(47),
    [anon_sym_COLONurl_COLON] = ACTIONS(49),
    [anon_sym_COLONcite_COLON] = ACTIONS(51),
    [anon_sym_COLONqed_COLON] = ACTIONS(53),
    [anon_sym_COLONtable_COLON] = ACTIONS(55),
    [anon_sym_COLONassume_COLON] = ACTIONS(57),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(57),
    [anon_sym_COLONprove_COLON] = ACTIONS(57),
    [anon_sym_COLONthen_COLON] = ACTIONS(57),
    [anon_sym_COLONnew_COLON] = ACTIONS(57),
    [anon_sym_COLONlet_COLON] = ACTIONS(57),
    [anon_sym_COLONcase_COLON] = ACTIONS(57),
    [anon_sym_COLONdefine_COLON] = ACTIONS(57),
    [anon_sym_COLONwrite_COLON] = ACTIONS(57),
    [anon_sym_COLONwlog_COLON] = ACTIONS(57),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(57),
    [anon_sym_COLONclaim_COLON] = ACTIONS(57),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(57),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(57),
    [anon_sym_COLONpick_COLON] = ACTIONS(57),
    [anon_sym_COLONst_COLON] = ACTIONS(57),
    [anon_sym_COLONdraft_COLON] = ACTIONS(59),
    [anon_sym_COLONnote_COLON] = ACTIONS(59),
    [anon_sym_COLONspan_COLON] = ACTIONS(59),
    [anon_sym_COLONabstract_COLON] = ACTIONS(61),
    [anon_sym_COLONauthor_COLON] = ACTIONS(61),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(61),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(61),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(61),
    [anon_sym_COLONexample_COLON] = ACTIONS(61),
    [anon_sym_COLONitemize_COLON] = ACTIONS(61),
    [anon_sym_COLONlemma_COLON] = ACTIONS(61),
    [anon_sym_COLONfigure_COLON] = ACTIONS(61),
    [anon_sym_COLONp_COLON] = ACTIONS(61),
    [anon_sym_COLONproof_COLON] = ACTIONS(61),
    [anon_sym_COLONproposition_COLON] = ACTIONS(61),
    [anon_sym_COLONremark_COLON] = ACTIONS(61),
    [anon_sym_COLONsketch_COLON] = ACTIONS(61),
    [anon_sym_COLONstep_COLON] = ACTIONS(61),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(71),
  },
  [STATE(28)] = {
    [sym_block] = STATE(30),
    [sym_paragraph] = STATE(30),
    [sym_inline] = STATE(98),
    [sym_construct] = STATE(98),
    [sym_mathblock] = STATE(30),
    [sym_specialblock] = STATE(30),
    [sym_caption] = STATE(61),
    [sym_item] = STATE(61),
    [sym_specialinline] = STATE(98),
    [sym_specialconstruct] = STATE(98),
    [sym_table] = STATE(62),
    [sym__paragraphcontent_no_special] = STATE(98),
    [aux_sym_subsubsection_repeat1] = STATE(30),
    [anon_sym_COLON_COLON] = ACTIONS(247),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(247),
    [anon_sym_COLONsection_COLON] = ACTIONS(247),
    [aux_sym_subsection_token1] = ACTIONS(247),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(247),
    [aux_sym_subsubsection_token1] = ACTIONS(247),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(247),
    [anon_sym_COLONappendix_COLON] = ACTIONS(247),
    [aux_sym_mathblock_token1] = ACTIONS(15),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(17),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(19),
    [aux_sym_specialblock_token1] = ACTIONS(21),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(23),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(25),
    [anon_sym_COLONcaption_COLON] = ACTIONS(27),
    [anon_sym_COLONitem_COLON] = ACTIONS(29),
    [anon_sym_COLONprev_COLON] = ACTIONS(31),
    [anon_sym_COLONprev2_COLON] = ACTIONS(31),
    [anon_sym_COLONprev3_COLON] = ACTIONS(31),
    [aux_sym_specialinline_token1] = ACTIONS(33),
    [aux_sym_specialinline_token2] = ACTIONS(35),
    [anon_sym_COLONmath_COLON] = ACTIONS(37),
    [anon_sym_COLONcode_COLON] = ACTIONS(39),
    [aux_sym_specialinline_token3] = ACTIONS(41),
    [aux_sym_specialinline_token4] = ACTIONS(43),
    [anon_sym_COLONref_COLON] = ACTIONS(45),
    [anon_sym_COLONprevious_COLON] = ACTIONS(47),
    [anon_sym_COLONurl_COLON] = ACTIONS(49),
    [anon_sym_COLONcite_COLON] = ACTIONS(51),
    [anon_sym_COLONqed_COLON] = ACTIONS(53),
    [anon_sym_COLONtable_COLON] = ACTIONS(55),
    [anon_sym_COLONassume_COLON] = ACTIONS(57),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(57),
    [anon_sym_COLONprove_COLON] = ACTIONS(57),
    [anon_sym_COLONthen_COLON] = ACTIONS(57),
    [anon_sym_COLONnew_COLON] = ACTIONS(57),
    [anon_sym_COLONlet_COLON] = ACTIONS(57),
    [anon_sym_COLONcase_COLON] = ACTIONS(57),
    [anon_sym_COLONdefine_COLON] = ACTIONS(57),
    [anon_sym_COLONwrite_COLON] = ACTIONS(57),
    [anon_sym_COLONwlog_COLON] = ACTIONS(57),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(57),
    [anon_sym_COLONclaim_COLON] = ACTIONS(57),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(57),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(57),
    [anon_sym_COLONpick_COLON] = ACTIONS(57),
    [anon_sym_COLONst_COLON] = ACTIONS(57),
    [anon_sym_COLONdraft_COLON] = ACTIONS(59),
    [anon_sym_COLONnote_COLON] = ACTIONS(59),
    [anon_sym_COLONspan_COLON] = ACTIONS(59),
    [anon_sym_COLONabstract_COLON] = ACTIONS(61),
    [anon_sym_COLONauthor_COLON] = ACTIONS(61),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(61),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(61),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(61),
    [anon_sym_COLONexample_COLON] = ACTIONS(61),
    [anon_sym_COLONitemize_COLON] = ACTIONS(61),
    [anon_sym_COLONlemma_COLON] = ACTIONS(61),
    [anon_sym_COLONfigure_COLON] = ACTIONS(61),
    [anon_sym_COLONp_COLON] = ACTIONS(61),
    [anon_sym_COLONproof_COLON] = ACTIONS(61),
    [anon_sym_COLONproposition_COLON] = ACTIONS(61),
    [anon_sym_COLONremark_COLON] = ACTIONS(61),
    [anon_sym_COLONsketch_COLON] = ACTIONS(61),
    [anon_sym_COLONstep_COLON] = ACTIONS(61),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(71),
  },
  [STATE(29)] = {
    [sym_block] = STATE(32),
    [sym_paragraph] = STATE(32),
    [sym_inline] = STATE(98),
    [sym_construct] = STATE(98),
    [sym_mathblock] = STATE(32),
    [sym_specialblock] = STATE(32),
    [sym_caption] = STATE(61),
    [sym_item] = STATE(61),
    [sym_specialinline] = STATE(98),
    [sym_specialconstruct] = STATE(98),
    [sym_table] = STATE(62),
    [sym__paragraphcontent_no_special] = STATE(98),
    [aux_sym_subsubsection_repeat1] = STATE(32),
    [anon_sym_COLON_COLON] = ACTIONS(249),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(249),
    [anon_sym_COLONsection_COLON] = ACTIONS(249),
    [aux_sym_subsection_token1] = ACTIONS(249),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(249),
    [aux_sym_subsubsection_token1] = ACTIONS(249),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(249),
    [anon_sym_COLONappendix_COLON] = ACTIONS(249),
    [aux_sym_mathblock_token1] = ACTIONS(15),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(17),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(19),
    [aux_sym_specialblock_token1] = ACTIONS(21),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(23),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(25),
    [anon_sym_COLONcaption_COLON] = ACTIONS(27),
    [anon_sym_COLONitem_COLON] = ACTIONS(29),
    [anon_sym_COLONprev_COLON] = ACTIONS(31),
    [anon_sym_COLONprev2_COLON] = ACTIONS(31),
    [anon_sym_COLONprev3_COLON] = ACTIONS(31),
    [aux_sym_specialinline_token1] = ACTIONS(33),
    [aux_sym_specialinline_token2] = ACTIONS(35),
    [anon_sym_COLONmath_COLON] = ACTIONS(37),
    [anon_sym_COLONcode_COLON] = ACTIONS(39),
    [aux_sym_specialinline_token3] = ACTIONS(41),
    [aux_sym_specialinline_token4] = ACTIONS(43),
    [anon_sym_COLONref_COLON] = ACTIONS(45),
    [anon_sym_COLONprevious_COLON] = ACTIONS(47),
    [anon_sym_COLONurl_COLON] = ACTIONS(49),
    [anon_sym_COLONcite_COLON] = ACTIONS(51),
    [anon_sym_COLONqed_COLON] = ACTIONS(53),
    [anon_sym_COLONtable_COLON] = ACTIONS(55),
    [anon_sym_COLONassume_COLON] = ACTIONS(57),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(57),
    [anon_sym_COLONprove_COLON] = ACTIONS(57),
    [anon_sym_COLONthen_COLON] = ACTIONS(57),
    [anon_sym_COLONnew_COLON] = ACTIONS(57),
    [anon_sym_COLONlet_COLON] = ACTIONS(57),
    [anon_sym_COLONcase_COLON] = ACTIONS(57),
    [anon_sym_COLONdefine_COLON] = ACTIONS(57),
    [anon_sym_COLONwrite_COLON] = ACTIONS(57),
    [anon_sym_COLONwlog_COLON] = ACTIONS(57),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(57),
    [anon_sym_COLONclaim_COLON] = ACTIONS(57),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(57),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(57),
    [anon_sym_COLONpick_COLON] = ACTIONS(57),
    [anon_sym_COLONst_COLON] = ACTIONS(57),
    [anon_sym_COLONdraft_COLON] = ACTIONS(59),
    [anon_sym_COLONnote_COLON] = ACTIONS(59),
    [anon_sym_COLONspan_COLON] = ACTIONS(59),
    [anon_sym_COLONabstract_COLON] = ACTIONS(61),
    [anon_sym_COLONauthor_COLON] = ACTIONS(61),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(61),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(61),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(61),
    [anon_sym_COLONexample_COLON] = ACTIONS(61),
    [anon_sym_COLONitemize_COLON] = ACTIONS(61),
    [anon_sym_COLONlemma_COLON] = ACTIONS(61),
    [anon_sym_COLONfigure_COLON] = ACTIONS(61),
    [anon_sym_COLONp_COLON] = ACTIONS(61),
    [anon_sym_COLONproof_COLON] = ACTIONS(61),
    [anon_sym_COLONproposition_COLON] = ACTIONS(61),
    [anon_sym_COLONremark_COLON] = ACTIONS(61),
    [anon_sym_COLONsketch_COLON] = ACTIONS(61),
    [anon_sym_COLONstep_COLON] = ACTIONS(61),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(71),
  },
  [STATE(30)] = {
    [sym_block] = STATE(30),
    [sym_paragraph] = STATE(30),
    [sym_inline] = STATE(98),
    [sym_construct] = STATE(98),
    [sym_mathblock] = STATE(30),
    [sym_specialblock] = STATE(30),
    [sym_caption] = STATE(61),
    [sym_item] = STATE(61),
    [sym_specialinline] = STATE(98),
    [sym_specialconstruct] = STATE(98),
    [sym_table] = STATE(62),
    [sym__paragraphcontent_no_special] = STATE(98),
    [aux_sym_subsubsection_repeat1] = STATE(30),
    [anon_sym_COLON_COLON] = ACTIONS(251),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(253),
    [aux_sym_section_token1] = ACTIONS(251),
    [anon_sym_COLONsection_COLON] = ACTIONS(251),
    [aux_sym_subsection_token1] = ACTIONS(251),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(251),
    [aux_sym_subsubsection_token1] = ACTIONS(251),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(251),
    [anon_sym_COLONappendix_COLON] = ACTIONS(251),
    [aux_sym_mathblock_token1] = ACTIONS(256),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(259),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(262),
    [anon_sym_COLONtoc_COLON] = ACTIONS(262),
    [aux_sym_specialblock_token1] = ACTIONS(265),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(268),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(271),
    [anon_sym_COLONcaption_COLON] = ACTIONS(274),
    [anon_sym_COLONitem_COLON] = ACTIONS(277),
    [anon_sym_COLONprev_COLON] = ACTIONS(280),
    [anon_sym_COLONprev2_COLON] = ACTIONS(280),
    [anon_sym_COLONprev3_COLON] = ACTIONS(280),
    [aux_sym_specialinline_token1] = ACTIONS(283),
    [aux_sym_specialinline_token2] = ACTIONS(286),
    [anon_sym_COLONmath_COLON] = ACTIONS(289),
    [anon_sym_COLONcode_COLON] = ACTIONS(292),
    [aux_sym_specialinline_token3] = ACTIONS(295),
    [aux_sym_specialinline_token4] = ACTIONS(298),
    [anon_sym_COLONref_COLON] = ACTIONS(301),
    [anon_sym_COLONprevious_COLON] = ACTIONS(304),
    [anon_sym_COLONurl_COLON] = ACTIONS(307),
    [anon_sym_COLONcite_COLON] = ACTIONS(310),
    [anon_sym_COLONqed_COLON] = ACTIONS(313),
    [anon_sym_COLONtable_COLON] = ACTIONS(316),
    [anon_sym_COLONassume_COLON] = ACTIONS(319),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(319),
    [anon_sym_COLONprove_COLON] = ACTIONS(319),
    [anon_sym_COLONthen_COLON] = ACTIONS(319),
    [anon_sym_COLONnew_COLON] = ACTIONS(319),
    [anon_sym_COLONlet_COLON] = ACTIONS(319),
    [anon_sym_COLONcase_COLON] = ACTIONS(319),
    [anon_sym_COLONdefine_COLON] = ACTIONS(319),
    [anon_sym_COLONwrite_COLON] = ACTIONS(319),
    [anon_sym_COLONwlog_COLON] = ACTIONS(319),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(319),
    [anon_sym_COLONclaim_COLON] = ACTIONS(319),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(319),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(319),
    [anon_sym_COLONpick_COLON] = ACTIONS(319),
    [anon_sym_COLONst_COLON] = ACTIONS(319),
    [anon_sym_COLONdraft_COLON] = ACTIONS(322),
    [anon_sym_COLONnote_COLON] = ACTIONS(322),
    [anon_sym_COLONspan_COLON] = ACTIONS(322),
    [anon_sym_COLONabstract_COLON] = ACTIONS(325),
    [anon_sym_COLONauthor_COLON] = ACTIONS(325),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(325),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(325),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(325),
    [anon_sym_COLONexample_COLON] = ACTIONS(325),
    [anon_sym_COLONitemize_COLON] = ACTIONS(325),
    [anon_sym_COLONlemma_COLON] = ACTIONS(325),
    [anon_sym_COLONfigure_COLON] = ACTIONS(325),
    [anon_sym_COLONp_COLON] = ACTIONS(325),
    [anon_sym_COLONproof_COLON] = ACTIONS(325),
    [anon_sym_COLONproposition_COLON] = ACTIONS(325),
    [anon_sym_COLONremark_COLON] = ACTIONS(325),
    [anon_sym_COLONsketch_COLON] = ACTIONS(325),
    [anon_sym_COLONstep_COLON] = ACTIONS(325),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(325),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(328),
  },
  [STATE(31)] = {
    [sym_block] = STATE(30),
    [sym_paragraph] = STATE(30),
    [sym_inline] = STATE(98),
    [sym_construct] = STATE(98),
    [sym_mathblock] = STATE(30),
    [sym_specialblock] = STATE(30),
    [sym_caption] = STATE(61),
    [sym_item] = STATE(61),
    [sym_specialinline] = STATE(98),
    [sym_specialconstruct] = STATE(98),
    [sym_table] = STATE(62),
    [sym__paragraphcontent_no_special] = STATE(98),
    [aux_sym_subsubsection_repeat1] = STATE(30),
    [anon_sym_COLON_COLON] = ACTIONS(331),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(331),
    [anon_sym_COLONsection_COLON] = ACTIONS(331),
    [aux_sym_subsection_token1] = ACTIONS(331),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(331),
    [aux_sym_subsubsection_token1] = ACTIONS(331),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(331),
    [anon_sym_COLONappendix_COLON] = ACTIONS(331),
    [aux_sym_mathblock_token1] = ACTIONS(15),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(17),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(19),
    [aux_sym_specialblock_token1] = ACTIONS(21),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(23),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(25),
    [anon_sym_COLONcaption_COLON] = ACTIONS(27),
    [anon_sym_COLONitem_COLON] = ACTIONS(29),
    [anon_sym_COLONprev_COLON] = ACTIONS(31),
    [anon_sym_COLONprev2_COLON] = ACTIONS(31),
    [anon_sym_COLONprev3_COLON] = ACTIONS(31),
    [aux_sym_specialinline_token1] = ACTIONS(33),
    [aux_sym_specialinline_token2] = ACTIONS(35),
    [anon_sym_COLONmath_COLON] = ACTIONS(37),
    [anon_sym_COLONcode_COLON] = ACTIONS(39),
    [aux_sym_specialinline_token3] = ACTIONS(41),
    [aux_sym_specialinline_token4] = ACTIONS(43),
    [anon_sym_COLONref_COLON] = ACTIONS(45),
    [anon_sym_COLONprevious_COLON] = ACTIONS(47),
    [anon_sym_COLONurl_COLON] = ACTIONS(49),
    [anon_sym_COLONcite_COLON] = ACTIONS(51),
    [anon_sym_COLONqed_COLON] = ACTIONS(53),
    [anon_sym_COLONtable_COLON] = ACTIONS(55),
    [anon_sym_COLONassume_COLON] = ACTIONS(57),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(57),
    [anon_sym_COLONprove_COLON] = ACTIONS(57),
    [anon_sym_COLONthen_COLON] = ACTIONS(57),
    [anon_sym_COLONnew_COLON] = ACTIONS(57),
    [anon_sym_COLONlet_COLON] = ACTIONS(57),
    [anon_sym_COLONcase_COLON] = ACTIONS(57),
    [anon_sym_COLONdefine_COLON] = ACTIONS(57),
    [anon_sym_COLONwrite_COLON] = ACTIONS(57),
    [anon_sym_COLONwlog_COLON] = ACTIONS(57),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(57),
    [anon_sym_COLONclaim_COLON] = ACTIONS(57),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(57),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(57),
    [anon_sym_COLONpick_COLON] = ACTIONS(57),
    [anon_sym_COLONst_COLON] = ACTIONS(57),
    [anon_sym_COLONdraft_COLON] = ACTIONS(59),
    [anon_sym_COLONnote_COLON] = ACTIONS(59),
    [anon_sym_COLONspan_COLON] = ACTIONS(59),
    [anon_sym_COLONabstract_COLON] = ACTIONS(61),
    [anon_sym_COLONauthor_COLON] = ACTIONS(61),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(61),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(61),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(61),
    [anon_sym_COLONexample_COLON] = ACTIONS(61),
    [anon_sym_COLONitemize_COLON] = ACTIONS(61),
    [anon_sym_COLONlemma_COLON] = ACTIONS(61),
    [anon_sym_COLONfigure_COLON] = ACTIONS(61),
    [anon_sym_COLONp_COLON] = ACTIONS(61),
    [anon_sym_COLONproof_COLON] = ACTIONS(61),
    [anon_sym_COLONproposition_COLON] = ACTIONS(61),
    [anon_sym_COLONremark_COLON] = ACTIONS(61),
    [anon_sym_COLONsketch_COLON] = ACTIONS(61),
    [anon_sym_COLONstep_COLON] = ACTIONS(61),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(71),
  },
  [STATE(32)] = {
    [sym_block] = STATE(30),
    [sym_paragraph] = STATE(30),
    [sym_inline] = STATE(98),
    [sym_construct] = STATE(98),
    [sym_mathblock] = STATE(30),
    [sym_specialblock] = STATE(30),
    [sym_caption] = STATE(61),
    [sym_item] = STATE(61),
    [sym_specialinline] = STATE(98),
    [sym_specialconstruct] = STATE(98),
    [sym_table] = STATE(62),
    [sym__paragraphcontent_no_special] = STATE(98),
    [aux_sym_subsubsection_repeat1] = STATE(30),
    [anon_sym_COLON_COLON] = ACTIONS(333),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(333),
    [anon_sym_COLONsection_COLON] = ACTIONS(333),
    [aux_sym_subsection_token1] = ACTIONS(333),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(333),
    [aux_sym_subsubsection_token1] = ACTIONS(333),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(333),
    [anon_sym_COLONappendix_COLON] = ACTIONS(333),
    [aux_sym_mathblock_token1] = ACTIONS(15),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(17),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(19),
    [aux_sym_specialblock_token1] = ACTIONS(21),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(23),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(25),
    [anon_sym_COLONcaption_COLON] = ACTIONS(27),
    [anon_sym_COLONitem_COLON] = ACTIONS(29),
    [anon_sym_COLONprev_COLON] = ACTIONS(31),
    [anon_sym_COLONprev2_COLON] = ACTIONS(31),
    [anon_sym_COLONprev3_COLON] = ACTIONS(31),
    [aux_sym_specialinline_token1] = ACTIONS(33),
    [aux_sym_specialinline_token2] = ACTIONS(35),
    [anon_sym_COLONmath_COLON] = ACTIONS(37),
    [anon_sym_COLONcode_COLON] = ACTIONS(39),
    [aux_sym_specialinline_token3] = ACTIONS(41),
    [aux_sym_specialinline_token4] = ACTIONS(43),
    [anon_sym_COLONref_COLON] = ACTIONS(45),
    [anon_sym_COLONprevious_COLON] = ACTIONS(47),
    [anon_sym_COLONurl_COLON] = ACTIONS(49),
    [anon_sym_COLONcite_COLON] = ACTIONS(51),
    [anon_sym_COLONqed_COLON] = ACTIONS(53),
    [anon_sym_COLONtable_COLON] = ACTIONS(55),
    [anon_sym_COLONassume_COLON] = ACTIONS(57),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(57),
    [anon_sym_COLONprove_COLON] = ACTIONS(57),
    [anon_sym_COLONthen_COLON] = ACTIONS(57),
    [anon_sym_COLONnew_COLON] = ACTIONS(57),
    [anon_sym_COLONlet_COLON] = ACTIONS(57),
    [anon_sym_COLONcase_COLON] = ACTIONS(57),
    [anon_sym_COLONdefine_COLON] = ACTIONS(57),
    [anon_sym_COLONwrite_COLON] = ACTIONS(57),
    [anon_sym_COLONwlog_COLON] = ACTIONS(57),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(57),
    [anon_sym_COLONclaim_COLON] = ACTIONS(57),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(57),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(57),
    [anon_sym_COLONpick_COLON] = ACTIONS(57),
    [anon_sym_COLONst_COLON] = ACTIONS(57),
    [anon_sym_COLONdraft_COLON] = ACTIONS(59),
    [anon_sym_COLONnote_COLON] = ACTIONS(59),
    [anon_sym_COLONspan_COLON] = ACTIONS(59),
    [anon_sym_COLONabstract_COLON] = ACTIONS(61),
    [anon_sym_COLONauthor_COLON] = ACTIONS(61),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(61),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(61),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(61),
    [anon_sym_COLONexample_COLON] = ACTIONS(61),
    [anon_sym_COLONitemize_COLON] = ACTIONS(61),
    [anon_sym_COLONlemma_COLON] = ACTIONS(61),
    [anon_sym_COLONfigure_COLON] = ACTIONS(61),
    [anon_sym_COLONp_COLON] = ACTIONS(61),
    [anon_sym_COLONproof_COLON] = ACTIONS(61),
    [anon_sym_COLONproposition_COLON] = ACTIONS(61),
    [anon_sym_COLONremark_COLON] = ACTIONS(61),
    [anon_sym_COLONsketch_COLON] = ACTIONS(61),
    [anon_sym_COLONstep_COLON] = ACTIONS(61),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(71),
  },
  [STATE(33)] = {
    [sym_block] = STATE(33),
    [sym_paragraph] = STATE(33),
    [sym_inline] = STATE(98),
    [sym_construct] = STATE(98),
    [sym_subsection] = STATE(33),
    [sym_mathblock] = STATE(33),
    [sym_specialblock] = STATE(33),
    [sym_caption] = STATE(61),
    [sym_item] = STATE(61),
    [sym_specialinline] = STATE(98),
    [sym_specialconstruct] = STATE(98),
    [sym_table] = STATE(62),
    [sym__paragraphcontent_no_special] = STATE(98),
    [aux_sym_section_repeat1] = STATE(33),
    [anon_sym_COLON_COLON] = ACTIONS(335),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(337),
    [aux_sym_section_token1] = ACTIONS(335),
    [anon_sym_COLONsection_COLON] = ACTIONS(335),
    [aux_sym_subsection_token1] = ACTIONS(340),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(343),
    [anon_sym_COLONappendix_COLON] = ACTIONS(335),
    [aux_sym_mathblock_token1] = ACTIONS(346),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(349),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(352),
    [anon_sym_COLONtoc_COLON] = ACTIONS(352),
    [aux_sym_specialblock_token1] = ACTIONS(355),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(358),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(361),
    [anon_sym_COLONcaption_COLON] = ACTIONS(364),
    [anon_sym_COLONitem_COLON] = ACTIONS(367),
    [anon_sym_COLONprev_COLON] = ACTIONS(370),
    [anon_sym_COLONprev2_COLON] = ACTIONS(370),
    [anon_sym_COLONprev3_COLON] = ACTIONS(370),
    [aux_sym_specialinline_token1] = ACTIONS(373),
    [aux_sym_specialinline_token2] = ACTIONS(376),
    [anon_sym_COLONmath_COLON] = ACTIONS(379),
    [anon_sym_COLONcode_COLON] = ACTIONS(382),
    [aux_sym_specialinline_token3] = ACTIONS(385),
    [aux_sym_specialinline_token4] = ACTIONS(388),
    [anon_sym_COLONref_COLON] = ACTIONS(391),
    [anon_sym_COLONprevious_COLON] = ACTIONS(394),
    [anon_sym_COLONurl_COLON] = ACTIONS(397),
    [anon_sym_COLONcite_COLON] = ACTIONS(400),
    [anon_sym_COLONqed_COLON] = ACTIONS(403),
    [anon_sym_COLONtable_COLON] = ACTIONS(406),
    [anon_sym_COLONassume_COLON] = ACTIONS(409),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(409),
    [anon_sym_COLONprove_COLON] = ACTIONS(409),
    [anon_sym_COLONthen_COLON] = ACTIONS(409),
    [anon_sym_COLONnew_COLON] = ACTIONS(409),
    [anon_sym_COLONlet_COLON] = ACTIONS(409),
    [anon_sym_COLONcase_COLON] = ACTIONS(409),
    [anon_sym_COLONdefine_COLON] = ACTIONS(409),
    [anon_sym_COLONwrite_COLON] = ACTIONS(409),
    [anon_sym_COLONwlog_COLON] = ACTIONS(409),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(409),
    [anon_sym_COLONclaim_COLON] = ACTIONS(409),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(409),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(409),
    [anon_sym_COLONpick_COLON] = ACTIONS(409),
    [anon_sym_COLONst_COLON] = ACTIONS(409),
    [anon_sym_COLONdraft_COLON] = ACTIONS(412),
    [anon_sym_COLONnote_COLON] = ACTIONS(412),
    [anon_sym_COLONspan_COLON] = ACTIONS(412),
    [anon_sym_COLONabstract_COLON] = ACTIONS(415),
    [anon_sym_COLONauthor_COLON] = ACTIONS(415),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(415),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(415),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(415),
    [anon_sym_COLONexample_COLON] = ACTIONS(415),
    [anon_sym_COLONitemize_COLON] = ACTIONS(415),
    [anon_sym_COLONlemma_COLON] = ACTIONS(415),
    [anon_sym_COLONfigure_COLON] = ACTIONS(415),
    [anon_sym_COLONp_COLON] = ACTIONS(415),
    [anon_sym_COLONproof_COLON] = ACTIONS(415),
    [anon_sym_COLONproposition_COLON] = ACTIONS(415),
    [anon_sym_COLONremark_COLON] = ACTIONS(415),
    [anon_sym_COLONsketch_COLON] = ACTIONS(415),
    [anon_sym_COLONstep_COLON] = ACTIONS(415),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(415),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(418),
  },
  [STATE(34)] = {
    [sym_block] = STATE(33),
    [sym_paragraph] = STATE(33),
    [sym_inline] = STATE(98),
    [sym_construct] = STATE(98),
    [sym_subsection] = STATE(33),
    [sym_mathblock] = STATE(33),
    [sym_specialblock] = STATE(33),
    [sym_caption] = STATE(61),
    [sym_item] = STATE(61),
    [sym_specialinline] = STATE(98),
    [sym_specialconstruct] = STATE(98),
    [sym_table] = STATE(62),
    [sym__paragraphcontent_no_special] = STATE(98),
    [aux_sym_section_repeat1] = STATE(33),
    [anon_sym_COLON_COLON] = ACTIONS(421),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(421),
    [anon_sym_COLONsection_COLON] = ACTIONS(421),
    [aux_sym_subsection_token1] = ACTIONS(81),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(83),
    [anon_sym_COLONappendix_COLON] = ACTIONS(421),
    [aux_sym_mathblock_token1] = ACTIONS(15),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(17),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(19),
    [aux_sym_specialblock_token1] = ACTIONS(21),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(23),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(25),
    [anon_sym_COLONcaption_COLON] = ACTIONS(27),
    [anon_sym_COLONitem_COLON] = ACTIONS(29),
    [anon_sym_COLONprev_COLON] = ACTIONS(31),
    [anon_sym_COLONprev2_COLON] = ACTIONS(31),
    [anon_sym_COLONprev3_COLON] = ACTIONS(31),
    [aux_sym_specialinline_token1] = ACTIONS(33),
    [aux_sym_specialinline_token2] = ACTIONS(35),
    [anon_sym_COLONmath_COLON] = ACTIONS(37),
    [anon_sym_COLONcode_COLON] = ACTIONS(39),
    [aux_sym_specialinline_token3] = ACTIONS(41),
    [aux_sym_specialinline_token4] = ACTIONS(43),
    [anon_sym_COLONref_COLON] = ACTIONS(45),
    [anon_sym_COLONprevious_COLON] = ACTIONS(47),
    [anon_sym_COLONurl_COLON] = ACTIONS(49),
    [anon_sym_COLONcite_COLON] = ACTIONS(51),
    [anon_sym_COLONqed_COLON] = ACTIONS(53),
    [anon_sym_COLONtable_COLON] = ACTIONS(55),
    [anon_sym_COLONassume_COLON] = ACTIONS(57),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(57),
    [anon_sym_COLONprove_COLON] = ACTIONS(57),
    [anon_sym_COLONthen_COLON] = ACTIONS(57),
    [anon_sym_COLONnew_COLON] = ACTIONS(57),
    [anon_sym_COLONlet_COLON] = ACTIONS(57),
    [anon_sym_COLONcase_COLON] = ACTIONS(57),
    [anon_sym_COLONdefine_COLON] = ACTIONS(57),
    [anon_sym_COLONwrite_COLON] = ACTIONS(57),
    [anon_sym_COLONwlog_COLON] = ACTIONS(57),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(57),
    [anon_sym_COLONclaim_COLON] = ACTIONS(57),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(57),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(57),
    [anon_sym_COLONpick_COLON] = ACTIONS(57),
    [anon_sym_COLONst_COLON] = ACTIONS(57),
    [anon_sym_COLONdraft_COLON] = ACTIONS(59),
    [anon_sym_COLONnote_COLON] = ACTIONS(59),
    [anon_sym_COLONspan_COLON] = ACTIONS(59),
    [anon_sym_COLONabstract_COLON] = ACTIONS(61),
    [anon_sym_COLONauthor_COLON] = ACTIONS(61),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(61),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(61),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(61),
    [anon_sym_COLONexample_COLON] = ACTIONS(61),
    [anon_sym_COLONitemize_COLON] = ACTIONS(61),
    [anon_sym_COLONlemma_COLON] = ACTIONS(61),
    [anon_sym_COLONfigure_COLON] = ACTIONS(61),
    [anon_sym_COLONp_COLON] = ACTIONS(61),
    [anon_sym_COLONproof_COLON] = ACTIONS(61),
    [anon_sym_COLONproposition_COLON] = ACTIONS(61),
    [anon_sym_COLONremark_COLON] = ACTIONS(61),
    [anon_sym_COLONsketch_COLON] = ACTIONS(61),
    [anon_sym_COLONstep_COLON] = ACTIONS(61),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(71),
  },
  [STATE(35)] = {
    [sym_block] = STATE(33),
    [sym_paragraph] = STATE(33),
    [sym_inline] = STATE(98),
    [sym_construct] = STATE(98),
    [sym_subsection] = STATE(33),
    [sym_mathblock] = STATE(33),
    [sym_specialblock] = STATE(33),
    [sym_caption] = STATE(61),
    [sym_item] = STATE(61),
    [sym_specialinline] = STATE(98),
    [sym_specialconstruct] = STATE(98),
    [sym_table] = STATE(62),
    [sym__paragraphcontent_no_special] = STATE(98),
    [aux_sym_section_repeat1] = STATE(33),
    [anon_sym_COLON_COLON] = ACTIONS(423),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(423),
    [anon_sym_COLONsection_COLON] = ACTIONS(423),
    [aux_sym_subsection_token1] = ACTIONS(81),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(83),
    [anon_sym_COLONappendix_COLON] = ACTIONS(423),
    [aux_sym_mathblock_token1] = ACTIONS(15),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(17),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(19),
    [aux_sym_specialblock_token1] = ACTIONS(21),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(23),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(25),
    [anon_sym_COLONcaption_COLON] = ACTIONS(27),
    [anon_sym_COLONitem_COLON] = ACTIONS(29),
    [anon_sym_COLONprev_COLON] = ACTIONS(31),
    [anon_sym_COLONprev2_COLON] = ACTIONS(31),
    [anon_sym_COLONprev3_COLON] = ACTIONS(31),
    [aux_sym_specialinline_token1] = ACTIONS(33),
    [aux_sym_specialinline_token2] = ACTIONS(35),
    [anon_sym_COLONmath_COLON] = ACTIONS(37),
    [anon_sym_COLONcode_COLON] = ACTIONS(39),
    [aux_sym_specialinline_token3] = ACTIONS(41),
    [aux_sym_specialinline_token4] = ACTIONS(43),
    [anon_sym_COLONref_COLON] = ACTIONS(45),
    [anon_sym_COLONprevious_COLON] = ACTIONS(47),
    [anon_sym_COLONurl_COLON] = ACTIONS(49),
    [anon_sym_COLONcite_COLON] = ACTIONS(51),
    [anon_sym_COLONqed_COLON] = ACTIONS(53),
    [anon_sym_COLONtable_COLON] = ACTIONS(55),
    [anon_sym_COLONassume_COLON] = ACTIONS(57),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(57),
    [anon_sym_COLONprove_COLON] = ACTIONS(57),
    [anon_sym_COLONthen_COLON] = ACTIONS(57),
    [anon_sym_COLONnew_COLON] = ACTIONS(57),
    [anon_sym_COLONlet_COLON] = ACTIONS(57),
    [anon_sym_COLONcase_COLON] = ACTIONS(57),
    [anon_sym_COLONdefine_COLON] = ACTIONS(57),
    [anon_sym_COLONwrite_COLON] = ACTIONS(57),
    [anon_sym_COLONwlog_COLON] = ACTIONS(57),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(57),
    [anon_sym_COLONclaim_COLON] = ACTIONS(57),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(57),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(57),
    [anon_sym_COLONpick_COLON] = ACTIONS(57),
    [anon_sym_COLONst_COLON] = ACTIONS(57),
    [anon_sym_COLONdraft_COLON] = ACTIONS(59),
    [anon_sym_COLONnote_COLON] = ACTIONS(59),
    [anon_sym_COLONspan_COLON] = ACTIONS(59),
    [anon_sym_COLONabstract_COLON] = ACTIONS(61),
    [anon_sym_COLONauthor_COLON] = ACTIONS(61),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(61),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(61),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(61),
    [anon_sym_COLONexample_COLON] = ACTIONS(61),
    [anon_sym_COLONitemize_COLON] = ACTIONS(61),
    [anon_sym_COLONlemma_COLON] = ACTIONS(61),
    [anon_sym_COLONfigure_COLON] = ACTIONS(61),
    [anon_sym_COLONp_COLON] = ACTIONS(61),
    [anon_sym_COLONproof_COLON] = ACTIONS(61),
    [anon_sym_COLONproposition_COLON] = ACTIONS(61),
    [anon_sym_COLONremark_COLON] = ACTIONS(61),
    [anon_sym_COLONsketch_COLON] = ACTIONS(61),
    [anon_sym_COLONstep_COLON] = ACTIONS(61),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(71),
  },
  [STATE(36)] = {
    [sym_block] = STATE(33),
    [sym_paragraph] = STATE(33),
    [sym_inline] = STATE(98),
    [sym_construct] = STATE(98),
    [sym_subsection] = STATE(33),
    [sym_mathblock] = STATE(33),
    [sym_specialblock] = STATE(33),
    [sym_caption] = STATE(61),
    [sym_item] = STATE(61),
    [sym_specialinline] = STATE(98),
    [sym_specialconstruct] = STATE(98),
    [sym_table] = STATE(62),
    [sym__paragraphcontent_no_special] = STATE(98),
    [aux_sym_section_repeat1] = STATE(33),
    [anon_sym_COLON_COLON] = ACTIONS(425),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(425),
    [anon_sym_COLONsection_COLON] = ACTIONS(425),
    [aux_sym_subsection_token1] = ACTIONS(81),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(83),
    [anon_sym_COLONappendix_COLON] = ACTIONS(425),
    [aux_sym_mathblock_token1] = ACTIONS(15),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(17),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(19),
    [aux_sym_specialblock_token1] = ACTIONS(21),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(23),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(25),
    [anon_sym_COLONcaption_COLON] = ACTIONS(27),
    [anon_sym_COLONitem_COLON] = ACTIONS(29),
    [anon_sym_COLONprev_COLON] = ACTIONS(31),
    [anon_sym_COLONprev2_COLON] = ACTIONS(31),
    [anon_sym_COLONprev3_COLON] = ACTIONS(31),
    [aux_sym_specialinline_token1] = ACTIONS(33),
    [aux_sym_specialinline_token2] = ACTIONS(35),
    [anon_sym_COLONmath_COLON] = ACTIONS(37),
    [anon_sym_COLONcode_COLON] = ACTIONS(39),
    [aux_sym_specialinline_token3] = ACTIONS(41),
    [aux_sym_specialinline_token4] = ACTIONS(43),
    [anon_sym_COLONref_COLON] = ACTIONS(45),
    [anon_sym_COLONprevious_COLON] = ACTIONS(47),
    [anon_sym_COLONurl_COLON] = ACTIONS(49),
    [anon_sym_COLONcite_COLON] = ACTIONS(51),
    [anon_sym_COLONqed_COLON] = ACTIONS(53),
    [anon_sym_COLONtable_COLON] = ACTIONS(55),
    [anon_sym_COLONassume_COLON] = ACTIONS(57),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(57),
    [anon_sym_COLONprove_COLON] = ACTIONS(57),
    [anon_sym_COLONthen_COLON] = ACTIONS(57),
    [anon_sym_COLONnew_COLON] = ACTIONS(57),
    [anon_sym_COLONlet_COLON] = ACTIONS(57),
    [anon_sym_COLONcase_COLON] = ACTIONS(57),
    [anon_sym_COLONdefine_COLON] = ACTIONS(57),
    [anon_sym_COLONwrite_COLON] = ACTIONS(57),
    [anon_sym_COLONwlog_COLON] = ACTIONS(57),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(57),
    [anon_sym_COLONclaim_COLON] = ACTIONS(57),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(57),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(57),
    [anon_sym_COLONpick_COLON] = ACTIONS(57),
    [anon_sym_COLONst_COLON] = ACTIONS(57),
    [anon_sym_COLONdraft_COLON] = ACTIONS(59),
    [anon_sym_COLONnote_COLON] = ACTIONS(59),
    [anon_sym_COLONspan_COLON] = ACTIONS(59),
    [anon_sym_COLONabstract_COLON] = ACTIONS(61),
    [anon_sym_COLONauthor_COLON] = ACTIONS(61),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(61),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(61),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(61),
    [anon_sym_COLONexample_COLON] = ACTIONS(61),
    [anon_sym_COLONitemize_COLON] = ACTIONS(61),
    [anon_sym_COLONlemma_COLON] = ACTIONS(61),
    [anon_sym_COLONfigure_COLON] = ACTIONS(61),
    [anon_sym_COLONp_COLON] = ACTIONS(61),
    [anon_sym_COLONproof_COLON] = ACTIONS(61),
    [anon_sym_COLONproposition_COLON] = ACTIONS(61),
    [anon_sym_COLONremark_COLON] = ACTIONS(61),
    [anon_sym_COLONsketch_COLON] = ACTIONS(61),
    [anon_sym_COLONstep_COLON] = ACTIONS(61),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(71),
  },
  [STATE(37)] = {
    [sym_block] = STATE(33),
    [sym_paragraph] = STATE(33),
    [sym_inline] = STATE(98),
    [sym_construct] = STATE(98),
    [sym_subsection] = STATE(33),
    [sym_mathblock] = STATE(33),
    [sym_specialblock] = STATE(33),
    [sym_caption] = STATE(61),
    [sym_item] = STATE(61),
    [sym_specialinline] = STATE(98),
    [sym_specialconstruct] = STATE(98),
    [sym_table] = STATE(62),
    [sym__paragraphcontent_no_special] = STATE(98),
    [aux_sym_section_repeat1] = STATE(33),
    [anon_sym_COLON_COLON] = ACTIONS(427),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(427),
    [anon_sym_COLONsection_COLON] = ACTIONS(427),
    [aux_sym_subsection_token1] = ACTIONS(81),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(83),
    [anon_sym_COLONappendix_COLON] = ACTIONS(427),
    [aux_sym_mathblock_token1] = ACTIONS(15),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(17),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(19),
    [aux_sym_specialblock_token1] = ACTIONS(21),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(23),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(25),
    [anon_sym_COLONcaption_COLON] = ACTIONS(27),
    [anon_sym_COLONitem_COLON] = ACTIONS(29),
    [anon_sym_COLONprev_COLON] = ACTIONS(31),
    [anon_sym_COLONprev2_COLON] = ACTIONS(31),
    [anon_sym_COLONprev3_COLON] = ACTIONS(31),
    [aux_sym_specialinline_token1] = ACTIONS(33),
    [aux_sym_specialinline_token2] = ACTIONS(35),
    [anon_sym_COLONmath_COLON] = ACTIONS(37),
    [anon_sym_COLONcode_COLON] = ACTIONS(39),
    [aux_sym_specialinline_token3] = ACTIONS(41),
    [aux_sym_specialinline_token4] = ACTIONS(43),
    [anon_sym_COLONref_COLON] = ACTIONS(45),
    [anon_sym_COLONprevious_COLON] = ACTIONS(47),
    [anon_sym_COLONurl_COLON] = ACTIONS(49),
    [anon_sym_COLONcite_COLON] = ACTIONS(51),
    [anon_sym_COLONqed_COLON] = ACTIONS(53),
    [anon_sym_COLONtable_COLON] = ACTIONS(55),
    [anon_sym_COLONassume_COLON] = ACTIONS(57),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(57),
    [anon_sym_COLONprove_COLON] = ACTIONS(57),
    [anon_sym_COLONthen_COLON] = ACTIONS(57),
    [anon_sym_COLONnew_COLON] = ACTIONS(57),
    [anon_sym_COLONlet_COLON] = ACTIONS(57),
    [anon_sym_COLONcase_COLON] = ACTIONS(57),
    [anon_sym_COLONdefine_COLON] = ACTIONS(57),
    [anon_sym_COLONwrite_COLON] = ACTIONS(57),
    [anon_sym_COLONwlog_COLON] = ACTIONS(57),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(57),
    [anon_sym_COLONclaim_COLON] = ACTIONS(57),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(57),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(57),
    [anon_sym_COLONpick_COLON] = ACTIONS(57),
    [anon_sym_COLONst_COLON] = ACTIONS(57),
    [anon_sym_COLONdraft_COLON] = ACTIONS(59),
    [anon_sym_COLONnote_COLON] = ACTIONS(59),
    [anon_sym_COLONspan_COLON] = ACTIONS(59),
    [anon_sym_COLONabstract_COLON] = ACTIONS(61),
    [anon_sym_COLONauthor_COLON] = ACTIONS(61),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(61),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(61),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(61),
    [anon_sym_COLONexample_COLON] = ACTIONS(61),
    [anon_sym_COLONitemize_COLON] = ACTIONS(61),
    [anon_sym_COLONlemma_COLON] = ACTIONS(61),
    [anon_sym_COLONfigure_COLON] = ACTIONS(61),
    [anon_sym_COLONp_COLON] = ACTIONS(61),
    [anon_sym_COLONproof_COLON] = ACTIONS(61),
    [anon_sym_COLONproposition_COLON] = ACTIONS(61),
    [anon_sym_COLONremark_COLON] = ACTIONS(61),
    [anon_sym_COLONsketch_COLON] = ACTIONS(61),
    [anon_sym_COLONstep_COLON] = ACTIONS(61),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(71),
  },
  [STATE(38)] = {
    [sym_block] = STATE(35),
    [sym_paragraph] = STATE(35),
    [sym_inline] = STATE(98),
    [sym_construct] = STATE(98),
    [sym_subsection] = STATE(35),
    [sym_mathblock] = STATE(35),
    [sym_specialblock] = STATE(35),
    [sym_caption] = STATE(61),
    [sym_item] = STATE(61),
    [sym_specialinline] = STATE(98),
    [sym_specialconstruct] = STATE(98),
    [sym_table] = STATE(62),
    [sym__paragraphcontent_no_special] = STATE(98),
    [aux_sym_section_repeat1] = STATE(35),
    [anon_sym_COLON_COLON] = ACTIONS(429),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(429),
    [anon_sym_COLONsection_COLON] = ACTIONS(429),
    [aux_sym_subsection_token1] = ACTIONS(81),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(83),
    [anon_sym_COLONappendix_COLON] = ACTIONS(429),
    [aux_sym_mathblock_token1] = ACTIONS(15),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(17),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(19),
    [aux_sym_specialblock_token1] = ACTIONS(21),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(23),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(25),
    [anon_sym_COLONcaption_COLON] = ACTIONS(27),
    [anon_sym_COLONitem_COLON] = ACTIONS(29),
    [anon_sym_COLONprev_COLON] = ACTIONS(31),
    [anon_sym_COLONprev2_COLON] = ACTIONS(31),
    [anon_sym_COLONprev3_COLON] = ACTIONS(31),
    [aux_sym_specialinline_token1] = ACTIONS(33),
    [aux_sym_specialinline_token2] = ACTIONS(35),
    [anon_sym_COLONmath_COLON] = ACTIONS(37),
    [anon_sym_COLONcode_COLON] = ACTIONS(39),
    [aux_sym_specialinline_token3] = ACTIONS(41),
    [aux_sym_specialinline_token4] = ACTIONS(43),
    [anon_sym_COLONref_COLON] = ACTIONS(45),
    [anon_sym_COLONprevious_COLON] = ACTIONS(47),
    [anon_sym_COLONurl_COLON] = ACTIONS(49),
    [anon_sym_COLONcite_COLON] = ACTIONS(51),
    [anon_sym_COLONqed_COLON] = ACTIONS(53),
    [anon_sym_COLONtable_COLON] = ACTIONS(55),
    [anon_sym_COLONassume_COLON] = ACTIONS(57),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(57),
    [anon_sym_COLONprove_COLON] = ACTIONS(57),
    [anon_sym_COLONthen_COLON] = ACTIONS(57),
    [anon_sym_COLONnew_COLON] = ACTIONS(57),
    [anon_sym_COLONlet_COLON] = ACTIONS(57),
    [anon_sym_COLONcase_COLON] = ACTIONS(57),
    [anon_sym_COLONdefine_COLON] = ACTIONS(57),
    [anon_sym_COLONwrite_COLON] = ACTIONS(57),
    [anon_sym_COLONwlog_COLON] = ACTIONS(57),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(57),
    [anon_sym_COLONclaim_COLON] = ACTIONS(57),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(57),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(57),
    [anon_sym_COLONpick_COLON] = ACTIONS(57),
    [anon_sym_COLONst_COLON] = ACTIONS(57),
    [anon_sym_COLONdraft_COLON] = ACTIONS(59),
    [anon_sym_COLONnote_COLON] = ACTIONS(59),
    [anon_sym_COLONspan_COLON] = ACTIONS(59),
    [anon_sym_COLONabstract_COLON] = ACTIONS(61),
    [anon_sym_COLONauthor_COLON] = ACTIONS(61),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(61),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(61),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(61),
    [anon_sym_COLONexample_COLON] = ACTIONS(61),
    [anon_sym_COLONitemize_COLON] = ACTIONS(61),
    [anon_sym_COLONlemma_COLON] = ACTIONS(61),
    [anon_sym_COLONfigure_COLON] = ACTIONS(61),
    [anon_sym_COLONp_COLON] = ACTIONS(61),
    [anon_sym_COLONproof_COLON] = ACTIONS(61),
    [anon_sym_COLONproposition_COLON] = ACTIONS(61),
    [anon_sym_COLONremark_COLON] = ACTIONS(61),
    [anon_sym_COLONsketch_COLON] = ACTIONS(61),
    [anon_sym_COLONstep_COLON] = ACTIONS(61),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(71),
  },
  [STATE(39)] = {
    [sym_block] = STATE(34),
    [sym_paragraph] = STATE(34),
    [sym_inline] = STATE(98),
    [sym_construct] = STATE(98),
    [sym_subsection] = STATE(34),
    [sym_mathblock] = STATE(34),
    [sym_specialblock] = STATE(34),
    [sym_caption] = STATE(61),
    [sym_item] = STATE(61),
    [sym_specialinline] = STATE(98),
    [sym_specialconstruct] = STATE(98),
    [sym_table] = STATE(62),
    [sym__paragraphcontent_no_special] = STATE(98),
    [aux_sym_section_repeat1] = STATE(34),
    [anon_sym_COLON_COLON] = ACTIONS(431),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(431),
    [anon_sym_COLONsection_COLON] = ACTIONS(431),
    [aux_sym_subsection_token1] = ACTIONS(81),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(83),
    [anon_sym_COLONappendix_COLON] = ACTIONS(431),
    [aux_sym_mathblock_token1] = ACTIONS(15),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(17),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(19),
    [aux_sym_specialblock_token1] = ACTIONS(21),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(23),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(25),
    [anon_sym_COLONcaption_COLON] = ACTIONS(27),
    [anon_sym_COLONitem_COLON] = ACTIONS(29),
    [anon_sym_COLONprev_COLON] = ACTIONS(31),
    [anon_sym_COLONprev2_COLON] = ACTIONS(31),
    [anon_sym_COLONprev3_COLON] = ACTIONS(31),
    [aux_sym_specialinline_token1] = ACTIONS(33),
    [aux_sym_specialinline_token2] = ACTIONS(35),
    [anon_sym_COLONmath_COLON] = ACTIONS(37),
    [anon_sym_COLONcode_COLON] = ACTIONS(39),
    [aux_sym_specialinline_token3] = ACTIONS(41),
    [aux_sym_specialinline_token4] = ACTIONS(43),
    [anon_sym_COLONref_COLON] = ACTIONS(45),
    [anon_sym_COLONprevious_COLON] = ACTIONS(47),
    [anon_sym_COLONurl_COLON] = ACTIONS(49),
    [anon_sym_COLONcite_COLON] = ACTIONS(51),
    [anon_sym_COLONqed_COLON] = ACTIONS(53),
    [anon_sym_COLONtable_COLON] = ACTIONS(55),
    [anon_sym_COLONassume_COLON] = ACTIONS(57),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(57),
    [anon_sym_COLONprove_COLON] = ACTIONS(57),
    [anon_sym_COLONthen_COLON] = ACTIONS(57),
    [anon_sym_COLONnew_COLON] = ACTIONS(57),
    [anon_sym_COLONlet_COLON] = ACTIONS(57),
    [anon_sym_COLONcase_COLON] = ACTIONS(57),
    [anon_sym_COLONdefine_COLON] = ACTIONS(57),
    [anon_sym_COLONwrite_COLON] = ACTIONS(57),
    [anon_sym_COLONwlog_COLON] = ACTIONS(57),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(57),
    [anon_sym_COLONclaim_COLON] = ACTIONS(57),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(57),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(57),
    [anon_sym_COLONpick_COLON] = ACTIONS(57),
    [anon_sym_COLONst_COLON] = ACTIONS(57),
    [anon_sym_COLONdraft_COLON] = ACTIONS(59),
    [anon_sym_COLONnote_COLON] = ACTIONS(59),
    [anon_sym_COLONspan_COLON] = ACTIONS(59),
    [anon_sym_COLONabstract_COLON] = ACTIONS(61),
    [anon_sym_COLONauthor_COLON] = ACTIONS(61),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(61),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(61),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(61),
    [anon_sym_COLONexample_COLON] = ACTIONS(61),
    [anon_sym_COLONitemize_COLON] = ACTIONS(61),
    [anon_sym_COLONlemma_COLON] = ACTIONS(61),
    [anon_sym_COLONfigure_COLON] = ACTIONS(61),
    [anon_sym_COLONp_COLON] = ACTIONS(61),
    [anon_sym_COLONproof_COLON] = ACTIONS(61),
    [anon_sym_COLONproposition_COLON] = ACTIONS(61),
    [anon_sym_COLONremark_COLON] = ACTIONS(61),
    [anon_sym_COLONsketch_COLON] = ACTIONS(61),
    [anon_sym_COLONstep_COLON] = ACTIONS(61),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(71),
  },
  [STATE(40)] = {
    [sym_block] = STATE(40),
    [sym_paragraph] = STATE(40),
    [sym_inline] = STATE(98),
    [sym_construct] = STATE(98),
    [sym_section] = STATE(40),
    [sym_appendix] = STATE(40),
    [sym_mathblock] = STATE(40),
    [sym_specialblock] = STATE(40),
    [sym_caption] = STATE(61),
    [sym_item] = STATE(61),
    [sym_specialinline] = STATE(98),
    [sym_specialconstruct] = STATE(98),
    [sym_table] = STATE(62),
    [sym__paragraphcontent_no_special] = STATE(98),
    [aux_sym_source_file_repeat1] = STATE(40),
    [anon_sym_COLON_COLON] = ACTIONS(433),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(435),
    [aux_sym_section_token1] = ACTIONS(438),
    [anon_sym_COLONsection_COLON] = ACTIONS(441),
    [anon_sym_COLONappendix_COLON] = ACTIONS(444),
    [aux_sym_mathblock_token1] = ACTIONS(447),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(450),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(453),
    [anon_sym_COLONtoc_COLON] = ACTIONS(453),
    [aux_sym_specialblock_token1] = ACTIONS(456),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(459),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(462),
    [anon_sym_COLONcaption_COLON] = ACTIONS(465),
    [anon_sym_COLONitem_COLON] = ACTIONS(468),
    [anon_sym_COLONprev_COLON] = ACTIONS(471),
    [anon_sym_COLONprev2_COLON] = ACTIONS(471),
    [anon_sym_COLONprev3_COLON] = ACTIONS(471),
    [aux_sym_specialinline_token1] = ACTIONS(474),
    [aux_sym_specialinline_token2] = ACTIONS(477),
    [anon_sym_COLONmath_COLON] = ACTIONS(480),
    [anon_sym_COLONcode_COLON] = ACTIONS(483),
    [aux_sym_specialinline_token3] = ACTIONS(486),
    [aux_sym_specialinline_token4] = ACTIONS(489),
    [anon_sym_COLONref_COLON] = ACTIONS(492),
    [anon_sym_COLONprevious_COLON] = ACTIONS(495),
    [anon_sym_COLONurl_COLON] = ACTIONS(498),
    [anon_sym_COLONcite_COLON] = ACTIONS(501),
    [anon_sym_COLONqed_COLON] = ACTIONS(504),
    [anon_sym_COLONtable_COLON] = ACTIONS(507),
    [anon_sym_COLONassume_COLON] = ACTIONS(510),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(510),
    [anon_sym_COLONprove_COLON] = ACTIONS(510),
    [anon_sym_COLONthen_COLON] = ACTIONS(510),
    [anon_sym_COLONnew_COLON] = ACTIONS(510),
    [anon_sym_COLONlet_COLON] = ACTIONS(510),
    [anon_sym_COLONcase_COLON] = ACTIONS(510),
    [anon_sym_COLONdefine_COLON] = ACTIONS(510),
    [anon_sym_COLONwrite_COLON] = ACTIONS(510),
    [anon_sym_COLONwlog_COLON] = ACTIONS(510),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(510),
    [anon_sym_COLONclaim_COLON] = ACTIONS(510),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(510),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(510),
    [anon_sym_COLONpick_COLON] = ACTIONS(510),
    [anon_sym_COLONst_COLON] = ACTIONS(510),
    [anon_sym_COLONdraft_COLON] = ACTIONS(513),
    [anon_sym_COLONnote_COLON] = ACTIONS(513),
    [anon_sym_COLONspan_COLON] = ACTIONS(513),
    [anon_sym_COLONabstract_COLON] = ACTIONS(516),
    [anon_sym_COLONauthor_COLON] = ACTIONS(516),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(516),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(516),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(516),
    [anon_sym_COLONexample_COLON] = ACTIONS(516),
    [anon_sym_COLONitemize_COLON] = ACTIONS(516),
    [anon_sym_COLONlemma_COLON] = ACTIONS(516),
    [anon_sym_COLONfigure_COLON] = ACTIONS(516),
    [anon_sym_COLONp_COLON] = ACTIONS(516),
    [anon_sym_COLONproof_COLON] = ACTIONS(516),
    [anon_sym_COLONproposition_COLON] = ACTIONS(516),
    [anon_sym_COLONremark_COLON] = ACTIONS(516),
    [anon_sym_COLONsketch_COLON] = ACTIONS(516),
    [anon_sym_COLONstep_COLON] = ACTIONS(516),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(516),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(519),
  },
  [STATE(41)] = {
    [sym_block] = STATE(42),
    [sym_paragraph] = STATE(42),
    [sym_inline] = STATE(98),
    [sym_construct] = STATE(98),
    [sym_section] = STATE(42),
    [sym_appendix] = STATE(42),
    [sym_mathblock] = STATE(42),
    [sym_specialblock] = STATE(42),
    [sym_caption] = STATE(61),
    [sym_item] = STATE(61),
    [sym_specialinline] = STATE(98),
    [sym_specialconstruct] = STATE(98),
    [sym_table] = STATE(62),
    [sym__paragraphcontent_no_special] = STATE(98),
    [aux_sym_source_file_repeat1] = STATE(42),
    [anon_sym_COLON_COLON] = ACTIONS(522),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(89),
    [anon_sym_COLONsection_COLON] = ACTIONS(91),
    [anon_sym_COLONappendix_COLON] = ACTIONS(93),
    [aux_sym_mathblock_token1] = ACTIONS(15),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(17),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(19),
    [aux_sym_specialblock_token1] = ACTIONS(21),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(23),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(25),
    [anon_sym_COLONcaption_COLON] = ACTIONS(27),
    [anon_sym_COLONitem_COLON] = ACTIONS(29),
    [anon_sym_COLONprev_COLON] = ACTIONS(31),
    [anon_sym_COLONprev2_COLON] = ACTIONS(31),
    [anon_sym_COLONprev3_COLON] = ACTIONS(31),
    [aux_sym_specialinline_token1] = ACTIONS(33),
    [aux_sym_specialinline_token2] = ACTIONS(35),
    [anon_sym_COLONmath_COLON] = ACTIONS(37),
    [anon_sym_COLONcode_COLON] = ACTIONS(39),
    [aux_sym_specialinline_token3] = ACTIONS(41),
    [aux_sym_specialinline_token4] = ACTIONS(43),
    [anon_sym_COLONref_COLON] = ACTIONS(45),
    [anon_sym_COLONprevious_COLON] = ACTIONS(47),
    [anon_sym_COLONurl_COLON] = ACTIONS(49),
    [anon_sym_COLONcite_COLON] = ACTIONS(51),
    [anon_sym_COLONqed_COLON] = ACTIONS(53),
    [anon_sym_COLONtable_COLON] = ACTIONS(55),
    [anon_sym_COLONassume_COLON] = ACTIONS(57),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(57),
    [anon_sym_COLONprove_COLON] = ACTIONS(57),
    [anon_sym_COLONthen_COLON] = ACTIONS(57),
    [anon_sym_COLONnew_COLON] = ACTIONS(57),
    [anon_sym_COLONlet_COLON] = ACTIONS(57),
    [anon_sym_COLONcase_COLON] = ACTIONS(57),
    [anon_sym_COLONdefine_COLON] = ACTIONS(57),
    [anon_sym_COLONwrite_COLON] = ACTIONS(57),
    [anon_sym_COLONwlog_COLON] = ACTIONS(57),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(57),
    [anon_sym_COLONclaim_COLON] = ACTIONS(57),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(57),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(57),
    [anon_sym_COLONpick_COLON] = ACTIONS(57),
    [anon_sym_COLONst_COLON] = ACTIONS(57),
    [anon_sym_COLONdraft_COLON] = ACTIONS(59),
    [anon_sym_COLONnote_COLON] = ACTIONS(59),
    [anon_sym_COLONspan_COLON] = ACTIONS(59),
    [anon_sym_COLONabstract_COLON] = ACTIONS(61),
    [anon_sym_COLONauthor_COLON] = ACTIONS(61),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(61),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(61),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(61),
    [anon_sym_COLONexample_COLON] = ACTIONS(61),
    [anon_sym_COLONitemize_COLON] = ACTIONS(61),
    [anon_sym_COLONlemma_COLON] = ACTIONS(61),
    [anon_sym_COLONfigure_COLON] = ACTIONS(61),
    [anon_sym_COLONp_COLON] = ACTIONS(61),
    [anon_sym_COLONproof_COLON] = ACTIONS(61),
    [anon_sym_COLONproposition_COLON] = ACTIONS(61),
    [anon_sym_COLONremark_COLON] = ACTIONS(61),
    [anon_sym_COLONsketch_COLON] = ACTIONS(61),
    [anon_sym_COLONstep_COLON] = ACTIONS(61),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(71),
  },
  [STATE(42)] = {
    [sym_block] = STATE(40),
    [sym_paragraph] = STATE(40),
    [sym_inline] = STATE(98),
    [sym_construct] = STATE(98),
    [sym_section] = STATE(40),
    [sym_appendix] = STATE(40),
    [sym_mathblock] = STATE(40),
    [sym_specialblock] = STATE(40),
    [sym_caption] = STATE(61),
    [sym_item] = STATE(61),
    [sym_specialinline] = STATE(98),
    [sym_specialconstruct] = STATE(98),
    [sym_table] = STATE(62),
    [sym__paragraphcontent_no_special] = STATE(98),
    [aux_sym_source_file_repeat1] = STATE(40),
    [anon_sym_COLON_COLON] = ACTIONS(524),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(89),
    [anon_sym_COLONsection_COLON] = ACTIONS(91),
    [anon_sym_COLONappendix_COLON] = ACTIONS(93),
    [aux_sym_mathblock_token1] = ACTIONS(15),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(17),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(19),
    [aux_sym_specialblock_token1] = ACTIONS(21),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(23),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(25),
    [anon_sym_COLONcaption_COLON] = ACTIONS(27),
    [anon_sym_COLONitem_COLON] = ACTIONS(29),
    [anon_sym_COLONprev_COLON] = ACTIONS(31),
    [anon_sym_COLONprev2_COLON] = ACTIONS(31),
    [anon_sym_COLONprev3_COLON] = ACTIONS(31),
    [aux_sym_specialinline_token1] = ACTIONS(33),
    [aux_sym_specialinline_token2] = ACTIONS(35),
    [anon_sym_COLONmath_COLON] = ACTIONS(37),
    [anon_sym_COLONcode_COLON] = ACTIONS(39),
    [aux_sym_specialinline_token3] = ACTIONS(41),
    [aux_sym_specialinline_token4] = ACTIONS(43),
    [anon_sym_COLONref_COLON] = ACTIONS(45),
    [anon_sym_COLONprevious_COLON] = ACTIONS(47),
    [anon_sym_COLONurl_COLON] = ACTIONS(49),
    [anon_sym_COLONcite_COLON] = ACTIONS(51),
    [anon_sym_COLONqed_COLON] = ACTIONS(53),
    [anon_sym_COLONtable_COLON] = ACTIONS(55),
    [anon_sym_COLONassume_COLON] = ACTIONS(57),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(57),
    [anon_sym_COLONprove_COLON] = ACTIONS(57),
    [anon_sym_COLONthen_COLON] = ACTIONS(57),
    [anon_sym_COLONnew_COLON] = ACTIONS(57),
    [anon_sym_COLONlet_COLON] = ACTIONS(57),
    [anon_sym_COLONcase_COLON] = ACTIONS(57),
    [anon_sym_COLONdefine_COLON] = ACTIONS(57),
    [anon_sym_COLONwrite_COLON] = ACTIONS(57),
    [anon_sym_COLONwlog_COLON] = ACTIONS(57),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(57),
    [anon_sym_COLONclaim_COLON] = ACTIONS(57),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(57),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(57),
    [anon_sym_COLONpick_COLON] = ACTIONS(57),
    [anon_sym_COLONst_COLON] = ACTIONS(57),
    [anon_sym_COLONdraft_COLON] = ACTIONS(59),
    [anon_sym_COLONnote_COLON] = ACTIONS(59),
    [anon_sym_COLONspan_COLON] = ACTIONS(59),
    [anon_sym_COLONabstract_COLON] = ACTIONS(61),
    [anon_sym_COLONauthor_COLON] = ACTIONS(61),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(61),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(61),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(61),
    [anon_sym_COLONexample_COLON] = ACTIONS(61),
    [anon_sym_COLONitemize_COLON] = ACTIONS(61),
    [anon_sym_COLONlemma_COLON] = ACTIONS(61),
    [anon_sym_COLONfigure_COLON] = ACTIONS(61),
    [anon_sym_COLONp_COLON] = ACTIONS(61),
    [anon_sym_COLONproof_COLON] = ACTIONS(61),
    [anon_sym_COLONproposition_COLON] = ACTIONS(61),
    [anon_sym_COLONremark_COLON] = ACTIONS(61),
    [anon_sym_COLONsketch_COLON] = ACTIONS(61),
    [anon_sym_COLONstep_COLON] = ACTIONS(61),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(71),
  },
  [STATE(43)] = {
    [sym_block] = STATE(40),
    [sym_paragraph] = STATE(40),
    [sym_inline] = STATE(98),
    [sym_construct] = STATE(98),
    [sym_section] = STATE(40),
    [sym_appendix] = STATE(40),
    [sym_mathblock] = STATE(40),
    [sym_specialblock] = STATE(40),
    [sym_caption] = STATE(61),
    [sym_item] = STATE(61),
    [sym_specialinline] = STATE(98),
    [sym_specialconstruct] = STATE(98),
    [sym_table] = STATE(62),
    [sym__paragraphcontent_no_special] = STATE(98),
    [aux_sym_source_file_repeat1] = STATE(40),
    [anon_sym_COLON_COLON] = ACTIONS(526),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_section_token1] = ACTIONS(89),
    [anon_sym_COLONsection_COLON] = ACTIONS(91),
    [anon_sym_COLONappendix_COLON] = ACTIONS(93),
    [aux_sym_mathblock_token1] = ACTIONS(15),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(17),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(19),
    [aux_sym_specialblock_token1] = ACTIONS(21),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(23),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(25),
    [anon_sym_COLONcaption_COLON] = ACTIONS(27),
    [anon_sym_COLONitem_COLON] = ACTIONS(29),
    [anon_sym_COLONprev_COLON] = ACTIONS(31),
    [anon_sym_COLONprev2_COLON] = ACTIONS(31),
    [anon_sym_COLONprev3_COLON] = ACTIONS(31),
    [aux_sym_specialinline_token1] = ACTIONS(33),
    [aux_sym_specialinline_token2] = ACTIONS(35),
    [anon_sym_COLONmath_COLON] = ACTIONS(37),
    [anon_sym_COLONcode_COLON] = ACTIONS(39),
    [aux_sym_specialinline_token3] = ACTIONS(41),
    [aux_sym_specialinline_token4] = ACTIONS(43),
    [anon_sym_COLONref_COLON] = ACTIONS(45),
    [anon_sym_COLONprevious_COLON] = ACTIONS(47),
    [anon_sym_COLONurl_COLON] = ACTIONS(49),
    [anon_sym_COLONcite_COLON] = ACTIONS(51),
    [anon_sym_COLONqed_COLON] = ACTIONS(53),
    [anon_sym_COLONtable_COLON] = ACTIONS(55),
    [anon_sym_COLONassume_COLON] = ACTIONS(57),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(57),
    [anon_sym_COLONprove_COLON] = ACTIONS(57),
    [anon_sym_COLONthen_COLON] = ACTIONS(57),
    [anon_sym_COLONnew_COLON] = ACTIONS(57),
    [anon_sym_COLONlet_COLON] = ACTIONS(57),
    [anon_sym_COLONcase_COLON] = ACTIONS(57),
    [anon_sym_COLONdefine_COLON] = ACTIONS(57),
    [anon_sym_COLONwrite_COLON] = ACTIONS(57),
    [anon_sym_COLONwlog_COLON] = ACTIONS(57),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(57),
    [anon_sym_COLONclaim_COLON] = ACTIONS(57),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(57),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(57),
    [anon_sym_COLONpick_COLON] = ACTIONS(57),
    [anon_sym_COLONst_COLON] = ACTIONS(57),
    [anon_sym_COLONdraft_COLON] = ACTIONS(59),
    [anon_sym_COLONnote_COLON] = ACTIONS(59),
    [anon_sym_COLONspan_COLON] = ACTIONS(59),
    [anon_sym_COLONabstract_COLON] = ACTIONS(61),
    [anon_sym_COLONauthor_COLON] = ACTIONS(61),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(61),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(61),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(61),
    [anon_sym_COLONexample_COLON] = ACTIONS(61),
    [anon_sym_COLONitemize_COLON] = ACTIONS(61),
    [anon_sym_COLONlemma_COLON] = ACTIONS(61),
    [anon_sym_COLONfigure_COLON] = ACTIONS(61),
    [anon_sym_COLONp_COLON] = ACTIONS(61),
    [anon_sym_COLONproof_COLON] = ACTIONS(61),
    [anon_sym_COLONproposition_COLON] = ACTIONS(61),
    [anon_sym_COLONremark_COLON] = ACTIONS(61),
    [anon_sym_COLONsketch_COLON] = ACTIONS(61),
    [anon_sym_COLONstep_COLON] = ACTIONS(61),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(71),
  },
  [STATE(44)] = {
    [sym_block] = STATE(45),
    [sym_paragraph] = STATE(45),
    [sym_inline] = STATE(98),
    [sym_construct] = STATE(98),
    [sym_mathblock] = STATE(45),
    [sym_specialblock] = STATE(45),
    [sym_caption] = STATE(61),
    [sym_item] = STATE(61),
    [sym_specialinline] = STATE(98),
    [sym_specialconstruct] = STATE(98),
    [sym_table] = STATE(62),
    [sym__paragraphcontent_no_special] = STATE(98),
    [aux_sym_block_repeat1] = STATE(45),
    [anon_sym_COLON_COLON] = ACTIONS(528),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_mathblock_token1] = ACTIONS(15),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(17),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(19),
    [aux_sym_specialblock_token1] = ACTIONS(21),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(23),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(25),
    [anon_sym_COLONcaption_COLON] = ACTIONS(27),
    [anon_sym_COLONitem_COLON] = ACTIONS(29),
    [anon_sym_COLONprev_COLON] = ACTIONS(31),
    [anon_sym_COLONprev2_COLON] = ACTIONS(31),
    [anon_sym_COLONprev3_COLON] = ACTIONS(31),
    [aux_sym_specialinline_token1] = ACTIONS(33),
    [aux_sym_specialinline_token2] = ACTIONS(35),
    [anon_sym_COLONmath_COLON] = ACTIONS(37),
    [anon_sym_COLONcode_COLON] = ACTIONS(39),
    [aux_sym_specialinline_token3] = ACTIONS(41),
    [aux_sym_specialinline_token4] = ACTIONS(43),
    [anon_sym_COLONref_COLON] = ACTIONS(45),
    [anon_sym_COLONprevious_COLON] = ACTIONS(47),
    [anon_sym_COLONurl_COLON] = ACTIONS(49),
    [anon_sym_COLONcite_COLON] = ACTIONS(51),
    [anon_sym_COLONqed_COLON] = ACTIONS(53),
    [anon_sym_COLONtable_COLON] = ACTIONS(55),
    [anon_sym_COLONassume_COLON] = ACTIONS(57),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(57),
    [anon_sym_COLONprove_COLON] = ACTIONS(57),
    [anon_sym_COLONthen_COLON] = ACTIONS(57),
    [anon_sym_COLONnew_COLON] = ACTIONS(57),
    [anon_sym_COLONlet_COLON] = ACTIONS(57),
    [anon_sym_COLONcase_COLON] = ACTIONS(57),
    [anon_sym_COLONdefine_COLON] = ACTIONS(57),
    [anon_sym_COLONwrite_COLON] = ACTIONS(57),
    [anon_sym_COLONwlog_COLON] = ACTIONS(57),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(57),
    [anon_sym_COLONclaim_COLON] = ACTIONS(57),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(57),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(57),
    [anon_sym_COLONpick_COLON] = ACTIONS(57),
    [anon_sym_COLONst_COLON] = ACTIONS(57),
    [anon_sym_COLONdraft_COLON] = ACTIONS(59),
    [anon_sym_COLONnote_COLON] = ACTIONS(59),
    [anon_sym_COLONspan_COLON] = ACTIONS(59),
    [anon_sym_COLONabstract_COLON] = ACTIONS(61),
    [anon_sym_COLONauthor_COLON] = ACTIONS(61),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(61),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(61),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(61),
    [anon_sym_COLONexample_COLON] = ACTIONS(61),
    [anon_sym_COLONitemize_COLON] = ACTIONS(61),
    [anon_sym_COLONlemma_COLON] = ACTIONS(61),
    [anon_sym_COLONfigure_COLON] = ACTIONS(61),
    [anon_sym_COLONp_COLON] = ACTIONS(61),
    [anon_sym_COLONproof_COLON] = ACTIONS(61),
    [anon_sym_COLONproposition_COLON] = ACTIONS(61),
    [anon_sym_COLONremark_COLON] = ACTIONS(61),
    [anon_sym_COLONsketch_COLON] = ACTIONS(61),
    [anon_sym_COLONstep_COLON] = ACTIONS(61),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(71),
  },
  [STATE(45)] = {
    [sym_block] = STATE(46),
    [sym_paragraph] = STATE(46),
    [sym_inline] = STATE(98),
    [sym_construct] = STATE(98),
    [sym_mathblock] = STATE(46),
    [sym_specialblock] = STATE(46),
    [sym_caption] = STATE(61),
    [sym_item] = STATE(61),
    [sym_specialinline] = STATE(98),
    [sym_specialconstruct] = STATE(98),
    [sym_table] = STATE(62),
    [sym__paragraphcontent_no_special] = STATE(98),
    [aux_sym_block_repeat1] = STATE(46),
    [anon_sym_COLON_COLON] = ACTIONS(530),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_mathblock_token1] = ACTIONS(15),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(17),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(19),
    [aux_sym_specialblock_token1] = ACTIONS(21),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(23),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(25),
    [anon_sym_COLONcaption_COLON] = ACTIONS(27),
    [anon_sym_COLONitem_COLON] = ACTIONS(29),
    [anon_sym_COLONprev_COLON] = ACTIONS(31),
    [anon_sym_COLONprev2_COLON] = ACTIONS(31),
    [anon_sym_COLONprev3_COLON] = ACTIONS(31),
    [aux_sym_specialinline_token1] = ACTIONS(33),
    [aux_sym_specialinline_token2] = ACTIONS(35),
    [anon_sym_COLONmath_COLON] = ACTIONS(37),
    [anon_sym_COLONcode_COLON] = ACTIONS(39),
    [aux_sym_specialinline_token3] = ACTIONS(41),
    [aux_sym_specialinline_token4] = ACTIONS(43),
    [anon_sym_COLONref_COLON] = ACTIONS(45),
    [anon_sym_COLONprevious_COLON] = ACTIONS(47),
    [anon_sym_COLONurl_COLON] = ACTIONS(49),
    [anon_sym_COLONcite_COLON] = ACTIONS(51),
    [anon_sym_COLONqed_COLON] = ACTIONS(53),
    [anon_sym_COLONtable_COLON] = ACTIONS(55),
    [anon_sym_COLONassume_COLON] = ACTIONS(57),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(57),
    [anon_sym_COLONprove_COLON] = ACTIONS(57),
    [anon_sym_COLONthen_COLON] = ACTIONS(57),
    [anon_sym_COLONnew_COLON] = ACTIONS(57),
    [anon_sym_COLONlet_COLON] = ACTIONS(57),
    [anon_sym_COLONcase_COLON] = ACTIONS(57),
    [anon_sym_COLONdefine_COLON] = ACTIONS(57),
    [anon_sym_COLONwrite_COLON] = ACTIONS(57),
    [anon_sym_COLONwlog_COLON] = ACTIONS(57),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(57),
    [anon_sym_COLONclaim_COLON] = ACTIONS(57),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(57),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(57),
    [anon_sym_COLONpick_COLON] = ACTIONS(57),
    [anon_sym_COLONst_COLON] = ACTIONS(57),
    [anon_sym_COLONdraft_COLON] = ACTIONS(59),
    [anon_sym_COLONnote_COLON] = ACTIONS(59),
    [anon_sym_COLONspan_COLON] = ACTIONS(59),
    [anon_sym_COLONabstract_COLON] = ACTIONS(61),
    [anon_sym_COLONauthor_COLON] = ACTIONS(61),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(61),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(61),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(61),
    [anon_sym_COLONexample_COLON] = ACTIONS(61),
    [anon_sym_COLONitemize_COLON] = ACTIONS(61),
    [anon_sym_COLONlemma_COLON] = ACTIONS(61),
    [anon_sym_COLONfigure_COLON] = ACTIONS(61),
    [anon_sym_COLONp_COLON] = ACTIONS(61),
    [anon_sym_COLONproof_COLON] = ACTIONS(61),
    [anon_sym_COLONproposition_COLON] = ACTIONS(61),
    [anon_sym_COLONremark_COLON] = ACTIONS(61),
    [anon_sym_COLONsketch_COLON] = ACTIONS(61),
    [anon_sym_COLONstep_COLON] = ACTIONS(61),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(71),
  },
  [STATE(46)] = {
    [sym_block] = STATE(46),
    [sym_paragraph] = STATE(46),
    [sym_inline] = STATE(98),
    [sym_construct] = STATE(98),
    [sym_mathblock] = STATE(46),
    [sym_specialblock] = STATE(46),
    [sym_caption] = STATE(61),
    [sym_item] = STATE(61),
    [sym_specialinline] = STATE(98),
    [sym_specialconstruct] = STATE(98),
    [sym_table] = STATE(62),
    [sym__paragraphcontent_no_special] = STATE(98),
    [aux_sym_block_repeat1] = STATE(46),
    [anon_sym_COLON_COLON] = ACTIONS(532),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(534),
    [aux_sym_mathblock_token1] = ACTIONS(537),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(540),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(543),
    [anon_sym_COLONtoc_COLON] = ACTIONS(543),
    [aux_sym_specialblock_token1] = ACTIONS(546),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(549),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(552),
    [anon_sym_COLONcaption_COLON] = ACTIONS(555),
    [anon_sym_COLONitem_COLON] = ACTIONS(558),
    [anon_sym_COLONprev_COLON] = ACTIONS(561),
    [anon_sym_COLONprev2_COLON] = ACTIONS(561),
    [anon_sym_COLONprev3_COLON] = ACTIONS(561),
    [aux_sym_specialinline_token1] = ACTIONS(564),
    [aux_sym_specialinline_token2] = ACTIONS(567),
    [anon_sym_COLONmath_COLON] = ACTIONS(570),
    [anon_sym_COLONcode_COLON] = ACTIONS(573),
    [aux_sym_specialinline_token3] = ACTIONS(576),
    [aux_sym_specialinline_token4] = ACTIONS(579),
    [anon_sym_COLONref_COLON] = ACTIONS(582),
    [anon_sym_COLONprevious_COLON] = ACTIONS(585),
    [anon_sym_COLONurl_COLON] = ACTIONS(588),
    [anon_sym_COLONcite_COLON] = ACTIONS(591),
    [anon_sym_COLONqed_COLON] = ACTIONS(594),
    [anon_sym_COLONtable_COLON] = ACTIONS(597),
    [anon_sym_COLONassume_COLON] = ACTIONS(600),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(600),
    [anon_sym_COLONprove_COLON] = ACTIONS(600),
    [anon_sym_COLONthen_COLON] = ACTIONS(600),
    [anon_sym_COLONnew_COLON] = ACTIONS(600),
    [anon_sym_COLONlet_COLON] = ACTIONS(600),
    [anon_sym_COLONcase_COLON] = ACTIONS(600),
    [anon_sym_COLONdefine_COLON] = ACTIONS(600),
    [anon_sym_COLONwrite_COLON] = ACTIONS(600),
    [anon_sym_COLONwlog_COLON] = ACTIONS(600),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(600),
    [anon_sym_COLONclaim_COLON] = ACTIONS(600),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(600),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(600),
    [anon_sym_COLONpick_COLON] = ACTIONS(600),
    [anon_sym_COLONst_COLON] = ACTIONS(600),
    [anon_sym_COLONdraft_COLON] = ACTIONS(603),
    [anon_sym_COLONnote_COLON] = ACTIONS(603),
    [anon_sym_COLONspan_COLON] = ACTIONS(603),
    [anon_sym_COLONabstract_COLON] = ACTIONS(606),
    [anon_sym_COLONauthor_COLON] = ACTIONS(606),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(606),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(606),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(606),
    [anon_sym_COLONexample_COLON] = ACTIONS(606),
    [anon_sym_COLONitemize_COLON] = ACTIONS(606),
    [anon_sym_COLONlemma_COLON] = ACTIONS(606),
    [anon_sym_COLONfigure_COLON] = ACTIONS(606),
    [anon_sym_COLONp_COLON] = ACTIONS(606),
    [anon_sym_COLONproof_COLON] = ACTIONS(606),
    [anon_sym_COLONproposition_COLON] = ACTIONS(606),
    [anon_sym_COLONremark_COLON] = ACTIONS(606),
    [anon_sym_COLONsketch_COLON] = ACTIONS(606),
    [anon_sym_COLONstep_COLON] = ACTIONS(606),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(606),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(609),
  },
  [STATE(47)] = {
    [sym_block] = STATE(46),
    [sym_paragraph] = STATE(46),
    [sym_inline] = STATE(98),
    [sym_construct] = STATE(98),
    [sym_mathblock] = STATE(46),
    [sym_specialblock] = STATE(46),
    [sym_caption] = STATE(61),
    [sym_item] = STATE(61),
    [sym_specialinline] = STATE(98),
    [sym_specialconstruct] = STATE(98),
    [sym_table] = STATE(62),
    [sym__paragraphcontent_no_special] = STATE(98),
    [aux_sym_block_repeat1] = STATE(46),
    [anon_sym_COLON_COLON] = ACTIONS(612),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(9),
    [aux_sym_mathblock_token1] = ACTIONS(15),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(17),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(19),
    [anon_sym_COLONtoc_COLON] = ACTIONS(19),
    [aux_sym_specialblock_token1] = ACTIONS(21),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(23),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(25),
    [anon_sym_COLONcaption_COLON] = ACTIONS(27),
    [anon_sym_COLONitem_COLON] = ACTIONS(29),
    [anon_sym_COLONprev_COLON] = ACTIONS(31),
    [anon_sym_COLONprev2_COLON] = ACTIONS(31),
    [anon_sym_COLONprev3_COLON] = ACTIONS(31),
    [aux_sym_specialinline_token1] = ACTIONS(33),
    [aux_sym_specialinline_token2] = ACTIONS(35),
    [anon_sym_COLONmath_COLON] = ACTIONS(37),
    [anon_sym_COLONcode_COLON] = ACTIONS(39),
    [aux_sym_specialinline_token3] = ACTIONS(41),
    [aux_sym_specialinline_token4] = ACTIONS(43),
    [anon_sym_COLONref_COLON] = ACTIONS(45),
    [anon_sym_COLONprevious_COLON] = ACTIONS(47),
    [anon_sym_COLONurl_COLON] = ACTIONS(49),
    [anon_sym_COLONcite_COLON] = ACTIONS(51),
    [anon_sym_COLONqed_COLON] = ACTIONS(53),
    [anon_sym_COLONtable_COLON] = ACTIONS(55),
    [anon_sym_COLONassume_COLON] = ACTIONS(57),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(57),
    [anon_sym_COLONprove_COLON] = ACTIONS(57),
    [anon_sym_COLONthen_COLON] = ACTIONS(57),
    [anon_sym_COLONnew_COLON] = ACTIONS(57),
    [anon_sym_COLONlet_COLON] = ACTIONS(57),
    [anon_sym_COLONcase_COLON] = ACTIONS(57),
    [anon_sym_COLONdefine_COLON] = ACTIONS(57),
    [anon_sym_COLONwrite_COLON] = ACTIONS(57),
    [anon_sym_COLONwlog_COLON] = ACTIONS(57),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(57),
    [anon_sym_COLONclaim_COLON] = ACTIONS(57),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(57),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(57),
    [anon_sym_COLONpick_COLON] = ACTIONS(57),
    [anon_sym_COLONst_COLON] = ACTIONS(57),
    [anon_sym_COLONdraft_COLON] = ACTIONS(59),
    [anon_sym_COLONnote_COLON] = ACTIONS(59),
    [anon_sym_COLONspan_COLON] = ACTIONS(59),
    [anon_sym_COLONabstract_COLON] = ACTIONS(61),
    [anon_sym_COLONauthor_COLON] = ACTIONS(61),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(61),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(61),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(61),
    [anon_sym_COLONexample_COLON] = ACTIONS(61),
    [anon_sym_COLONitemize_COLON] = ACTIONS(61),
    [anon_sym_COLONlemma_COLON] = ACTIONS(61),
    [anon_sym_COLONfigure_COLON] = ACTIONS(61),
    [anon_sym_COLONp_COLON] = ACTIONS(61),
    [anon_sym_COLONproof_COLON] = ACTIONS(61),
    [anon_sym_COLONproposition_COLON] = ACTIONS(61),
    [anon_sym_COLONremark_COLON] = ACTIONS(61),
    [anon_sym_COLONsketch_COLON] = ACTIONS(61),
    [anon_sym_COLONstep_COLON] = ACTIONS(61),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(71),
  },
  [STATE(48)] = {
    [anon_sym_COLON_COLON] = ACTIONS(614),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(614),
    [aux_sym_section_token1] = ACTIONS(614),
    [anon_sym_COLONsection_COLON] = ACTIONS(614),
    [aux_sym_subsection_token1] = ACTIONS(614),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(614),
    [aux_sym_subsubsection_token1] = ACTIONS(614),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(614),
    [anon_sym_COLONappendix_COLON] = ACTIONS(614),
    [aux_sym_mathblock_token1] = ACTIONS(614),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(614),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(614),
    [anon_sym_COLONtoc_COLON] = ACTIONS(614),
    [aux_sym_specialblock_token1] = ACTIONS(614),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(614),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(614),
    [anon_sym_COLONcaption_COLON] = ACTIONS(614),
    [anon_sym_COLONitem_COLON] = ACTIONS(614),
    [anon_sym_COLONprev_COLON] = ACTIONS(614),
    [anon_sym_COLONprev2_COLON] = ACTIONS(614),
    [anon_sym_COLONprev3_COLON] = ACTIONS(614),
    [aux_sym_specialinline_token1] = ACTIONS(616),
    [aux_sym_specialinline_token2] = ACTIONS(616),
    [anon_sym_COLONmath_COLON] = ACTIONS(614),
    [anon_sym_COLONcode_COLON] = ACTIONS(614),
    [aux_sym_specialinline_token3] = ACTIONS(614),
    [aux_sym_specialinline_token4] = ACTIONS(614),
    [anon_sym_COLONref_COLON] = ACTIONS(614),
    [anon_sym_COLONprevious_COLON] = ACTIONS(614),
    [anon_sym_COLONurl_COLON] = ACTIONS(614),
    [anon_sym_COLONcite_COLON] = ACTIONS(614),
    [anon_sym_COLONqed_COLON] = ACTIONS(614),
    [anon_sym_COLONtable_COLON] = ACTIONS(614),
    [anon_sym_COLONassume_COLON] = ACTIONS(614),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(614),
    [anon_sym_COLONprove_COLON] = ACTIONS(614),
    [anon_sym_COLONthen_COLON] = ACTIONS(614),
    [anon_sym_COLONnew_COLON] = ACTIONS(614),
    [anon_sym_COLONlet_COLON] = ACTIONS(614),
    [anon_sym_COLONcase_COLON] = ACTIONS(614),
    [anon_sym_COLONdefine_COLON] = ACTIONS(614),
    [anon_sym_COLONwrite_COLON] = ACTIONS(614),
    [anon_sym_COLONwlog_COLON] = ACTIONS(614),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(614),
    [anon_sym_COLONclaim_COLON] = ACTIONS(614),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(614),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(614),
    [anon_sym_COLONpick_COLON] = ACTIONS(614),
    [anon_sym_COLONst_COLON] = ACTIONS(614),
    [anon_sym_COLONdraft_COLON] = ACTIONS(614),
    [anon_sym_COLONnote_COLON] = ACTIONS(614),
    [anon_sym_COLONspan_COLON] = ACTIONS(614),
    [anon_sym_COLONabstract_COLON] = ACTIONS(614),
    [anon_sym_COLONauthor_COLON] = ACTIONS(614),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(614),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(614),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(614),
    [anon_sym_COLONexample_COLON] = ACTIONS(614),
    [anon_sym_COLONitemize_COLON] = ACTIONS(614),
    [anon_sym_COLONlemma_COLON] = ACTIONS(614),
    [anon_sym_COLONfigure_COLON] = ACTIONS(614),
    [anon_sym_COLONp_COLON] = ACTIONS(614),
    [anon_sym_COLONproof_COLON] = ACTIONS(614),
    [anon_sym_COLONproposition_COLON] = ACTIONS(614),
    [anon_sym_COLONremark_COLON] = ACTIONS(614),
    [anon_sym_COLONsketch_COLON] = ACTIONS(614),
    [anon_sym_COLONstep_COLON] = ACTIONS(614),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(614),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(614),
  },
  [STATE(49)] = {
    [anon_sym_COLON_COLON] = ACTIONS(618),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(618),
    [aux_sym_section_token1] = ACTIONS(618),
    [anon_sym_COLONsection_COLON] = ACTIONS(618),
    [aux_sym_subsection_token1] = ACTIONS(618),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(618),
    [aux_sym_subsubsection_token1] = ACTIONS(618),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(618),
    [anon_sym_COLONappendix_COLON] = ACTIONS(618),
    [aux_sym_mathblock_token1] = ACTIONS(618),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(618),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(618),
    [anon_sym_COLONtoc_COLON] = ACTIONS(618),
    [aux_sym_specialblock_token1] = ACTIONS(618),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(618),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(618),
    [anon_sym_COLONcaption_COLON] = ACTIONS(618),
    [anon_sym_COLONitem_COLON] = ACTIONS(618),
    [anon_sym_COLONprev_COLON] = ACTIONS(618),
    [anon_sym_COLONprev2_COLON] = ACTIONS(618),
    [anon_sym_COLONprev3_COLON] = ACTIONS(618),
    [aux_sym_specialinline_token1] = ACTIONS(620),
    [aux_sym_specialinline_token2] = ACTIONS(620),
    [anon_sym_COLONmath_COLON] = ACTIONS(618),
    [anon_sym_COLONcode_COLON] = ACTIONS(618),
    [aux_sym_specialinline_token3] = ACTIONS(618),
    [aux_sym_specialinline_token4] = ACTIONS(618),
    [anon_sym_COLONref_COLON] = ACTIONS(618),
    [anon_sym_COLONprevious_COLON] = ACTIONS(618),
    [anon_sym_COLONurl_COLON] = ACTIONS(618),
    [anon_sym_COLONcite_COLON] = ACTIONS(618),
    [anon_sym_COLONqed_COLON] = ACTIONS(618),
    [anon_sym_COLONtable_COLON] = ACTIONS(618),
    [anon_sym_COLONassume_COLON] = ACTIONS(618),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(618),
    [anon_sym_COLONprove_COLON] = ACTIONS(618),
    [anon_sym_COLONthen_COLON] = ACTIONS(618),
    [anon_sym_COLONnew_COLON] = ACTIONS(618),
    [anon_sym_COLONlet_COLON] = ACTIONS(618),
    [anon_sym_COLONcase_COLON] = ACTIONS(618),
    [anon_sym_COLONdefine_COLON] = ACTIONS(618),
    [anon_sym_COLONwrite_COLON] = ACTIONS(618),
    [anon_sym_COLONwlog_COLON] = ACTIONS(618),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(618),
    [anon_sym_COLONclaim_COLON] = ACTIONS(618),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(618),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(618),
    [anon_sym_COLONpick_COLON] = ACTIONS(618),
    [anon_sym_COLONst_COLON] = ACTIONS(618),
    [anon_sym_COLONdraft_COLON] = ACTIONS(618),
    [anon_sym_COLONnote_COLON] = ACTIONS(618),
    [anon_sym_COLONspan_COLON] = ACTIONS(618),
    [anon_sym_COLONabstract_COLON] = ACTIONS(618),
    [anon_sym_COLONauthor_COLON] = ACTIONS(618),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(618),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(618),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(618),
    [anon_sym_COLONexample_COLON] = ACTIONS(618),
    [anon_sym_COLONitemize_COLON] = ACTIONS(618),
    [anon_sym_COLONlemma_COLON] = ACTIONS(618),
    [anon_sym_COLONfigure_COLON] = ACTIONS(618),
    [anon_sym_COLONp_COLON] = ACTIONS(618),
    [anon_sym_COLONproof_COLON] = ACTIONS(618),
    [anon_sym_COLONproposition_COLON] = ACTIONS(618),
    [anon_sym_COLONremark_COLON] = ACTIONS(618),
    [anon_sym_COLONsketch_COLON] = ACTIONS(618),
    [anon_sym_COLONstep_COLON] = ACTIONS(618),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(618),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(618),
  },
  [STATE(50)] = {
    [anon_sym_COLON_COLON] = ACTIONS(622),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(622),
    [aux_sym_section_token1] = ACTIONS(622),
    [anon_sym_COLONsection_COLON] = ACTIONS(622),
    [aux_sym_subsection_token1] = ACTIONS(622),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(622),
    [aux_sym_subsubsection_token1] = ACTIONS(622),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(622),
    [anon_sym_COLONappendix_COLON] = ACTIONS(622),
    [aux_sym_mathblock_token1] = ACTIONS(622),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(622),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(622),
    [anon_sym_COLONtoc_COLON] = ACTIONS(622),
    [aux_sym_specialblock_token1] = ACTIONS(622),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(622),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(622),
    [anon_sym_COLONcaption_COLON] = ACTIONS(622),
    [anon_sym_COLONitem_COLON] = ACTIONS(622),
    [anon_sym_COLONprev_COLON] = ACTIONS(622),
    [anon_sym_COLONprev2_COLON] = ACTIONS(622),
    [anon_sym_COLONprev3_COLON] = ACTIONS(622),
    [aux_sym_specialinline_token1] = ACTIONS(624),
    [aux_sym_specialinline_token2] = ACTIONS(624),
    [anon_sym_COLONmath_COLON] = ACTIONS(622),
    [anon_sym_COLONcode_COLON] = ACTIONS(622),
    [aux_sym_specialinline_token3] = ACTIONS(622),
    [aux_sym_specialinline_token4] = ACTIONS(622),
    [anon_sym_COLONref_COLON] = ACTIONS(622),
    [anon_sym_COLONprevious_COLON] = ACTIONS(622),
    [anon_sym_COLONurl_COLON] = ACTIONS(622),
    [anon_sym_COLONcite_COLON] = ACTIONS(622),
    [anon_sym_COLONqed_COLON] = ACTIONS(622),
    [anon_sym_COLONtable_COLON] = ACTIONS(622),
    [anon_sym_COLONassume_COLON] = ACTIONS(622),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(622),
    [anon_sym_COLONprove_COLON] = ACTIONS(622),
    [anon_sym_COLONthen_COLON] = ACTIONS(622),
    [anon_sym_COLONnew_COLON] = ACTIONS(622),
    [anon_sym_COLONlet_COLON] = ACTIONS(622),
    [anon_sym_COLONcase_COLON] = ACTIONS(622),
    [anon_sym_COLONdefine_COLON] = ACTIONS(622),
    [anon_sym_COLONwrite_COLON] = ACTIONS(622),
    [anon_sym_COLONwlog_COLON] = ACTIONS(622),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(622),
    [anon_sym_COLONclaim_COLON] = ACTIONS(622),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(622),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(622),
    [anon_sym_COLONpick_COLON] = ACTIONS(622),
    [anon_sym_COLONst_COLON] = ACTIONS(622),
    [anon_sym_COLONdraft_COLON] = ACTIONS(622),
    [anon_sym_COLONnote_COLON] = ACTIONS(622),
    [anon_sym_COLONspan_COLON] = ACTIONS(622),
    [anon_sym_COLONabstract_COLON] = ACTIONS(622),
    [anon_sym_COLONauthor_COLON] = ACTIONS(622),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(622),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(622),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(622),
    [anon_sym_COLONexample_COLON] = ACTIONS(622),
    [anon_sym_COLONitemize_COLON] = ACTIONS(622),
    [anon_sym_COLONlemma_COLON] = ACTIONS(622),
    [anon_sym_COLONfigure_COLON] = ACTIONS(622),
    [anon_sym_COLONp_COLON] = ACTIONS(622),
    [anon_sym_COLONproof_COLON] = ACTIONS(622),
    [anon_sym_COLONproposition_COLON] = ACTIONS(622),
    [anon_sym_COLONremark_COLON] = ACTIONS(622),
    [anon_sym_COLONsketch_COLON] = ACTIONS(622),
    [anon_sym_COLONstep_COLON] = ACTIONS(622),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(622),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(622),
  },
  [STATE(51)] = {
    [anon_sym_COLON_COLON] = ACTIONS(626),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(626),
    [aux_sym_section_token1] = ACTIONS(626),
    [anon_sym_COLONsection_COLON] = ACTIONS(626),
    [aux_sym_subsection_token1] = ACTIONS(626),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(626),
    [aux_sym_subsubsection_token1] = ACTIONS(626),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(626),
    [anon_sym_COLONappendix_COLON] = ACTIONS(626),
    [aux_sym_mathblock_token1] = ACTIONS(626),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(626),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(626),
    [anon_sym_COLONtoc_COLON] = ACTIONS(626),
    [aux_sym_specialblock_token1] = ACTIONS(626),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(626),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(626),
    [anon_sym_COLONcaption_COLON] = ACTIONS(626),
    [anon_sym_COLONitem_COLON] = ACTIONS(626),
    [anon_sym_COLONprev_COLON] = ACTIONS(626),
    [anon_sym_COLONprev2_COLON] = ACTIONS(626),
    [anon_sym_COLONprev3_COLON] = ACTIONS(626),
    [aux_sym_specialinline_token1] = ACTIONS(628),
    [aux_sym_specialinline_token2] = ACTIONS(628),
    [anon_sym_COLONmath_COLON] = ACTIONS(626),
    [anon_sym_COLONcode_COLON] = ACTIONS(626),
    [aux_sym_specialinline_token3] = ACTIONS(626),
    [aux_sym_specialinline_token4] = ACTIONS(626),
    [anon_sym_COLONref_COLON] = ACTIONS(626),
    [anon_sym_COLONprevious_COLON] = ACTIONS(626),
    [anon_sym_COLONurl_COLON] = ACTIONS(626),
    [anon_sym_COLONcite_COLON] = ACTIONS(626),
    [anon_sym_COLONqed_COLON] = ACTIONS(626),
    [anon_sym_COLONtable_COLON] = ACTIONS(626),
    [anon_sym_COLONassume_COLON] = ACTIONS(626),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(626),
    [anon_sym_COLONprove_COLON] = ACTIONS(626),
    [anon_sym_COLONthen_COLON] = ACTIONS(626),
    [anon_sym_COLONnew_COLON] = ACTIONS(626),
    [anon_sym_COLONlet_COLON] = ACTIONS(626),
    [anon_sym_COLONcase_COLON] = ACTIONS(626),
    [anon_sym_COLONdefine_COLON] = ACTIONS(626),
    [anon_sym_COLONwrite_COLON] = ACTIONS(626),
    [anon_sym_COLONwlog_COLON] = ACTIONS(626),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(626),
    [anon_sym_COLONclaim_COLON] = ACTIONS(626),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(626),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(626),
    [anon_sym_COLONpick_COLON] = ACTIONS(626),
    [anon_sym_COLONst_COLON] = ACTIONS(626),
    [anon_sym_COLONdraft_COLON] = ACTIONS(626),
    [anon_sym_COLONnote_COLON] = ACTIONS(626),
    [anon_sym_COLONspan_COLON] = ACTIONS(626),
    [anon_sym_COLONabstract_COLON] = ACTIONS(626),
    [anon_sym_COLONauthor_COLON] = ACTIONS(626),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(626),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(626),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(626),
    [anon_sym_COLONexample_COLON] = ACTIONS(626),
    [anon_sym_COLONitemize_COLON] = ACTIONS(626),
    [anon_sym_COLONlemma_COLON] = ACTIONS(626),
    [anon_sym_COLONfigure_COLON] = ACTIONS(626),
    [anon_sym_COLONp_COLON] = ACTIONS(626),
    [anon_sym_COLONproof_COLON] = ACTIONS(626),
    [anon_sym_COLONproposition_COLON] = ACTIONS(626),
    [anon_sym_COLONremark_COLON] = ACTIONS(626),
    [anon_sym_COLONsketch_COLON] = ACTIONS(626),
    [anon_sym_COLONstep_COLON] = ACTIONS(626),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(626),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(626),
  },
  [STATE(52)] = {
    [anon_sym_COLON_COLON] = ACTIONS(630),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(630),
    [aux_sym_section_token1] = ACTIONS(630),
    [anon_sym_COLONsection_COLON] = ACTIONS(630),
    [aux_sym_subsection_token1] = ACTIONS(630),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(630),
    [aux_sym_subsubsection_token1] = ACTIONS(630),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(630),
    [anon_sym_COLONappendix_COLON] = ACTIONS(630),
    [aux_sym_mathblock_token1] = ACTIONS(630),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(630),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(630),
    [anon_sym_COLONtoc_COLON] = ACTIONS(630),
    [aux_sym_specialblock_token1] = ACTIONS(630),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(630),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(630),
    [anon_sym_COLONcaption_COLON] = ACTIONS(630),
    [anon_sym_COLONitem_COLON] = ACTIONS(630),
    [anon_sym_COLONprev_COLON] = ACTIONS(630),
    [anon_sym_COLONprev2_COLON] = ACTIONS(630),
    [anon_sym_COLONprev3_COLON] = ACTIONS(630),
    [aux_sym_specialinline_token1] = ACTIONS(632),
    [aux_sym_specialinline_token2] = ACTIONS(632),
    [anon_sym_COLONmath_COLON] = ACTIONS(630),
    [anon_sym_COLONcode_COLON] = ACTIONS(630),
    [aux_sym_specialinline_token3] = ACTIONS(630),
    [aux_sym_specialinline_token4] = ACTIONS(630),
    [anon_sym_COLONref_COLON] = ACTIONS(630),
    [anon_sym_COLONprevious_COLON] = ACTIONS(630),
    [anon_sym_COLONurl_COLON] = ACTIONS(630),
    [anon_sym_COLONcite_COLON] = ACTIONS(630),
    [anon_sym_COLONqed_COLON] = ACTIONS(630),
    [anon_sym_COLONtable_COLON] = ACTIONS(630),
    [anon_sym_COLONassume_COLON] = ACTIONS(630),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(630),
    [anon_sym_COLONprove_COLON] = ACTIONS(630),
    [anon_sym_COLONthen_COLON] = ACTIONS(630),
    [anon_sym_COLONnew_COLON] = ACTIONS(630),
    [anon_sym_COLONlet_COLON] = ACTIONS(630),
    [anon_sym_COLONcase_COLON] = ACTIONS(630),
    [anon_sym_COLONdefine_COLON] = ACTIONS(630),
    [anon_sym_COLONwrite_COLON] = ACTIONS(630),
    [anon_sym_COLONwlog_COLON] = ACTIONS(630),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(630),
    [anon_sym_COLONclaim_COLON] = ACTIONS(630),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(630),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(630),
    [anon_sym_COLONpick_COLON] = ACTIONS(630),
    [anon_sym_COLONst_COLON] = ACTIONS(630),
    [anon_sym_COLONdraft_COLON] = ACTIONS(630),
    [anon_sym_COLONnote_COLON] = ACTIONS(630),
    [anon_sym_COLONspan_COLON] = ACTIONS(630),
    [anon_sym_COLONabstract_COLON] = ACTIONS(630),
    [anon_sym_COLONauthor_COLON] = ACTIONS(630),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(630),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(630),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(630),
    [anon_sym_COLONexample_COLON] = ACTIONS(630),
    [anon_sym_COLONitemize_COLON] = ACTIONS(630),
    [anon_sym_COLONlemma_COLON] = ACTIONS(630),
    [anon_sym_COLONfigure_COLON] = ACTIONS(630),
    [anon_sym_COLONp_COLON] = ACTIONS(630),
    [anon_sym_COLONproof_COLON] = ACTIONS(630),
    [anon_sym_COLONproposition_COLON] = ACTIONS(630),
    [anon_sym_COLONremark_COLON] = ACTIONS(630),
    [anon_sym_COLONsketch_COLON] = ACTIONS(630),
    [anon_sym_COLONstep_COLON] = ACTIONS(630),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(630),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(630),
  },
  [STATE(53)] = {
    [anon_sym_COLON_COLON] = ACTIONS(634),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(634),
    [aux_sym_section_token1] = ACTIONS(634),
    [anon_sym_COLONsection_COLON] = ACTIONS(634),
    [aux_sym_subsection_token1] = ACTIONS(634),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(634),
    [aux_sym_subsubsection_token1] = ACTIONS(634),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(634),
    [anon_sym_COLONappendix_COLON] = ACTIONS(634),
    [aux_sym_mathblock_token1] = ACTIONS(634),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(634),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(634),
    [anon_sym_COLONtoc_COLON] = ACTIONS(634),
    [aux_sym_specialblock_token1] = ACTIONS(634),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(634),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(634),
    [anon_sym_COLONcaption_COLON] = ACTIONS(634),
    [anon_sym_COLONitem_COLON] = ACTIONS(634),
    [anon_sym_COLONprev_COLON] = ACTIONS(634),
    [anon_sym_COLONprev2_COLON] = ACTIONS(634),
    [anon_sym_COLONprev3_COLON] = ACTIONS(634),
    [aux_sym_specialinline_token1] = ACTIONS(636),
    [aux_sym_specialinline_token2] = ACTIONS(636),
    [anon_sym_COLONmath_COLON] = ACTIONS(634),
    [anon_sym_COLONcode_COLON] = ACTIONS(634),
    [aux_sym_specialinline_token3] = ACTIONS(634),
    [aux_sym_specialinline_token4] = ACTIONS(634),
    [anon_sym_COLONref_COLON] = ACTIONS(634),
    [anon_sym_COLONprevious_COLON] = ACTIONS(634),
    [anon_sym_COLONurl_COLON] = ACTIONS(634),
    [anon_sym_COLONcite_COLON] = ACTIONS(634),
    [anon_sym_COLONqed_COLON] = ACTIONS(634),
    [anon_sym_COLONtable_COLON] = ACTIONS(634),
    [anon_sym_COLONassume_COLON] = ACTIONS(634),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(634),
    [anon_sym_COLONprove_COLON] = ACTIONS(634),
    [anon_sym_COLONthen_COLON] = ACTIONS(634),
    [anon_sym_COLONnew_COLON] = ACTIONS(634),
    [anon_sym_COLONlet_COLON] = ACTIONS(634),
    [anon_sym_COLONcase_COLON] = ACTIONS(634),
    [anon_sym_COLONdefine_COLON] = ACTIONS(634),
    [anon_sym_COLONwrite_COLON] = ACTIONS(634),
    [anon_sym_COLONwlog_COLON] = ACTIONS(634),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(634),
    [anon_sym_COLONclaim_COLON] = ACTIONS(634),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(634),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(634),
    [anon_sym_COLONpick_COLON] = ACTIONS(634),
    [anon_sym_COLONst_COLON] = ACTIONS(634),
    [anon_sym_COLONdraft_COLON] = ACTIONS(634),
    [anon_sym_COLONnote_COLON] = ACTIONS(634),
    [anon_sym_COLONspan_COLON] = ACTIONS(634),
    [anon_sym_COLONabstract_COLON] = ACTIONS(634),
    [anon_sym_COLONauthor_COLON] = ACTIONS(634),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(634),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(634),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(634),
    [anon_sym_COLONexample_COLON] = ACTIONS(634),
    [anon_sym_COLONitemize_COLON] = ACTIONS(634),
    [anon_sym_COLONlemma_COLON] = ACTIONS(634),
    [anon_sym_COLONfigure_COLON] = ACTIONS(634),
    [anon_sym_COLONp_COLON] = ACTIONS(634),
    [anon_sym_COLONproof_COLON] = ACTIONS(634),
    [anon_sym_COLONproposition_COLON] = ACTIONS(634),
    [anon_sym_COLONremark_COLON] = ACTIONS(634),
    [anon_sym_COLONsketch_COLON] = ACTIONS(634),
    [anon_sym_COLONstep_COLON] = ACTIONS(634),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(634),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(634),
  },
  [STATE(54)] = {
    [anon_sym_COLON_COLON] = ACTIONS(638),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(638),
    [aux_sym_section_token1] = ACTIONS(638),
    [anon_sym_COLONsection_COLON] = ACTIONS(638),
    [aux_sym_subsection_token1] = ACTIONS(638),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(638),
    [aux_sym_subsubsection_token1] = ACTIONS(638),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(638),
    [anon_sym_COLONappendix_COLON] = ACTIONS(638),
    [aux_sym_mathblock_token1] = ACTIONS(638),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(638),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(638),
    [anon_sym_COLONtoc_COLON] = ACTIONS(638),
    [aux_sym_specialblock_token1] = ACTIONS(638),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(638),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(638),
    [anon_sym_COLONcaption_COLON] = ACTIONS(638),
    [anon_sym_COLONitem_COLON] = ACTIONS(638),
    [anon_sym_COLONprev_COLON] = ACTIONS(638),
    [anon_sym_COLONprev2_COLON] = ACTIONS(638),
    [anon_sym_COLONprev3_COLON] = ACTIONS(638),
    [aux_sym_specialinline_token1] = ACTIONS(640),
    [aux_sym_specialinline_token2] = ACTIONS(640),
    [anon_sym_COLONmath_COLON] = ACTIONS(638),
    [anon_sym_COLONcode_COLON] = ACTIONS(638),
    [aux_sym_specialinline_token3] = ACTIONS(638),
    [aux_sym_specialinline_token4] = ACTIONS(638),
    [anon_sym_COLONref_COLON] = ACTIONS(638),
    [anon_sym_COLONprevious_COLON] = ACTIONS(638),
    [anon_sym_COLONurl_COLON] = ACTIONS(638),
    [anon_sym_COLONcite_COLON] = ACTIONS(638),
    [anon_sym_COLONqed_COLON] = ACTIONS(638),
    [anon_sym_COLONtable_COLON] = ACTIONS(638),
    [anon_sym_COLONassume_COLON] = ACTIONS(638),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(638),
    [anon_sym_COLONprove_COLON] = ACTIONS(638),
    [anon_sym_COLONthen_COLON] = ACTIONS(638),
    [anon_sym_COLONnew_COLON] = ACTIONS(638),
    [anon_sym_COLONlet_COLON] = ACTIONS(638),
    [anon_sym_COLONcase_COLON] = ACTIONS(638),
    [anon_sym_COLONdefine_COLON] = ACTIONS(638),
    [anon_sym_COLONwrite_COLON] = ACTIONS(638),
    [anon_sym_COLONwlog_COLON] = ACTIONS(638),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(638),
    [anon_sym_COLONclaim_COLON] = ACTIONS(638),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(638),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(638),
    [anon_sym_COLONpick_COLON] = ACTIONS(638),
    [anon_sym_COLONst_COLON] = ACTIONS(638),
    [anon_sym_COLONdraft_COLON] = ACTIONS(638),
    [anon_sym_COLONnote_COLON] = ACTIONS(638),
    [anon_sym_COLONspan_COLON] = ACTIONS(638),
    [anon_sym_COLONabstract_COLON] = ACTIONS(638),
    [anon_sym_COLONauthor_COLON] = ACTIONS(638),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(638),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(638),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(638),
    [anon_sym_COLONexample_COLON] = ACTIONS(638),
    [anon_sym_COLONitemize_COLON] = ACTIONS(638),
    [anon_sym_COLONlemma_COLON] = ACTIONS(638),
    [anon_sym_COLONfigure_COLON] = ACTIONS(638),
    [anon_sym_COLONp_COLON] = ACTIONS(638),
    [anon_sym_COLONproof_COLON] = ACTIONS(638),
    [anon_sym_COLONproposition_COLON] = ACTIONS(638),
    [anon_sym_COLONremark_COLON] = ACTIONS(638),
    [anon_sym_COLONsketch_COLON] = ACTIONS(638),
    [anon_sym_COLONstep_COLON] = ACTIONS(638),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(638),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(638),
  },
  [STATE(55)] = {
    [anon_sym_COLON_COLON] = ACTIONS(642),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(642),
    [aux_sym_section_token1] = ACTIONS(642),
    [anon_sym_COLONsection_COLON] = ACTIONS(642),
    [aux_sym_subsection_token1] = ACTIONS(642),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(642),
    [aux_sym_subsubsection_token1] = ACTIONS(642),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(642),
    [anon_sym_COLONappendix_COLON] = ACTIONS(642),
    [aux_sym_mathblock_token1] = ACTIONS(642),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(642),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(642),
    [anon_sym_COLONtoc_COLON] = ACTIONS(642),
    [aux_sym_specialblock_token1] = ACTIONS(642),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(642),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(642),
    [anon_sym_COLONcaption_COLON] = ACTIONS(642),
    [anon_sym_COLONitem_COLON] = ACTIONS(642),
    [anon_sym_COLONprev_COLON] = ACTIONS(642),
    [anon_sym_COLONprev2_COLON] = ACTIONS(642),
    [anon_sym_COLONprev3_COLON] = ACTIONS(642),
    [aux_sym_specialinline_token1] = ACTIONS(644),
    [aux_sym_specialinline_token2] = ACTIONS(644),
    [anon_sym_COLONmath_COLON] = ACTIONS(642),
    [anon_sym_COLONcode_COLON] = ACTIONS(642),
    [aux_sym_specialinline_token3] = ACTIONS(642),
    [aux_sym_specialinline_token4] = ACTIONS(642),
    [anon_sym_COLONref_COLON] = ACTIONS(642),
    [anon_sym_COLONprevious_COLON] = ACTIONS(642),
    [anon_sym_COLONurl_COLON] = ACTIONS(642),
    [anon_sym_COLONcite_COLON] = ACTIONS(642),
    [anon_sym_COLONqed_COLON] = ACTIONS(642),
    [anon_sym_COLONtable_COLON] = ACTIONS(642),
    [anon_sym_COLONassume_COLON] = ACTIONS(642),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(642),
    [anon_sym_COLONprove_COLON] = ACTIONS(642),
    [anon_sym_COLONthen_COLON] = ACTIONS(642),
    [anon_sym_COLONnew_COLON] = ACTIONS(642),
    [anon_sym_COLONlet_COLON] = ACTIONS(642),
    [anon_sym_COLONcase_COLON] = ACTIONS(642),
    [anon_sym_COLONdefine_COLON] = ACTIONS(642),
    [anon_sym_COLONwrite_COLON] = ACTIONS(642),
    [anon_sym_COLONwlog_COLON] = ACTIONS(642),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(642),
    [anon_sym_COLONclaim_COLON] = ACTIONS(642),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(642),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(642),
    [anon_sym_COLONpick_COLON] = ACTIONS(642),
    [anon_sym_COLONst_COLON] = ACTIONS(642),
    [anon_sym_COLONdraft_COLON] = ACTIONS(642),
    [anon_sym_COLONnote_COLON] = ACTIONS(642),
    [anon_sym_COLONspan_COLON] = ACTIONS(642),
    [anon_sym_COLONabstract_COLON] = ACTIONS(642),
    [anon_sym_COLONauthor_COLON] = ACTIONS(642),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(642),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(642),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(642),
    [anon_sym_COLONexample_COLON] = ACTIONS(642),
    [anon_sym_COLONitemize_COLON] = ACTIONS(642),
    [anon_sym_COLONlemma_COLON] = ACTIONS(642),
    [anon_sym_COLONfigure_COLON] = ACTIONS(642),
    [anon_sym_COLONp_COLON] = ACTIONS(642),
    [anon_sym_COLONproof_COLON] = ACTIONS(642),
    [anon_sym_COLONproposition_COLON] = ACTIONS(642),
    [anon_sym_COLONremark_COLON] = ACTIONS(642),
    [anon_sym_COLONsketch_COLON] = ACTIONS(642),
    [anon_sym_COLONstep_COLON] = ACTIONS(642),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(642),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(642),
  },
  [STATE(56)] = {
    [anon_sym_COLON_COLON] = ACTIONS(646),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(646),
    [aux_sym_section_token1] = ACTIONS(646),
    [anon_sym_COLONsection_COLON] = ACTIONS(646),
    [aux_sym_subsection_token1] = ACTIONS(646),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(646),
    [aux_sym_subsubsection_token1] = ACTIONS(646),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(646),
    [anon_sym_COLONappendix_COLON] = ACTIONS(646),
    [aux_sym_mathblock_token1] = ACTIONS(646),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(646),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(646),
    [anon_sym_COLONtoc_COLON] = ACTIONS(646),
    [aux_sym_specialblock_token1] = ACTIONS(646),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(646),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(646),
    [anon_sym_COLONcaption_COLON] = ACTIONS(646),
    [anon_sym_COLONitem_COLON] = ACTIONS(646),
    [anon_sym_COLONprev_COLON] = ACTIONS(646),
    [anon_sym_COLONprev2_COLON] = ACTIONS(646),
    [anon_sym_COLONprev3_COLON] = ACTIONS(646),
    [aux_sym_specialinline_token1] = ACTIONS(648),
    [aux_sym_specialinline_token2] = ACTIONS(648),
    [anon_sym_COLONmath_COLON] = ACTIONS(646),
    [anon_sym_COLONcode_COLON] = ACTIONS(646),
    [aux_sym_specialinline_token3] = ACTIONS(646),
    [aux_sym_specialinline_token4] = ACTIONS(646),
    [anon_sym_COLONref_COLON] = ACTIONS(646),
    [anon_sym_COLONprevious_COLON] = ACTIONS(646),
    [anon_sym_COLONurl_COLON] = ACTIONS(646),
    [anon_sym_COLONcite_COLON] = ACTIONS(646),
    [anon_sym_COLONqed_COLON] = ACTIONS(646),
    [anon_sym_COLONtable_COLON] = ACTIONS(646),
    [anon_sym_COLONassume_COLON] = ACTIONS(646),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(646),
    [anon_sym_COLONprove_COLON] = ACTIONS(646),
    [anon_sym_COLONthen_COLON] = ACTIONS(646),
    [anon_sym_COLONnew_COLON] = ACTIONS(646),
    [anon_sym_COLONlet_COLON] = ACTIONS(646),
    [anon_sym_COLONcase_COLON] = ACTIONS(646),
    [anon_sym_COLONdefine_COLON] = ACTIONS(646),
    [anon_sym_COLONwrite_COLON] = ACTIONS(646),
    [anon_sym_COLONwlog_COLON] = ACTIONS(646),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(646),
    [anon_sym_COLONclaim_COLON] = ACTIONS(646),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(646),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(646),
    [anon_sym_COLONpick_COLON] = ACTIONS(646),
    [anon_sym_COLONst_COLON] = ACTIONS(646),
    [anon_sym_COLONdraft_COLON] = ACTIONS(646),
    [anon_sym_COLONnote_COLON] = ACTIONS(646),
    [anon_sym_COLONspan_COLON] = ACTIONS(646),
    [anon_sym_COLONabstract_COLON] = ACTIONS(646),
    [anon_sym_COLONauthor_COLON] = ACTIONS(646),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(646),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(646),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(646),
    [anon_sym_COLONexample_COLON] = ACTIONS(646),
    [anon_sym_COLONitemize_COLON] = ACTIONS(646),
    [anon_sym_COLONlemma_COLON] = ACTIONS(646),
    [anon_sym_COLONfigure_COLON] = ACTIONS(646),
    [anon_sym_COLONp_COLON] = ACTIONS(646),
    [anon_sym_COLONproof_COLON] = ACTIONS(646),
    [anon_sym_COLONproposition_COLON] = ACTIONS(646),
    [anon_sym_COLONremark_COLON] = ACTIONS(646),
    [anon_sym_COLONsketch_COLON] = ACTIONS(646),
    [anon_sym_COLONstep_COLON] = ACTIONS(646),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(646),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(646),
  },
  [STATE(57)] = {
    [anon_sym_COLON_COLON] = ACTIONS(650),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(650),
    [aux_sym_section_token1] = ACTIONS(650),
    [anon_sym_COLONsection_COLON] = ACTIONS(650),
    [aux_sym_subsection_token1] = ACTIONS(650),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(650),
    [aux_sym_subsubsection_token1] = ACTIONS(650),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(650),
    [anon_sym_COLONappendix_COLON] = ACTIONS(650),
    [aux_sym_mathblock_token1] = ACTIONS(650),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(650),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(650),
    [anon_sym_COLONtoc_COLON] = ACTIONS(650),
    [aux_sym_specialblock_token1] = ACTIONS(650),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(650),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(650),
    [anon_sym_COLONcaption_COLON] = ACTIONS(650),
    [anon_sym_COLONitem_COLON] = ACTIONS(650),
    [anon_sym_COLONprev_COLON] = ACTIONS(650),
    [anon_sym_COLONprev2_COLON] = ACTIONS(650),
    [anon_sym_COLONprev3_COLON] = ACTIONS(650),
    [aux_sym_specialinline_token1] = ACTIONS(652),
    [aux_sym_specialinline_token2] = ACTIONS(652),
    [anon_sym_COLONmath_COLON] = ACTIONS(650),
    [anon_sym_COLONcode_COLON] = ACTIONS(650),
    [aux_sym_specialinline_token3] = ACTIONS(650),
    [aux_sym_specialinline_token4] = ACTIONS(650),
    [anon_sym_COLONref_COLON] = ACTIONS(650),
    [anon_sym_COLONprevious_COLON] = ACTIONS(650),
    [anon_sym_COLONurl_COLON] = ACTIONS(650),
    [anon_sym_COLONcite_COLON] = ACTIONS(650),
    [anon_sym_COLONqed_COLON] = ACTIONS(650),
    [anon_sym_COLONtable_COLON] = ACTIONS(650),
    [anon_sym_COLONassume_COLON] = ACTIONS(650),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(650),
    [anon_sym_COLONprove_COLON] = ACTIONS(650),
    [anon_sym_COLONthen_COLON] = ACTIONS(650),
    [anon_sym_COLONnew_COLON] = ACTIONS(650),
    [anon_sym_COLONlet_COLON] = ACTIONS(650),
    [anon_sym_COLONcase_COLON] = ACTIONS(650),
    [anon_sym_COLONdefine_COLON] = ACTIONS(650),
    [anon_sym_COLONwrite_COLON] = ACTIONS(650),
    [anon_sym_COLONwlog_COLON] = ACTIONS(650),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(650),
    [anon_sym_COLONclaim_COLON] = ACTIONS(650),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(650),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(650),
    [anon_sym_COLONpick_COLON] = ACTIONS(650),
    [anon_sym_COLONst_COLON] = ACTIONS(650),
    [anon_sym_COLONdraft_COLON] = ACTIONS(650),
    [anon_sym_COLONnote_COLON] = ACTIONS(650),
    [anon_sym_COLONspan_COLON] = ACTIONS(650),
    [anon_sym_COLONabstract_COLON] = ACTIONS(650),
    [anon_sym_COLONauthor_COLON] = ACTIONS(650),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(650),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(650),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(650),
    [anon_sym_COLONexample_COLON] = ACTIONS(650),
    [anon_sym_COLONitemize_COLON] = ACTIONS(650),
    [anon_sym_COLONlemma_COLON] = ACTIONS(650),
    [anon_sym_COLONfigure_COLON] = ACTIONS(650),
    [anon_sym_COLONp_COLON] = ACTIONS(650),
    [anon_sym_COLONproof_COLON] = ACTIONS(650),
    [anon_sym_COLONproposition_COLON] = ACTIONS(650),
    [anon_sym_COLONremark_COLON] = ACTIONS(650),
    [anon_sym_COLONsketch_COLON] = ACTIONS(650),
    [anon_sym_COLONstep_COLON] = ACTIONS(650),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(650),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(650),
  },
  [STATE(58)] = {
    [anon_sym_COLON_COLON] = ACTIONS(654),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(654),
    [aux_sym_section_token1] = ACTIONS(654),
    [anon_sym_COLONsection_COLON] = ACTIONS(654),
    [aux_sym_subsection_token1] = ACTIONS(654),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(654),
    [aux_sym_subsubsection_token1] = ACTIONS(654),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(654),
    [anon_sym_COLONappendix_COLON] = ACTIONS(654),
    [aux_sym_mathblock_token1] = ACTIONS(654),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(654),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(654),
    [anon_sym_COLONtoc_COLON] = ACTIONS(654),
    [aux_sym_specialblock_token1] = ACTIONS(654),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(654),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(654),
    [anon_sym_COLONcaption_COLON] = ACTIONS(654),
    [anon_sym_COLONitem_COLON] = ACTIONS(654),
    [anon_sym_COLONprev_COLON] = ACTIONS(654),
    [anon_sym_COLONprev2_COLON] = ACTIONS(654),
    [anon_sym_COLONprev3_COLON] = ACTIONS(654),
    [aux_sym_specialinline_token1] = ACTIONS(656),
    [aux_sym_specialinline_token2] = ACTIONS(656),
    [anon_sym_COLONmath_COLON] = ACTIONS(654),
    [anon_sym_COLONcode_COLON] = ACTIONS(654),
    [aux_sym_specialinline_token3] = ACTIONS(654),
    [aux_sym_specialinline_token4] = ACTIONS(654),
    [anon_sym_COLONref_COLON] = ACTIONS(654),
    [anon_sym_COLONprevious_COLON] = ACTIONS(654),
    [anon_sym_COLONurl_COLON] = ACTIONS(654),
    [anon_sym_COLONcite_COLON] = ACTIONS(654),
    [anon_sym_COLONqed_COLON] = ACTIONS(654),
    [anon_sym_COLONtable_COLON] = ACTIONS(654),
    [anon_sym_COLONassume_COLON] = ACTIONS(654),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(654),
    [anon_sym_COLONprove_COLON] = ACTIONS(654),
    [anon_sym_COLONthen_COLON] = ACTIONS(654),
    [anon_sym_COLONnew_COLON] = ACTIONS(654),
    [anon_sym_COLONlet_COLON] = ACTIONS(654),
    [anon_sym_COLONcase_COLON] = ACTIONS(654),
    [anon_sym_COLONdefine_COLON] = ACTIONS(654),
    [anon_sym_COLONwrite_COLON] = ACTIONS(654),
    [anon_sym_COLONwlog_COLON] = ACTIONS(654),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(654),
    [anon_sym_COLONclaim_COLON] = ACTIONS(654),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(654),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(654),
    [anon_sym_COLONpick_COLON] = ACTIONS(654),
    [anon_sym_COLONst_COLON] = ACTIONS(654),
    [anon_sym_COLONdraft_COLON] = ACTIONS(654),
    [anon_sym_COLONnote_COLON] = ACTIONS(654),
    [anon_sym_COLONspan_COLON] = ACTIONS(654),
    [anon_sym_COLONabstract_COLON] = ACTIONS(654),
    [anon_sym_COLONauthor_COLON] = ACTIONS(654),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(654),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(654),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(654),
    [anon_sym_COLONexample_COLON] = ACTIONS(654),
    [anon_sym_COLONitemize_COLON] = ACTIONS(654),
    [anon_sym_COLONlemma_COLON] = ACTIONS(654),
    [anon_sym_COLONfigure_COLON] = ACTIONS(654),
    [anon_sym_COLONp_COLON] = ACTIONS(654),
    [anon_sym_COLONproof_COLON] = ACTIONS(654),
    [anon_sym_COLONproposition_COLON] = ACTIONS(654),
    [anon_sym_COLONremark_COLON] = ACTIONS(654),
    [anon_sym_COLONsketch_COLON] = ACTIONS(654),
    [anon_sym_COLONstep_COLON] = ACTIONS(654),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(654),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(654),
  },
  [STATE(59)] = {
    [anon_sym_COLON_COLON] = ACTIONS(658),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(658),
    [aux_sym_section_token1] = ACTIONS(658),
    [anon_sym_COLONsection_COLON] = ACTIONS(658),
    [aux_sym_subsection_token1] = ACTIONS(658),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(658),
    [aux_sym_subsubsection_token1] = ACTIONS(658),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(658),
    [anon_sym_COLONappendix_COLON] = ACTIONS(658),
    [aux_sym_mathblock_token1] = ACTIONS(658),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(658),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(658),
    [anon_sym_COLONtoc_COLON] = ACTIONS(658),
    [aux_sym_specialblock_token1] = ACTIONS(658),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(658),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(658),
    [anon_sym_COLONcaption_COLON] = ACTIONS(658),
    [anon_sym_COLONitem_COLON] = ACTIONS(658),
    [anon_sym_COLONprev_COLON] = ACTIONS(658),
    [anon_sym_COLONprev2_COLON] = ACTIONS(658),
    [anon_sym_COLONprev3_COLON] = ACTIONS(658),
    [aux_sym_specialinline_token1] = ACTIONS(660),
    [aux_sym_specialinline_token2] = ACTIONS(660),
    [anon_sym_COLONmath_COLON] = ACTIONS(658),
    [anon_sym_COLONcode_COLON] = ACTIONS(658),
    [aux_sym_specialinline_token3] = ACTIONS(658),
    [aux_sym_specialinline_token4] = ACTIONS(658),
    [anon_sym_COLONref_COLON] = ACTIONS(658),
    [anon_sym_COLONprevious_COLON] = ACTIONS(658),
    [anon_sym_COLONurl_COLON] = ACTIONS(658),
    [anon_sym_COLONcite_COLON] = ACTIONS(658),
    [anon_sym_COLONqed_COLON] = ACTIONS(658),
    [anon_sym_COLONtable_COLON] = ACTIONS(658),
    [anon_sym_COLONassume_COLON] = ACTIONS(658),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(658),
    [anon_sym_COLONprove_COLON] = ACTIONS(658),
    [anon_sym_COLONthen_COLON] = ACTIONS(658),
    [anon_sym_COLONnew_COLON] = ACTIONS(658),
    [anon_sym_COLONlet_COLON] = ACTIONS(658),
    [anon_sym_COLONcase_COLON] = ACTIONS(658),
    [anon_sym_COLONdefine_COLON] = ACTIONS(658),
    [anon_sym_COLONwrite_COLON] = ACTIONS(658),
    [anon_sym_COLONwlog_COLON] = ACTIONS(658),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(658),
    [anon_sym_COLONclaim_COLON] = ACTIONS(658),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(658),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(658),
    [anon_sym_COLONpick_COLON] = ACTIONS(658),
    [anon_sym_COLONst_COLON] = ACTIONS(658),
    [anon_sym_COLONdraft_COLON] = ACTIONS(658),
    [anon_sym_COLONnote_COLON] = ACTIONS(658),
    [anon_sym_COLONspan_COLON] = ACTIONS(658),
    [anon_sym_COLONabstract_COLON] = ACTIONS(658),
    [anon_sym_COLONauthor_COLON] = ACTIONS(658),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(658),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(658),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(658),
    [anon_sym_COLONexample_COLON] = ACTIONS(658),
    [anon_sym_COLONitemize_COLON] = ACTIONS(658),
    [anon_sym_COLONlemma_COLON] = ACTIONS(658),
    [anon_sym_COLONfigure_COLON] = ACTIONS(658),
    [anon_sym_COLONp_COLON] = ACTIONS(658),
    [anon_sym_COLONproof_COLON] = ACTIONS(658),
    [anon_sym_COLONproposition_COLON] = ACTIONS(658),
    [anon_sym_COLONremark_COLON] = ACTIONS(658),
    [anon_sym_COLONsketch_COLON] = ACTIONS(658),
    [anon_sym_COLONstep_COLON] = ACTIONS(658),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(658),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(658),
  },
  [STATE(60)] = {
    [anon_sym_COLON_COLON] = ACTIONS(662),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(662),
    [aux_sym_section_token1] = ACTIONS(662),
    [anon_sym_COLONsection_COLON] = ACTIONS(662),
    [aux_sym_subsection_token1] = ACTIONS(662),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(662),
    [aux_sym_subsubsection_token1] = ACTIONS(662),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(662),
    [anon_sym_COLONappendix_COLON] = ACTIONS(662),
    [aux_sym_mathblock_token1] = ACTIONS(662),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(662),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(662),
    [anon_sym_COLONtoc_COLON] = ACTIONS(662),
    [aux_sym_specialblock_token1] = ACTIONS(662),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(662),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(662),
    [anon_sym_COLONcaption_COLON] = ACTIONS(662),
    [anon_sym_COLONitem_COLON] = ACTIONS(662),
    [anon_sym_COLONprev_COLON] = ACTIONS(662),
    [anon_sym_COLONprev2_COLON] = ACTIONS(662),
    [anon_sym_COLONprev3_COLON] = ACTIONS(662),
    [aux_sym_specialinline_token1] = ACTIONS(664),
    [aux_sym_specialinline_token2] = ACTIONS(664),
    [anon_sym_COLONmath_COLON] = ACTIONS(662),
    [anon_sym_COLONcode_COLON] = ACTIONS(662),
    [aux_sym_specialinline_token3] = ACTIONS(662),
    [aux_sym_specialinline_token4] = ACTIONS(662),
    [anon_sym_COLONref_COLON] = ACTIONS(662),
    [anon_sym_COLONprevious_COLON] = ACTIONS(662),
    [anon_sym_COLONurl_COLON] = ACTIONS(662),
    [anon_sym_COLONcite_COLON] = ACTIONS(662),
    [anon_sym_COLONqed_COLON] = ACTIONS(662),
    [anon_sym_COLONtable_COLON] = ACTIONS(662),
    [anon_sym_COLONassume_COLON] = ACTIONS(662),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(662),
    [anon_sym_COLONprove_COLON] = ACTIONS(662),
    [anon_sym_COLONthen_COLON] = ACTIONS(662),
    [anon_sym_COLONnew_COLON] = ACTIONS(662),
    [anon_sym_COLONlet_COLON] = ACTIONS(662),
    [anon_sym_COLONcase_COLON] = ACTIONS(662),
    [anon_sym_COLONdefine_COLON] = ACTIONS(662),
    [anon_sym_COLONwrite_COLON] = ACTIONS(662),
    [anon_sym_COLONwlog_COLON] = ACTIONS(662),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(662),
    [anon_sym_COLONclaim_COLON] = ACTIONS(662),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(662),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(662),
    [anon_sym_COLONpick_COLON] = ACTIONS(662),
    [anon_sym_COLONst_COLON] = ACTIONS(662),
    [anon_sym_COLONdraft_COLON] = ACTIONS(662),
    [anon_sym_COLONnote_COLON] = ACTIONS(662),
    [anon_sym_COLONspan_COLON] = ACTIONS(662),
    [anon_sym_COLONabstract_COLON] = ACTIONS(662),
    [anon_sym_COLONauthor_COLON] = ACTIONS(662),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(662),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(662),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(662),
    [anon_sym_COLONexample_COLON] = ACTIONS(662),
    [anon_sym_COLONitemize_COLON] = ACTIONS(662),
    [anon_sym_COLONlemma_COLON] = ACTIONS(662),
    [anon_sym_COLONfigure_COLON] = ACTIONS(662),
    [anon_sym_COLONp_COLON] = ACTIONS(662),
    [anon_sym_COLONproof_COLON] = ACTIONS(662),
    [anon_sym_COLONproposition_COLON] = ACTIONS(662),
    [anon_sym_COLONremark_COLON] = ACTIONS(662),
    [anon_sym_COLONsketch_COLON] = ACTIONS(662),
    [anon_sym_COLONstep_COLON] = ACTIONS(662),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(662),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(662),
  },
  [STATE(61)] = {
    [anon_sym_COLON_COLON] = ACTIONS(666),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(666),
    [aux_sym_section_token1] = ACTIONS(666),
    [anon_sym_COLONsection_COLON] = ACTIONS(666),
    [aux_sym_subsection_token1] = ACTIONS(666),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(666),
    [aux_sym_subsubsection_token1] = ACTIONS(666),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(666),
    [anon_sym_COLONappendix_COLON] = ACTIONS(666),
    [aux_sym_mathblock_token1] = ACTIONS(666),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(666),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(666),
    [anon_sym_COLONtoc_COLON] = ACTIONS(666),
    [aux_sym_specialblock_token1] = ACTIONS(666),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(666),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(666),
    [anon_sym_COLONcaption_COLON] = ACTIONS(666),
    [anon_sym_COLONitem_COLON] = ACTIONS(666),
    [anon_sym_COLONprev_COLON] = ACTIONS(666),
    [anon_sym_COLONprev2_COLON] = ACTIONS(666),
    [anon_sym_COLONprev3_COLON] = ACTIONS(666),
    [aux_sym_specialinline_token1] = ACTIONS(668),
    [aux_sym_specialinline_token2] = ACTIONS(668),
    [anon_sym_COLONmath_COLON] = ACTIONS(666),
    [anon_sym_COLONcode_COLON] = ACTIONS(666),
    [aux_sym_specialinline_token3] = ACTIONS(666),
    [aux_sym_specialinline_token4] = ACTIONS(666),
    [anon_sym_COLONref_COLON] = ACTIONS(666),
    [anon_sym_COLONprevious_COLON] = ACTIONS(666),
    [anon_sym_COLONurl_COLON] = ACTIONS(666),
    [anon_sym_COLONcite_COLON] = ACTIONS(666),
    [anon_sym_COLONqed_COLON] = ACTIONS(666),
    [anon_sym_COLONtable_COLON] = ACTIONS(666),
    [anon_sym_COLONassume_COLON] = ACTIONS(666),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(666),
    [anon_sym_COLONprove_COLON] = ACTIONS(666),
    [anon_sym_COLONthen_COLON] = ACTIONS(666),
    [anon_sym_COLONnew_COLON] = ACTIONS(666),
    [anon_sym_COLONlet_COLON] = ACTIONS(666),
    [anon_sym_COLONcase_COLON] = ACTIONS(666),
    [anon_sym_COLONdefine_COLON] = ACTIONS(666),
    [anon_sym_COLONwrite_COLON] = ACTIONS(666),
    [anon_sym_COLONwlog_COLON] = ACTIONS(666),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(666),
    [anon_sym_COLONclaim_COLON] = ACTIONS(666),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(666),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(666),
    [anon_sym_COLONpick_COLON] = ACTIONS(666),
    [anon_sym_COLONst_COLON] = ACTIONS(666),
    [anon_sym_COLONdraft_COLON] = ACTIONS(666),
    [anon_sym_COLONnote_COLON] = ACTIONS(666),
    [anon_sym_COLONspan_COLON] = ACTIONS(666),
    [anon_sym_COLONabstract_COLON] = ACTIONS(666),
    [anon_sym_COLONauthor_COLON] = ACTIONS(666),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(666),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(666),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(666),
    [anon_sym_COLONexample_COLON] = ACTIONS(666),
    [anon_sym_COLONitemize_COLON] = ACTIONS(666),
    [anon_sym_COLONlemma_COLON] = ACTIONS(666),
    [anon_sym_COLONfigure_COLON] = ACTIONS(666),
    [anon_sym_COLONp_COLON] = ACTIONS(666),
    [anon_sym_COLONproof_COLON] = ACTIONS(666),
    [anon_sym_COLONproposition_COLON] = ACTIONS(666),
    [anon_sym_COLONremark_COLON] = ACTIONS(666),
    [anon_sym_COLONsketch_COLON] = ACTIONS(666),
    [anon_sym_COLONstep_COLON] = ACTIONS(666),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(666),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(666),
  },
  [STATE(62)] = {
    [anon_sym_COLON_COLON] = ACTIONS(670),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(670),
    [aux_sym_section_token1] = ACTIONS(670),
    [anon_sym_COLONsection_COLON] = ACTIONS(670),
    [aux_sym_subsection_token1] = ACTIONS(670),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(670),
    [aux_sym_subsubsection_token1] = ACTIONS(670),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(670),
    [anon_sym_COLONappendix_COLON] = ACTIONS(670),
    [aux_sym_mathblock_token1] = ACTIONS(670),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(670),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(670),
    [anon_sym_COLONtoc_COLON] = ACTIONS(670),
    [aux_sym_specialblock_token1] = ACTIONS(670),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(670),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(670),
    [anon_sym_COLONcaption_COLON] = ACTIONS(670),
    [anon_sym_COLONitem_COLON] = ACTIONS(670),
    [anon_sym_COLONprev_COLON] = ACTIONS(670),
    [anon_sym_COLONprev2_COLON] = ACTIONS(670),
    [anon_sym_COLONprev3_COLON] = ACTIONS(670),
    [aux_sym_specialinline_token1] = ACTIONS(672),
    [aux_sym_specialinline_token2] = ACTIONS(672),
    [anon_sym_COLONmath_COLON] = ACTIONS(670),
    [anon_sym_COLONcode_COLON] = ACTIONS(670),
    [aux_sym_specialinline_token3] = ACTIONS(670),
    [aux_sym_specialinline_token4] = ACTIONS(670),
    [anon_sym_COLONref_COLON] = ACTIONS(670),
    [anon_sym_COLONprevious_COLON] = ACTIONS(670),
    [anon_sym_COLONurl_COLON] = ACTIONS(670),
    [anon_sym_COLONcite_COLON] = ACTIONS(670),
    [anon_sym_COLONqed_COLON] = ACTIONS(670),
    [anon_sym_COLONtable_COLON] = ACTIONS(670),
    [anon_sym_COLONassume_COLON] = ACTIONS(670),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(670),
    [anon_sym_COLONprove_COLON] = ACTIONS(670),
    [anon_sym_COLONthen_COLON] = ACTIONS(670),
    [anon_sym_COLONnew_COLON] = ACTIONS(670),
    [anon_sym_COLONlet_COLON] = ACTIONS(670),
    [anon_sym_COLONcase_COLON] = ACTIONS(670),
    [anon_sym_COLONdefine_COLON] = ACTIONS(670),
    [anon_sym_COLONwrite_COLON] = ACTIONS(670),
    [anon_sym_COLONwlog_COLON] = ACTIONS(670),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(670),
    [anon_sym_COLONclaim_COLON] = ACTIONS(670),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(670),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(670),
    [anon_sym_COLONpick_COLON] = ACTIONS(670),
    [anon_sym_COLONst_COLON] = ACTIONS(670),
    [anon_sym_COLONdraft_COLON] = ACTIONS(670),
    [anon_sym_COLONnote_COLON] = ACTIONS(670),
    [anon_sym_COLONspan_COLON] = ACTIONS(670),
    [anon_sym_COLONabstract_COLON] = ACTIONS(670),
    [anon_sym_COLONauthor_COLON] = ACTIONS(670),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(670),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(670),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(670),
    [anon_sym_COLONexample_COLON] = ACTIONS(670),
    [anon_sym_COLONitemize_COLON] = ACTIONS(670),
    [anon_sym_COLONlemma_COLON] = ACTIONS(670),
    [anon_sym_COLONfigure_COLON] = ACTIONS(670),
    [anon_sym_COLONp_COLON] = ACTIONS(670),
    [anon_sym_COLONproof_COLON] = ACTIONS(670),
    [anon_sym_COLONproposition_COLON] = ACTIONS(670),
    [anon_sym_COLONremark_COLON] = ACTIONS(670),
    [anon_sym_COLONsketch_COLON] = ACTIONS(670),
    [anon_sym_COLONstep_COLON] = ACTIONS(670),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(670),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(670),
  },
  [STATE(63)] = {
    [anon_sym_COLON_COLON] = ACTIONS(674),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(674),
    [aux_sym_section_token1] = ACTIONS(674),
    [anon_sym_COLONsection_COLON] = ACTIONS(674),
    [aux_sym_subsection_token1] = ACTIONS(674),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(674),
    [aux_sym_subsubsection_token1] = ACTIONS(674),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(674),
    [anon_sym_COLONappendix_COLON] = ACTIONS(674),
    [aux_sym_mathblock_token1] = ACTIONS(674),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(674),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(674),
    [anon_sym_COLONtoc_COLON] = ACTIONS(674),
    [aux_sym_specialblock_token1] = ACTIONS(674),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(674),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(674),
    [anon_sym_COLONcaption_COLON] = ACTIONS(674),
    [anon_sym_COLONitem_COLON] = ACTIONS(674),
    [anon_sym_COLONprev_COLON] = ACTIONS(674),
    [anon_sym_COLONprev2_COLON] = ACTIONS(674),
    [anon_sym_COLONprev3_COLON] = ACTIONS(674),
    [aux_sym_specialinline_token1] = ACTIONS(676),
    [aux_sym_specialinline_token2] = ACTIONS(676),
    [anon_sym_COLONmath_COLON] = ACTIONS(674),
    [anon_sym_COLONcode_COLON] = ACTIONS(674),
    [aux_sym_specialinline_token3] = ACTIONS(674),
    [aux_sym_specialinline_token4] = ACTIONS(674),
    [anon_sym_COLONref_COLON] = ACTIONS(674),
    [anon_sym_COLONprevious_COLON] = ACTIONS(674),
    [anon_sym_COLONurl_COLON] = ACTIONS(674),
    [anon_sym_COLONcite_COLON] = ACTIONS(674),
    [anon_sym_COLONqed_COLON] = ACTIONS(674),
    [anon_sym_COLONtable_COLON] = ACTIONS(674),
    [anon_sym_COLONassume_COLON] = ACTIONS(674),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(674),
    [anon_sym_COLONprove_COLON] = ACTIONS(674),
    [anon_sym_COLONthen_COLON] = ACTIONS(674),
    [anon_sym_COLONnew_COLON] = ACTIONS(674),
    [anon_sym_COLONlet_COLON] = ACTIONS(674),
    [anon_sym_COLONcase_COLON] = ACTIONS(674),
    [anon_sym_COLONdefine_COLON] = ACTIONS(674),
    [anon_sym_COLONwrite_COLON] = ACTIONS(674),
    [anon_sym_COLONwlog_COLON] = ACTIONS(674),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(674),
    [anon_sym_COLONclaim_COLON] = ACTIONS(674),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(674),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(674),
    [anon_sym_COLONpick_COLON] = ACTIONS(674),
    [anon_sym_COLONst_COLON] = ACTIONS(674),
    [anon_sym_COLONdraft_COLON] = ACTIONS(674),
    [anon_sym_COLONnote_COLON] = ACTIONS(674),
    [anon_sym_COLONspan_COLON] = ACTIONS(674),
    [anon_sym_COLONabstract_COLON] = ACTIONS(674),
    [anon_sym_COLONauthor_COLON] = ACTIONS(674),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(674),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(674),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(674),
    [anon_sym_COLONexample_COLON] = ACTIONS(674),
    [anon_sym_COLONitemize_COLON] = ACTIONS(674),
    [anon_sym_COLONlemma_COLON] = ACTIONS(674),
    [anon_sym_COLONfigure_COLON] = ACTIONS(674),
    [anon_sym_COLONp_COLON] = ACTIONS(674),
    [anon_sym_COLONproof_COLON] = ACTIONS(674),
    [anon_sym_COLONproposition_COLON] = ACTIONS(674),
    [anon_sym_COLONremark_COLON] = ACTIONS(674),
    [anon_sym_COLONsketch_COLON] = ACTIONS(674),
    [anon_sym_COLONstep_COLON] = ACTIONS(674),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(674),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(674),
  },
  [STATE(64)] = {
    [anon_sym_COLON_COLON] = ACTIONS(678),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(678),
    [aux_sym_section_token1] = ACTIONS(678),
    [anon_sym_COLONsection_COLON] = ACTIONS(678),
    [aux_sym_subsection_token1] = ACTIONS(678),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(678),
    [aux_sym_subsubsection_token1] = ACTIONS(678),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(678),
    [anon_sym_COLONappendix_COLON] = ACTIONS(678),
    [aux_sym_mathblock_token1] = ACTIONS(678),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(678),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(678),
    [anon_sym_COLONtoc_COLON] = ACTIONS(678),
    [aux_sym_specialblock_token1] = ACTIONS(678),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(678),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(678),
    [anon_sym_COLONcaption_COLON] = ACTIONS(678),
    [anon_sym_COLONitem_COLON] = ACTIONS(678),
    [anon_sym_COLONprev_COLON] = ACTIONS(678),
    [anon_sym_COLONprev2_COLON] = ACTIONS(678),
    [anon_sym_COLONprev3_COLON] = ACTIONS(678),
    [aux_sym_specialinline_token1] = ACTIONS(680),
    [aux_sym_specialinline_token2] = ACTIONS(680),
    [anon_sym_COLONmath_COLON] = ACTIONS(678),
    [anon_sym_COLONcode_COLON] = ACTIONS(678),
    [aux_sym_specialinline_token3] = ACTIONS(678),
    [aux_sym_specialinline_token4] = ACTIONS(678),
    [anon_sym_COLONref_COLON] = ACTIONS(678),
    [anon_sym_COLONprevious_COLON] = ACTIONS(678),
    [anon_sym_COLONurl_COLON] = ACTIONS(678),
    [anon_sym_COLONcite_COLON] = ACTIONS(678),
    [anon_sym_COLONqed_COLON] = ACTIONS(678),
    [anon_sym_COLONtable_COLON] = ACTIONS(678),
    [anon_sym_COLONassume_COLON] = ACTIONS(678),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(678),
    [anon_sym_COLONprove_COLON] = ACTIONS(678),
    [anon_sym_COLONthen_COLON] = ACTIONS(678),
    [anon_sym_COLONnew_COLON] = ACTIONS(678),
    [anon_sym_COLONlet_COLON] = ACTIONS(678),
    [anon_sym_COLONcase_COLON] = ACTIONS(678),
    [anon_sym_COLONdefine_COLON] = ACTIONS(678),
    [anon_sym_COLONwrite_COLON] = ACTIONS(678),
    [anon_sym_COLONwlog_COLON] = ACTIONS(678),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(678),
    [anon_sym_COLONclaim_COLON] = ACTIONS(678),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(678),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(678),
    [anon_sym_COLONpick_COLON] = ACTIONS(678),
    [anon_sym_COLONst_COLON] = ACTIONS(678),
    [anon_sym_COLONdraft_COLON] = ACTIONS(678),
    [anon_sym_COLONnote_COLON] = ACTIONS(678),
    [anon_sym_COLONspan_COLON] = ACTIONS(678),
    [anon_sym_COLONabstract_COLON] = ACTIONS(678),
    [anon_sym_COLONauthor_COLON] = ACTIONS(678),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(678),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(678),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(678),
    [anon_sym_COLONexample_COLON] = ACTIONS(678),
    [anon_sym_COLONitemize_COLON] = ACTIONS(678),
    [anon_sym_COLONlemma_COLON] = ACTIONS(678),
    [anon_sym_COLONfigure_COLON] = ACTIONS(678),
    [anon_sym_COLONp_COLON] = ACTIONS(678),
    [anon_sym_COLONproof_COLON] = ACTIONS(678),
    [anon_sym_COLONproposition_COLON] = ACTIONS(678),
    [anon_sym_COLONremark_COLON] = ACTIONS(678),
    [anon_sym_COLONsketch_COLON] = ACTIONS(678),
    [anon_sym_COLONstep_COLON] = ACTIONS(678),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(678),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(678),
  },
  [STATE(65)] = {
    [anon_sym_COLON_COLON] = ACTIONS(682),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(682),
    [aux_sym_section_token1] = ACTIONS(682),
    [anon_sym_COLONsection_COLON] = ACTIONS(682),
    [aux_sym_subsection_token1] = ACTIONS(682),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(682),
    [aux_sym_subsubsection_token1] = ACTIONS(682),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(682),
    [anon_sym_COLONappendix_COLON] = ACTIONS(682),
    [aux_sym_mathblock_token1] = ACTIONS(682),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(682),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(682),
    [anon_sym_COLONtoc_COLON] = ACTIONS(682),
    [aux_sym_specialblock_token1] = ACTIONS(682),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(682),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(682),
    [anon_sym_COLONcaption_COLON] = ACTIONS(682),
    [anon_sym_COLONitem_COLON] = ACTIONS(682),
    [anon_sym_COLONprev_COLON] = ACTIONS(682),
    [anon_sym_COLONprev2_COLON] = ACTIONS(682),
    [anon_sym_COLONprev3_COLON] = ACTIONS(682),
    [aux_sym_specialinline_token1] = ACTIONS(684),
    [aux_sym_specialinline_token2] = ACTIONS(684),
    [anon_sym_COLONmath_COLON] = ACTIONS(682),
    [anon_sym_COLONcode_COLON] = ACTIONS(682),
    [aux_sym_specialinline_token3] = ACTIONS(682),
    [aux_sym_specialinline_token4] = ACTIONS(682),
    [anon_sym_COLONref_COLON] = ACTIONS(682),
    [anon_sym_COLONprevious_COLON] = ACTIONS(682),
    [anon_sym_COLONurl_COLON] = ACTIONS(682),
    [anon_sym_COLONcite_COLON] = ACTIONS(682),
    [anon_sym_COLONqed_COLON] = ACTIONS(682),
    [anon_sym_COLONtable_COLON] = ACTIONS(682),
    [anon_sym_COLONassume_COLON] = ACTIONS(682),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(682),
    [anon_sym_COLONprove_COLON] = ACTIONS(682),
    [anon_sym_COLONthen_COLON] = ACTIONS(682),
    [anon_sym_COLONnew_COLON] = ACTIONS(682),
    [anon_sym_COLONlet_COLON] = ACTIONS(682),
    [anon_sym_COLONcase_COLON] = ACTIONS(682),
    [anon_sym_COLONdefine_COLON] = ACTIONS(682),
    [anon_sym_COLONwrite_COLON] = ACTIONS(682),
    [anon_sym_COLONwlog_COLON] = ACTIONS(682),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(682),
    [anon_sym_COLONclaim_COLON] = ACTIONS(682),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(682),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(682),
    [anon_sym_COLONpick_COLON] = ACTIONS(682),
    [anon_sym_COLONst_COLON] = ACTIONS(682),
    [anon_sym_COLONdraft_COLON] = ACTIONS(682),
    [anon_sym_COLONnote_COLON] = ACTIONS(682),
    [anon_sym_COLONspan_COLON] = ACTIONS(682),
    [anon_sym_COLONabstract_COLON] = ACTIONS(682),
    [anon_sym_COLONauthor_COLON] = ACTIONS(682),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(682),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(682),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(682),
    [anon_sym_COLONexample_COLON] = ACTIONS(682),
    [anon_sym_COLONitemize_COLON] = ACTIONS(682),
    [anon_sym_COLONlemma_COLON] = ACTIONS(682),
    [anon_sym_COLONfigure_COLON] = ACTIONS(682),
    [anon_sym_COLONp_COLON] = ACTIONS(682),
    [anon_sym_COLONproof_COLON] = ACTIONS(682),
    [anon_sym_COLONproposition_COLON] = ACTIONS(682),
    [anon_sym_COLONremark_COLON] = ACTIONS(682),
    [anon_sym_COLONsketch_COLON] = ACTIONS(682),
    [anon_sym_COLONstep_COLON] = ACTIONS(682),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(682),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(682),
  },
  [STATE(66)] = {
    [anon_sym_COLON_COLON] = ACTIONS(686),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(686),
    [aux_sym_section_token1] = ACTIONS(686),
    [anon_sym_COLONsection_COLON] = ACTIONS(686),
    [aux_sym_subsection_token1] = ACTIONS(686),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(686),
    [aux_sym_subsubsection_token1] = ACTIONS(686),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(686),
    [anon_sym_COLONappendix_COLON] = ACTIONS(686),
    [aux_sym_mathblock_token1] = ACTIONS(686),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(686),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(686),
    [anon_sym_COLONtoc_COLON] = ACTIONS(686),
    [aux_sym_specialblock_token1] = ACTIONS(686),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(686),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(686),
    [anon_sym_COLONcaption_COLON] = ACTIONS(686),
    [anon_sym_COLONitem_COLON] = ACTIONS(686),
    [anon_sym_COLONprev_COLON] = ACTIONS(686),
    [anon_sym_COLONprev2_COLON] = ACTIONS(686),
    [anon_sym_COLONprev3_COLON] = ACTIONS(686),
    [aux_sym_specialinline_token1] = ACTIONS(688),
    [aux_sym_specialinline_token2] = ACTIONS(688),
    [anon_sym_COLONmath_COLON] = ACTIONS(686),
    [anon_sym_COLONcode_COLON] = ACTIONS(686),
    [aux_sym_specialinline_token3] = ACTIONS(686),
    [aux_sym_specialinline_token4] = ACTIONS(686),
    [anon_sym_COLONref_COLON] = ACTIONS(686),
    [anon_sym_COLONprevious_COLON] = ACTIONS(686),
    [anon_sym_COLONurl_COLON] = ACTIONS(686),
    [anon_sym_COLONcite_COLON] = ACTIONS(686),
    [anon_sym_COLONqed_COLON] = ACTIONS(686),
    [anon_sym_COLONtable_COLON] = ACTIONS(686),
    [anon_sym_COLONassume_COLON] = ACTIONS(686),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(686),
    [anon_sym_COLONprove_COLON] = ACTIONS(686),
    [anon_sym_COLONthen_COLON] = ACTIONS(686),
    [anon_sym_COLONnew_COLON] = ACTIONS(686),
    [anon_sym_COLONlet_COLON] = ACTIONS(686),
    [anon_sym_COLONcase_COLON] = ACTIONS(686),
    [anon_sym_COLONdefine_COLON] = ACTIONS(686),
    [anon_sym_COLONwrite_COLON] = ACTIONS(686),
    [anon_sym_COLONwlog_COLON] = ACTIONS(686),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(686),
    [anon_sym_COLONclaim_COLON] = ACTIONS(686),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(686),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(686),
    [anon_sym_COLONpick_COLON] = ACTIONS(686),
    [anon_sym_COLONst_COLON] = ACTIONS(686),
    [anon_sym_COLONdraft_COLON] = ACTIONS(686),
    [anon_sym_COLONnote_COLON] = ACTIONS(686),
    [anon_sym_COLONspan_COLON] = ACTIONS(686),
    [anon_sym_COLONabstract_COLON] = ACTIONS(686),
    [anon_sym_COLONauthor_COLON] = ACTIONS(686),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(686),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(686),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(686),
    [anon_sym_COLONexample_COLON] = ACTIONS(686),
    [anon_sym_COLONitemize_COLON] = ACTIONS(686),
    [anon_sym_COLONlemma_COLON] = ACTIONS(686),
    [anon_sym_COLONfigure_COLON] = ACTIONS(686),
    [anon_sym_COLONp_COLON] = ACTIONS(686),
    [anon_sym_COLONproof_COLON] = ACTIONS(686),
    [anon_sym_COLONproposition_COLON] = ACTIONS(686),
    [anon_sym_COLONremark_COLON] = ACTIONS(686),
    [anon_sym_COLONsketch_COLON] = ACTIONS(686),
    [anon_sym_COLONstep_COLON] = ACTIONS(686),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(686),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(686),
  },
  [STATE(67)] = {
    [anon_sym_COLON_COLON] = ACTIONS(690),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(690),
    [aux_sym_section_token1] = ACTIONS(690),
    [anon_sym_COLONsection_COLON] = ACTIONS(690),
    [aux_sym_subsection_token1] = ACTIONS(690),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(690),
    [aux_sym_subsubsection_token1] = ACTIONS(690),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(690),
    [anon_sym_COLONappendix_COLON] = ACTIONS(690),
    [aux_sym_mathblock_token1] = ACTIONS(690),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(690),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(690),
    [anon_sym_COLONtoc_COLON] = ACTIONS(690),
    [aux_sym_specialblock_token1] = ACTIONS(690),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(690),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(690),
    [anon_sym_COLONcaption_COLON] = ACTIONS(690),
    [anon_sym_COLONitem_COLON] = ACTIONS(690),
    [anon_sym_COLONprev_COLON] = ACTIONS(690),
    [anon_sym_COLONprev2_COLON] = ACTIONS(690),
    [anon_sym_COLONprev3_COLON] = ACTIONS(690),
    [aux_sym_specialinline_token1] = ACTIONS(692),
    [aux_sym_specialinline_token2] = ACTIONS(692),
    [anon_sym_COLONmath_COLON] = ACTIONS(690),
    [anon_sym_COLONcode_COLON] = ACTIONS(690),
    [aux_sym_specialinline_token3] = ACTIONS(690),
    [aux_sym_specialinline_token4] = ACTIONS(690),
    [anon_sym_COLONref_COLON] = ACTIONS(690),
    [anon_sym_COLONprevious_COLON] = ACTIONS(690),
    [anon_sym_COLONurl_COLON] = ACTIONS(690),
    [anon_sym_COLONcite_COLON] = ACTIONS(690),
    [anon_sym_COLONqed_COLON] = ACTIONS(690),
    [anon_sym_COLONtable_COLON] = ACTIONS(690),
    [anon_sym_COLONassume_COLON] = ACTIONS(690),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(690),
    [anon_sym_COLONprove_COLON] = ACTIONS(690),
    [anon_sym_COLONthen_COLON] = ACTIONS(690),
    [anon_sym_COLONnew_COLON] = ACTIONS(690),
    [anon_sym_COLONlet_COLON] = ACTIONS(690),
    [anon_sym_COLONcase_COLON] = ACTIONS(690),
    [anon_sym_COLONdefine_COLON] = ACTIONS(690),
    [anon_sym_COLONwrite_COLON] = ACTIONS(690),
    [anon_sym_COLONwlog_COLON] = ACTIONS(690),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(690),
    [anon_sym_COLONclaim_COLON] = ACTIONS(690),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(690),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(690),
    [anon_sym_COLONpick_COLON] = ACTIONS(690),
    [anon_sym_COLONst_COLON] = ACTIONS(690),
    [anon_sym_COLONdraft_COLON] = ACTIONS(690),
    [anon_sym_COLONnote_COLON] = ACTIONS(690),
    [anon_sym_COLONspan_COLON] = ACTIONS(690),
    [anon_sym_COLONabstract_COLON] = ACTIONS(690),
    [anon_sym_COLONauthor_COLON] = ACTIONS(690),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(690),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(690),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(690),
    [anon_sym_COLONexample_COLON] = ACTIONS(690),
    [anon_sym_COLONitemize_COLON] = ACTIONS(690),
    [anon_sym_COLONlemma_COLON] = ACTIONS(690),
    [anon_sym_COLONfigure_COLON] = ACTIONS(690),
    [anon_sym_COLONp_COLON] = ACTIONS(690),
    [anon_sym_COLONproof_COLON] = ACTIONS(690),
    [anon_sym_COLONproposition_COLON] = ACTIONS(690),
    [anon_sym_COLONremark_COLON] = ACTIONS(690),
    [anon_sym_COLONsketch_COLON] = ACTIONS(690),
    [anon_sym_COLONstep_COLON] = ACTIONS(690),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(690),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(690),
  },
  [STATE(68)] = {
    [anon_sym_COLON_COLON] = ACTIONS(694),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(694),
    [aux_sym_section_token1] = ACTIONS(694),
    [anon_sym_COLONsection_COLON] = ACTIONS(694),
    [aux_sym_subsection_token1] = ACTIONS(694),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(694),
    [aux_sym_subsubsection_token1] = ACTIONS(694),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(694),
    [anon_sym_COLONappendix_COLON] = ACTIONS(694),
    [aux_sym_mathblock_token1] = ACTIONS(694),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(694),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(694),
    [anon_sym_COLONtoc_COLON] = ACTIONS(694),
    [aux_sym_specialblock_token1] = ACTIONS(694),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(694),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(694),
    [anon_sym_COLONcaption_COLON] = ACTIONS(694),
    [anon_sym_COLONitem_COLON] = ACTIONS(694),
    [anon_sym_COLONprev_COLON] = ACTIONS(694),
    [anon_sym_COLONprev2_COLON] = ACTIONS(694),
    [anon_sym_COLONprev3_COLON] = ACTIONS(694),
    [aux_sym_specialinline_token1] = ACTIONS(696),
    [aux_sym_specialinline_token2] = ACTIONS(696),
    [anon_sym_COLONmath_COLON] = ACTIONS(694),
    [anon_sym_COLONcode_COLON] = ACTIONS(694),
    [aux_sym_specialinline_token3] = ACTIONS(694),
    [aux_sym_specialinline_token4] = ACTIONS(694),
    [anon_sym_COLONref_COLON] = ACTIONS(694),
    [anon_sym_COLONprevious_COLON] = ACTIONS(694),
    [anon_sym_COLONurl_COLON] = ACTIONS(694),
    [anon_sym_COLONcite_COLON] = ACTIONS(694),
    [anon_sym_COLONqed_COLON] = ACTIONS(694),
    [anon_sym_COLONtable_COLON] = ACTIONS(694),
    [anon_sym_COLONassume_COLON] = ACTIONS(694),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(694),
    [anon_sym_COLONprove_COLON] = ACTIONS(694),
    [anon_sym_COLONthen_COLON] = ACTIONS(694),
    [anon_sym_COLONnew_COLON] = ACTIONS(694),
    [anon_sym_COLONlet_COLON] = ACTIONS(694),
    [anon_sym_COLONcase_COLON] = ACTIONS(694),
    [anon_sym_COLONdefine_COLON] = ACTIONS(694),
    [anon_sym_COLONwrite_COLON] = ACTIONS(694),
    [anon_sym_COLONwlog_COLON] = ACTIONS(694),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(694),
    [anon_sym_COLONclaim_COLON] = ACTIONS(694),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(694),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(694),
    [anon_sym_COLONpick_COLON] = ACTIONS(694),
    [anon_sym_COLONst_COLON] = ACTIONS(694),
    [anon_sym_COLONdraft_COLON] = ACTIONS(694),
    [anon_sym_COLONnote_COLON] = ACTIONS(694),
    [anon_sym_COLONspan_COLON] = ACTIONS(694),
    [anon_sym_COLONabstract_COLON] = ACTIONS(694),
    [anon_sym_COLONauthor_COLON] = ACTIONS(694),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(694),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(694),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(694),
    [anon_sym_COLONexample_COLON] = ACTIONS(694),
    [anon_sym_COLONitemize_COLON] = ACTIONS(694),
    [anon_sym_COLONlemma_COLON] = ACTIONS(694),
    [anon_sym_COLONfigure_COLON] = ACTIONS(694),
    [anon_sym_COLONp_COLON] = ACTIONS(694),
    [anon_sym_COLONproof_COLON] = ACTIONS(694),
    [anon_sym_COLONproposition_COLON] = ACTIONS(694),
    [anon_sym_COLONremark_COLON] = ACTIONS(694),
    [anon_sym_COLONsketch_COLON] = ACTIONS(694),
    [anon_sym_COLONstep_COLON] = ACTIONS(694),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(694),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(694),
  },
  [STATE(69)] = {
    [anon_sym_COLON_COLON] = ACTIONS(698),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(698),
    [aux_sym_section_token1] = ACTIONS(698),
    [anon_sym_COLONsection_COLON] = ACTIONS(698),
    [aux_sym_subsection_token1] = ACTIONS(698),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(698),
    [aux_sym_subsubsection_token1] = ACTIONS(698),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(698),
    [anon_sym_COLONappendix_COLON] = ACTIONS(698),
    [aux_sym_mathblock_token1] = ACTIONS(698),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(698),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(698),
    [anon_sym_COLONtoc_COLON] = ACTIONS(698),
    [aux_sym_specialblock_token1] = ACTIONS(698),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(698),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(698),
    [anon_sym_COLONcaption_COLON] = ACTIONS(698),
    [anon_sym_COLONitem_COLON] = ACTIONS(698),
    [anon_sym_COLONprev_COLON] = ACTIONS(698),
    [anon_sym_COLONprev2_COLON] = ACTIONS(698),
    [anon_sym_COLONprev3_COLON] = ACTIONS(698),
    [aux_sym_specialinline_token1] = ACTIONS(700),
    [aux_sym_specialinline_token2] = ACTIONS(700),
    [anon_sym_COLONmath_COLON] = ACTIONS(698),
    [anon_sym_COLONcode_COLON] = ACTIONS(698),
    [aux_sym_specialinline_token3] = ACTIONS(698),
    [aux_sym_specialinline_token4] = ACTIONS(698),
    [anon_sym_COLONref_COLON] = ACTIONS(698),
    [anon_sym_COLONprevious_COLON] = ACTIONS(698),
    [anon_sym_COLONurl_COLON] = ACTIONS(698),
    [anon_sym_COLONcite_COLON] = ACTIONS(698),
    [anon_sym_COLONqed_COLON] = ACTIONS(698),
    [anon_sym_COLONtable_COLON] = ACTIONS(698),
    [anon_sym_COLONassume_COLON] = ACTIONS(698),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(698),
    [anon_sym_COLONprove_COLON] = ACTIONS(698),
    [anon_sym_COLONthen_COLON] = ACTIONS(698),
    [anon_sym_COLONnew_COLON] = ACTIONS(698),
    [anon_sym_COLONlet_COLON] = ACTIONS(698),
    [anon_sym_COLONcase_COLON] = ACTIONS(698),
    [anon_sym_COLONdefine_COLON] = ACTIONS(698),
    [anon_sym_COLONwrite_COLON] = ACTIONS(698),
    [anon_sym_COLONwlog_COLON] = ACTIONS(698),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(698),
    [anon_sym_COLONclaim_COLON] = ACTIONS(698),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(698),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(698),
    [anon_sym_COLONpick_COLON] = ACTIONS(698),
    [anon_sym_COLONst_COLON] = ACTIONS(698),
    [anon_sym_COLONdraft_COLON] = ACTIONS(698),
    [anon_sym_COLONnote_COLON] = ACTIONS(698),
    [anon_sym_COLONspan_COLON] = ACTIONS(698),
    [anon_sym_COLONabstract_COLON] = ACTIONS(698),
    [anon_sym_COLONauthor_COLON] = ACTIONS(698),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(698),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(698),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(698),
    [anon_sym_COLONexample_COLON] = ACTIONS(698),
    [anon_sym_COLONitemize_COLON] = ACTIONS(698),
    [anon_sym_COLONlemma_COLON] = ACTIONS(698),
    [anon_sym_COLONfigure_COLON] = ACTIONS(698),
    [anon_sym_COLONp_COLON] = ACTIONS(698),
    [anon_sym_COLONproof_COLON] = ACTIONS(698),
    [anon_sym_COLONproposition_COLON] = ACTIONS(698),
    [anon_sym_COLONremark_COLON] = ACTIONS(698),
    [anon_sym_COLONsketch_COLON] = ACTIONS(698),
    [anon_sym_COLONstep_COLON] = ACTIONS(698),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(698),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(698),
  },
  [STATE(70)] = {
    [anon_sym_COLON_COLON] = ACTIONS(702),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(702),
    [aux_sym_section_token1] = ACTIONS(702),
    [anon_sym_COLONsection_COLON] = ACTIONS(702),
    [aux_sym_subsection_token1] = ACTIONS(702),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(702),
    [aux_sym_subsubsection_token1] = ACTIONS(702),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(702),
    [anon_sym_COLONappendix_COLON] = ACTIONS(702),
    [aux_sym_mathblock_token1] = ACTIONS(702),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(702),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(702),
    [anon_sym_COLONtoc_COLON] = ACTIONS(702),
    [aux_sym_specialblock_token1] = ACTIONS(702),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(702),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(702),
    [anon_sym_COLONcaption_COLON] = ACTIONS(702),
    [anon_sym_COLONitem_COLON] = ACTIONS(702),
    [anon_sym_COLONprev_COLON] = ACTIONS(702),
    [anon_sym_COLONprev2_COLON] = ACTIONS(702),
    [anon_sym_COLONprev3_COLON] = ACTIONS(702),
    [aux_sym_specialinline_token1] = ACTIONS(704),
    [aux_sym_specialinline_token2] = ACTIONS(704),
    [anon_sym_COLONmath_COLON] = ACTIONS(702),
    [anon_sym_COLONcode_COLON] = ACTIONS(702),
    [aux_sym_specialinline_token3] = ACTIONS(702),
    [aux_sym_specialinline_token4] = ACTIONS(702),
    [anon_sym_COLONref_COLON] = ACTIONS(702),
    [anon_sym_COLONprevious_COLON] = ACTIONS(702),
    [anon_sym_COLONurl_COLON] = ACTIONS(702),
    [anon_sym_COLONcite_COLON] = ACTIONS(702),
    [anon_sym_COLONqed_COLON] = ACTIONS(702),
    [anon_sym_COLONtable_COLON] = ACTIONS(702),
    [anon_sym_COLONassume_COLON] = ACTIONS(702),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(702),
    [anon_sym_COLONprove_COLON] = ACTIONS(702),
    [anon_sym_COLONthen_COLON] = ACTIONS(702),
    [anon_sym_COLONnew_COLON] = ACTIONS(702),
    [anon_sym_COLONlet_COLON] = ACTIONS(702),
    [anon_sym_COLONcase_COLON] = ACTIONS(702),
    [anon_sym_COLONdefine_COLON] = ACTIONS(702),
    [anon_sym_COLONwrite_COLON] = ACTIONS(702),
    [anon_sym_COLONwlog_COLON] = ACTIONS(702),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(702),
    [anon_sym_COLONclaim_COLON] = ACTIONS(702),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(702),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(702),
    [anon_sym_COLONpick_COLON] = ACTIONS(702),
    [anon_sym_COLONst_COLON] = ACTIONS(702),
    [anon_sym_COLONdraft_COLON] = ACTIONS(702),
    [anon_sym_COLONnote_COLON] = ACTIONS(702),
    [anon_sym_COLONspan_COLON] = ACTIONS(702),
    [anon_sym_COLONabstract_COLON] = ACTIONS(702),
    [anon_sym_COLONauthor_COLON] = ACTIONS(702),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(702),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(702),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(702),
    [anon_sym_COLONexample_COLON] = ACTIONS(702),
    [anon_sym_COLONitemize_COLON] = ACTIONS(702),
    [anon_sym_COLONlemma_COLON] = ACTIONS(702),
    [anon_sym_COLONfigure_COLON] = ACTIONS(702),
    [anon_sym_COLONp_COLON] = ACTIONS(702),
    [anon_sym_COLONproof_COLON] = ACTIONS(702),
    [anon_sym_COLONproposition_COLON] = ACTIONS(702),
    [anon_sym_COLONremark_COLON] = ACTIONS(702),
    [anon_sym_COLONsketch_COLON] = ACTIONS(702),
    [anon_sym_COLONstep_COLON] = ACTIONS(702),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(702),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(702),
  },
  [STATE(71)] = {
    [anon_sym_COLON_COLON] = ACTIONS(706),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(706),
    [aux_sym_section_token1] = ACTIONS(706),
    [anon_sym_COLONsection_COLON] = ACTIONS(706),
    [aux_sym_subsection_token1] = ACTIONS(706),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(706),
    [aux_sym_subsubsection_token1] = ACTIONS(706),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(706),
    [anon_sym_COLONappendix_COLON] = ACTIONS(706),
    [aux_sym_mathblock_token1] = ACTIONS(706),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(706),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(706),
    [anon_sym_COLONtoc_COLON] = ACTIONS(706),
    [aux_sym_specialblock_token1] = ACTIONS(706),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(706),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(706),
    [anon_sym_COLONcaption_COLON] = ACTIONS(706),
    [anon_sym_COLONitem_COLON] = ACTIONS(706),
    [anon_sym_COLONprev_COLON] = ACTIONS(706),
    [anon_sym_COLONprev2_COLON] = ACTIONS(706),
    [anon_sym_COLONprev3_COLON] = ACTIONS(706),
    [aux_sym_specialinline_token1] = ACTIONS(708),
    [aux_sym_specialinline_token2] = ACTIONS(708),
    [anon_sym_COLONmath_COLON] = ACTIONS(706),
    [anon_sym_COLONcode_COLON] = ACTIONS(706),
    [aux_sym_specialinline_token3] = ACTIONS(706),
    [aux_sym_specialinline_token4] = ACTIONS(706),
    [anon_sym_COLONref_COLON] = ACTIONS(706),
    [anon_sym_COLONprevious_COLON] = ACTIONS(706),
    [anon_sym_COLONurl_COLON] = ACTIONS(706),
    [anon_sym_COLONcite_COLON] = ACTIONS(706),
    [anon_sym_COLONqed_COLON] = ACTIONS(706),
    [anon_sym_COLONtable_COLON] = ACTIONS(706),
    [anon_sym_COLONassume_COLON] = ACTIONS(706),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(706),
    [anon_sym_COLONprove_COLON] = ACTIONS(706),
    [anon_sym_COLONthen_COLON] = ACTIONS(706),
    [anon_sym_COLONnew_COLON] = ACTIONS(706),
    [anon_sym_COLONlet_COLON] = ACTIONS(706),
    [anon_sym_COLONcase_COLON] = ACTIONS(706),
    [anon_sym_COLONdefine_COLON] = ACTIONS(706),
    [anon_sym_COLONwrite_COLON] = ACTIONS(706),
    [anon_sym_COLONwlog_COLON] = ACTIONS(706),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(706),
    [anon_sym_COLONclaim_COLON] = ACTIONS(706),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(706),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(706),
    [anon_sym_COLONpick_COLON] = ACTIONS(706),
    [anon_sym_COLONst_COLON] = ACTIONS(706),
    [anon_sym_COLONdraft_COLON] = ACTIONS(706),
    [anon_sym_COLONnote_COLON] = ACTIONS(706),
    [anon_sym_COLONspan_COLON] = ACTIONS(706),
    [anon_sym_COLONabstract_COLON] = ACTIONS(706),
    [anon_sym_COLONauthor_COLON] = ACTIONS(706),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(706),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(706),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(706),
    [anon_sym_COLONexample_COLON] = ACTIONS(706),
    [anon_sym_COLONitemize_COLON] = ACTIONS(706),
    [anon_sym_COLONlemma_COLON] = ACTIONS(706),
    [anon_sym_COLONfigure_COLON] = ACTIONS(706),
    [anon_sym_COLONp_COLON] = ACTIONS(706),
    [anon_sym_COLONproof_COLON] = ACTIONS(706),
    [anon_sym_COLONproposition_COLON] = ACTIONS(706),
    [anon_sym_COLONremark_COLON] = ACTIONS(706),
    [anon_sym_COLONsketch_COLON] = ACTIONS(706),
    [anon_sym_COLONstep_COLON] = ACTIONS(706),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(706),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(706),
  },
  [STATE(72)] = {
    [anon_sym_COLON_COLON] = ACTIONS(710),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(710),
    [aux_sym_section_token1] = ACTIONS(710),
    [anon_sym_COLONsection_COLON] = ACTIONS(710),
    [aux_sym_subsection_token1] = ACTIONS(710),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(710),
    [aux_sym_subsubsection_token1] = ACTIONS(710),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(710),
    [anon_sym_COLONappendix_COLON] = ACTIONS(710),
    [aux_sym_mathblock_token1] = ACTIONS(710),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(710),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(710),
    [anon_sym_COLONtoc_COLON] = ACTIONS(710),
    [aux_sym_specialblock_token1] = ACTIONS(710),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(710),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(710),
    [anon_sym_COLONcaption_COLON] = ACTIONS(710),
    [anon_sym_COLONitem_COLON] = ACTIONS(710),
    [anon_sym_COLONprev_COLON] = ACTIONS(710),
    [anon_sym_COLONprev2_COLON] = ACTIONS(710),
    [anon_sym_COLONprev3_COLON] = ACTIONS(710),
    [aux_sym_specialinline_token1] = ACTIONS(712),
    [aux_sym_specialinline_token2] = ACTIONS(712),
    [anon_sym_COLONmath_COLON] = ACTIONS(710),
    [anon_sym_COLONcode_COLON] = ACTIONS(710),
    [aux_sym_specialinline_token3] = ACTIONS(710),
    [aux_sym_specialinline_token4] = ACTIONS(710),
    [anon_sym_COLONref_COLON] = ACTIONS(710),
    [anon_sym_COLONprevious_COLON] = ACTIONS(710),
    [anon_sym_COLONurl_COLON] = ACTIONS(710),
    [anon_sym_COLONcite_COLON] = ACTIONS(710),
    [anon_sym_COLONqed_COLON] = ACTIONS(710),
    [anon_sym_COLONtable_COLON] = ACTIONS(710),
    [anon_sym_COLONassume_COLON] = ACTIONS(710),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(710),
    [anon_sym_COLONprove_COLON] = ACTIONS(710),
    [anon_sym_COLONthen_COLON] = ACTIONS(710),
    [anon_sym_COLONnew_COLON] = ACTIONS(710),
    [anon_sym_COLONlet_COLON] = ACTIONS(710),
    [anon_sym_COLONcase_COLON] = ACTIONS(710),
    [anon_sym_COLONdefine_COLON] = ACTIONS(710),
    [anon_sym_COLONwrite_COLON] = ACTIONS(710),
    [anon_sym_COLONwlog_COLON] = ACTIONS(710),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(710),
    [anon_sym_COLONclaim_COLON] = ACTIONS(710),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(710),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(710),
    [anon_sym_COLONpick_COLON] = ACTIONS(710),
    [anon_sym_COLONst_COLON] = ACTIONS(710),
    [anon_sym_COLONdraft_COLON] = ACTIONS(710),
    [anon_sym_COLONnote_COLON] = ACTIONS(710),
    [anon_sym_COLONspan_COLON] = ACTIONS(710),
    [anon_sym_COLONabstract_COLON] = ACTIONS(710),
    [anon_sym_COLONauthor_COLON] = ACTIONS(710),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(710),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(710),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(710),
    [anon_sym_COLONexample_COLON] = ACTIONS(710),
    [anon_sym_COLONitemize_COLON] = ACTIONS(710),
    [anon_sym_COLONlemma_COLON] = ACTIONS(710),
    [anon_sym_COLONfigure_COLON] = ACTIONS(710),
    [anon_sym_COLONp_COLON] = ACTIONS(710),
    [anon_sym_COLONproof_COLON] = ACTIONS(710),
    [anon_sym_COLONproposition_COLON] = ACTIONS(710),
    [anon_sym_COLONremark_COLON] = ACTIONS(710),
    [anon_sym_COLONsketch_COLON] = ACTIONS(710),
    [anon_sym_COLONstep_COLON] = ACTIONS(710),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(710),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(710),
  },
  [STATE(73)] = {
    [anon_sym_COLON_COLON] = ACTIONS(714),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(714),
    [aux_sym_section_token1] = ACTIONS(714),
    [anon_sym_COLONsection_COLON] = ACTIONS(714),
    [aux_sym_subsection_token1] = ACTIONS(714),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(714),
    [aux_sym_subsubsection_token1] = ACTIONS(714),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(714),
    [anon_sym_COLONappendix_COLON] = ACTIONS(714),
    [aux_sym_mathblock_token1] = ACTIONS(714),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(714),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(714),
    [anon_sym_COLONtoc_COLON] = ACTIONS(714),
    [aux_sym_specialblock_token1] = ACTIONS(714),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(714),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(714),
    [anon_sym_COLONcaption_COLON] = ACTIONS(714),
    [anon_sym_COLONitem_COLON] = ACTIONS(714),
    [anon_sym_COLONprev_COLON] = ACTIONS(714),
    [anon_sym_COLONprev2_COLON] = ACTIONS(714),
    [anon_sym_COLONprev3_COLON] = ACTIONS(714),
    [aux_sym_specialinline_token1] = ACTIONS(716),
    [aux_sym_specialinline_token2] = ACTIONS(716),
    [anon_sym_COLONmath_COLON] = ACTIONS(714),
    [anon_sym_COLONcode_COLON] = ACTIONS(714),
    [aux_sym_specialinline_token3] = ACTIONS(714),
    [aux_sym_specialinline_token4] = ACTIONS(714),
    [anon_sym_COLONref_COLON] = ACTIONS(714),
    [anon_sym_COLONprevious_COLON] = ACTIONS(714),
    [anon_sym_COLONurl_COLON] = ACTIONS(714),
    [anon_sym_COLONcite_COLON] = ACTIONS(714),
    [anon_sym_COLONqed_COLON] = ACTIONS(714),
    [anon_sym_COLONtable_COLON] = ACTIONS(714),
    [anon_sym_COLONassume_COLON] = ACTIONS(714),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(714),
    [anon_sym_COLONprove_COLON] = ACTIONS(714),
    [anon_sym_COLONthen_COLON] = ACTIONS(714),
    [anon_sym_COLONnew_COLON] = ACTIONS(714),
    [anon_sym_COLONlet_COLON] = ACTIONS(714),
    [anon_sym_COLONcase_COLON] = ACTIONS(714),
    [anon_sym_COLONdefine_COLON] = ACTIONS(714),
    [anon_sym_COLONwrite_COLON] = ACTIONS(714),
    [anon_sym_COLONwlog_COLON] = ACTIONS(714),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(714),
    [anon_sym_COLONclaim_COLON] = ACTIONS(714),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(714),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(714),
    [anon_sym_COLONpick_COLON] = ACTIONS(714),
    [anon_sym_COLONst_COLON] = ACTIONS(714),
    [anon_sym_COLONdraft_COLON] = ACTIONS(714),
    [anon_sym_COLONnote_COLON] = ACTIONS(714),
    [anon_sym_COLONspan_COLON] = ACTIONS(714),
    [anon_sym_COLONabstract_COLON] = ACTIONS(714),
    [anon_sym_COLONauthor_COLON] = ACTIONS(714),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(714),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(714),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(714),
    [anon_sym_COLONexample_COLON] = ACTIONS(714),
    [anon_sym_COLONitemize_COLON] = ACTIONS(714),
    [anon_sym_COLONlemma_COLON] = ACTIONS(714),
    [anon_sym_COLONfigure_COLON] = ACTIONS(714),
    [anon_sym_COLONp_COLON] = ACTIONS(714),
    [anon_sym_COLONproof_COLON] = ACTIONS(714),
    [anon_sym_COLONproposition_COLON] = ACTIONS(714),
    [anon_sym_COLONremark_COLON] = ACTIONS(714),
    [anon_sym_COLONsketch_COLON] = ACTIONS(714),
    [anon_sym_COLONstep_COLON] = ACTIONS(714),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(714),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(714),
  },
  [STATE(74)] = {
    [anon_sym_COLON_COLON] = ACTIONS(718),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(718),
    [aux_sym_section_token1] = ACTIONS(718),
    [anon_sym_COLONsection_COLON] = ACTIONS(718),
    [aux_sym_subsection_token1] = ACTIONS(718),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(718),
    [aux_sym_subsubsection_token1] = ACTIONS(718),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(718),
    [anon_sym_COLONappendix_COLON] = ACTIONS(718),
    [aux_sym_mathblock_token1] = ACTIONS(718),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(718),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(718),
    [anon_sym_COLONtoc_COLON] = ACTIONS(718),
    [aux_sym_specialblock_token1] = ACTIONS(718),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(718),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(718),
    [anon_sym_COLONcaption_COLON] = ACTIONS(718),
    [anon_sym_COLONitem_COLON] = ACTIONS(718),
    [anon_sym_COLONprev_COLON] = ACTIONS(718),
    [anon_sym_COLONprev2_COLON] = ACTIONS(718),
    [anon_sym_COLONprev3_COLON] = ACTIONS(718),
    [aux_sym_specialinline_token1] = ACTIONS(720),
    [aux_sym_specialinline_token2] = ACTIONS(720),
    [anon_sym_COLONmath_COLON] = ACTIONS(718),
    [anon_sym_COLONcode_COLON] = ACTIONS(718),
    [aux_sym_specialinline_token3] = ACTIONS(718),
    [aux_sym_specialinline_token4] = ACTIONS(718),
    [anon_sym_COLONref_COLON] = ACTIONS(718),
    [anon_sym_COLONprevious_COLON] = ACTIONS(718),
    [anon_sym_COLONurl_COLON] = ACTIONS(718),
    [anon_sym_COLONcite_COLON] = ACTIONS(718),
    [anon_sym_COLONqed_COLON] = ACTIONS(718),
    [anon_sym_COLONtable_COLON] = ACTIONS(718),
    [anon_sym_COLONassume_COLON] = ACTIONS(718),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(718),
    [anon_sym_COLONprove_COLON] = ACTIONS(718),
    [anon_sym_COLONthen_COLON] = ACTIONS(718),
    [anon_sym_COLONnew_COLON] = ACTIONS(718),
    [anon_sym_COLONlet_COLON] = ACTIONS(718),
    [anon_sym_COLONcase_COLON] = ACTIONS(718),
    [anon_sym_COLONdefine_COLON] = ACTIONS(718),
    [anon_sym_COLONwrite_COLON] = ACTIONS(718),
    [anon_sym_COLONwlog_COLON] = ACTIONS(718),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(718),
    [anon_sym_COLONclaim_COLON] = ACTIONS(718),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(718),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(718),
    [anon_sym_COLONpick_COLON] = ACTIONS(718),
    [anon_sym_COLONst_COLON] = ACTIONS(718),
    [anon_sym_COLONdraft_COLON] = ACTIONS(718),
    [anon_sym_COLONnote_COLON] = ACTIONS(718),
    [anon_sym_COLONspan_COLON] = ACTIONS(718),
    [anon_sym_COLONabstract_COLON] = ACTIONS(718),
    [anon_sym_COLONauthor_COLON] = ACTIONS(718),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(718),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(718),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(718),
    [anon_sym_COLONexample_COLON] = ACTIONS(718),
    [anon_sym_COLONitemize_COLON] = ACTIONS(718),
    [anon_sym_COLONlemma_COLON] = ACTIONS(718),
    [anon_sym_COLONfigure_COLON] = ACTIONS(718),
    [anon_sym_COLONp_COLON] = ACTIONS(718),
    [anon_sym_COLONproof_COLON] = ACTIONS(718),
    [anon_sym_COLONproposition_COLON] = ACTIONS(718),
    [anon_sym_COLONremark_COLON] = ACTIONS(718),
    [anon_sym_COLONsketch_COLON] = ACTIONS(718),
    [anon_sym_COLONstep_COLON] = ACTIONS(718),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(718),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(718),
  },
  [STATE(75)] = {
    [anon_sym_COLON_COLON] = ACTIONS(722),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(722),
    [aux_sym_section_token1] = ACTIONS(722),
    [anon_sym_COLONsection_COLON] = ACTIONS(722),
    [aux_sym_subsection_token1] = ACTIONS(722),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(722),
    [aux_sym_subsubsection_token1] = ACTIONS(722),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(722),
    [anon_sym_COLONappendix_COLON] = ACTIONS(722),
    [aux_sym_mathblock_token1] = ACTIONS(722),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(722),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(722),
    [anon_sym_COLONtoc_COLON] = ACTIONS(722),
    [aux_sym_specialblock_token1] = ACTIONS(722),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(722),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(722),
    [anon_sym_COLONcaption_COLON] = ACTIONS(722),
    [anon_sym_COLONitem_COLON] = ACTIONS(722),
    [anon_sym_COLONprev_COLON] = ACTIONS(722),
    [anon_sym_COLONprev2_COLON] = ACTIONS(722),
    [anon_sym_COLONprev3_COLON] = ACTIONS(722),
    [aux_sym_specialinline_token1] = ACTIONS(724),
    [aux_sym_specialinline_token2] = ACTIONS(724),
    [anon_sym_COLONmath_COLON] = ACTIONS(722),
    [anon_sym_COLONcode_COLON] = ACTIONS(722),
    [aux_sym_specialinline_token3] = ACTIONS(722),
    [aux_sym_specialinline_token4] = ACTIONS(722),
    [anon_sym_COLONref_COLON] = ACTIONS(722),
    [anon_sym_COLONprevious_COLON] = ACTIONS(722),
    [anon_sym_COLONurl_COLON] = ACTIONS(722),
    [anon_sym_COLONcite_COLON] = ACTIONS(722),
    [anon_sym_COLONqed_COLON] = ACTIONS(722),
    [anon_sym_COLONtable_COLON] = ACTIONS(722),
    [anon_sym_COLONassume_COLON] = ACTIONS(722),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(722),
    [anon_sym_COLONprove_COLON] = ACTIONS(722),
    [anon_sym_COLONthen_COLON] = ACTIONS(722),
    [anon_sym_COLONnew_COLON] = ACTIONS(722),
    [anon_sym_COLONlet_COLON] = ACTIONS(722),
    [anon_sym_COLONcase_COLON] = ACTIONS(722),
    [anon_sym_COLONdefine_COLON] = ACTIONS(722),
    [anon_sym_COLONwrite_COLON] = ACTIONS(722),
    [anon_sym_COLONwlog_COLON] = ACTIONS(722),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(722),
    [anon_sym_COLONclaim_COLON] = ACTIONS(722),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(722),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(722),
    [anon_sym_COLONpick_COLON] = ACTIONS(722),
    [anon_sym_COLONst_COLON] = ACTIONS(722),
    [anon_sym_COLONdraft_COLON] = ACTIONS(722),
    [anon_sym_COLONnote_COLON] = ACTIONS(722),
    [anon_sym_COLONspan_COLON] = ACTIONS(722),
    [anon_sym_COLONabstract_COLON] = ACTIONS(722),
    [anon_sym_COLONauthor_COLON] = ACTIONS(722),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(722),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(722),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(722),
    [anon_sym_COLONexample_COLON] = ACTIONS(722),
    [anon_sym_COLONitemize_COLON] = ACTIONS(722),
    [anon_sym_COLONlemma_COLON] = ACTIONS(722),
    [anon_sym_COLONfigure_COLON] = ACTIONS(722),
    [anon_sym_COLONp_COLON] = ACTIONS(722),
    [anon_sym_COLONproof_COLON] = ACTIONS(722),
    [anon_sym_COLONproposition_COLON] = ACTIONS(722),
    [anon_sym_COLONremark_COLON] = ACTIONS(722),
    [anon_sym_COLONsketch_COLON] = ACTIONS(722),
    [anon_sym_COLONstep_COLON] = ACTIONS(722),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(722),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(722),
  },
  [STATE(76)] = {
    [anon_sym_COLON_COLON] = ACTIONS(726),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(726),
    [aux_sym_section_token1] = ACTIONS(726),
    [anon_sym_COLONsection_COLON] = ACTIONS(726),
    [aux_sym_subsection_token1] = ACTIONS(726),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(726),
    [aux_sym_subsubsection_token1] = ACTIONS(726),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(726),
    [anon_sym_COLONappendix_COLON] = ACTIONS(726),
    [aux_sym_mathblock_token1] = ACTIONS(726),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(726),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(726),
    [anon_sym_COLONtoc_COLON] = ACTIONS(726),
    [aux_sym_specialblock_token1] = ACTIONS(726),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(726),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(726),
    [anon_sym_COLONcaption_COLON] = ACTIONS(726),
    [anon_sym_COLONitem_COLON] = ACTIONS(726),
    [anon_sym_COLONprev_COLON] = ACTIONS(726),
    [anon_sym_COLONprev2_COLON] = ACTIONS(726),
    [anon_sym_COLONprev3_COLON] = ACTIONS(726),
    [aux_sym_specialinline_token1] = ACTIONS(728),
    [aux_sym_specialinline_token2] = ACTIONS(728),
    [anon_sym_COLONmath_COLON] = ACTIONS(726),
    [anon_sym_COLONcode_COLON] = ACTIONS(726),
    [aux_sym_specialinline_token3] = ACTIONS(726),
    [aux_sym_specialinline_token4] = ACTIONS(726),
    [anon_sym_COLONref_COLON] = ACTIONS(726),
    [anon_sym_COLONprevious_COLON] = ACTIONS(726),
    [anon_sym_COLONurl_COLON] = ACTIONS(726),
    [anon_sym_COLONcite_COLON] = ACTIONS(726),
    [anon_sym_COLONqed_COLON] = ACTIONS(726),
    [anon_sym_COLONtable_COLON] = ACTIONS(726),
    [anon_sym_COLONassume_COLON] = ACTIONS(726),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(726),
    [anon_sym_COLONprove_COLON] = ACTIONS(726),
    [anon_sym_COLONthen_COLON] = ACTIONS(726),
    [anon_sym_COLONnew_COLON] = ACTIONS(726),
    [anon_sym_COLONlet_COLON] = ACTIONS(726),
    [anon_sym_COLONcase_COLON] = ACTIONS(726),
    [anon_sym_COLONdefine_COLON] = ACTIONS(726),
    [anon_sym_COLONwrite_COLON] = ACTIONS(726),
    [anon_sym_COLONwlog_COLON] = ACTIONS(726),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(726),
    [anon_sym_COLONclaim_COLON] = ACTIONS(726),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(726),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(726),
    [anon_sym_COLONpick_COLON] = ACTIONS(726),
    [anon_sym_COLONst_COLON] = ACTIONS(726),
    [anon_sym_COLONdraft_COLON] = ACTIONS(726),
    [anon_sym_COLONnote_COLON] = ACTIONS(726),
    [anon_sym_COLONspan_COLON] = ACTIONS(726),
    [anon_sym_COLONabstract_COLON] = ACTIONS(726),
    [anon_sym_COLONauthor_COLON] = ACTIONS(726),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(726),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(726),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(726),
    [anon_sym_COLONexample_COLON] = ACTIONS(726),
    [anon_sym_COLONitemize_COLON] = ACTIONS(726),
    [anon_sym_COLONlemma_COLON] = ACTIONS(726),
    [anon_sym_COLONfigure_COLON] = ACTIONS(726),
    [anon_sym_COLONp_COLON] = ACTIONS(726),
    [anon_sym_COLONproof_COLON] = ACTIONS(726),
    [anon_sym_COLONproposition_COLON] = ACTIONS(726),
    [anon_sym_COLONremark_COLON] = ACTIONS(726),
    [anon_sym_COLONsketch_COLON] = ACTIONS(726),
    [anon_sym_COLONstep_COLON] = ACTIONS(726),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(726),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(726),
  },
  [STATE(77)] = {
    [anon_sym_COLON_COLON] = ACTIONS(730),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(730),
    [aux_sym_section_token1] = ACTIONS(730),
    [anon_sym_COLONsection_COLON] = ACTIONS(730),
    [aux_sym_subsection_token1] = ACTIONS(730),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(730),
    [aux_sym_subsubsection_token1] = ACTIONS(730),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(730),
    [anon_sym_COLONappendix_COLON] = ACTIONS(730),
    [aux_sym_mathblock_token1] = ACTIONS(730),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(730),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(730),
    [anon_sym_COLONtoc_COLON] = ACTIONS(730),
    [aux_sym_specialblock_token1] = ACTIONS(730),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(730),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(730),
    [anon_sym_COLONcaption_COLON] = ACTIONS(730),
    [anon_sym_COLONitem_COLON] = ACTIONS(730),
    [anon_sym_COLONprev_COLON] = ACTIONS(730),
    [anon_sym_COLONprev2_COLON] = ACTIONS(730),
    [anon_sym_COLONprev3_COLON] = ACTIONS(730),
    [aux_sym_specialinline_token1] = ACTIONS(732),
    [aux_sym_specialinline_token2] = ACTIONS(732),
    [anon_sym_COLONmath_COLON] = ACTIONS(730),
    [anon_sym_COLONcode_COLON] = ACTIONS(730),
    [aux_sym_specialinline_token3] = ACTIONS(730),
    [aux_sym_specialinline_token4] = ACTIONS(730),
    [anon_sym_COLONref_COLON] = ACTIONS(730),
    [anon_sym_COLONprevious_COLON] = ACTIONS(730),
    [anon_sym_COLONurl_COLON] = ACTIONS(730),
    [anon_sym_COLONcite_COLON] = ACTIONS(730),
    [anon_sym_COLONqed_COLON] = ACTIONS(730),
    [anon_sym_COLONtable_COLON] = ACTIONS(730),
    [anon_sym_COLONassume_COLON] = ACTIONS(730),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(730),
    [anon_sym_COLONprove_COLON] = ACTIONS(730),
    [anon_sym_COLONthen_COLON] = ACTIONS(730),
    [anon_sym_COLONnew_COLON] = ACTIONS(730),
    [anon_sym_COLONlet_COLON] = ACTIONS(730),
    [anon_sym_COLONcase_COLON] = ACTIONS(730),
    [anon_sym_COLONdefine_COLON] = ACTIONS(730),
    [anon_sym_COLONwrite_COLON] = ACTIONS(730),
    [anon_sym_COLONwlog_COLON] = ACTIONS(730),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(730),
    [anon_sym_COLONclaim_COLON] = ACTIONS(730),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(730),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(730),
    [anon_sym_COLONpick_COLON] = ACTIONS(730),
    [anon_sym_COLONst_COLON] = ACTIONS(730),
    [anon_sym_COLONdraft_COLON] = ACTIONS(730),
    [anon_sym_COLONnote_COLON] = ACTIONS(730),
    [anon_sym_COLONspan_COLON] = ACTIONS(730),
    [anon_sym_COLONabstract_COLON] = ACTIONS(730),
    [anon_sym_COLONauthor_COLON] = ACTIONS(730),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(730),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(730),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(730),
    [anon_sym_COLONexample_COLON] = ACTIONS(730),
    [anon_sym_COLONitemize_COLON] = ACTIONS(730),
    [anon_sym_COLONlemma_COLON] = ACTIONS(730),
    [anon_sym_COLONfigure_COLON] = ACTIONS(730),
    [anon_sym_COLONp_COLON] = ACTIONS(730),
    [anon_sym_COLONproof_COLON] = ACTIONS(730),
    [anon_sym_COLONproposition_COLON] = ACTIONS(730),
    [anon_sym_COLONremark_COLON] = ACTIONS(730),
    [anon_sym_COLONsketch_COLON] = ACTIONS(730),
    [anon_sym_COLONstep_COLON] = ACTIONS(730),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(730),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(730),
  },
  [STATE(78)] = {
    [anon_sym_COLON_COLON] = ACTIONS(734),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(734),
    [aux_sym_section_token1] = ACTIONS(734),
    [anon_sym_COLONsection_COLON] = ACTIONS(734),
    [aux_sym_subsection_token1] = ACTIONS(734),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(734),
    [aux_sym_subsubsection_token1] = ACTIONS(734),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(734),
    [anon_sym_COLONappendix_COLON] = ACTIONS(734),
    [aux_sym_mathblock_token1] = ACTIONS(734),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(734),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(734),
    [anon_sym_COLONtoc_COLON] = ACTIONS(734),
    [aux_sym_specialblock_token1] = ACTIONS(734),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(734),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(734),
    [anon_sym_COLONcaption_COLON] = ACTIONS(734),
    [anon_sym_COLONitem_COLON] = ACTIONS(734),
    [anon_sym_COLONprev_COLON] = ACTIONS(734),
    [anon_sym_COLONprev2_COLON] = ACTIONS(734),
    [anon_sym_COLONprev3_COLON] = ACTIONS(734),
    [aux_sym_specialinline_token1] = ACTIONS(736),
    [aux_sym_specialinline_token2] = ACTIONS(736),
    [anon_sym_COLONmath_COLON] = ACTIONS(734),
    [anon_sym_COLONcode_COLON] = ACTIONS(734),
    [aux_sym_specialinline_token3] = ACTIONS(734),
    [aux_sym_specialinline_token4] = ACTIONS(734),
    [anon_sym_COLONref_COLON] = ACTIONS(734),
    [anon_sym_COLONprevious_COLON] = ACTIONS(734),
    [anon_sym_COLONurl_COLON] = ACTIONS(734),
    [anon_sym_COLONcite_COLON] = ACTIONS(734),
    [anon_sym_COLONqed_COLON] = ACTIONS(734),
    [anon_sym_COLONtable_COLON] = ACTIONS(734),
    [anon_sym_COLONassume_COLON] = ACTIONS(734),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(734),
    [anon_sym_COLONprove_COLON] = ACTIONS(734),
    [anon_sym_COLONthen_COLON] = ACTIONS(734),
    [anon_sym_COLONnew_COLON] = ACTIONS(734),
    [anon_sym_COLONlet_COLON] = ACTIONS(734),
    [anon_sym_COLONcase_COLON] = ACTIONS(734),
    [anon_sym_COLONdefine_COLON] = ACTIONS(734),
    [anon_sym_COLONwrite_COLON] = ACTIONS(734),
    [anon_sym_COLONwlog_COLON] = ACTIONS(734),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(734),
    [anon_sym_COLONclaim_COLON] = ACTIONS(734),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(734),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(734),
    [anon_sym_COLONpick_COLON] = ACTIONS(734),
    [anon_sym_COLONst_COLON] = ACTIONS(734),
    [anon_sym_COLONdraft_COLON] = ACTIONS(734),
    [anon_sym_COLONnote_COLON] = ACTIONS(734),
    [anon_sym_COLONspan_COLON] = ACTIONS(734),
    [anon_sym_COLONabstract_COLON] = ACTIONS(734),
    [anon_sym_COLONauthor_COLON] = ACTIONS(734),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(734),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(734),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(734),
    [anon_sym_COLONexample_COLON] = ACTIONS(734),
    [anon_sym_COLONitemize_COLON] = ACTIONS(734),
    [anon_sym_COLONlemma_COLON] = ACTIONS(734),
    [anon_sym_COLONfigure_COLON] = ACTIONS(734),
    [anon_sym_COLONp_COLON] = ACTIONS(734),
    [anon_sym_COLONproof_COLON] = ACTIONS(734),
    [anon_sym_COLONproposition_COLON] = ACTIONS(734),
    [anon_sym_COLONremark_COLON] = ACTIONS(734),
    [anon_sym_COLONsketch_COLON] = ACTIONS(734),
    [anon_sym_COLONstep_COLON] = ACTIONS(734),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(734),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(734),
  },
  [STATE(79)] = {
    [anon_sym_COLON_COLON] = ACTIONS(738),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(738),
    [aux_sym_section_token1] = ACTIONS(738),
    [anon_sym_COLONsection_COLON] = ACTIONS(738),
    [aux_sym_subsection_token1] = ACTIONS(738),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(738),
    [aux_sym_subsubsection_token1] = ACTIONS(738),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(738),
    [anon_sym_COLONappendix_COLON] = ACTIONS(738),
    [aux_sym_mathblock_token1] = ACTIONS(738),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(738),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(738),
    [anon_sym_COLONtoc_COLON] = ACTIONS(738),
    [aux_sym_specialblock_token1] = ACTIONS(738),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(738),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(738),
    [anon_sym_COLONcaption_COLON] = ACTIONS(738),
    [anon_sym_COLONitem_COLON] = ACTIONS(738),
    [anon_sym_COLONprev_COLON] = ACTIONS(738),
    [anon_sym_COLONprev2_COLON] = ACTIONS(738),
    [anon_sym_COLONprev3_COLON] = ACTIONS(738),
    [aux_sym_specialinline_token1] = ACTIONS(740),
    [aux_sym_specialinline_token2] = ACTIONS(740),
    [anon_sym_COLONmath_COLON] = ACTIONS(738),
    [anon_sym_COLONcode_COLON] = ACTIONS(738),
    [aux_sym_specialinline_token3] = ACTIONS(738),
    [aux_sym_specialinline_token4] = ACTIONS(738),
    [anon_sym_COLONref_COLON] = ACTIONS(738),
    [anon_sym_COLONprevious_COLON] = ACTIONS(738),
    [anon_sym_COLONurl_COLON] = ACTIONS(738),
    [anon_sym_COLONcite_COLON] = ACTIONS(738),
    [anon_sym_COLONqed_COLON] = ACTIONS(738),
    [anon_sym_COLONtable_COLON] = ACTIONS(738),
    [anon_sym_COLONassume_COLON] = ACTIONS(738),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(738),
    [anon_sym_COLONprove_COLON] = ACTIONS(738),
    [anon_sym_COLONthen_COLON] = ACTIONS(738),
    [anon_sym_COLONnew_COLON] = ACTIONS(738),
    [anon_sym_COLONlet_COLON] = ACTIONS(738),
    [anon_sym_COLONcase_COLON] = ACTIONS(738),
    [anon_sym_COLONdefine_COLON] = ACTIONS(738),
    [anon_sym_COLONwrite_COLON] = ACTIONS(738),
    [anon_sym_COLONwlog_COLON] = ACTIONS(738),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(738),
    [anon_sym_COLONclaim_COLON] = ACTIONS(738),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(738),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(738),
    [anon_sym_COLONpick_COLON] = ACTIONS(738),
    [anon_sym_COLONst_COLON] = ACTIONS(738),
    [anon_sym_COLONdraft_COLON] = ACTIONS(738),
    [anon_sym_COLONnote_COLON] = ACTIONS(738),
    [anon_sym_COLONspan_COLON] = ACTIONS(738),
    [anon_sym_COLONabstract_COLON] = ACTIONS(738),
    [anon_sym_COLONauthor_COLON] = ACTIONS(738),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(738),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(738),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(738),
    [anon_sym_COLONexample_COLON] = ACTIONS(738),
    [anon_sym_COLONitemize_COLON] = ACTIONS(738),
    [anon_sym_COLONlemma_COLON] = ACTIONS(738),
    [anon_sym_COLONfigure_COLON] = ACTIONS(738),
    [anon_sym_COLONp_COLON] = ACTIONS(738),
    [anon_sym_COLONproof_COLON] = ACTIONS(738),
    [anon_sym_COLONproposition_COLON] = ACTIONS(738),
    [anon_sym_COLONremark_COLON] = ACTIONS(738),
    [anon_sym_COLONsketch_COLON] = ACTIONS(738),
    [anon_sym_COLONstep_COLON] = ACTIONS(738),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(738),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(738),
  },
  [STATE(80)] = {
    [anon_sym_COLON_COLON] = ACTIONS(742),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(742),
    [aux_sym_section_token1] = ACTIONS(742),
    [anon_sym_COLONsection_COLON] = ACTIONS(742),
    [aux_sym_subsection_token1] = ACTIONS(742),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(742),
    [aux_sym_subsubsection_token1] = ACTIONS(742),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(742),
    [anon_sym_COLONappendix_COLON] = ACTIONS(742),
    [aux_sym_mathblock_token1] = ACTIONS(742),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(742),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(742),
    [anon_sym_COLONtoc_COLON] = ACTIONS(742),
    [aux_sym_specialblock_token1] = ACTIONS(742),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(742),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(742),
    [anon_sym_COLONcaption_COLON] = ACTIONS(742),
    [anon_sym_COLONitem_COLON] = ACTIONS(742),
    [anon_sym_COLONprev_COLON] = ACTIONS(742),
    [anon_sym_COLONprev2_COLON] = ACTIONS(742),
    [anon_sym_COLONprev3_COLON] = ACTIONS(742),
    [aux_sym_specialinline_token1] = ACTIONS(744),
    [aux_sym_specialinline_token2] = ACTIONS(744),
    [anon_sym_COLONmath_COLON] = ACTIONS(742),
    [anon_sym_COLONcode_COLON] = ACTIONS(742),
    [aux_sym_specialinline_token3] = ACTIONS(742),
    [aux_sym_specialinline_token4] = ACTIONS(742),
    [anon_sym_COLONref_COLON] = ACTIONS(742),
    [anon_sym_COLONprevious_COLON] = ACTIONS(742),
    [anon_sym_COLONurl_COLON] = ACTIONS(742),
    [anon_sym_COLONcite_COLON] = ACTIONS(742),
    [anon_sym_COLONqed_COLON] = ACTIONS(742),
    [anon_sym_COLONtable_COLON] = ACTIONS(742),
    [anon_sym_COLONassume_COLON] = ACTIONS(742),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(742),
    [anon_sym_COLONprove_COLON] = ACTIONS(742),
    [anon_sym_COLONthen_COLON] = ACTIONS(742),
    [anon_sym_COLONnew_COLON] = ACTIONS(742),
    [anon_sym_COLONlet_COLON] = ACTIONS(742),
    [anon_sym_COLONcase_COLON] = ACTIONS(742),
    [anon_sym_COLONdefine_COLON] = ACTIONS(742),
    [anon_sym_COLONwrite_COLON] = ACTIONS(742),
    [anon_sym_COLONwlog_COLON] = ACTIONS(742),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(742),
    [anon_sym_COLONclaim_COLON] = ACTIONS(742),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(742),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(742),
    [anon_sym_COLONpick_COLON] = ACTIONS(742),
    [anon_sym_COLONst_COLON] = ACTIONS(742),
    [anon_sym_COLONdraft_COLON] = ACTIONS(742),
    [anon_sym_COLONnote_COLON] = ACTIONS(742),
    [anon_sym_COLONspan_COLON] = ACTIONS(742),
    [anon_sym_COLONabstract_COLON] = ACTIONS(742),
    [anon_sym_COLONauthor_COLON] = ACTIONS(742),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(742),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(742),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(742),
    [anon_sym_COLONexample_COLON] = ACTIONS(742),
    [anon_sym_COLONitemize_COLON] = ACTIONS(742),
    [anon_sym_COLONlemma_COLON] = ACTIONS(742),
    [anon_sym_COLONfigure_COLON] = ACTIONS(742),
    [anon_sym_COLONp_COLON] = ACTIONS(742),
    [anon_sym_COLONproof_COLON] = ACTIONS(742),
    [anon_sym_COLONproposition_COLON] = ACTIONS(742),
    [anon_sym_COLONremark_COLON] = ACTIONS(742),
    [anon_sym_COLONsketch_COLON] = ACTIONS(742),
    [anon_sym_COLONstep_COLON] = ACTIONS(742),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(742),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(742),
  },
  [STATE(81)] = {
    [anon_sym_COLON_COLON] = ACTIONS(746),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(746),
    [aux_sym_section_token1] = ACTIONS(746),
    [anon_sym_COLONsection_COLON] = ACTIONS(746),
    [aux_sym_subsection_token1] = ACTIONS(746),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(746),
    [aux_sym_subsubsection_token1] = ACTIONS(746),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(746),
    [anon_sym_COLONappendix_COLON] = ACTIONS(746),
    [aux_sym_mathblock_token1] = ACTIONS(746),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(746),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(746),
    [anon_sym_COLONtoc_COLON] = ACTIONS(746),
    [aux_sym_specialblock_token1] = ACTIONS(746),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(746),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(746),
    [anon_sym_COLONcaption_COLON] = ACTIONS(746),
    [anon_sym_COLONitem_COLON] = ACTIONS(746),
    [anon_sym_COLONprev_COLON] = ACTIONS(746),
    [anon_sym_COLONprev2_COLON] = ACTIONS(746),
    [anon_sym_COLONprev3_COLON] = ACTIONS(746),
    [aux_sym_specialinline_token1] = ACTIONS(748),
    [aux_sym_specialinline_token2] = ACTIONS(748),
    [anon_sym_COLONmath_COLON] = ACTIONS(746),
    [anon_sym_COLONcode_COLON] = ACTIONS(746),
    [aux_sym_specialinline_token3] = ACTIONS(746),
    [aux_sym_specialinline_token4] = ACTIONS(746),
    [anon_sym_COLONref_COLON] = ACTIONS(746),
    [anon_sym_COLONprevious_COLON] = ACTIONS(746),
    [anon_sym_COLONurl_COLON] = ACTIONS(746),
    [anon_sym_COLONcite_COLON] = ACTIONS(746),
    [anon_sym_COLONqed_COLON] = ACTIONS(746),
    [anon_sym_COLONtable_COLON] = ACTIONS(746),
    [anon_sym_COLONassume_COLON] = ACTIONS(746),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(746),
    [anon_sym_COLONprove_COLON] = ACTIONS(746),
    [anon_sym_COLONthen_COLON] = ACTIONS(746),
    [anon_sym_COLONnew_COLON] = ACTIONS(746),
    [anon_sym_COLONlet_COLON] = ACTIONS(746),
    [anon_sym_COLONcase_COLON] = ACTIONS(746),
    [anon_sym_COLONdefine_COLON] = ACTIONS(746),
    [anon_sym_COLONwrite_COLON] = ACTIONS(746),
    [anon_sym_COLONwlog_COLON] = ACTIONS(746),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(746),
    [anon_sym_COLONclaim_COLON] = ACTIONS(746),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(746),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(746),
    [anon_sym_COLONpick_COLON] = ACTIONS(746),
    [anon_sym_COLONst_COLON] = ACTIONS(746),
    [anon_sym_COLONdraft_COLON] = ACTIONS(746),
    [anon_sym_COLONnote_COLON] = ACTIONS(746),
    [anon_sym_COLONspan_COLON] = ACTIONS(746),
    [anon_sym_COLONabstract_COLON] = ACTIONS(746),
    [anon_sym_COLONauthor_COLON] = ACTIONS(746),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(746),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(746),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(746),
    [anon_sym_COLONexample_COLON] = ACTIONS(746),
    [anon_sym_COLONitemize_COLON] = ACTIONS(746),
    [anon_sym_COLONlemma_COLON] = ACTIONS(746),
    [anon_sym_COLONfigure_COLON] = ACTIONS(746),
    [anon_sym_COLONp_COLON] = ACTIONS(746),
    [anon_sym_COLONproof_COLON] = ACTIONS(746),
    [anon_sym_COLONproposition_COLON] = ACTIONS(746),
    [anon_sym_COLONremark_COLON] = ACTIONS(746),
    [anon_sym_COLONsketch_COLON] = ACTIONS(746),
    [anon_sym_COLONstep_COLON] = ACTIONS(746),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(746),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(746),
  },
  [STATE(82)] = {
    [anon_sym_COLON_COLON] = ACTIONS(750),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(750),
    [aux_sym_section_token1] = ACTIONS(750),
    [anon_sym_COLONsection_COLON] = ACTIONS(750),
    [aux_sym_subsection_token1] = ACTIONS(750),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(750),
    [aux_sym_subsubsection_token1] = ACTIONS(750),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(750),
    [anon_sym_COLONappendix_COLON] = ACTIONS(750),
    [aux_sym_mathblock_token1] = ACTIONS(750),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(750),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(750),
    [anon_sym_COLONtoc_COLON] = ACTIONS(750),
    [aux_sym_specialblock_token1] = ACTIONS(750),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(750),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(750),
    [anon_sym_COLONcaption_COLON] = ACTIONS(750),
    [anon_sym_COLONitem_COLON] = ACTIONS(750),
    [anon_sym_COLONprev_COLON] = ACTIONS(750),
    [anon_sym_COLONprev2_COLON] = ACTIONS(750),
    [anon_sym_COLONprev3_COLON] = ACTIONS(750),
    [aux_sym_specialinline_token1] = ACTIONS(752),
    [aux_sym_specialinline_token2] = ACTIONS(752),
    [anon_sym_COLONmath_COLON] = ACTIONS(750),
    [anon_sym_COLONcode_COLON] = ACTIONS(750),
    [aux_sym_specialinline_token3] = ACTIONS(750),
    [aux_sym_specialinline_token4] = ACTIONS(750),
    [anon_sym_COLONref_COLON] = ACTIONS(750),
    [anon_sym_COLONprevious_COLON] = ACTIONS(750),
    [anon_sym_COLONurl_COLON] = ACTIONS(750),
    [anon_sym_COLONcite_COLON] = ACTIONS(750),
    [anon_sym_COLONqed_COLON] = ACTIONS(750),
    [anon_sym_COLONtable_COLON] = ACTIONS(750),
    [anon_sym_COLONassume_COLON] = ACTIONS(750),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(750),
    [anon_sym_COLONprove_COLON] = ACTIONS(750),
    [anon_sym_COLONthen_COLON] = ACTIONS(750),
    [anon_sym_COLONnew_COLON] = ACTIONS(750),
    [anon_sym_COLONlet_COLON] = ACTIONS(750),
    [anon_sym_COLONcase_COLON] = ACTIONS(750),
    [anon_sym_COLONdefine_COLON] = ACTIONS(750),
    [anon_sym_COLONwrite_COLON] = ACTIONS(750),
    [anon_sym_COLONwlog_COLON] = ACTIONS(750),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(750),
    [anon_sym_COLONclaim_COLON] = ACTIONS(750),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(750),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(750),
    [anon_sym_COLONpick_COLON] = ACTIONS(750),
    [anon_sym_COLONst_COLON] = ACTIONS(750),
    [anon_sym_COLONdraft_COLON] = ACTIONS(750),
    [anon_sym_COLONnote_COLON] = ACTIONS(750),
    [anon_sym_COLONspan_COLON] = ACTIONS(750),
    [anon_sym_COLONabstract_COLON] = ACTIONS(750),
    [anon_sym_COLONauthor_COLON] = ACTIONS(750),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(750),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(750),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(750),
    [anon_sym_COLONexample_COLON] = ACTIONS(750),
    [anon_sym_COLONitemize_COLON] = ACTIONS(750),
    [anon_sym_COLONlemma_COLON] = ACTIONS(750),
    [anon_sym_COLONfigure_COLON] = ACTIONS(750),
    [anon_sym_COLONp_COLON] = ACTIONS(750),
    [anon_sym_COLONproof_COLON] = ACTIONS(750),
    [anon_sym_COLONproposition_COLON] = ACTIONS(750),
    [anon_sym_COLONremark_COLON] = ACTIONS(750),
    [anon_sym_COLONsketch_COLON] = ACTIONS(750),
    [anon_sym_COLONstep_COLON] = ACTIONS(750),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(750),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(750),
  },
  [STATE(83)] = {
    [anon_sym_COLON_COLON] = ACTIONS(754),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(754),
    [aux_sym_section_token1] = ACTIONS(754),
    [anon_sym_COLONsection_COLON] = ACTIONS(754),
    [aux_sym_subsection_token1] = ACTIONS(754),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(754),
    [aux_sym_subsubsection_token1] = ACTIONS(754),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(754),
    [anon_sym_COLONappendix_COLON] = ACTIONS(754),
    [aux_sym_mathblock_token1] = ACTIONS(754),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(754),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(754),
    [anon_sym_COLONtoc_COLON] = ACTIONS(754),
    [aux_sym_specialblock_token1] = ACTIONS(754),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(754),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(754),
    [anon_sym_COLONcaption_COLON] = ACTIONS(754),
    [anon_sym_COLONitem_COLON] = ACTIONS(754),
    [anon_sym_COLONprev_COLON] = ACTIONS(754),
    [anon_sym_COLONprev2_COLON] = ACTIONS(754),
    [anon_sym_COLONprev3_COLON] = ACTIONS(754),
    [aux_sym_specialinline_token1] = ACTIONS(756),
    [aux_sym_specialinline_token2] = ACTIONS(756),
    [anon_sym_COLONmath_COLON] = ACTIONS(754),
    [anon_sym_COLONcode_COLON] = ACTIONS(754),
    [aux_sym_specialinline_token3] = ACTIONS(754),
    [aux_sym_specialinline_token4] = ACTIONS(754),
    [anon_sym_COLONref_COLON] = ACTIONS(754),
    [anon_sym_COLONprevious_COLON] = ACTIONS(754),
    [anon_sym_COLONurl_COLON] = ACTIONS(754),
    [anon_sym_COLONcite_COLON] = ACTIONS(754),
    [anon_sym_COLONqed_COLON] = ACTIONS(754),
    [anon_sym_COLONtable_COLON] = ACTIONS(754),
    [anon_sym_COLONassume_COLON] = ACTIONS(754),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(754),
    [anon_sym_COLONprove_COLON] = ACTIONS(754),
    [anon_sym_COLONthen_COLON] = ACTIONS(754),
    [anon_sym_COLONnew_COLON] = ACTIONS(754),
    [anon_sym_COLONlet_COLON] = ACTIONS(754),
    [anon_sym_COLONcase_COLON] = ACTIONS(754),
    [anon_sym_COLONdefine_COLON] = ACTIONS(754),
    [anon_sym_COLONwrite_COLON] = ACTIONS(754),
    [anon_sym_COLONwlog_COLON] = ACTIONS(754),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(754),
    [anon_sym_COLONclaim_COLON] = ACTIONS(754),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(754),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(754),
    [anon_sym_COLONpick_COLON] = ACTIONS(754),
    [anon_sym_COLONst_COLON] = ACTIONS(754),
    [anon_sym_COLONdraft_COLON] = ACTIONS(754),
    [anon_sym_COLONnote_COLON] = ACTIONS(754),
    [anon_sym_COLONspan_COLON] = ACTIONS(754),
    [anon_sym_COLONabstract_COLON] = ACTIONS(754),
    [anon_sym_COLONauthor_COLON] = ACTIONS(754),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(754),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(754),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(754),
    [anon_sym_COLONexample_COLON] = ACTIONS(754),
    [anon_sym_COLONitemize_COLON] = ACTIONS(754),
    [anon_sym_COLONlemma_COLON] = ACTIONS(754),
    [anon_sym_COLONfigure_COLON] = ACTIONS(754),
    [anon_sym_COLONp_COLON] = ACTIONS(754),
    [anon_sym_COLONproof_COLON] = ACTIONS(754),
    [anon_sym_COLONproposition_COLON] = ACTIONS(754),
    [anon_sym_COLONremark_COLON] = ACTIONS(754),
    [anon_sym_COLONsketch_COLON] = ACTIONS(754),
    [anon_sym_COLONstep_COLON] = ACTIONS(754),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(754),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(754),
  },
  [STATE(84)] = {
    [anon_sym_COLON_COLON] = ACTIONS(758),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(758),
    [aux_sym_section_token1] = ACTIONS(758),
    [anon_sym_COLONsection_COLON] = ACTIONS(758),
    [aux_sym_subsection_token1] = ACTIONS(758),
    [anon_sym_COLONsubsection_COLON] = ACTIONS(758),
    [aux_sym_subsubsection_token1] = ACTIONS(758),
    [anon_sym_COLONsubsubsection_COLON] = ACTIONS(758),
    [anon_sym_COLONappendix_COLON] = ACTIONS(758),
    [aux_sym_mathblock_token1] = ACTIONS(758),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(758),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(758),
    [anon_sym_COLONtoc_COLON] = ACTIONS(758),
    [aux_sym_specialblock_token1] = ACTIONS(758),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(758),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(758),
    [anon_sym_COLONcaption_COLON] = ACTIONS(758),
    [anon_sym_COLONitem_COLON] = ACTIONS(758),
    [anon_sym_COLONprev_COLON] = ACTIONS(758),
    [anon_sym_COLONprev2_COLON] = ACTIONS(758),
    [anon_sym_COLONprev3_COLON] = ACTIONS(758),
    [aux_sym_specialinline_token1] = ACTIONS(760),
    [aux_sym_specialinline_token2] = ACTIONS(760),
    [anon_sym_COLONmath_COLON] = ACTIONS(758),
    [anon_sym_COLONcode_COLON] = ACTIONS(758),
    [aux_sym_specialinline_token3] = ACTIONS(758),
    [aux_sym_specialinline_token4] = ACTIONS(758),
    [anon_sym_COLONref_COLON] = ACTIONS(758),
    [anon_sym_COLONprevious_COLON] = ACTIONS(758),
    [anon_sym_COLONurl_COLON] = ACTIONS(758),
    [anon_sym_COLONcite_COLON] = ACTIONS(758),
    [anon_sym_COLONqed_COLON] = ACTIONS(758),
    [anon_sym_COLONtable_COLON] = ACTIONS(758),
    [anon_sym_COLONassume_COLON] = ACTIONS(758),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(758),
    [anon_sym_COLONprove_COLON] = ACTIONS(758),
    [anon_sym_COLONthen_COLON] = ACTIONS(758),
    [anon_sym_COLONnew_COLON] = ACTIONS(758),
    [anon_sym_COLONlet_COLON] = ACTIONS(758),
    [anon_sym_COLONcase_COLON] = ACTIONS(758),
    [anon_sym_COLONdefine_COLON] = ACTIONS(758),
    [anon_sym_COLONwrite_COLON] = ACTIONS(758),
    [anon_sym_COLONwlog_COLON] = ACTIONS(758),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(758),
    [anon_sym_COLONclaim_COLON] = ACTIONS(758),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(758),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(758),
    [anon_sym_COLONpick_COLON] = ACTIONS(758),
    [anon_sym_COLONst_COLON] = ACTIONS(758),
    [anon_sym_COLONdraft_COLON] = ACTIONS(758),
    [anon_sym_COLONnote_COLON] = ACTIONS(758),
    [anon_sym_COLONspan_COLON] = ACTIONS(758),
    [anon_sym_COLONabstract_COLON] = ACTIONS(758),
    [anon_sym_COLONauthor_COLON] = ACTIONS(758),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(758),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(758),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(758),
    [anon_sym_COLONexample_COLON] = ACTIONS(758),
    [anon_sym_COLONitemize_COLON] = ACTIONS(758),
    [anon_sym_COLONlemma_COLON] = ACTIONS(758),
    [anon_sym_COLONfigure_COLON] = ACTIONS(758),
    [anon_sym_COLONp_COLON] = ACTIONS(758),
    [anon_sym_COLONproof_COLON] = ACTIONS(758),
    [anon_sym_COLONproposition_COLON] = ACTIONS(758),
    [anon_sym_COLONremark_COLON] = ACTIONS(758),
    [anon_sym_COLONsketch_COLON] = ACTIONS(758),
    [anon_sym_COLONstep_COLON] = ACTIONS(758),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(758),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(758),
  },
  [STATE(85)] = {
    [anon_sym_COLON_COLON] = ACTIONS(762),
    [anon_sym_COLONparagraph_COLON] = ACTIONS(762),
    [aux_sym_section_token1] = ACTIONS(762),
    [anon_sym_COLONsection_COLON] = ACTIONS(762),
    [anon_sym_COLONappendix_COLON] = ACTIONS(762),
    [aux_sym_mathblock_token1] = ACTIONS(762),
    [anon_sym_COLONmathblock_COLON] = ACTIONS(762),
    [anon_sym_COLONbibliography_COLON] = ACTIONS(762),
    [anon_sym_COLONtoc_COLON] = ACTIONS(762),
    [aux_sym_specialblock_token1] = ACTIONS(762),
    [anon_sym_COLONcodeblock_COLON] = ACTIONS(762),
    [anon_sym_COLONalgorithm_COLON] = ACTIONS(762),
    [anon_sym_COLONcaption_COLON] = ACTIONS(762),
    [anon_sym_COLONitem_COLON] = ACTIONS(762),
    [anon_sym_COLONprev_COLON] = ACTIONS(762),
    [anon_sym_COLONprev2_COLON] = ACTIONS(762),
    [anon_sym_COLONprev3_COLON] = ACTIONS(762),
    [aux_sym_specialinline_token1] = ACTIONS(764),
    [aux_sym_specialinline_token2] = ACTIONS(764),
    [anon_sym_COLONmath_COLON] = ACTIONS(762),
    [anon_sym_COLONcode_COLON] = ACTIONS(762),
    [aux_sym_specialinline_token3] = ACTIONS(762),
    [aux_sym_specialinline_token4] = ACTIONS(762),
    [anon_sym_COLONref_COLON] = ACTIONS(762),
    [anon_sym_COLONprevious_COLON] = ACTIONS(762),
    [anon_sym_COLONurl_COLON] = ACTIONS(762),
    [anon_sym_COLONcite_COLON] = ACTIONS(762),
    [anon_sym_COLONqed_COLON] = ACTIONS(762),
    [anon_sym_COLONtable_COLON] = ACTIONS(762),
    [anon_sym_COLONassume_COLON] = ACTIONS(762),
    [anon_sym_COLONsuppose_COLON] = ACTIONS(762),
    [anon_sym_COLONprove_COLON] = ACTIONS(762),
    [anon_sym_COLONthen_COLON] = ACTIONS(762),
    [anon_sym_COLONnew_COLON] = ACTIONS(762),
    [anon_sym_COLONlet_COLON] = ACTIONS(762),
    [anon_sym_COLONcase_COLON] = ACTIONS(762),
    [anon_sym_COLONdefine_COLON] = ACTIONS(762),
    [anon_sym_COLONwrite_COLON] = ACTIONS(762),
    [anon_sym_COLONwlog_COLON] = ACTIONS(762),
    [anon_sym_COLONsuffices_COLON] = ACTIONS(762),
    [anon_sym_COLONclaim_COLON] = ACTIONS(762),
    [anon_sym_COLON_PIPE_DASH_COLON] = ACTIONS(762),
    [anon_sym_COLONu22a2_COLON] = ACTIONS(762),
    [anon_sym_COLONpick_COLON] = ACTIONS(762),
    [anon_sym_COLONst_COLON] = ACTIONS(762),
    [anon_sym_COLONdraft_COLON] = ACTIONS(762),
    [anon_sym_COLONnote_COLON] = ACTIONS(762),
    [anon_sym_COLONspan_COLON] = ACTIONS(762),
    [anon_sym_COLONabstract_COLON] = ACTIONS(762),
    [anon_sym_COLONauthor_COLON] = ACTIONS(762),
    [anon_sym_COLONdefinition_COLON] = ACTIONS(762),
    [anon_sym_COLONcorollary_COLON] = ACTIONS(762),
    [anon_sym_COLONenumerate_COLON] = ACTIONS(762),
    [anon_sym_COLONexample_COLON] = ACTIONS(762),
    [anon_sym_COLONitemize_COLON] = ACTIONS(762),
    [anon_sym_COLONlemma_COLON] = ACTIONS(762),
    [anon_sym_COLONfigure_COLON] = ACTIONS(762),
    [anon_sym_COLONp_COLON] = ACTIONS(762),
    [anon_sym_COLONproof_COLON] = ACTIONS(762),
    [anon_sym_COLONproposition_COLON] = ACTIONS(762),
    [anon_sym_COLONremark_COLON] = ACTIONS(762),
    [anon_sym_COLONsketch_COLON] = ACTIONS(762),
    [anon_sym_COLONstep_COLON] = ACTIONS(762),
    [anon_sym_COLONtheorem_COLON] = ACTIONS(762),
    [sym_comment] = ACTIONS(3),
    [sym_text] = ACTIONS(762),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 1,
      aux_sym_specialinline_token1,
    ACTIONS(770), 1,
      aux_sym_specialinline_token2,
    ACTIONS(772), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(774), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(776), 1,
      aux_sym_specialinline_token3,
    ACTIONS(778), 1,
      aux_sym_specialinline_token4,
    ACTIONS(780), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(782), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(784), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(786), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(788), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(790), 1,
      anon_sym_COLONtd_COLON,
    ACTIONS(796), 1,
      sym_text,
    STATE(117), 1,
      aux_sym_trshort_repeat1,
    STATE(439), 1,
      sym_tdcontent,
    STATE(355), 2,
      sym_td,
      aux_sym_tr_repeat1,
    ACTIONS(766), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(794), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(116), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(792), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [88] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      aux_sym_specialinline_token1,
    ACTIONS(37), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(39), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(41), 1,
      aux_sym_specialinline_token3,
    ACTIONS(43), 1,
      aux_sym_specialinline_token4,
    ACTIONS(45), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(47), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(798), 1,
      aux_sym_mathblock_token1,
    ACTIONS(800), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(802), 1,
      aux_sym_specialinline_token2,
    ACTIONS(804), 1,
      anon_sym_LBRACE,
    ACTIONS(806), 1,
      sym_text,
    STATE(102), 1,
      sym_inlinemeta,
    ACTIONS(31), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(59), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(94), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(57), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [176] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      aux_sym_specialinline_token1,
    ACTIONS(37), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(39), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(41), 1,
      aux_sym_specialinline_token3,
    ACTIONS(43), 1,
      aux_sym_specialinline_token4,
    ACTIONS(45), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(47), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(798), 1,
      aux_sym_mathblock_token1,
    ACTIONS(800), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(802), 1,
      aux_sym_specialinline_token2,
    ACTIONS(804), 1,
      anon_sym_LBRACE,
    ACTIONS(808), 1,
      sym_text,
    STATE(101), 1,
      sym_inlinemeta,
    ACTIONS(31), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(59), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(93), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(57), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [264] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      aux_sym_specialinline_token1,
    ACTIONS(37), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(39), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(41), 1,
      aux_sym_specialinline_token3,
    ACTIONS(43), 1,
      aux_sym_specialinline_token4,
    ACTIONS(45), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(47), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(798), 1,
      aux_sym_mathblock_token1,
    ACTIONS(800), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(802), 1,
      aux_sym_specialinline_token2,
    ACTIONS(804), 1,
      anon_sym_LBRACE,
    ACTIONS(810), 1,
      sym_text,
    STATE(114), 1,
      sym_inlinemeta,
    ACTIONS(31), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(59), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(99), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(57), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [352] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      aux_sym_specialinline_token1,
    ACTIONS(37), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(39), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(41), 1,
      aux_sym_specialinline_token3,
    ACTIONS(43), 1,
      aux_sym_specialinline_token4,
    ACTIONS(45), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(47), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(798), 1,
      aux_sym_mathblock_token1,
    ACTIONS(800), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(802), 1,
      aux_sym_specialinline_token2,
    ACTIONS(812), 1,
      sym_text,
    ACTIONS(814), 1,
      sym_paragraph_end,
    ACTIONS(31), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(59), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(96), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(57), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [437] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      aux_sym_specialinline_token1,
    ACTIONS(37), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(39), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(41), 1,
      aux_sym_specialinline_token3,
    ACTIONS(43), 1,
      aux_sym_specialinline_token4,
    ACTIONS(45), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(47), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(798), 1,
      aux_sym_mathblock_token1,
    ACTIONS(800), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(802), 1,
      aux_sym_specialinline_token2,
    ACTIONS(816), 1,
      sym_text,
    ACTIONS(818), 1,
      sym_paragraph_end,
    ACTIONS(31), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(59), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(90), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(57), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [522] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      aux_sym_specialinline_token1,
    ACTIONS(37), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(39), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(41), 1,
      aux_sym_specialinline_token3,
    ACTIONS(43), 1,
      aux_sym_specialinline_token4,
    ACTIONS(45), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(47), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(798), 1,
      aux_sym_mathblock_token1,
    ACTIONS(800), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(802), 1,
      aux_sym_specialinline_token2,
    ACTIONS(812), 1,
      sym_text,
    ACTIONS(820), 1,
      sym_paragraph_end,
    ACTIONS(31), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(59), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(96), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(57), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [607] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      aux_sym_specialinline_token1,
    ACTIONS(37), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(39), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(41), 1,
      aux_sym_specialinline_token3,
    ACTIONS(43), 1,
      aux_sym_specialinline_token4,
    ACTIONS(45), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(47), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(798), 1,
      aux_sym_mathblock_token1,
    ACTIONS(800), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(802), 1,
      aux_sym_specialinline_token2,
    ACTIONS(812), 1,
      sym_text,
    ACTIONS(822), 1,
      sym_paragraph_end,
    ACTIONS(31), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(59), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(96), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(57), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [692] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      aux_sym_specialinline_token1,
    ACTIONS(37), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(39), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(41), 1,
      aux_sym_specialinline_token3,
    ACTIONS(43), 1,
      aux_sym_specialinline_token4,
    ACTIONS(45), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(47), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(798), 1,
      aux_sym_mathblock_token1,
    ACTIONS(800), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(802), 1,
      aux_sym_specialinline_token2,
    ACTIONS(812), 1,
      sym_text,
    ACTIONS(824), 1,
      sym_paragraph_end,
    ACTIONS(31), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(59), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(96), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(57), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [777] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      aux_sym_specialinline_token1,
    ACTIONS(37), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(39), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(41), 1,
      aux_sym_specialinline_token3,
    ACTIONS(43), 1,
      aux_sym_specialinline_token4,
    ACTIONS(45), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(47), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(798), 1,
      aux_sym_mathblock_token1,
    ACTIONS(800), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(802), 1,
      aux_sym_specialinline_token2,
    ACTIONS(812), 1,
      sym_text,
    ACTIONS(826), 1,
      sym_paragraph_end,
    ACTIONS(31), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(59), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(96), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(57), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [862] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(828), 1,
      aux_sym_mathblock_token1,
    ACTIONS(831), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(837), 1,
      aux_sym_specialinline_token1,
    ACTIONS(840), 1,
      aux_sym_specialinline_token2,
    ACTIONS(843), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(846), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(849), 1,
      aux_sym_specialinline_token3,
    ACTIONS(852), 1,
      aux_sym_specialinline_token4,
    ACTIONS(855), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(858), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(861), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(864), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(867), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(876), 1,
      sym_text,
    ACTIONS(879), 1,
      sym_paragraph_end,
    ACTIONS(834), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(873), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(96), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(870), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [947] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      aux_sym_specialinline_token1,
    ACTIONS(37), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(39), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(41), 1,
      aux_sym_specialinline_token3,
    ACTIONS(43), 1,
      aux_sym_specialinline_token4,
    ACTIONS(45), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(47), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(798), 1,
      aux_sym_mathblock_token1,
    ACTIONS(800), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(802), 1,
      aux_sym_specialinline_token2,
    ACTIONS(812), 1,
      sym_text,
    ACTIONS(881), 1,
      sym_paragraph_end,
    ACTIONS(31), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(59), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(96), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(57), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [1032] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      aux_sym_specialinline_token1,
    ACTIONS(37), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(39), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(41), 1,
      aux_sym_specialinline_token3,
    ACTIONS(43), 1,
      aux_sym_specialinline_token4,
    ACTIONS(45), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(47), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(798), 1,
      aux_sym_mathblock_token1,
    ACTIONS(800), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(802), 1,
      aux_sym_specialinline_token2,
    ACTIONS(883), 1,
      sym_text,
    ACTIONS(885), 1,
      sym_paragraph_end,
    ACTIONS(31), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(59), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(95), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(57), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [1117] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      aux_sym_specialinline_token1,
    ACTIONS(37), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(39), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(41), 1,
      aux_sym_specialinline_token3,
    ACTIONS(43), 1,
      aux_sym_specialinline_token4,
    ACTIONS(45), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(47), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(798), 1,
      aux_sym_mathblock_token1,
    ACTIONS(800), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(802), 1,
      aux_sym_specialinline_token2,
    ACTIONS(812), 1,
      sym_text,
    ACTIONS(887), 1,
      sym_paragraph_end,
    ACTIONS(31), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(59), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(96), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(57), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [1202] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      aux_sym_specialinline_token1,
    ACTIONS(37), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(39), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(41), 1,
      aux_sym_specialinline_token3,
    ACTIONS(43), 1,
      aux_sym_specialinline_token4,
    ACTIONS(45), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(47), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(798), 1,
      aux_sym_mathblock_token1,
    ACTIONS(800), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(802), 1,
      aux_sym_specialinline_token2,
    ACTIONS(812), 1,
      sym_text,
    ACTIONS(889), 1,
      sym_paragraph_end,
    ACTIONS(31), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(59), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(96), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(57), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [1287] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      aux_sym_specialinline_token1,
    ACTIONS(37), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(39), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(41), 1,
      aux_sym_specialinline_token3,
    ACTIONS(43), 1,
      aux_sym_specialinline_token4,
    ACTIONS(45), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(47), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(798), 1,
      aux_sym_mathblock_token1,
    ACTIONS(800), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(802), 1,
      aux_sym_specialinline_token2,
    ACTIONS(891), 1,
      sym_text,
    ACTIONS(31), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(59), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(92), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(57), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [1369] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      aux_sym_specialinline_token1,
    ACTIONS(37), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(39), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(41), 1,
      aux_sym_specialinline_token3,
    ACTIONS(43), 1,
      aux_sym_specialinline_token4,
    ACTIONS(45), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(47), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(798), 1,
      aux_sym_mathblock_token1,
    ACTIONS(800), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(802), 1,
      aux_sym_specialinline_token2,
    ACTIONS(893), 1,
      sym_text,
    ACTIONS(31), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(59), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(97), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(57), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [1451] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 1,
      aux_sym_specialinline_token1,
    ACTIONS(770), 1,
      aux_sym_specialinline_token2,
    ACTIONS(772), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(774), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(776), 1,
      aux_sym_specialinline_token3,
    ACTIONS(778), 1,
      aux_sym_specialinline_token4,
    ACTIONS(780), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(782), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(784), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(786), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(788), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(796), 1,
      sym_text,
    ACTIONS(895), 1,
      anon_sym_LBRACE,
    STATE(125), 1,
      sym_inlinemeta,
    STATE(589), 1,
      sym_tdcontent,
    ACTIONS(766), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(794), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(116), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(792), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [1535] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 1,
      aux_sym_specialinline_token1,
    ACTIONS(770), 1,
      aux_sym_specialinline_token2,
    ACTIONS(772), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(774), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(776), 1,
      aux_sym_specialinline_token3,
    ACTIONS(778), 1,
      aux_sym_specialinline_token4,
    ACTIONS(780), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(782), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(784), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(786), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(788), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(895), 1,
      anon_sym_LBRACE,
    ACTIONS(897), 1,
      anon_sym_COLON_COLON,
    ACTIONS(899), 1,
      sym_text,
    STATE(153), 1,
      sym_inlinemeta,
    ACTIONS(766), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(794), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(154), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(792), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [1619] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 1,
      aux_sym_specialinline_token1,
    ACTIONS(770), 1,
      aux_sym_specialinline_token2,
    ACTIONS(772), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(774), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(776), 1,
      aux_sym_specialinline_token3,
    ACTIONS(778), 1,
      aux_sym_specialinline_token4,
    ACTIONS(780), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(782), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(784), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(786), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(788), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(895), 1,
      anon_sym_LBRACE,
    ACTIONS(901), 1,
      anon_sym_COLON_COLON,
    ACTIONS(903), 1,
      sym_text,
    STATE(164), 1,
      sym_inlinemeta,
    ACTIONS(766), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(794), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(165), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(792), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [1703] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 1,
      aux_sym_specialinline_token1,
    ACTIONS(770), 1,
      aux_sym_specialinline_token2,
    ACTIONS(772), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(774), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(776), 1,
      aux_sym_specialinline_token3,
    ACTIONS(778), 1,
      aux_sym_specialinline_token4,
    ACTIONS(780), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(782), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(784), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(786), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(788), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(895), 1,
      anon_sym_LBRACE,
    ACTIONS(905), 1,
      anon_sym_COLON_COLON,
    ACTIONS(907), 1,
      sym_text,
    STATE(157), 1,
      sym_inlinemeta,
    ACTIONS(766), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(794), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(158), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(792), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [1787] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 1,
      aux_sym_specialinline_token1,
    ACTIONS(770), 1,
      aux_sym_specialinline_token2,
    ACTIONS(772), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(774), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(776), 1,
      aux_sym_specialinline_token3,
    ACTIONS(778), 1,
      aux_sym_specialinline_token4,
    ACTIONS(780), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(782), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(784), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(786), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(788), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(895), 1,
      anon_sym_LBRACE,
    ACTIONS(909), 1,
      anon_sym_COLON_COLON,
    ACTIONS(911), 1,
      sym_text,
    STATE(136), 1,
      sym_inlinemeta,
    ACTIONS(766), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(794), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(137), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(792), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [1871] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 1,
      aux_sym_specialinline_token1,
    ACTIONS(770), 1,
      aux_sym_specialinline_token2,
    ACTIONS(772), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(774), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(776), 1,
      aux_sym_specialinline_token3,
    ACTIONS(778), 1,
      aux_sym_specialinline_token4,
    ACTIONS(780), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(782), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(784), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(786), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(788), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(895), 1,
      anon_sym_LBRACE,
    ACTIONS(913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(915), 1,
      sym_text,
    STATE(145), 1,
      sym_inlinemeta,
    ACTIONS(766), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(794), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(146), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(792), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [1955] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 1,
      aux_sym_specialinline_token1,
    ACTIONS(770), 1,
      aux_sym_specialinline_token2,
    ACTIONS(772), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(774), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(776), 1,
      aux_sym_specialinline_token3,
    ACTIONS(778), 1,
      aux_sym_specialinline_token4,
    ACTIONS(780), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(782), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(784), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(786), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(788), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(895), 1,
      anon_sym_LBRACE,
    ACTIONS(917), 1,
      anon_sym_COLON_COLON,
    ACTIONS(919), 1,
      sym_text,
    STATE(147), 1,
      sym_inlinemeta,
    ACTIONS(766), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(794), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(148), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(792), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [2039] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 1,
      aux_sym_specialinline_token1,
    ACTIONS(770), 1,
      aux_sym_specialinline_token2,
    ACTIONS(772), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(774), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(776), 1,
      aux_sym_specialinline_token3,
    ACTIONS(778), 1,
      aux_sym_specialinline_token4,
    ACTIONS(780), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(782), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(784), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(786), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(788), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(895), 1,
      anon_sym_LBRACE,
    ACTIONS(921), 1,
      anon_sym_COLON_COLON,
    ACTIONS(923), 1,
      sym_text,
    STATE(159), 1,
      sym_inlinemeta,
    ACTIONS(766), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(794), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(160), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(792), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [2123] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 1,
      aux_sym_specialinline_token1,
    ACTIONS(770), 1,
      aux_sym_specialinline_token2,
    ACTIONS(772), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(774), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(776), 1,
      aux_sym_specialinline_token3,
    ACTIONS(778), 1,
      aux_sym_specialinline_token4,
    ACTIONS(780), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(782), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(784), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(786), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(788), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(895), 1,
      anon_sym_LBRACE,
    ACTIONS(925), 1,
      anon_sym_COLON_COLON,
    ACTIONS(927), 1,
      sym_text,
    STATE(168), 1,
      sym_inlinemeta,
    ACTIONS(766), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(794), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(169), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(792), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [2207] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 1,
      aux_sym_specialinline_token1,
    ACTIONS(770), 1,
      aux_sym_specialinline_token2,
    ACTIONS(772), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(774), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(776), 1,
      aux_sym_specialinline_token3,
    ACTIONS(778), 1,
      aux_sym_specialinline_token4,
    ACTIONS(780), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(782), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(784), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(786), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(788), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(895), 1,
      anon_sym_LBRACE,
    ACTIONS(929), 1,
      anon_sym_COLON_COLON,
    ACTIONS(931), 1,
      sym_text,
    STATE(173), 1,
      sym_inlinemeta,
    ACTIONS(766), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(794), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(138), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(792), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [2291] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 1,
      aux_sym_specialinline_token1,
    ACTIONS(770), 1,
      aux_sym_specialinline_token2,
    ACTIONS(772), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(774), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(776), 1,
      aux_sym_specialinline_token3,
    ACTIONS(778), 1,
      aux_sym_specialinline_token4,
    ACTIONS(780), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(782), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(784), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(786), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(788), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(895), 1,
      anon_sym_LBRACE,
    ACTIONS(933), 1,
      anon_sym_COLON_COLON,
    ACTIONS(935), 1,
      sym_text,
    STATE(170), 1,
      sym_inlinemeta,
    ACTIONS(766), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(794), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(171), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(792), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [2375] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      aux_sym_specialinline_token1,
    ACTIONS(37), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(39), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(41), 1,
      aux_sym_specialinline_token3,
    ACTIONS(43), 1,
      aux_sym_specialinline_token4,
    ACTIONS(45), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(47), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(798), 1,
      aux_sym_mathblock_token1,
    ACTIONS(800), 1,
      anon_sym_COLONmathblock_COLON,
    ACTIONS(802), 1,
      aux_sym_specialinline_token2,
    ACTIONS(937), 1,
      sym_text,
    ACTIONS(31), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(59), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(100), 6,
      sym_inline,
      sym_construct,
      sym_mathblock,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_paragraph_repeat1,
    ACTIONS(57), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [2457] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(942), 1,
      aux_sym_specialinline_token1,
    ACTIONS(945), 1,
      aux_sym_specialinline_token2,
    ACTIONS(948), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(951), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(954), 1,
      aux_sym_specialinline_token3,
    ACTIONS(957), 1,
      aux_sym_specialinline_token4,
    ACTIONS(960), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(963), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(966), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(969), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(972), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(981), 1,
      sym_text,
    STATE(115), 1,
      aux_sym_trshort_repeat1,
    STATE(506), 1,
      sym_tdcontent,
    ACTIONS(939), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(978), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(130), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(975), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [2538] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 1,
      aux_sym_specialinline_token1,
    ACTIONS(770), 1,
      aux_sym_specialinline_token2,
    ACTIONS(772), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(774), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(776), 1,
      aux_sym_specialinline_token3,
    ACTIONS(778), 1,
      aux_sym_specialinline_token4,
    ACTIONS(780), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(782), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(784), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(786), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(788), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(984), 1,
      anon_sym_COLON_COLON,
    ACTIONS(986), 1,
      anon_sym_COLON,
    ACTIONS(988), 1,
      sym_text,
    ACTIONS(766), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(794), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(118), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(792), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [2619] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 1,
      aux_sym_specialinline_token1,
    ACTIONS(770), 1,
      aux_sym_specialinline_token2,
    ACTIONS(772), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(774), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(776), 1,
      aux_sym_specialinline_token3,
    ACTIONS(778), 1,
      aux_sym_specialinline_token4,
    ACTIONS(780), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(782), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(784), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(786), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(788), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(796), 1,
      sym_text,
    STATE(115), 1,
      aux_sym_trshort_repeat1,
    STATE(403), 1,
      sym_tdcontent,
    ACTIONS(766), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(794), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(116), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(792), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [2700] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(990), 1,
      anon_sym_COLON_COLON,
    ACTIONS(995), 1,
      aux_sym_specialinline_token1,
    ACTIONS(998), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1001), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1004), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1007), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1010), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1013), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1016), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1019), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1022), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1025), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1028), 1,
      anon_sym_COLON,
    ACTIONS(1036), 1,
      sym_text,
    ACTIONS(992), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1033), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(118), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1030), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [2781] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 1,
      aux_sym_specialinline_token1,
    ACTIONS(770), 1,
      aux_sym_specialinline_token2,
    ACTIONS(772), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(774), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(776), 1,
      aux_sym_specialinline_token3,
    ACTIONS(778), 1,
      aux_sym_specialinline_token4,
    ACTIONS(780), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(782), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(784), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(786), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(788), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(988), 1,
      sym_text,
    ACTIONS(1039), 1,
      anon_sym_COLON_COLON,
    ACTIONS(766), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(794), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(118), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(792), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [2859] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 1,
      aux_sym_specialinline_token1,
    ACTIONS(770), 1,
      aux_sym_specialinline_token2,
    ACTIONS(772), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(774), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(776), 1,
      aux_sym_specialinline_token3,
    ACTIONS(778), 1,
      aux_sym_specialinline_token4,
    ACTIONS(780), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(782), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(784), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(786), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(788), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(988), 1,
      sym_text,
    ACTIONS(1041), 1,
      anon_sym_COLON_COLON,
    ACTIONS(766), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(794), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(118), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(792), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [2937] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(990), 1,
      anon_sym_STAR,
    ACTIONS(1046), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1049), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1052), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1055), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1058), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1061), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1064), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1067), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1070), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1073), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1076), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1085), 1,
      sym_text,
    ACTIONS(1043), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1082), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(121), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1079), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [3015] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1090), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1092), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1094), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1096), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1098), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1100), 1,
      anon_sym_STAR,
    ACTIONS(1102), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1104), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1106), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1108), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1110), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1112), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1118), 1,
      sym_text,
    ACTIONS(1088), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1116), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(127), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1114), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [3093] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1100), 1,
      anon_sym_SLASH,
    ACTIONS(1122), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1124), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1126), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1128), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1130), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1132), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1134), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1136), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1138), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1140), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1142), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1148), 1,
      sym_text,
    ACTIONS(1120), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1146), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(128), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1144), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [3171] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 1,
      aux_sym_specialinline_token1,
    ACTIONS(770), 1,
      aux_sym_specialinline_token2,
    ACTIONS(772), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(774), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(776), 1,
      aux_sym_specialinline_token3,
    ACTIONS(778), 1,
      aux_sym_specialinline_token4,
    ACTIONS(780), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(782), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(784), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(786), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(788), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(988), 1,
      sym_text,
    ACTIONS(1150), 1,
      anon_sym_COLON_COLON,
    ACTIONS(766), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(794), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(118), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(792), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [3249] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 1,
      aux_sym_specialinline_token1,
    ACTIONS(770), 1,
      aux_sym_specialinline_token2,
    ACTIONS(772), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(774), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(776), 1,
      aux_sym_specialinline_token3,
    ACTIONS(778), 1,
      aux_sym_specialinline_token4,
    ACTIONS(780), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(782), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(784), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(786), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(788), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(796), 1,
      sym_text,
    STATE(502), 1,
      sym_tdcontent,
    ACTIONS(766), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(794), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(116), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(792), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [3327] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 1,
      aux_sym_specialinline_token1,
    ACTIONS(770), 1,
      aux_sym_specialinline_token2,
    ACTIONS(772), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(774), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(776), 1,
      aux_sym_specialinline_token3,
    ACTIONS(778), 1,
      aux_sym_specialinline_token4,
    ACTIONS(780), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(782), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(784), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(786), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(788), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(988), 1,
      sym_text,
    ACTIONS(1152), 1,
      anon_sym_COLON_COLON,
    ACTIONS(766), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(794), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(118), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(792), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [3405] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1090), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1092), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1094), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1096), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1098), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1102), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1104), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1106), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1108), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1110), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1112), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1154), 1,
      anon_sym_STAR,
    ACTIONS(1156), 1,
      sym_text,
    ACTIONS(1088), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1116), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(121), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1114), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [3483] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1122), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1124), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1126), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1128), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1130), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1132), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1134), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1136), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1138), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1140), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1142), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1154), 1,
      anon_sym_SLASH,
    ACTIONS(1158), 1,
      sym_text,
    ACTIONS(1120), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1146), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(129), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1144), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [3561] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(990), 1,
      anon_sym_SLASH,
    ACTIONS(1163), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1166), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1169), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1172), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1175), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1178), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1181), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1184), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1187), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1190), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1193), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1202), 1,
      sym_text,
    ACTIONS(1160), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1199), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(129), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1196), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [3639] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(986), 1,
      anon_sym_COLON,
    ACTIONS(1207), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1209), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1211), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1213), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1215), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1217), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1219), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1221), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1223), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1225), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1227), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1233), 1,
      sym_text,
    ACTIONS(1205), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1231), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(131), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1229), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [3717] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1028), 1,
      anon_sym_COLON,
    ACTIONS(1238), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1241), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1244), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1247), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1250), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1253), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1256), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1259), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1262), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1265), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1268), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1277), 1,
      sym_text,
    ACTIONS(1235), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1274), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(131), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1271), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [3795] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1090), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1092), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1094), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1096), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1098), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1102), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1104), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1106), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1108), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1110), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1112), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1280), 1,
      anon_sym_STAR,
    ACTIONS(1282), 1,
      sym_text,
    ACTIONS(1088), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1116), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(134), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1114), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [3873] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1122), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1124), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1126), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1128), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1130), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1132), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1134), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1136), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1138), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1140), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1142), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1280), 1,
      anon_sym_SLASH,
    ACTIONS(1284), 1,
      sym_text,
    ACTIONS(1120), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1146), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(135), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1144), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [3951] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1090), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1092), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1094), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1096), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1098), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1102), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1104), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1106), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1108), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1110), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1112), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1156), 1,
      sym_text,
    ACTIONS(1286), 1,
      anon_sym_STAR,
    ACTIONS(1088), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1116), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(121), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1114), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [4029] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1122), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1124), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1126), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1128), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1130), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1132), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1134), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1136), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1138), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1140), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1142), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1158), 1,
      sym_text,
    ACTIONS(1286), 1,
      anon_sym_SLASH,
    ACTIONS(1120), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1146), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(129), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1144), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [4107] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 1,
      aux_sym_specialinline_token1,
    ACTIONS(770), 1,
      aux_sym_specialinline_token2,
    ACTIONS(772), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(774), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(776), 1,
      aux_sym_specialinline_token3,
    ACTIONS(778), 1,
      aux_sym_specialinline_token4,
    ACTIONS(780), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(782), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(784), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(786), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(788), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1288), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1290), 1,
      sym_text,
    ACTIONS(766), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(794), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(139), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(792), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [4185] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 1,
      aux_sym_specialinline_token1,
    ACTIONS(770), 1,
      aux_sym_specialinline_token2,
    ACTIONS(772), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(774), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(776), 1,
      aux_sym_specialinline_token3,
    ACTIONS(778), 1,
      aux_sym_specialinline_token4,
    ACTIONS(780), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(782), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(784), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(786), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(788), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(988), 1,
      sym_text,
    ACTIONS(1292), 1,
      anon_sym_COLON_COLON,
    ACTIONS(766), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(794), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(118), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(792), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [4263] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 1,
      aux_sym_specialinline_token1,
    ACTIONS(770), 1,
      aux_sym_specialinline_token2,
    ACTIONS(772), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(774), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(776), 1,
      aux_sym_specialinline_token3,
    ACTIONS(778), 1,
      aux_sym_specialinline_token4,
    ACTIONS(780), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(782), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(784), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(786), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(788), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(988), 1,
      sym_text,
    ACTIONS(1294), 1,
      anon_sym_COLON_COLON,
    ACTIONS(766), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(794), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(118), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(792), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [4341] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 1,
      aux_sym_specialinline_token1,
    ACTIONS(770), 1,
      aux_sym_specialinline_token2,
    ACTIONS(772), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(774), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(776), 1,
      aux_sym_specialinline_token3,
    ACTIONS(778), 1,
      aux_sym_specialinline_token4,
    ACTIONS(780), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(782), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(784), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(786), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(788), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(988), 1,
      sym_text,
    ACTIONS(1296), 1,
      anon_sym_COLON_COLON,
    ACTIONS(766), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(794), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(118), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(792), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [4419] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 1,
      aux_sym_specialinline_token1,
    ACTIONS(770), 1,
      aux_sym_specialinline_token2,
    ACTIONS(772), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(774), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(776), 1,
      aux_sym_specialinline_token3,
    ACTIONS(778), 1,
      aux_sym_specialinline_token4,
    ACTIONS(780), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(782), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(784), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(786), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(788), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(988), 1,
      sym_text,
    ACTIONS(1298), 1,
      anon_sym_COLON_COLON,
    ACTIONS(766), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(794), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(118), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(792), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [4497] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1090), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1092), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1094), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1096), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1098), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1102), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1104), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1106), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1108), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1110), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1112), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1300), 1,
      anon_sym_STAR,
    ACTIONS(1302), 1,
      sym_text,
    ACTIONS(1088), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1116), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(143), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1114), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [4575] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1122), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1124), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1126), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1128), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1130), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1132), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1134), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1136), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1138), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1140), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1142), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1300), 1,
      anon_sym_SLASH,
    ACTIONS(1304), 1,
      sym_text,
    ACTIONS(1120), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1146), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(144), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1144), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [4653] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1090), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1092), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1094), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1096), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1098), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1102), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1104), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1106), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1108), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1110), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1112), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1156), 1,
      sym_text,
    ACTIONS(1306), 1,
      anon_sym_STAR,
    ACTIONS(1088), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1116), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(121), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1114), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [4731] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1122), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1124), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1126), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1128), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1130), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1132), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1134), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1136), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1138), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1140), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1142), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1158), 1,
      sym_text,
    ACTIONS(1306), 1,
      anon_sym_SLASH,
    ACTIONS(1120), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1146), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(129), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1144), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [4809] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 1,
      aux_sym_specialinline_token1,
    ACTIONS(770), 1,
      aux_sym_specialinline_token2,
    ACTIONS(772), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(774), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(776), 1,
      aux_sym_specialinline_token3,
    ACTIONS(778), 1,
      aux_sym_specialinline_token4,
    ACTIONS(780), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(782), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(784), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(786), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(788), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1308), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1310), 1,
      sym_text,
    ACTIONS(766), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(794), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(149), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(792), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [4887] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 1,
      aux_sym_specialinline_token1,
    ACTIONS(770), 1,
      aux_sym_specialinline_token2,
    ACTIONS(772), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(774), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(776), 1,
      aux_sym_specialinline_token3,
    ACTIONS(778), 1,
      aux_sym_specialinline_token4,
    ACTIONS(780), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(782), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(784), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(786), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(788), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(988), 1,
      sym_text,
    ACTIONS(1312), 1,
      anon_sym_COLON_COLON,
    ACTIONS(766), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(794), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(118), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(792), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [4965] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 1,
      aux_sym_specialinline_token1,
    ACTIONS(770), 1,
      aux_sym_specialinline_token2,
    ACTIONS(772), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(774), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(776), 1,
      aux_sym_specialinline_token3,
    ACTIONS(778), 1,
      aux_sym_specialinline_token4,
    ACTIONS(780), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(782), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(784), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(786), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(788), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1314), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1316), 1,
      sym_text,
    ACTIONS(766), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(794), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(150), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(792), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [5043] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 1,
      aux_sym_specialinline_token1,
    ACTIONS(770), 1,
      aux_sym_specialinline_token2,
    ACTIONS(772), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(774), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(776), 1,
      aux_sym_specialinline_token3,
    ACTIONS(778), 1,
      aux_sym_specialinline_token4,
    ACTIONS(780), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(782), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(784), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(786), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(788), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(988), 1,
      sym_text,
    ACTIONS(1318), 1,
      anon_sym_COLON_COLON,
    ACTIONS(766), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(794), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(118), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(792), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [5121] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 1,
      aux_sym_specialinline_token1,
    ACTIONS(770), 1,
      aux_sym_specialinline_token2,
    ACTIONS(772), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(774), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(776), 1,
      aux_sym_specialinline_token3,
    ACTIONS(778), 1,
      aux_sym_specialinline_token4,
    ACTIONS(780), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(782), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(784), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(786), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(788), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(988), 1,
      sym_text,
    ACTIONS(1320), 1,
      anon_sym_COLON_COLON,
    ACTIONS(766), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(794), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(118), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(792), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [5199] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 1,
      aux_sym_specialinline_token1,
    ACTIONS(770), 1,
      aux_sym_specialinline_token2,
    ACTIONS(772), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(774), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(776), 1,
      aux_sym_specialinline_token3,
    ACTIONS(778), 1,
      aux_sym_specialinline_token4,
    ACTIONS(780), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(782), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(784), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(786), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(788), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(988), 1,
      sym_text,
    ACTIONS(1322), 1,
      anon_sym_COLON_COLON,
    ACTIONS(766), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(794), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(118), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(792), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [5277] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1090), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1092), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1094), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1096), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1098), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1102), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1104), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1106), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1108), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1110), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1112), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1324), 1,
      anon_sym_STAR,
    ACTIONS(1326), 1,
      sym_text,
    ACTIONS(1088), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1116), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(155), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1114), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [5355] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1122), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1124), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1126), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1128), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1130), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1132), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1134), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1136), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1138), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1140), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1142), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1324), 1,
      anon_sym_SLASH,
    ACTIONS(1328), 1,
      sym_text,
    ACTIONS(1120), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1146), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(156), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1144), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [5433] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 1,
      aux_sym_specialinline_token1,
    ACTIONS(770), 1,
      aux_sym_specialinline_token2,
    ACTIONS(772), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(774), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(776), 1,
      aux_sym_specialinline_token3,
    ACTIONS(778), 1,
      aux_sym_specialinline_token4,
    ACTIONS(780), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(782), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(784), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(786), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(788), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1330), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1332), 1,
      sym_text,
    ACTIONS(766), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(794), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(124), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(792), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [5511] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 1,
      aux_sym_specialinline_token1,
    ACTIONS(770), 1,
      aux_sym_specialinline_token2,
    ACTIONS(772), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(774), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(776), 1,
      aux_sym_specialinline_token3,
    ACTIONS(778), 1,
      aux_sym_specialinline_token4,
    ACTIONS(780), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(782), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(784), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(786), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(788), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(988), 1,
      sym_text,
    ACTIONS(1334), 1,
      anon_sym_COLON_COLON,
    ACTIONS(766), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(794), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(118), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(792), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [5589] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1090), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1092), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1094), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1096), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1098), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1102), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1104), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1106), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1108), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1110), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1112), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1156), 1,
      sym_text,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(1088), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1116), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(121), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1114), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [5667] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1122), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1124), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1126), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1128), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1130), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1132), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1134), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1136), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1138), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1140), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1142), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1158), 1,
      sym_text,
    ACTIONS(1336), 1,
      anon_sym_SLASH,
    ACTIONS(1120), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1146), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(129), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1144), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [5745] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 1,
      aux_sym_specialinline_token1,
    ACTIONS(770), 1,
      aux_sym_specialinline_token2,
    ACTIONS(772), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(774), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(776), 1,
      aux_sym_specialinline_token3,
    ACTIONS(778), 1,
      aux_sym_specialinline_token4,
    ACTIONS(780), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(782), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(784), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(786), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(788), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1338), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1340), 1,
      sym_text,
    ACTIONS(766), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(794), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(119), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(792), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [5823] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 1,
      aux_sym_specialinline_token1,
    ACTIONS(770), 1,
      aux_sym_specialinline_token2,
    ACTIONS(772), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(774), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(776), 1,
      aux_sym_specialinline_token3,
    ACTIONS(778), 1,
      aux_sym_specialinline_token4,
    ACTIONS(780), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(782), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(784), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(786), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(788), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(988), 1,
      sym_text,
    ACTIONS(1342), 1,
      anon_sym_COLON_COLON,
    ACTIONS(766), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(794), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(118), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(792), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [5901] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 1,
      aux_sym_specialinline_token1,
    ACTIONS(770), 1,
      aux_sym_specialinline_token2,
    ACTIONS(772), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(774), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(776), 1,
      aux_sym_specialinline_token3,
    ACTIONS(778), 1,
      aux_sym_specialinline_token4,
    ACTIONS(780), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(782), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(784), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(786), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(788), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1344), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1346), 1,
      sym_text,
    ACTIONS(766), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(794), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(161), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(792), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [5979] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 1,
      aux_sym_specialinline_token1,
    ACTIONS(770), 1,
      aux_sym_specialinline_token2,
    ACTIONS(772), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(774), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(776), 1,
      aux_sym_specialinline_token3,
    ACTIONS(778), 1,
      aux_sym_specialinline_token4,
    ACTIONS(780), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(782), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(784), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(786), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(788), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(988), 1,
      sym_text,
    ACTIONS(1348), 1,
      anon_sym_COLON_COLON,
    ACTIONS(766), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(794), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(118), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(792), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [6057] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 1,
      aux_sym_specialinline_token1,
    ACTIONS(770), 1,
      aux_sym_specialinline_token2,
    ACTIONS(772), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(774), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(776), 1,
      aux_sym_specialinline_token3,
    ACTIONS(778), 1,
      aux_sym_specialinline_token4,
    ACTIONS(780), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(782), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(784), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(786), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(788), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(988), 1,
      sym_text,
    ACTIONS(1350), 1,
      anon_sym_COLON_COLON,
    ACTIONS(766), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(794), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(118), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(792), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [6135] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1090), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1092), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1094), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1096), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1098), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1102), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1104), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1106), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1108), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1110), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1112), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1352), 1,
      anon_sym_STAR,
    ACTIONS(1354), 1,
      sym_text,
    ACTIONS(1088), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1116), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(166), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1114), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [6213] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1122), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1124), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1126), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1128), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1130), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1132), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1134), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1136), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1138), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1140), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1142), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1352), 1,
      anon_sym_SLASH,
    ACTIONS(1356), 1,
      sym_text,
    ACTIONS(1120), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1146), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(167), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1144), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [6291] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 1,
      aux_sym_specialinline_token1,
    ACTIONS(770), 1,
      aux_sym_specialinline_token2,
    ACTIONS(772), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(774), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(776), 1,
      aux_sym_specialinline_token3,
    ACTIONS(778), 1,
      aux_sym_specialinline_token4,
    ACTIONS(780), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(782), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(784), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(786), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(788), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1358), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1360), 1,
      sym_text,
    ACTIONS(766), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(794), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(126), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(792), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [6369] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 1,
      aux_sym_specialinline_token1,
    ACTIONS(770), 1,
      aux_sym_specialinline_token2,
    ACTIONS(772), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(774), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(776), 1,
      aux_sym_specialinline_token3,
    ACTIONS(778), 1,
      aux_sym_specialinline_token4,
    ACTIONS(780), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(782), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(784), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(786), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(788), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(988), 1,
      sym_text,
    ACTIONS(1362), 1,
      anon_sym_COLON_COLON,
    ACTIONS(766), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(794), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(118), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(792), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [6447] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1090), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1092), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1094), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1096), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1098), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1102), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1104), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1106), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1108), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1110), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1112), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1156), 1,
      sym_text,
    ACTIONS(1364), 1,
      anon_sym_STAR,
    ACTIONS(1088), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1116), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(121), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1114), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [6525] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1122), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1124), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1126), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(1128), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(1130), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1132), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1134), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(1136), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(1138), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(1140), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(1142), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1158), 1,
      sym_text,
    ACTIONS(1364), 1,
      anon_sym_SLASH,
    ACTIONS(1120), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(1146), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(129), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(1144), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [6603] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 1,
      aux_sym_specialinline_token1,
    ACTIONS(770), 1,
      aux_sym_specialinline_token2,
    ACTIONS(772), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(774), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(776), 1,
      aux_sym_specialinline_token3,
    ACTIONS(778), 1,
      aux_sym_specialinline_token4,
    ACTIONS(780), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(782), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(784), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(786), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(788), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1366), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1368), 1,
      sym_text,
    ACTIONS(766), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(794), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(172), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(792), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [6681] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 1,
      aux_sym_specialinline_token1,
    ACTIONS(770), 1,
      aux_sym_specialinline_token2,
    ACTIONS(772), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(774), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(776), 1,
      aux_sym_specialinline_token3,
    ACTIONS(778), 1,
      aux_sym_specialinline_token4,
    ACTIONS(780), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(782), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(784), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(786), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(788), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(988), 1,
      sym_text,
    ACTIONS(1370), 1,
      anon_sym_COLON_COLON,
    ACTIONS(766), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(794), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(118), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(792), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [6759] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 1,
      aux_sym_specialinline_token1,
    ACTIONS(770), 1,
      aux_sym_specialinline_token2,
    ACTIONS(772), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(774), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(776), 1,
      aux_sym_specialinline_token3,
    ACTIONS(778), 1,
      aux_sym_specialinline_token4,
    ACTIONS(780), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(782), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(784), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(786), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(788), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1372), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1374), 1,
      sym_text,
    ACTIONS(766), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(794), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(120), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(792), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [6837] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 1,
      aux_sym_specialinline_token1,
    ACTIONS(770), 1,
      aux_sym_specialinline_token2,
    ACTIONS(772), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(774), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(776), 1,
      aux_sym_specialinline_token3,
    ACTIONS(778), 1,
      aux_sym_specialinline_token4,
    ACTIONS(780), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(782), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(784), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(786), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(788), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(988), 1,
      sym_text,
    ACTIONS(1376), 1,
      anon_sym_COLON_COLON,
    ACTIONS(766), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(794), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(118), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(792), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [6915] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 1,
      aux_sym_specialinline_token1,
    ACTIONS(770), 1,
      aux_sym_specialinline_token2,
    ACTIONS(772), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(774), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(776), 1,
      aux_sym_specialinline_token3,
    ACTIONS(778), 1,
      aux_sym_specialinline_token4,
    ACTIONS(780), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(782), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(784), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(786), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(788), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(988), 1,
      sym_text,
    ACTIONS(1378), 1,
      anon_sym_COLON_COLON,
    ACTIONS(766), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(794), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(118), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(792), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [6993] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 1,
      aux_sym_specialinline_token1,
    ACTIONS(770), 1,
      aux_sym_specialinline_token2,
    ACTIONS(772), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(774), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(776), 1,
      aux_sym_specialinline_token3,
    ACTIONS(778), 1,
      aux_sym_specialinline_token4,
    ACTIONS(780), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(782), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(784), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(786), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(788), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(1380), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1382), 1,
      sym_text,
    ACTIONS(766), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(794), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(140), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      aux_sym_inline_repeat1,
    ACTIONS(792), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [7071] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_COLONmath_COLON,
    ACTIONS(39), 1,
      anon_sym_COLONcode_COLON,
    ACTIONS(41), 1,
      aux_sym_specialinline_token3,
    ACTIONS(43), 1,
      aux_sym_specialinline_token4,
    ACTIONS(45), 1,
      anon_sym_COLONref_COLON,
    ACTIONS(47), 1,
      anon_sym_COLONprevious_COLON,
    ACTIONS(49), 1,
      anon_sym_COLONurl_COLON,
    ACTIONS(51), 1,
      anon_sym_COLONcite_COLON,
    ACTIONS(53), 1,
      anon_sym_COLONqed_COLON,
    ACTIONS(802), 1,
      aux_sym_specialinline_token2,
    ACTIONS(1384), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1386), 1,
      sym_text,
    ACTIONS(31), 3,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
    ACTIONS(59), 3,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
    STATE(91), 5,
      sym_inline,
      sym_construct,
      sym_specialinline,
      sym_specialconstruct,
      sym__paragraphcontent_no_special,
    ACTIONS(57), 16,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
  [7146] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1390), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1388), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7191] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1394), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1392), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7236] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1398), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1396), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7281] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1402), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1400), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7326] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1406), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1404), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7371] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1410), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1408), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7416] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1414), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1412), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7461] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1418), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1416), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7506] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1422), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1420), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7551] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1426), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1424), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7596] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1430), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1428), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7641] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1434), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1432), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7686] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1438), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1436), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7731] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1442), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1440), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7776] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1446), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1444), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7821] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1450), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1448), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7866] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1454), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1452), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7911] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1458), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1456), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [7956] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1462), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1460), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8001] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1454), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1452), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8046] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1466), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1464), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8091] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(756), 1,
      aux_sym_specialinline_token1,
    ACTIONS(754), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8136] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1470), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1468), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8181] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(680), 1,
      aux_sym_specialinline_token1,
    ACTIONS(678), 36,
      sym_text,
      sym_paragraph_end,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8226] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1394), 1,
      anon_sym_COLON,
    ACTIONS(1392), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8270] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1474), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1472), 35,
      sym_text,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8314] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1390), 1,
      anon_sym_COLON,
    ACTIONS(1388), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8358] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1414), 1,
      anon_sym_COLON,
    ACTIONS(1412), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8402] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1462), 1,
      anon_sym_COLON,
    ACTIONS(1460), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8446] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1450), 1,
      anon_sym_COLON,
    ACTIONS(1448), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8490] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1430), 1,
      anon_sym_COLON,
    ACTIONS(1428), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8534] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1466), 1,
      anon_sym_COLON,
    ACTIONS(1464), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8578] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1438), 1,
      anon_sym_COLON,
    ACTIONS(1436), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8622] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1454), 1,
      anon_sym_COLON,
    ACTIONS(1452), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8666] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1454), 1,
      anon_sym_COLON,
    ACTIONS(1452), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8710] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1470), 1,
      anon_sym_COLON,
    ACTIONS(1468), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8754] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1418), 1,
      anon_sym_COLON,
    ACTIONS(1416), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8798] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1442), 1,
      anon_sym_COLON,
    ACTIONS(1440), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8842] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1446), 1,
      anon_sym_COLON,
    ACTIONS(1444), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8886] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1458), 1,
      anon_sym_COLON,
    ACTIONS(1456), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8930] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1398), 1,
      anon_sym_COLON,
    ACTIONS(1396), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [8974] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1410), 1,
      anon_sym_COLON,
    ACTIONS(1408), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9018] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1422), 1,
      anon_sym_COLON,
    ACTIONS(1420), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9062] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1402), 1,
      anon_sym_COLON,
    ACTIONS(1400), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9106] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1406), 1,
      anon_sym_COLON,
    ACTIONS(1404), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9150] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1426), 1,
      anon_sym_COLON,
    ACTIONS(1424), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9194] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1434), 1,
      anon_sym_COLON,
    ACTIONS(1432), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9238] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1478), 1,
      aux_sym_specialinline_token1,
    ACTIONS(1476), 35,
      sym_text,
      aux_sym_mathblock_token1,
      anon_sym_COLONmathblock_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9282] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1466), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1464), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_SLASH,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9325] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1454), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1452), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_SLASH,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9368] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1454), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1452), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_SLASH,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9411] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1470), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1468), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_SLASH,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9454] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1394), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1392), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_SLASH,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9497] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1418), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1416), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_SLASH,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9540] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1442), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1440), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_SLASH,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9583] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1446), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1444), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_SLASH,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9626] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1458), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1456), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_SLASH,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9669] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1398), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1396), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_SLASH,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9712] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1410), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1408), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_SLASH,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9755] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1422), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1420), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_SLASH,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9798] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1402), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1400), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_SLASH,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9841] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1406), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1404), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_SLASH,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9884] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1426), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1424), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_SLASH,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9927] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1434), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1432), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_SLASH,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [9970] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1450), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1448), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_SLASH,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10013] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1430), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1428), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_SLASH,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10056] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1390), 1,
      anon_sym_COLON,
    ACTIONS(1388), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10099] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1414), 1,
      anon_sym_COLON,
    ACTIONS(1412), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10142] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1462), 1,
      anon_sym_COLON,
    ACTIONS(1460), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10185] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1450), 1,
      anon_sym_COLON,
    ACTIONS(1448), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10228] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1430), 1,
      anon_sym_COLON,
    ACTIONS(1428), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10271] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1466), 1,
      anon_sym_COLON,
    ACTIONS(1464), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10314] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1438), 1,
      anon_sym_COLON,
    ACTIONS(1436), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10357] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1454), 1,
      anon_sym_COLON,
    ACTIONS(1452), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10400] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1454), 1,
      anon_sym_COLON,
    ACTIONS(1452), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10443] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1470), 1,
      anon_sym_COLON,
    ACTIONS(1468), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10486] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1394), 1,
      anon_sym_COLON,
    ACTIONS(1392), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10529] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1418), 1,
      anon_sym_COLON,
    ACTIONS(1416), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10572] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1442), 1,
      anon_sym_COLON,
    ACTIONS(1440), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10615] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1446), 1,
      anon_sym_COLON,
    ACTIONS(1444), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10658] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1458), 1,
      anon_sym_COLON,
    ACTIONS(1456), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10701] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1398), 1,
      anon_sym_COLON,
    ACTIONS(1396), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10744] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1462), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1460), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_SLASH,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10787] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1422), 1,
      anon_sym_COLON,
    ACTIONS(1420), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10830] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1402), 1,
      anon_sym_COLON,
    ACTIONS(1400), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10873] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1406), 1,
      anon_sym_COLON,
    ACTIONS(1404), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10916] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1426), 1,
      anon_sym_COLON,
    ACTIONS(1424), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [10959] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1434), 1,
      anon_sym_COLON,
    ACTIONS(1432), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11002] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11043] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1472), 35,
      sym_text,
      anon_sym_COLON_COLON,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11084] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1390), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1388), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11127] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1414), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1412), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11170] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1462), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1460), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11213] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1450), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1448), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11256] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1430), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1428), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11299] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1466), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1464), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11342] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1438), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1436), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11385] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1454), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1452), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11428] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1454), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1452), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11471] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1470), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1468), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11514] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1394), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1392), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11557] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1418), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1416), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11600] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1442), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1440), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11643] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1446), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1444), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11686] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1458), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1456), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11729] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1414), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1412), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_SLASH,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11772] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1398), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1396), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11815] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1410), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1408), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11858] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1422), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1420), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11901] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1402), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1400), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11944] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1406), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1404), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [11987] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1438), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1436), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_SLASH,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [12030] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1426), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1424), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [12073] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1434), 1,
      aux_sym_specialinline_token3,
    ACTIONS(1432), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      anon_sym_STAR,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [12116] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1390), 1,
      aux_sym_specialinline_token4,
    ACTIONS(1388), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      anon_sym_SLASH,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [12159] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1410), 1,
      anon_sym_COLON,
    ACTIONS(1408), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [12202] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1480), 34,
      sym_text,
      anon_sym_COLONprev_COLON,
      anon_sym_COLONprev2_COLON,
      anon_sym_COLONprev3_COLON,
      aux_sym_specialinline_token1,
      aux_sym_specialinline_token2,
      anon_sym_COLONmath_COLON,
      anon_sym_COLONcode_COLON,
      aux_sym_specialinline_token3,
      aux_sym_specialinline_token4,
      anon_sym_COLONref_COLON,
      anon_sym_COLONprevious_COLON,
      anon_sym_COLONurl_COLON,
      anon_sym_COLONcite_COLON,
      anon_sym_COLONqed_COLON,
      anon_sym_COLONassume_COLON,
      anon_sym_COLONsuppose_COLON,
      anon_sym_COLONprove_COLON,
      anon_sym_COLONthen_COLON,
      anon_sym_COLONnew_COLON,
      anon_sym_COLONlet_COLON,
      anon_sym_COLONcase_COLON,
      anon_sym_COLONdefine_COLON,
      anon_sym_COLONwrite_COLON,
      anon_sym_COLONwlog_COLON,
      anon_sym_COLONsuffices_COLON,
      anon_sym_COLONclaim_COLON,
      anon_sym_COLON_PIPE_DASH_COLON,
      anon_sym_COLONu22a2_COLON,
      anon_sym_COLONpick_COLON,
      anon_sym_COLONst_COLON,
      anon_sym_COLONdraft_COLON,
      anon_sym_COLONnote_COLON,
      anon_sym_COLONspan_COLON,
  [12242] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1482), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1484), 1,
      anon_sym_COLONcaption_COLON,
    ACTIONS(1486), 1,
      anon_sym_COLONthead_COLON,
    ACTIONS(1488), 1,
      anon_sym_COLONtbody_COLON,
    STATE(320), 1,
      sym_metakey_bool,
    STATE(348), 1,
      sym_blockmeta,
    STATE(352), 1,
      sym_thead,
    STATE(362), 1,
      sym_tbody,
    STATE(378), 1,
      sym_metakey_list,
    STATE(432), 1,
      sym_metakey_text,
    STATE(434), 1,
      sym_metakey_any,
    STATE(476), 1,
      sym_caption,
    STATE(293), 2,
      sym_pair,
      aux_sym_blockmeta_repeat1,
    ACTIONS(67), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(69), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1490), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(63), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [12313] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(320), 1,
      sym_metakey_bool,
    STATE(378), 1,
      sym_metakey_list,
    STATE(432), 1,
      sym_metakey_text,
    STATE(434), 1,
      sym_metakey_any,
    STATE(294), 2,
      sym_pair,
      aux_sym_blockmeta_repeat1,
    ACTIONS(67), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(69), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(113), 4,
      anon_sym_COLON_COLON,
      anon_sym_COLONcaption_COLON,
      anon_sym_COLONthead_COLON,
      anon_sym_COLONtbody_COLON,
    ACTIONS(1490), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(63), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [12366] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(320), 1,
      sym_metakey_bool,
    STATE(378), 1,
      sym_metakey_list,
    STATE(432), 1,
      sym_metakey_text,
    STATE(434), 1,
      sym_metakey_any,
    STATE(294), 2,
      sym_pair,
      aux_sym_blockmeta_repeat1,
    ACTIONS(107), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(110), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(97), 4,
      anon_sym_COLON_COLON,
      anon_sym_COLONcaption_COLON,
      anon_sym_COLONthead_COLON,
      anon_sym_COLONtbody_COLON,
    ACTIONS(1492), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(101), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [12419] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1497), 1,
      sym_asis_two_dollars_text,
    STATE(329), 1,
      sym_metakey_bool,
    STATE(366), 1,
      sym_metakey_list,
    STATE(456), 1,
      sym_metakey_text,
    STATE(459), 1,
      sym_metakey_any,
    STATE(489), 1,
      sym_blockmeta,
    STATE(304), 2,
      sym_pair,
      aux_sym_blockmeta_repeat1,
    ACTIONS(67), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(69), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1495), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(63), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [12472] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1501), 1,
      sym_asis_halmos_text,
    STATE(342), 1,
      sym_metakey_bool,
    STATE(372), 1,
      sym_metakey_list,
    STATE(404), 1,
      sym_metakey_text,
    STATE(406), 1,
      sym_metakey_any,
    STATE(576), 1,
      sym_blockmeta,
    STATE(302), 2,
      sym_pair,
      aux_sym_blockmeta_repeat1,
    ACTIONS(67), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(69), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1499), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(63), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [12525] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1503), 1,
      sym_asis_halmos_text,
    STATE(342), 1,
      sym_metakey_bool,
    STATE(372), 1,
      sym_metakey_list,
    STATE(404), 1,
      sym_metakey_text,
    STATE(406), 1,
      sym_metakey_any,
    STATE(582), 1,
      sym_blockmeta,
    STATE(302), 2,
      sym_pair,
      aux_sym_blockmeta_repeat1,
    ACTIONS(67), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(69), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1499), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(63), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [12578] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1505), 1,
      sym_asis_halmos_text,
    STATE(342), 1,
      sym_metakey_bool,
    STATE(372), 1,
      sym_metakey_list,
    STATE(404), 1,
      sym_metakey_text,
    STATE(406), 1,
      sym_metakey_any,
    STATE(574), 1,
      sym_blockmeta,
    STATE(302), 2,
      sym_pair,
      aux_sym_blockmeta_repeat1,
    ACTIONS(67), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(69), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1499), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(63), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [12631] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1509), 1,
      sym_asis_three_backticks_text,
    STATE(340), 1,
      sym_metakey_bool,
    STATE(375), 1,
      sym_metakey_list,
    STATE(399), 1,
      sym_metakey_text,
    STATE(419), 1,
      sym_metakey_any,
    STATE(545), 1,
      sym_blockmeta,
    STATE(306), 2,
      sym_pair,
      aux_sym_blockmeta_repeat1,
    ACTIONS(67), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(69), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1507), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(63), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [12684] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1511), 1,
      sym_asis_halmos_text,
    STATE(342), 1,
      sym_metakey_bool,
    STATE(372), 1,
      sym_metakey_list,
    STATE(404), 1,
      sym_metakey_text,
    STATE(406), 1,
      sym_metakey_any,
    STATE(491), 1,
      sym_blockmeta,
    STATE(302), 2,
      sym_pair,
      aux_sym_blockmeta_repeat1,
    ACTIONS(67), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(69), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1499), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(63), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [12737] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1513), 1,
      sym_asis_two_dollars_text,
    STATE(329), 1,
      sym_metakey_bool,
    STATE(366), 1,
      sym_metakey_list,
    STATE(456), 1,
      sym_metakey_text,
    STATE(459), 1,
      sym_metakey_any,
    STATE(575), 1,
      sym_blockmeta,
    STATE(304), 2,
      sym_pair,
      aux_sym_blockmeta_repeat1,
    ACTIONS(67), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(69), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1495), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(63), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [12790] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(113), 1,
      sym_asis_halmos_text,
    STATE(342), 1,
      sym_metakey_bool,
    STATE(372), 1,
      sym_metakey_list,
    STATE(404), 1,
      sym_metakey_text,
    STATE(406), 1,
      sym_metakey_any,
    STATE(303), 2,
      sym_pair,
      aux_sym_blockmeta_repeat1,
    ACTIONS(67), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(69), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1499), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(63), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [12840] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(97), 1,
      sym_asis_halmos_text,
    STATE(342), 1,
      sym_metakey_bool,
    STATE(372), 1,
      sym_metakey_list,
    STATE(404), 1,
      sym_metakey_text,
    STATE(406), 1,
      sym_metakey_any,
    STATE(303), 2,
      sym_pair,
      aux_sym_blockmeta_repeat1,
    ACTIONS(107), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(110), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1515), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(101), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [12890] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(113), 1,
      sym_asis_two_dollars_text,
    STATE(329), 1,
      sym_metakey_bool,
    STATE(366), 1,
      sym_metakey_list,
    STATE(456), 1,
      sym_metakey_text,
    STATE(459), 1,
      sym_metakey_any,
    STATE(305), 2,
      sym_pair,
      aux_sym_blockmeta_repeat1,
    ACTIONS(67), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(69), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1495), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(63), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [12940] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(97), 1,
      sym_asis_two_dollars_text,
    STATE(329), 1,
      sym_metakey_bool,
    STATE(366), 1,
      sym_metakey_list,
    STATE(456), 1,
      sym_metakey_text,
    STATE(459), 1,
      sym_metakey_any,
    STATE(305), 2,
      sym_pair,
      aux_sym_blockmeta_repeat1,
    ACTIONS(107), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(110), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1518), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(101), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [12990] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(113), 1,
      sym_asis_three_backticks_text,
    STATE(340), 1,
      sym_metakey_bool,
    STATE(375), 1,
      sym_metakey_list,
    STATE(399), 1,
      sym_metakey_text,
    STATE(419), 1,
      sym_metakey_any,
    STATE(307), 2,
      sym_pair,
      aux_sym_blockmeta_repeat1,
    ACTIONS(67), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(69), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1507), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(63), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [13040] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(97), 1,
      sym_asis_three_backticks_text,
    STATE(340), 1,
      sym_metakey_bool,
    STATE(375), 1,
      sym_metakey_list,
    STATE(399), 1,
      sym_metakey_text,
    STATE(419), 1,
      sym_metakey_any,
    STATE(307), 2,
      sym_pair,
      aux_sym_blockmeta_repeat1,
    ACTIONS(107), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(110), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1521), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(101), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [13090] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(313), 1,
      aux_sym_inlinemeta_repeat1,
    STATE(380), 1,
      sym_metakey_list,
    STATE(435), 1,
      sym_inlinemetapair,
    STATE(441), 1,
      sym_metakey_text,
    STATE(444), 1,
      sym_metakey_bool,
    STATE(446), 1,
      sym_metakey_any,
    ACTIONS(1526), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(1528), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1490), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(1524), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [13139] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(313), 1,
      aux_sym_inlinemeta_repeat1,
    STATE(380), 1,
      sym_metakey_list,
    STATE(441), 1,
      sym_metakey_text,
    STATE(442), 1,
      sym_inlinemetapair,
    STATE(444), 1,
      sym_metakey_bool,
    STATE(446), 1,
      sym_metakey_any,
    ACTIONS(1526), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(1528), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1490), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(1524), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [13188] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(314), 1,
      aux_sym_inlinemeta_repeat1,
    STATE(380), 1,
      sym_metakey_list,
    STATE(441), 1,
      sym_metakey_text,
    STATE(444), 1,
      sym_metakey_bool,
    STATE(446), 1,
      sym_metakey_any,
    STATE(465), 1,
      sym_inlinemetapair,
    ACTIONS(1526), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(1528), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1490), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(1524), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [13237] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(308), 1,
      aux_sym_inlinemeta_repeat1,
    STATE(380), 1,
      sym_metakey_list,
    STATE(440), 1,
      sym_inlinemetapair,
    STATE(441), 1,
      sym_metakey_text,
    STATE(444), 1,
      sym_metakey_bool,
    STATE(446), 1,
      sym_metakey_any,
    ACTIONS(1526), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(1528), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1490), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(1524), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [13286] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(141), 25,
      anon_sym_COLON_COLON,
      anon_sym_COLONcaption_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLONthead_COLON,
      anon_sym_COLONtbody_COLON,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [13317] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(313), 1,
      aux_sym_inlinemeta_repeat1,
    STATE(380), 1,
      sym_metakey_list,
    STATE(441), 1,
      sym_metakey_text,
    STATE(444), 1,
      sym_metakey_bool,
    STATE(446), 1,
      sym_metakey_any,
    STATE(534), 1,
      sym_inlinemetapair,
    ACTIONS(1536), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(1539), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1533), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(1530), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [13366] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(313), 1,
      aux_sym_inlinemeta_repeat1,
    STATE(380), 1,
      sym_metakey_list,
    STATE(400), 1,
      sym_inlinemetapair,
    STATE(441), 1,
      sym_metakey_text,
    STATE(444), 1,
      sym_metakey_bool,
    STATE(446), 1,
      sym_metakey_any,
    ACTIONS(1526), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(1528), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1490), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(1524), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [13415] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(316), 1,
      aux_sym_inlinemeta_repeat1,
    STATE(380), 1,
      sym_metakey_list,
    STATE(410), 1,
      sym_inlinemetapair,
    STATE(441), 1,
      sym_metakey_text,
    STATE(444), 1,
      sym_metakey_bool,
    STATE(446), 1,
      sym_metakey_any,
    ACTIONS(1526), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(1528), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1490), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(1524), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [13464] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(313), 1,
      aux_sym_inlinemeta_repeat1,
    STATE(380), 1,
      sym_metakey_list,
    STATE(412), 1,
      sym_inlinemetapair,
    STATE(441), 1,
      sym_metakey_text,
    STATE(444), 1,
      sym_metakey_bool,
    STATE(446), 1,
      sym_metakey_any,
    ACTIONS(1526), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(1528), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1490), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(1524), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [13513] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(318), 1,
      aux_sym_inlinemeta_repeat1,
    STATE(380), 1,
      sym_metakey_list,
    STATE(423), 1,
      sym_inlinemetapair,
    STATE(441), 1,
      sym_metakey_text,
    STATE(444), 1,
      sym_metakey_bool,
    STATE(446), 1,
      sym_metakey_any,
    ACTIONS(1526), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(1528), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1490), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(1524), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [13562] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(313), 1,
      aux_sym_inlinemeta_repeat1,
    STATE(380), 1,
      sym_metakey_list,
    STATE(426), 1,
      sym_inlinemetapair,
    STATE(441), 1,
      sym_metakey_text,
    STATE(444), 1,
      sym_metakey_bool,
    STATE(446), 1,
      sym_metakey_any,
    ACTIONS(1526), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(1528), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1490), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(1524), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [13611] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(309), 1,
      aux_sym_inlinemeta_repeat1,
    STATE(380), 1,
      sym_metakey_list,
    STATE(441), 1,
      sym_metakey_text,
    STATE(444), 1,
      sym_metakey_bool,
    STATE(446), 1,
      sym_metakey_any,
    STATE(473), 1,
      sym_inlinemetapair,
    ACTIONS(1526), 3,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
    ACTIONS(1528), 3,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
    ACTIONS(1490), 4,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
    ACTIONS(1524), 9,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
  [13660] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(133), 23,
      anon_sym_COLON_COLON,
      anon_sym_COLONcaption_COLON,
      anon_sym_COLONthead_COLON,
      anon_sym_COLONtbody_COLON,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [13689] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(129), 23,
      anon_sym_COLON_COLON,
      anon_sym_COLONcaption_COLON,
      anon_sym_COLONthead_COLON,
      anon_sym_COLONtbody_COLON,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [13718] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 23,
      anon_sym_COLON_COLON,
      anon_sym_COLONcaption_COLON,
      anon_sym_COLONthead_COLON,
      anon_sym_COLONtbody_COLON,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [13747] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 23,
      anon_sym_COLON_COLON,
      anon_sym_COLONcaption_COLON,
      anon_sym_COLONthead_COLON,
      anon_sym_COLONtbody_COLON,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [13776] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(137), 23,
      anon_sym_COLON_COLON,
      anon_sym_COLONcaption_COLON,
      anon_sym_COLONthead_COLON,
      anon_sym_COLONtbody_COLON,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [13805] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(117), 23,
      anon_sym_COLON_COLON,
      anon_sym_COLONcaption_COLON,
      anon_sym_COLONthead_COLON,
      anon_sym_COLONtbody_COLON,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [13834] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(117), 20,
      sym_asis_halmos_text,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [13860] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(117), 20,
      sym_asis_two_dollars_text,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [13886] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 20,
      sym_asis_halmos_text,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [13912] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(133), 20,
      sym_asis_two_dollars_text,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [13938] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 20,
      sym_asis_two_dollars_text,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [13964] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(129), 20,
      sym_asis_two_dollars_text,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [13990] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(129), 20,
      sym_asis_halmos_text,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [14016] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(141), 20,
      sym_asis_three_backticks_text,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [14042] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 20,
      sym_asis_two_dollars_text,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [14068] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(137), 20,
      sym_asis_two_dollars_text,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [14094] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 20,
      sym_asis_halmos_text,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [14120] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(141), 20,
      sym_asis_halmos_text,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [14146] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(141), 20,
      sym_asis_two_dollars_text,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [14172] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(129), 20,
      sym_asis_three_backticks_text,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [14198] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(133), 20,
      sym_asis_three_backticks_text,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [14224] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(117), 20,
      sym_asis_three_backticks_text,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [14250] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(133), 20,
      sym_asis_halmos_text,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [14276] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 20,
      sym_asis_three_backticks_text,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [14302] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 20,
      sym_asis_three_backticks_text,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [14328] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(137), 20,
      sym_asis_three_backticks_text,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [14354] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(137), 20,
      sym_asis_halmos_text,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [14380] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1542), 19,
      anon_sym_COLONaffiliation_COLON,
      anon_sym_COLONemail_COLON,
      anon_sym_COLONlabel_COLON,
      anon_sym_COLONname_COLON,
      anon_sym_COLONreftext_COLON,
      anon_sym_COLONtitle_COLON,
      anon_sym_COLONgoal_COLON,
      anon_sym_COLONlang_COLON,
      anon_sym_COLONicon_COLON,
      anon_sym_COLONnonum_COLON,
      anon_sym_COLONstrong_COLON,
      anon_sym_COLONemphas_COLON,
      anon_sym_COLONisclaim_COLON,
      anon_sym_COLONkeywords_COLON,
      anon_sym_COLONmsc_COLON,
      anon_sym_COLONtypes_COLON,
      anon_sym_COLONdate_COLON,
      anon_sym_COLONpath_COLON,
      anon_sym_COLONscale_COLON,
  [14405] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1484), 1,
      anon_sym_COLONcaption_COLON,
    ACTIONS(1486), 1,
      anon_sym_COLONthead_COLON,
    ACTIONS(1488), 1,
      anon_sym_COLONtbody_COLON,
    ACTIONS(1544), 1,
      anon_sym_COLON_COLON,
    STATE(351), 1,
      sym_thead,
    STATE(367), 1,
      sym_tbody,
    STATE(552), 1,
      sym_caption,
  [14430] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1546), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1548), 1,
      anon_sym_COLONtr_COLON,
    STATE(349), 3,
      sym_tr,
      sym_trshort,
      aux_sym_thead_repeat1,
  [14445] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1551), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1553), 1,
      anon_sym_COLONtr_COLON,
    STATE(349), 3,
      sym_tr,
      sym_trshort,
      aux_sym_thead_repeat1,
  [14460] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1484), 1,
      anon_sym_COLONcaption_COLON,
    ACTIONS(1488), 1,
      anon_sym_COLONtbody_COLON,
    ACTIONS(1555), 1,
      anon_sym_COLON_COLON,
    STATE(379), 1,
      sym_tbody,
    STATE(587), 1,
      sym_caption,
  [14479] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1484), 1,
      anon_sym_COLONcaption_COLON,
    ACTIONS(1488), 1,
      anon_sym_COLONtbody_COLON,
    ACTIONS(1557), 1,
      anon_sym_COLON_COLON,
    STATE(368), 1,
      sym_tbody,
    STATE(602), 1,
      sym_caption,
  [14498] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1553), 1,
      anon_sym_COLONtr_COLON,
    ACTIONS(1559), 1,
      anon_sym_COLON_COLON,
    STATE(349), 3,
      sym_tr,
      sym_trshort,
      aux_sym_thead_repeat1,
  [14513] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1561), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1563), 1,
      anon_sym_AT,
    STATE(360), 2,
      sym_bibitem,
      aux_sym_bibtex_repeat1,
  [14527] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(790), 1,
      anon_sym_COLONtd_COLON,
    ACTIONS(1565), 1,
      anon_sym_COLON_COLON,
    STATE(358), 2,
      sym_td,
      aux_sym_tr_repeat1,
  [14541] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1553), 1,
      anon_sym_COLONtr_COLON,
    STATE(353), 3,
      sym_tr,
      sym_trshort,
      aux_sym_thead_repeat1,
  [14553] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1553), 1,
      anon_sym_COLONtr_COLON,
    STATE(350), 3,
      sym_tr,
      sym_trshort,
      aux_sym_thead_repeat1,
  [14565] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1567), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1569), 1,
      anon_sym_COLONtd_COLON,
    STATE(358), 2,
      sym_td,
      aux_sym_tr_repeat1,
  [14579] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1572), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1574), 1,
      anon_sym_AT,
    STATE(359), 2,
      sym_bibitem,
      aux_sym_bibtex_repeat1,
  [14593] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1563), 1,
      anon_sym_AT,
    ACTIONS(1577), 1,
      anon_sym_COLON_COLON,
    STATE(359), 2,
      sym_bibitem,
      aux_sym_bibtex_repeat1,
  [14607] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1579), 1,
      ts_builtin_sym_end,
    ACTIONS(1581), 1,
      anon_sym_COLONbibtex_COLON,
    STATE(508), 1,
      sym_bibtex,
  [14620] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1484), 1,
      anon_sym_COLONcaption_COLON,
    ACTIONS(1583), 1,
      anon_sym_COLON_COLON,
    STATE(623), 1,
      sym_caption,
  [14633] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1585), 1,
      aux_sym_bibitempair_token1,
    STATE(364), 1,
      aux_sym_bibitem_repeat1,
    STATE(445), 1,
      sym_bibitempair,
  [14646] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1585), 1,
      aux_sym_bibitempair_token1,
    STATE(365), 1,
      aux_sym_bibitem_repeat1,
    STATE(449), 1,
      sym_bibitempair,
  [14659] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1587), 1,
      aux_sym_bibitempair_token1,
    STATE(365), 1,
      aux_sym_bibitem_repeat1,
    STATE(539), 1,
      sym_bibitempair,
  [14672] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1590), 1,
      anon_sym_LBRACE,
    ACTIONS(1592), 1,
      sym_text,
    STATE(331), 1,
      sym_metaval_list,
  [14685] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1484), 1,
      anon_sym_COLONcaption_COLON,
    ACTIONS(1594), 1,
      anon_sym_COLON_COLON,
    STATE(628), 1,
      sym_caption,
  [14698] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1484), 1,
      anon_sym_COLONcaption_COLON,
    ACTIONS(1596), 1,
      anon_sym_COLON_COLON,
    STATE(478), 1,
      sym_caption,
  [14711] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1598), 1,
      anon_sym_LBRACE,
    ACTIONS(1600), 1,
      sym_asis_dollar_text,
    STATE(533), 1,
      sym_inlinemeta,
  [14724] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1602), 1,
      anon_sym_LBRACE,
    ACTIONS(1604), 1,
      sym_asis_backtick_text,
    STATE(516), 1,
      sym_inlinemeta,
  [14737] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1581), 1,
      anon_sym_COLONbibtex_COLON,
    ACTIONS(1606), 1,
      ts_builtin_sym_end,
    STATE(498), 1,
      sym_bibtex,
  [14750] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1608), 1,
      anon_sym_LBRACE,
    ACTIONS(1610), 1,
      sym_text,
    STATE(332), 1,
      sym_metaval_list,
  [14763] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1612), 1,
      anon_sym_LBRACE,
    ACTIONS(1614), 1,
      sym_asis_halmos_text,
    STATE(640), 1,
      sym_inlinemeta,
  [14776] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1612), 1,
      anon_sym_LBRACE,
    ACTIONS(1616), 1,
      sym_asis_halmos_text,
    STATE(632), 1,
      sym_inlinemeta,
  [14789] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1618), 1,
      anon_sym_LBRACE,
    ACTIONS(1620), 1,
      sym_text,
    STATE(339), 1,
      sym_metaval_list,
  [14802] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1622), 3,
      anon_sym_COLON_COLON,
      anon_sym_COLONcaption_COLON,
      anon_sym_COLONtbody_COLON,
  [14811] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1624), 1,
      anon_sym_LBRACE,
    ACTIONS(1626), 1,
      sym_text,
    STATE(15), 1,
      sym_metaval_list,
  [14824] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1628), 1,
      anon_sym_LBRACE,
    ACTIONS(1630), 1,
      sym_text,
    STATE(321), 1,
      sym_metaval_list,
  [14837] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1484), 1,
      anon_sym_COLONcaption_COLON,
    ACTIONS(1632), 1,
      anon_sym_COLON_COLON,
    STATE(479), 1,
      sym_caption,
  [14850] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1634), 1,
      anon_sym_LBRACE,
    ACTIONS(1636), 1,
      sym_upto_brace_or_comma_text,
    STATE(428), 1,
      sym_metaval_list_inline,
  [14863] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1598), 1,
      anon_sym_LBRACE,
    ACTIONS(1638), 1,
      sym_asis_dollar_text,
    STATE(578), 1,
      sym_inlinemeta,
  [14876] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1602), 1,
      anon_sym_LBRACE,
    ACTIONS(1640), 1,
      sym_asis_backtick_text,
    STATE(579), 1,
      sym_inlinemeta,
  [14889] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1612), 1,
      anon_sym_LBRACE,
    ACTIONS(1642), 1,
      sym_asis_halmos_text,
    STATE(580), 1,
      sym_inlinemeta,
  [14902] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1612), 1,
      anon_sym_LBRACE,
    ACTIONS(1644), 1,
      sym_asis_halmos_text,
    STATE(581), 1,
      sym_inlinemeta,
  [14915] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1598), 1,
      anon_sym_LBRACE,
    ACTIONS(1646), 1,
      sym_asis_dollar_text,
    STATE(595), 1,
      sym_inlinemeta,
  [14928] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1602), 1,
      anon_sym_LBRACE,
    ACTIONS(1648), 1,
      sym_asis_backtick_text,
    STATE(596), 1,
      sym_inlinemeta,
  [14941] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1612), 1,
      anon_sym_LBRACE,
    ACTIONS(1650), 1,
      sym_asis_halmos_text,
    STATE(597), 1,
      sym_inlinemeta,
  [14954] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1612), 1,
      anon_sym_LBRACE,
    ACTIONS(1652), 1,
      sym_asis_halmos_text,
    STATE(598), 1,
      sym_inlinemeta,
  [14967] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1612), 1,
      anon_sym_LBRACE,
    ACTIONS(1654), 1,
      sym_asis_halmos_text,
    STATE(503), 1,
      sym_inlinemeta,
  [14980] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1598), 1,
      anon_sym_LBRACE,
    ACTIONS(1656), 1,
      sym_asis_dollar_text,
    STATE(612), 1,
      sym_inlinemeta,
  [14993] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1602), 1,
      anon_sym_LBRACE,
    ACTIONS(1658), 1,
      sym_asis_backtick_text,
    STATE(613), 1,
      sym_inlinemeta,
  [15006] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1612), 1,
      anon_sym_LBRACE,
    ACTIONS(1660), 1,
      sym_asis_halmos_text,
    STATE(614), 1,
      sym_inlinemeta,
  [15019] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1612), 1,
      anon_sym_LBRACE,
    ACTIONS(1662), 1,
      sym_asis_halmos_text,
    STATE(615), 1,
      sym_inlinemeta,
  [15032] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1581), 1,
      anon_sym_COLONbibtex_COLON,
    ACTIONS(1664), 1,
      ts_builtin_sym_end,
    STATE(551), 1,
      sym_bibtex,
  [15045] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1598), 1,
      anon_sym_LBRACE,
    ACTIONS(1666), 1,
      sym_asis_dollar_text,
    STATE(629), 1,
      sym_inlinemeta,
  [15058] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1602), 1,
      anon_sym_LBRACE,
    ACTIONS(1668), 1,
      sym_asis_backtick_text,
    STATE(630), 1,
      sym_inlinemeta,
  [15071] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1612), 1,
      anon_sym_LBRACE,
    ACTIONS(1670), 1,
      sym_asis_halmos_text,
    STATE(631), 1,
      sym_inlinemeta,
  [15084] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1581), 1,
      anon_sym_COLONbibtex_COLON,
    ACTIONS(1672), 1,
      ts_builtin_sym_end,
    STATE(514), 1,
      sym_bibtex,
  [15097] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1674), 1,
      sym_text,
    STATE(339), 1,
      sym_metaval_text,
  [15107] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1676), 1,
      anon_sym_COMMA,
    ACTIONS(1678), 1,
      anon_sym_RBRACE,
  [15117] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1680), 1,
      anon_sym_COMMA,
    ACTIONS(1682), 1,
      anon_sym_RBRACE,
  [15127] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1684), 1,
      sym_upto_brace_or_comma_text,
    STATE(466), 1,
      aux_sym_metaval_list_repeat1,
  [15137] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1686), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1688), 1,
      anon_sym_COLON,
  [15147] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1690), 1,
      sym_text,
    STATE(332), 1,
      sym_metaval_text,
  [15157] = 3,
    ACTIONS(1692), 1,
      aux_sym_metaval_any_token1,
    ACTIONS(1694), 1,
      sym_comment,
    STATE(15), 1,
      sym_metaval_any,
  [15167] = 3,
    ACTIONS(1694), 1,
      sym_comment,
    ACTIONS(1696), 1,
      aux_sym_metaval_any_token1,
    STATE(332), 1,
      sym_metaval_any,
  [15177] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1698), 1,
      sym_text,
    STATE(15), 1,
      sym_metaval_text,
  [15187] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1700), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1702), 1,
      anon_sym_COMMA,
  [15197] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1704), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1706), 1,
      anon_sym_COMMA,
  [15207] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1676), 1,
      anon_sym_COMMA,
    ACTIONS(1708), 1,
      anon_sym_RBRACE,
  [15217] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1710), 2,
      sym_text,
      anon_sym_LBRACE,
  [15225] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1676), 1,
      anon_sym_COMMA,
    ACTIONS(1712), 1,
      anon_sym_RBRACE,
  [15235] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1680), 1,
      anon_sym_COMMA,
    ACTIONS(1714), 1,
      anon_sym_RBRACE,
  [15245] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1680), 1,
      anon_sym_COMMA,
    ACTIONS(1716), 1,
      anon_sym_RBRACE,
  [15255] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1718), 1,
      sym_upto_brace_or_comma_text,
    STATE(416), 1,
      aux_sym_metaval_list_repeat1,
  [15265] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1720), 1,
      sym_upto_brace_or_comma_text,
    STATE(466), 1,
      aux_sym_metaval_list_repeat1,
  [15275] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1718), 1,
      sym_upto_brace_or_comma_text,
    STATE(469), 1,
      aux_sym_metaval_list_repeat1,
  [15285] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1722), 2,
      anon_sym_COLON_COLON,
      anon_sym_COLONtd_COLON,
  [15293] = 3,
    ACTIONS(1694), 1,
      sym_comment,
    ACTIONS(1724), 1,
      aux_sym_metaval_any_token1,
    STATE(339), 1,
      sym_metaval_any,
  [15303] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1726), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1728), 1,
      anon_sym_COMMA,
  [15313] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1730), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1732), 1,
      anon_sym_COMMA,
  [15323] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1734), 2,
      anon_sym_COLON_COLON,
      anon_sym_COLONtr_COLON,
  [15331] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1676), 1,
      anon_sym_COMMA,
    ACTIONS(1736), 1,
      anon_sym_RBRACE,
  [15341] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1738), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1740), 1,
      anon_sym_COMMA,
  [15351] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1742), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [15359] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1676), 1,
      anon_sym_COMMA,
    ACTIONS(1744), 1,
      anon_sym_RBRACE,
  [15369] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1680), 1,
      anon_sym_COMMA,
    ACTIONS(1746), 1,
      anon_sym_RBRACE,
  [15379] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1748), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [15387] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1750), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [15395] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1718), 1,
      sym_upto_brace_or_comma_text,
    STATE(402), 1,
      aux_sym_metaval_list_repeat1,
  [15405] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1752), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [15413] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1754), 1,
      sym_text,
    STATE(321), 1,
      sym_metaval_text,
  [15423] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1756), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [15431] = 3,
    ACTIONS(1694), 1,
      sym_comment,
    ACTIONS(1758), 1,
      aux_sym_metaval_any_token1,
    STATE(321), 1,
      sym_metaval_any,
  [15441] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1676), 1,
      anon_sym_COMMA,
    ACTIONS(1760), 1,
      anon_sym_RBRACE,
  [15451] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1762), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1764), 1,
      anon_sym_COMMA,
  [15461] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1766), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1768), 1,
      anon_sym_COMMA,
  [15471] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1770), 2,
      anon_sym_COLON_COLON,
      anon_sym_COLONtd_COLON,
  [15479] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1688), 1,
      anon_sym_COLON,
    ACTIONS(1772), 1,
      anon_sym_COLON_COLON,
  [15489] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1676), 1,
      anon_sym_COMMA,
    ACTIONS(1774), 1,
      anon_sym_RBRACE,
  [15499] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1776), 1,
      sym_upto_brace_or_comma_text,
    STATE(428), 1,
      sym_metaval_text_inline,
  [15509] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1676), 1,
      anon_sym_COMMA,
    ACTIONS(1778), 1,
      anon_sym_RBRACE,
  [15519] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1680), 1,
      anon_sym_COMMA,
    ACTIONS(1780), 1,
      anon_sym_RBRACE,
  [15529] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1782), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [15537] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1784), 1,
      anon_sym_COMMA,
    ACTIONS(1786), 1,
      anon_sym_RBRACE,
  [15547] = 3,
    ACTIONS(1694), 1,
      sym_comment,
    ACTIONS(1788), 1,
      aux_sym_metaval_any_inline_token1,
    STATE(428), 1,
      sym_metaval_any_inline,
  [15557] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1790), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1792), 1,
      anon_sym_COMMA,
  [15567] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1794), 2,
      anon_sym_COLON_COLON,
      anon_sym_AT,
  [15575] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1796), 1,
      anon_sym_COMMA,
    ACTIONS(1798), 1,
      anon_sym_RBRACE,
  [15585] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1800), 2,
      anon_sym_COLON_COLON,
      anon_sym_COLONcaption_COLON,
  [15593] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1802), 1,
      sym_upto_brace_or_comma_text,
    STATE(466), 1,
      aux_sym_metaval_list_repeat1,
  [15603] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1804), 1,
      anon_sym_RBRACE,
    ACTIONS(1806), 1,
      aux_sym_bibitempair_token1,
  [15613] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1808), 2,
      anon_sym_COLON_COLON,
      anon_sym_AT,
  [15621] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1810), 2,
      anon_sym_COLON_COLON,
      anon_sym_AT,
  [15629] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1812), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [15637] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1814), 1,
      sym_text,
    STATE(331), 1,
      sym_metaval_text,
  [15647] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1816), 1,
      sym_upto_brace_or_comma_text,
    STATE(466), 1,
      aux_sym_metaval_list_repeat1,
  [15657] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1680), 1,
      anon_sym_COMMA,
    ACTIONS(1818), 1,
      anon_sym_RBRACE,
  [15667] = 3,
    ACTIONS(1694), 1,
      sym_comment,
    ACTIONS(1820), 1,
      aux_sym_metaval_any_token1,
    STATE(331), 1,
      sym_metaval_any,
  [15677] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1710), 2,
      sym_upto_brace_or_comma_text,
      anon_sym_LBRACE,
  [15685] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1822), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1824), 1,
      anon_sym_COMMA,
  [15695] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1826), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1828), 1,
      anon_sym_COMMA,
  [15705] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1830), 1,
      sym_upto_brace_or_comma_text,
    STATE(466), 1,
      aux_sym_metaval_list_repeat1,
  [15715] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1832), 2,
      anon_sym_COLON_COLON,
      anon_sym_COLONtr_COLON,
  [15723] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1676), 1,
      anon_sym_COMMA,
    ACTIONS(1834), 1,
      anon_sym_RBRACE,
  [15733] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1836), 1,
      sym_upto_brace_or_comma_text,
    STATE(466), 1,
      aux_sym_metaval_list_repeat1,
  [15743] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1839), 2,
      anon_sym_COLON_COLON,
      anon_sym_COLONtr_COLON,
  [15751] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(895), 1,
      anon_sym_LBRACE,
    STATE(174), 1,
      sym_inlinemeta,
  [15761] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1841), 1,
      sym_upto_brace_or_comma_text,
    STATE(466), 1,
      aux_sym_metaval_list_repeat1,
  [15771] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1718), 1,
      sym_upto_brace_or_comma_text,
    STATE(451), 1,
      aux_sym_metaval_list_repeat1,
  [15781] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1718), 1,
      sym_upto_brace_or_comma_text,
    STATE(457), 1,
      aux_sym_metaval_list_repeat1,
  [15791] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1718), 1,
      sym_upto_brace_or_comma_text,
    STATE(463), 1,
      aux_sym_metaval_list_repeat1,
  [15801] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1676), 1,
      anon_sym_COMMA,
    ACTIONS(1843), 1,
      anon_sym_RBRACE,
  [15811] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1845), 1,
      aux_sym_specialinline_token1,
  [15818] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1847), 1,
      sym_text,
  [15825] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1849), 1,
      anon_sym_COLON_COLON,
  [15832] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1851), 1,
      sym_text,
  [15839] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1853), 1,
      anon_sym_COLON_COLON,
  [15846] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1855), 1,
      anon_sym_COLON_COLON,
  [15853] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1857), 1,
      aux_sym_specialinline_token1,
  [15860] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1859), 1,
      aux_sym_specialinline_token2,
  [15867] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1861), 1,
      anon_sym_COLON_COLON,
  [15874] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1859), 1,
      anon_sym_COLON_COLON,
  [15881] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1863), 1,
      sym_text,
  [15888] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(618), 1,
      anon_sym_COLON_COLON,
  [15895] = 2,
    ACTIONS(1694), 1,
      sym_comment,
    ACTIONS(1865), 1,
      aux_sym_specialinline_token7,
  [15902] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1867), 1,
      anon_sym_COLON_COLON,
  [15909] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1869), 1,
      aux_sym_mathblock_token1,
  [15916] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1871), 1,
      sym_asis_two_dollars_text,
  [15923] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1869), 1,
      anon_sym_COLON_COLON,
  [15930] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1873), 1,
      sym_asis_halmos_text,
  [15937] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_COMMA,
  [15944] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1877), 1,
      aux_sym_specialinline_token1,
  [15951] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1879), 1,
      aux_sym_specialinline_token2,
  [15958] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1881), 1,
      anon_sym_COLON_COLON,
  [15965] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1879), 1,
      anon_sym_COLON_COLON,
  [15972] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1883), 1,
      anon_sym_COLON_COLON,
  [15979] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1579), 1,
      ts_builtin_sym_end,
  [15986] = 2,
    ACTIONS(1694), 1,
      sym_comment,
    ACTIONS(1885), 1,
      aux_sym_specialinline_token8,
  [15993] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1887), 1,
      anon_sym_COLON_COLON,
  [16000] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1889), 1,
      anon_sym_COLON_COLON,
  [16007] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1891), 1,
      anon_sym_COLON_COLON,
  [16014] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1893), 1,
      sym_asis_halmos_text,
  [16021] = 2,
    ACTIONS(1694), 1,
      sym_comment,
    ACTIONS(1865), 1,
      aux_sym_specialinline_token5,
  [16028] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1680), 1,
      anon_sym_COMMA,
  [16035] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1895), 1,
      anon_sym_COLON,
  [16042] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1897), 1,
      sym_text,
  [16049] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1899), 1,
      ts_builtin_sym_end,
  [16056] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1901), 1,
      sym_upto_brace_or_comma_text,
  [16063] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1903), 1,
      anon_sym_COLON_COLON,
  [16070] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1905), 1,
      aux_sym_specialinline_token2,
  [16077] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1907), 1,
      anon_sym_COLON_COLON,
  [16084] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1905), 1,
      anon_sym_COLON_COLON,
  [16091] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1909), 1,
      ts_builtin_sym_end,
  [16098] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1911), 1,
      anon_sym_LBRACE,
  [16105] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1913), 1,
      sym_asis_backtick_text,
  [16112] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1915), 1,
      anon_sym_EQ,
  [16119] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1917), 1,
      ts_builtin_sym_end,
  [16126] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(690), 1,
      anon_sym_COLON_COLON,
  [16133] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1883), 1,
      aux_sym_specialinline_token2,
  [16140] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1919), 1,
      aux_sym_specialblock_token1,
  [16147] = 2,
    ACTIONS(1694), 1,
      sym_comment,
    ACTIONS(1921), 1,
      aux_sym_bibitem_token2,
  [16154] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1923), 1,
      aux_sym_specialinline_token1,
  [16161] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1925), 1,
      aux_sym_specialinline_token2,
  [16168] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1927), 1,
      anon_sym_COLON_COLON,
  [16175] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1925), 1,
      anon_sym_COLON_COLON,
  [16182] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1929), 1,
      anon_sym_LBRACE,
  [16189] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1806), 1,
      aux_sym_bibitempair_token1,
  [16196] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      sym_asis_halmos_text,
  [16203] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1931), 1,
      anon_sym_COLON_COLON,
  [16210] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1933), 1,
      anon_sym_COLON_COLON,
  [16217] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1935), 1,
      aux_sym_mathblock_token1,
  [16224] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1937), 1,
      sym_asis_dollar_text,
  [16231] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1676), 1,
      anon_sym_COMMA,
  [16238] = 2,
    ACTIONS(1694), 1,
      sym_comment,
    ACTIONS(1939), 1,
      aux_sym_bibitempair_token2,
  [16245] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1941), 1,
      aux_sym_specialinline_token6,
  [16252] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1472), 1,
      sym_asis_halmos_text,
  [16259] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1935), 1,
      anon_sym_COLON_COLON,
  [16266] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1784), 1,
      anon_sym_COMMA,
  [16273] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1943), 1,
      aux_sym_specialinline_token1,
  [16280] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1945), 1,
      aux_sym_specialinline_token2,
  [16287] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1947), 1,
      anon_sym_COLON_COLON,
  [16294] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1945), 1,
      anon_sym_COLON_COLON,
  [16301] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1949), 1,
      anon_sym_RBRACE,
  [16308] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1951), 1,
      sym_asis_three_backticks_text,
  [16315] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1953), 1,
      aux_sym_specialinline_token1,
  [16322] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1472), 1,
      sym_asis_dollar_text,
  [16329] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1919), 1,
      anon_sym_COLON_COLON,
  [16336] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1955), 1,
      ts_builtin_sym_end,
  [16343] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1957), 1,
      aux_sym_bibitem_token1,
  [16350] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1672), 1,
      ts_builtin_sym_end,
  [16357] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1959), 1,
      anon_sym_COLON_COLON,
  [16364] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1961), 1,
      aux_sym_specialinline_token1,
  [16371] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1963), 1,
      aux_sym_specialinline_token2,
  [16378] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1965), 1,
      anon_sym_COLON_COLON,
  [16385] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1963), 1,
      anon_sym_COLON_COLON,
  [16392] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1967), 1,
      aux_sym_specialinline_token2,
  [16399] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1969), 1,
      anon_sym_COLON_COLON,
  [16406] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1971), 1,
      anon_sym_COLON_COLON,
  [16413] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1973), 1,
      anon_sym_COLON_COLON,
  [16420] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1975), 1,
      anon_sym_COLON_COLON,
  [16427] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1977), 1,
      anon_sym_COLON_COLON,
  [16434] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1979), 1,
      anon_sym_COLON_COLON,
  [16441] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1847), 1,
      sym_upto_brace_or_comma_text,
  [16448] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1981), 1,
      aux_sym_specialinline_token1,
  [16455] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      aux_sym_specialinline_token2,
  [16462] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1985), 1,
      anon_sym_COLON_COLON,
  [16469] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      anon_sym_COLON_COLON,
  [16476] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1987), 1,
      anon_sym_COLON_COLON,
  [16483] = 2,
    ACTIONS(1694), 1,
      sym_comment,
    ACTIONS(1989), 1,
      aux_sym_specialinline_token5,
  [16490] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1991), 1,
      aux_sym_specialinline_token6,
  [16497] = 2,
    ACTIONS(1694), 1,
      sym_comment,
    ACTIONS(1989), 1,
      aux_sym_specialinline_token7,
  [16504] = 2,
    ACTIONS(1694), 1,
      sym_comment,
    ACTIONS(1993), 1,
      aux_sym_specialinline_token8,
  [16511] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1995), 1,
      sym_asis_halmos_text,
  [16518] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1997), 1,
      sym_asis_two_dollars_text,
  [16525] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1999), 1,
      sym_asis_halmos_text,
  [16532] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2001), 1,
      anon_sym_COLON_COLON,
  [16539] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2003), 1,
      sym_asis_dollar_text,
  [16546] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2005), 1,
      sym_asis_backtick_text,
  [16553] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2007), 1,
      sym_asis_halmos_text,
  [16560] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2009), 1,
      sym_asis_halmos_text,
  [16567] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2011), 1,
      sym_asis_halmos_text,
  [16574] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2013), 1,
      sym_text,
  [16581] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2015), 1,
      sym_text,
  [16588] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      sym_asis_backtick_text,
  [16595] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1967), 1,
      anon_sym_COLON_COLON,
  [16602] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2017), 1,
      anon_sym_COLON_COLON,
  [16609] = 2,
    ACTIONS(1694), 1,
      sym_comment,
    ACTIONS(2019), 1,
      aux_sym_metaval_any_inline_token1,
  [16616] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2021), 1,
      anon_sym_COLON_COLON,
  [16623] = 2,
    ACTIONS(1694), 1,
      sym_comment,
    ACTIONS(2023), 1,
      aux_sym_specialinline_token5,
  [16630] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2025), 1,
      aux_sym_specialinline_token6,
  [16637] = 2,
    ACTIONS(1694), 1,
      sym_comment,
    ACTIONS(2023), 1,
      aux_sym_specialinline_token7,
  [16644] = 2,
    ACTIONS(1694), 1,
      sym_comment,
    ACTIONS(2027), 1,
      aux_sym_specialinline_token8,
  [16651] = 2,
    ACTIONS(1694), 1,
      sym_comment,
    ACTIONS(2019), 1,
      aux_sym_metaval_any_token1,
  [16658] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2029), 1,
      sym_asis_dollar_text,
  [16665] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2031), 1,
      sym_asis_backtick_text,
  [16672] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2033), 1,
      sym_asis_halmos_text,
  [16679] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2035), 1,
      sym_asis_halmos_text,
  [16686] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2037), 1,
      ts_builtin_sym_end,
  [16693] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2039), 1,
      sym_text,
  [16700] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2041), 1,
      sym_text,
  [16707] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2043), 1,
      anon_sym_COLON_COLON,
  [16714] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 1,
      sym_asis_dollar_text,
  [16721] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2045), 1,
      aux_sym_mathblock_token1,
  [16728] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2045), 1,
      anon_sym_COLON_COLON,
  [16735] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2047), 1,
      aux_sym_specialblock_token1,
  [16742] = 2,
    ACTIONS(1694), 1,
      sym_comment,
    ACTIONS(2049), 1,
      aux_sym_specialinline_token5,
  [16749] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2051), 1,
      aux_sym_specialinline_token6,
  [16756] = 2,
    ACTIONS(1694), 1,
      sym_comment,
    ACTIONS(2049), 1,
      aux_sym_specialinline_token7,
  [16763] = 2,
    ACTIONS(1694), 1,
      sym_comment,
    ACTIONS(2053), 1,
      aux_sym_specialinline_token8,
  [16770] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2055), 1,
      sym_text,
  [16777] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2057), 1,
      sym_asis_dollar_text,
  [16784] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2059), 1,
      sym_asis_backtick_text,
  [16791] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2061), 1,
      sym_asis_halmos_text,
  [16798] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2063), 1,
      sym_asis_halmos_text,
  [16805] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2065), 1,
      aux_sym_specialinline_token1,
  [16812] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2067), 1,
      sym_text,
  [16819] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2069), 1,
      sym_text,
  [16826] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2071), 1,
      aux_sym_specialinline_token2,
  [16833] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2073), 1,
      anon_sym_COLON_COLON,
  [16840] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2071), 1,
      anon_sym_COLON_COLON,
  [16847] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1472), 1,
      sym_asis_backtick_text,
  [16854] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2075), 1,
      anon_sym_COLON_COLON,
  [16861] = 2,
    ACTIONS(1694), 1,
      sym_comment,
    ACTIONS(2077), 1,
      aux_sym_specialinline_token5,
  [16868] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2079), 1,
      aux_sym_specialinline_token6,
  [16875] = 2,
    ACTIONS(1694), 1,
      sym_comment,
    ACTIONS(2077), 1,
      aux_sym_specialinline_token7,
  [16882] = 2,
    ACTIONS(1694), 1,
      sym_comment,
    ACTIONS(2081), 1,
      aux_sym_specialinline_token8,
  [16889] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2083), 1,
      anon_sym_COLON_COLON,
  [16896] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2085), 1,
      sym_asis_dollar_text,
  [16903] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2087), 1,
      sym_asis_backtick_text,
  [16910] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2089), 1,
      sym_asis_halmos_text,
  [16917] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2091), 1,
      sym_asis_halmos_text,
  [16924] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2093), 1,
      aux_sym_specialinline_token1,
  [16931] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2095), 1,
      sym_text,
  [16938] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2097), 1,
      sym_text,
  [16945] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2099), 1,
      anon_sym_COLON_COLON,
  [16952] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2101), 1,
      anon_sym_COLON_COLON,
  [16959] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2047), 1,
      anon_sym_COLON_COLON,
  [16966] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2103), 1,
      sym_text,
  [16973] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2105), 1,
      sym_asis_halmos_text,
  [16980] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1979), 1,
      aux_sym_mathblock_token1,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(86)] = 0,
  [SMALL_STATE(87)] = 88,
  [SMALL_STATE(88)] = 176,
  [SMALL_STATE(89)] = 264,
  [SMALL_STATE(90)] = 352,
  [SMALL_STATE(91)] = 437,
  [SMALL_STATE(92)] = 522,
  [SMALL_STATE(93)] = 607,
  [SMALL_STATE(94)] = 692,
  [SMALL_STATE(95)] = 777,
  [SMALL_STATE(96)] = 862,
  [SMALL_STATE(97)] = 947,
  [SMALL_STATE(98)] = 1032,
  [SMALL_STATE(99)] = 1117,
  [SMALL_STATE(100)] = 1202,
  [SMALL_STATE(101)] = 1287,
  [SMALL_STATE(102)] = 1369,
  [SMALL_STATE(103)] = 1451,
  [SMALL_STATE(104)] = 1535,
  [SMALL_STATE(105)] = 1619,
  [SMALL_STATE(106)] = 1703,
  [SMALL_STATE(107)] = 1787,
  [SMALL_STATE(108)] = 1871,
  [SMALL_STATE(109)] = 1955,
  [SMALL_STATE(110)] = 2039,
  [SMALL_STATE(111)] = 2123,
  [SMALL_STATE(112)] = 2207,
  [SMALL_STATE(113)] = 2291,
  [SMALL_STATE(114)] = 2375,
  [SMALL_STATE(115)] = 2457,
  [SMALL_STATE(116)] = 2538,
  [SMALL_STATE(117)] = 2619,
  [SMALL_STATE(118)] = 2700,
  [SMALL_STATE(119)] = 2781,
  [SMALL_STATE(120)] = 2859,
  [SMALL_STATE(121)] = 2937,
  [SMALL_STATE(122)] = 3015,
  [SMALL_STATE(123)] = 3093,
  [SMALL_STATE(124)] = 3171,
  [SMALL_STATE(125)] = 3249,
  [SMALL_STATE(126)] = 3327,
  [SMALL_STATE(127)] = 3405,
  [SMALL_STATE(128)] = 3483,
  [SMALL_STATE(129)] = 3561,
  [SMALL_STATE(130)] = 3639,
  [SMALL_STATE(131)] = 3717,
  [SMALL_STATE(132)] = 3795,
  [SMALL_STATE(133)] = 3873,
  [SMALL_STATE(134)] = 3951,
  [SMALL_STATE(135)] = 4029,
  [SMALL_STATE(136)] = 4107,
  [SMALL_STATE(137)] = 4185,
  [SMALL_STATE(138)] = 4263,
  [SMALL_STATE(139)] = 4341,
  [SMALL_STATE(140)] = 4419,
  [SMALL_STATE(141)] = 4497,
  [SMALL_STATE(142)] = 4575,
  [SMALL_STATE(143)] = 4653,
  [SMALL_STATE(144)] = 4731,
  [SMALL_STATE(145)] = 4809,
  [SMALL_STATE(146)] = 4887,
  [SMALL_STATE(147)] = 4965,
  [SMALL_STATE(148)] = 5043,
  [SMALL_STATE(149)] = 5121,
  [SMALL_STATE(150)] = 5199,
  [SMALL_STATE(151)] = 5277,
  [SMALL_STATE(152)] = 5355,
  [SMALL_STATE(153)] = 5433,
  [SMALL_STATE(154)] = 5511,
  [SMALL_STATE(155)] = 5589,
  [SMALL_STATE(156)] = 5667,
  [SMALL_STATE(157)] = 5745,
  [SMALL_STATE(158)] = 5823,
  [SMALL_STATE(159)] = 5901,
  [SMALL_STATE(160)] = 5979,
  [SMALL_STATE(161)] = 6057,
  [SMALL_STATE(162)] = 6135,
  [SMALL_STATE(163)] = 6213,
  [SMALL_STATE(164)] = 6291,
  [SMALL_STATE(165)] = 6369,
  [SMALL_STATE(166)] = 6447,
  [SMALL_STATE(167)] = 6525,
  [SMALL_STATE(168)] = 6603,
  [SMALL_STATE(169)] = 6681,
  [SMALL_STATE(170)] = 6759,
  [SMALL_STATE(171)] = 6837,
  [SMALL_STATE(172)] = 6915,
  [SMALL_STATE(173)] = 6993,
  [SMALL_STATE(174)] = 7071,
  [SMALL_STATE(175)] = 7146,
  [SMALL_STATE(176)] = 7191,
  [SMALL_STATE(177)] = 7236,
  [SMALL_STATE(178)] = 7281,
  [SMALL_STATE(179)] = 7326,
  [SMALL_STATE(180)] = 7371,
  [SMALL_STATE(181)] = 7416,
  [SMALL_STATE(182)] = 7461,
  [SMALL_STATE(183)] = 7506,
  [SMALL_STATE(184)] = 7551,
  [SMALL_STATE(185)] = 7596,
  [SMALL_STATE(186)] = 7641,
  [SMALL_STATE(187)] = 7686,
  [SMALL_STATE(188)] = 7731,
  [SMALL_STATE(189)] = 7776,
  [SMALL_STATE(190)] = 7821,
  [SMALL_STATE(191)] = 7866,
  [SMALL_STATE(192)] = 7911,
  [SMALL_STATE(193)] = 7956,
  [SMALL_STATE(194)] = 8001,
  [SMALL_STATE(195)] = 8046,
  [SMALL_STATE(196)] = 8091,
  [SMALL_STATE(197)] = 8136,
  [SMALL_STATE(198)] = 8181,
  [SMALL_STATE(199)] = 8226,
  [SMALL_STATE(200)] = 8270,
  [SMALL_STATE(201)] = 8314,
  [SMALL_STATE(202)] = 8358,
  [SMALL_STATE(203)] = 8402,
  [SMALL_STATE(204)] = 8446,
  [SMALL_STATE(205)] = 8490,
  [SMALL_STATE(206)] = 8534,
  [SMALL_STATE(207)] = 8578,
  [SMALL_STATE(208)] = 8622,
  [SMALL_STATE(209)] = 8666,
  [SMALL_STATE(210)] = 8710,
  [SMALL_STATE(211)] = 8754,
  [SMALL_STATE(212)] = 8798,
  [SMALL_STATE(213)] = 8842,
  [SMALL_STATE(214)] = 8886,
  [SMALL_STATE(215)] = 8930,
  [SMALL_STATE(216)] = 8974,
  [SMALL_STATE(217)] = 9018,
  [SMALL_STATE(218)] = 9062,
  [SMALL_STATE(219)] = 9106,
  [SMALL_STATE(220)] = 9150,
  [SMALL_STATE(221)] = 9194,
  [SMALL_STATE(222)] = 9238,
  [SMALL_STATE(223)] = 9282,
  [SMALL_STATE(224)] = 9325,
  [SMALL_STATE(225)] = 9368,
  [SMALL_STATE(226)] = 9411,
  [SMALL_STATE(227)] = 9454,
  [SMALL_STATE(228)] = 9497,
  [SMALL_STATE(229)] = 9540,
  [SMALL_STATE(230)] = 9583,
  [SMALL_STATE(231)] = 9626,
  [SMALL_STATE(232)] = 9669,
  [SMALL_STATE(233)] = 9712,
  [SMALL_STATE(234)] = 9755,
  [SMALL_STATE(235)] = 9798,
  [SMALL_STATE(236)] = 9841,
  [SMALL_STATE(237)] = 9884,
  [SMALL_STATE(238)] = 9927,
  [SMALL_STATE(239)] = 9970,
  [SMALL_STATE(240)] = 10013,
  [SMALL_STATE(241)] = 10056,
  [SMALL_STATE(242)] = 10099,
  [SMALL_STATE(243)] = 10142,
  [SMALL_STATE(244)] = 10185,
  [SMALL_STATE(245)] = 10228,
  [SMALL_STATE(246)] = 10271,
  [SMALL_STATE(247)] = 10314,
  [SMALL_STATE(248)] = 10357,
  [SMALL_STATE(249)] = 10400,
  [SMALL_STATE(250)] = 10443,
  [SMALL_STATE(251)] = 10486,
  [SMALL_STATE(252)] = 10529,
  [SMALL_STATE(253)] = 10572,
  [SMALL_STATE(254)] = 10615,
  [SMALL_STATE(255)] = 10658,
  [SMALL_STATE(256)] = 10701,
  [SMALL_STATE(257)] = 10744,
  [SMALL_STATE(258)] = 10787,
  [SMALL_STATE(259)] = 10830,
  [SMALL_STATE(260)] = 10873,
  [SMALL_STATE(261)] = 10916,
  [SMALL_STATE(262)] = 10959,
  [SMALL_STATE(263)] = 11002,
  [SMALL_STATE(264)] = 11043,
  [SMALL_STATE(265)] = 11084,
  [SMALL_STATE(266)] = 11127,
  [SMALL_STATE(267)] = 11170,
  [SMALL_STATE(268)] = 11213,
  [SMALL_STATE(269)] = 11256,
  [SMALL_STATE(270)] = 11299,
  [SMALL_STATE(271)] = 11342,
  [SMALL_STATE(272)] = 11385,
  [SMALL_STATE(273)] = 11428,
  [SMALL_STATE(274)] = 11471,
  [SMALL_STATE(275)] = 11514,
  [SMALL_STATE(276)] = 11557,
  [SMALL_STATE(277)] = 11600,
  [SMALL_STATE(278)] = 11643,
  [SMALL_STATE(279)] = 11686,
  [SMALL_STATE(280)] = 11729,
  [SMALL_STATE(281)] = 11772,
  [SMALL_STATE(282)] = 11815,
  [SMALL_STATE(283)] = 11858,
  [SMALL_STATE(284)] = 11901,
  [SMALL_STATE(285)] = 11944,
  [SMALL_STATE(286)] = 11987,
  [SMALL_STATE(287)] = 12030,
  [SMALL_STATE(288)] = 12073,
  [SMALL_STATE(289)] = 12116,
  [SMALL_STATE(290)] = 12159,
  [SMALL_STATE(291)] = 12202,
  [SMALL_STATE(292)] = 12242,
  [SMALL_STATE(293)] = 12313,
  [SMALL_STATE(294)] = 12366,
  [SMALL_STATE(295)] = 12419,
  [SMALL_STATE(296)] = 12472,
  [SMALL_STATE(297)] = 12525,
  [SMALL_STATE(298)] = 12578,
  [SMALL_STATE(299)] = 12631,
  [SMALL_STATE(300)] = 12684,
  [SMALL_STATE(301)] = 12737,
  [SMALL_STATE(302)] = 12790,
  [SMALL_STATE(303)] = 12840,
  [SMALL_STATE(304)] = 12890,
  [SMALL_STATE(305)] = 12940,
  [SMALL_STATE(306)] = 12990,
  [SMALL_STATE(307)] = 13040,
  [SMALL_STATE(308)] = 13090,
  [SMALL_STATE(309)] = 13139,
  [SMALL_STATE(310)] = 13188,
  [SMALL_STATE(311)] = 13237,
  [SMALL_STATE(312)] = 13286,
  [SMALL_STATE(313)] = 13317,
  [SMALL_STATE(314)] = 13366,
  [SMALL_STATE(315)] = 13415,
  [SMALL_STATE(316)] = 13464,
  [SMALL_STATE(317)] = 13513,
  [SMALL_STATE(318)] = 13562,
  [SMALL_STATE(319)] = 13611,
  [SMALL_STATE(320)] = 13660,
  [SMALL_STATE(321)] = 13689,
  [SMALL_STATE(322)] = 13718,
  [SMALL_STATE(323)] = 13747,
  [SMALL_STATE(324)] = 13776,
  [SMALL_STATE(325)] = 13805,
  [SMALL_STATE(326)] = 13834,
  [SMALL_STATE(327)] = 13860,
  [SMALL_STATE(328)] = 13886,
  [SMALL_STATE(329)] = 13912,
  [SMALL_STATE(330)] = 13938,
  [SMALL_STATE(331)] = 13964,
  [SMALL_STATE(332)] = 13990,
  [SMALL_STATE(333)] = 14016,
  [SMALL_STATE(334)] = 14042,
  [SMALL_STATE(335)] = 14068,
  [SMALL_STATE(336)] = 14094,
  [SMALL_STATE(337)] = 14120,
  [SMALL_STATE(338)] = 14146,
  [SMALL_STATE(339)] = 14172,
  [SMALL_STATE(340)] = 14198,
  [SMALL_STATE(341)] = 14224,
  [SMALL_STATE(342)] = 14250,
  [SMALL_STATE(343)] = 14276,
  [SMALL_STATE(344)] = 14302,
  [SMALL_STATE(345)] = 14328,
  [SMALL_STATE(346)] = 14354,
  [SMALL_STATE(347)] = 14380,
  [SMALL_STATE(348)] = 14405,
  [SMALL_STATE(349)] = 14430,
  [SMALL_STATE(350)] = 14445,
  [SMALL_STATE(351)] = 14460,
  [SMALL_STATE(352)] = 14479,
  [SMALL_STATE(353)] = 14498,
  [SMALL_STATE(354)] = 14513,
  [SMALL_STATE(355)] = 14527,
  [SMALL_STATE(356)] = 14541,
  [SMALL_STATE(357)] = 14553,
  [SMALL_STATE(358)] = 14565,
  [SMALL_STATE(359)] = 14579,
  [SMALL_STATE(360)] = 14593,
  [SMALL_STATE(361)] = 14607,
  [SMALL_STATE(362)] = 14620,
  [SMALL_STATE(363)] = 14633,
  [SMALL_STATE(364)] = 14646,
  [SMALL_STATE(365)] = 14659,
  [SMALL_STATE(366)] = 14672,
  [SMALL_STATE(367)] = 14685,
  [SMALL_STATE(368)] = 14698,
  [SMALL_STATE(369)] = 14711,
  [SMALL_STATE(370)] = 14724,
  [SMALL_STATE(371)] = 14737,
  [SMALL_STATE(372)] = 14750,
  [SMALL_STATE(373)] = 14763,
  [SMALL_STATE(374)] = 14776,
  [SMALL_STATE(375)] = 14789,
  [SMALL_STATE(376)] = 14802,
  [SMALL_STATE(377)] = 14811,
  [SMALL_STATE(378)] = 14824,
  [SMALL_STATE(379)] = 14837,
  [SMALL_STATE(380)] = 14850,
  [SMALL_STATE(381)] = 14863,
  [SMALL_STATE(382)] = 14876,
  [SMALL_STATE(383)] = 14889,
  [SMALL_STATE(384)] = 14902,
  [SMALL_STATE(385)] = 14915,
  [SMALL_STATE(386)] = 14928,
  [SMALL_STATE(387)] = 14941,
  [SMALL_STATE(388)] = 14954,
  [SMALL_STATE(389)] = 14967,
  [SMALL_STATE(390)] = 14980,
  [SMALL_STATE(391)] = 14993,
  [SMALL_STATE(392)] = 15006,
  [SMALL_STATE(393)] = 15019,
  [SMALL_STATE(394)] = 15032,
  [SMALL_STATE(395)] = 15045,
  [SMALL_STATE(396)] = 15058,
  [SMALL_STATE(397)] = 15071,
  [SMALL_STATE(398)] = 15084,
  [SMALL_STATE(399)] = 15097,
  [SMALL_STATE(400)] = 15107,
  [SMALL_STATE(401)] = 15117,
  [SMALL_STATE(402)] = 15127,
  [SMALL_STATE(403)] = 15137,
  [SMALL_STATE(404)] = 15147,
  [SMALL_STATE(405)] = 15157,
  [SMALL_STATE(406)] = 15167,
  [SMALL_STATE(407)] = 15177,
  [SMALL_STATE(408)] = 15187,
  [SMALL_STATE(409)] = 15197,
  [SMALL_STATE(410)] = 15207,
  [SMALL_STATE(411)] = 15217,
  [SMALL_STATE(412)] = 15225,
  [SMALL_STATE(413)] = 15235,
  [SMALL_STATE(414)] = 15245,
  [SMALL_STATE(415)] = 15255,
  [SMALL_STATE(416)] = 15265,
  [SMALL_STATE(417)] = 15275,
  [SMALL_STATE(418)] = 15285,
  [SMALL_STATE(419)] = 15293,
  [SMALL_STATE(420)] = 15303,
  [SMALL_STATE(421)] = 15313,
  [SMALL_STATE(422)] = 15323,
  [SMALL_STATE(423)] = 15331,
  [SMALL_STATE(424)] = 15341,
  [SMALL_STATE(425)] = 15351,
  [SMALL_STATE(426)] = 15359,
  [SMALL_STATE(427)] = 15369,
  [SMALL_STATE(428)] = 15379,
  [SMALL_STATE(429)] = 15387,
  [SMALL_STATE(430)] = 15395,
  [SMALL_STATE(431)] = 15405,
  [SMALL_STATE(432)] = 15413,
  [SMALL_STATE(433)] = 15423,
  [SMALL_STATE(434)] = 15431,
  [SMALL_STATE(435)] = 15441,
  [SMALL_STATE(436)] = 15451,
  [SMALL_STATE(437)] = 15461,
  [SMALL_STATE(438)] = 15471,
  [SMALL_STATE(439)] = 15479,
  [SMALL_STATE(440)] = 15489,
  [SMALL_STATE(441)] = 15499,
  [SMALL_STATE(442)] = 15509,
  [SMALL_STATE(443)] = 15519,
  [SMALL_STATE(444)] = 15529,
  [SMALL_STATE(445)] = 15537,
  [SMALL_STATE(446)] = 15547,
  [SMALL_STATE(447)] = 15557,
  [SMALL_STATE(448)] = 15567,
  [SMALL_STATE(449)] = 15575,
  [SMALL_STATE(450)] = 15585,
  [SMALL_STATE(451)] = 15593,
  [SMALL_STATE(452)] = 15603,
  [SMALL_STATE(453)] = 15613,
  [SMALL_STATE(454)] = 15621,
  [SMALL_STATE(455)] = 15629,
  [SMALL_STATE(456)] = 15637,
  [SMALL_STATE(457)] = 15647,
  [SMALL_STATE(458)] = 15657,
  [SMALL_STATE(459)] = 15667,
  [SMALL_STATE(460)] = 15677,
  [SMALL_STATE(461)] = 15685,
  [SMALL_STATE(462)] = 15695,
  [SMALL_STATE(463)] = 15705,
  [SMALL_STATE(464)] = 15715,
  [SMALL_STATE(465)] = 15723,
  [SMALL_STATE(466)] = 15733,
  [SMALL_STATE(467)] = 15743,
  [SMALL_STATE(468)] = 15751,
  [SMALL_STATE(469)] = 15761,
  [SMALL_STATE(470)] = 15771,
  [SMALL_STATE(471)] = 15781,
  [SMALL_STATE(472)] = 15791,
  [SMALL_STATE(473)] = 15801,
  [SMALL_STATE(474)] = 15811,
  [SMALL_STATE(475)] = 15818,
  [SMALL_STATE(476)] = 15825,
  [SMALL_STATE(477)] = 15832,
  [SMALL_STATE(478)] = 15839,
  [SMALL_STATE(479)] = 15846,
  [SMALL_STATE(480)] = 15853,
  [SMALL_STATE(481)] = 15860,
  [SMALL_STATE(482)] = 15867,
  [SMALL_STATE(483)] = 15874,
  [SMALL_STATE(484)] = 15881,
  [SMALL_STATE(485)] = 15888,
  [SMALL_STATE(486)] = 15895,
  [SMALL_STATE(487)] = 15902,
  [SMALL_STATE(488)] = 15909,
  [SMALL_STATE(489)] = 15916,
  [SMALL_STATE(490)] = 15923,
  [SMALL_STATE(491)] = 15930,
  [SMALL_STATE(492)] = 15937,
  [SMALL_STATE(493)] = 15944,
  [SMALL_STATE(494)] = 15951,
  [SMALL_STATE(495)] = 15958,
  [SMALL_STATE(496)] = 15965,
  [SMALL_STATE(497)] = 15972,
  [SMALL_STATE(498)] = 15979,
  [SMALL_STATE(499)] = 15986,
  [SMALL_STATE(500)] = 15993,
  [SMALL_STATE(501)] = 16000,
  [SMALL_STATE(502)] = 16007,
  [SMALL_STATE(503)] = 16014,
  [SMALL_STATE(504)] = 16021,
  [SMALL_STATE(505)] = 16028,
  [SMALL_STATE(506)] = 16035,
  [SMALL_STATE(507)] = 16042,
  [SMALL_STATE(508)] = 16049,
  [SMALL_STATE(509)] = 16056,
  [SMALL_STATE(510)] = 16063,
  [SMALL_STATE(511)] = 16070,
  [SMALL_STATE(512)] = 16077,
  [SMALL_STATE(513)] = 16084,
  [SMALL_STATE(514)] = 16091,
  [SMALL_STATE(515)] = 16098,
  [SMALL_STATE(516)] = 16105,
  [SMALL_STATE(517)] = 16112,
  [SMALL_STATE(518)] = 16119,
  [SMALL_STATE(519)] = 16126,
  [SMALL_STATE(520)] = 16133,
  [SMALL_STATE(521)] = 16140,
  [SMALL_STATE(522)] = 16147,
  [SMALL_STATE(523)] = 16154,
  [SMALL_STATE(524)] = 16161,
  [SMALL_STATE(525)] = 16168,
  [SMALL_STATE(526)] = 16175,
  [SMALL_STATE(527)] = 16182,
  [SMALL_STATE(528)] = 16189,
  [SMALL_STATE(529)] = 16196,
  [SMALL_STATE(530)] = 16203,
  [SMALL_STATE(531)] = 16210,
  [SMALL_STATE(532)] = 16217,
  [SMALL_STATE(533)] = 16224,
  [SMALL_STATE(534)] = 16231,
  [SMALL_STATE(535)] = 16238,
  [SMALL_STATE(536)] = 16245,
  [SMALL_STATE(537)] = 16252,
  [SMALL_STATE(538)] = 16259,
  [SMALL_STATE(539)] = 16266,
  [SMALL_STATE(540)] = 16273,
  [SMALL_STATE(541)] = 16280,
  [SMALL_STATE(542)] = 16287,
  [SMALL_STATE(543)] = 16294,
  [SMALL_STATE(544)] = 16301,
  [SMALL_STATE(545)] = 16308,
  [SMALL_STATE(546)] = 16315,
  [SMALL_STATE(547)] = 16322,
  [SMALL_STATE(548)] = 16329,
  [SMALL_STATE(549)] = 16336,
  [SMALL_STATE(550)] = 16343,
  [SMALL_STATE(551)] = 16350,
  [SMALL_STATE(552)] = 16357,
  [SMALL_STATE(553)] = 16364,
  [SMALL_STATE(554)] = 16371,
  [SMALL_STATE(555)] = 16378,
  [SMALL_STATE(556)] = 16385,
  [SMALL_STATE(557)] = 16392,
  [SMALL_STATE(558)] = 16399,
  [SMALL_STATE(559)] = 16406,
  [SMALL_STATE(560)] = 16413,
  [SMALL_STATE(561)] = 16420,
  [SMALL_STATE(562)] = 16427,
  [SMALL_STATE(563)] = 16434,
  [SMALL_STATE(564)] = 16441,
  [SMALL_STATE(565)] = 16448,
  [SMALL_STATE(566)] = 16455,
  [SMALL_STATE(567)] = 16462,
  [SMALL_STATE(568)] = 16469,
  [SMALL_STATE(569)] = 16476,
  [SMALL_STATE(570)] = 16483,
  [SMALL_STATE(571)] = 16490,
  [SMALL_STATE(572)] = 16497,
  [SMALL_STATE(573)] = 16504,
  [SMALL_STATE(574)] = 16511,
  [SMALL_STATE(575)] = 16518,
  [SMALL_STATE(576)] = 16525,
  [SMALL_STATE(577)] = 16532,
  [SMALL_STATE(578)] = 16539,
  [SMALL_STATE(579)] = 16546,
  [SMALL_STATE(580)] = 16553,
  [SMALL_STATE(581)] = 16560,
  [SMALL_STATE(582)] = 16567,
  [SMALL_STATE(583)] = 16574,
  [SMALL_STATE(584)] = 16581,
  [SMALL_STATE(585)] = 16588,
  [SMALL_STATE(586)] = 16595,
  [SMALL_STATE(587)] = 16602,
  [SMALL_STATE(588)] = 16609,
  [SMALL_STATE(589)] = 16616,
  [SMALL_STATE(590)] = 16623,
  [SMALL_STATE(591)] = 16630,
  [SMALL_STATE(592)] = 16637,
  [SMALL_STATE(593)] = 16644,
  [SMALL_STATE(594)] = 16651,
  [SMALL_STATE(595)] = 16658,
  [SMALL_STATE(596)] = 16665,
  [SMALL_STATE(597)] = 16672,
  [SMALL_STATE(598)] = 16679,
  [SMALL_STATE(599)] = 16686,
  [SMALL_STATE(600)] = 16693,
  [SMALL_STATE(601)] = 16700,
  [SMALL_STATE(602)] = 16707,
  [SMALL_STATE(603)] = 16714,
  [SMALL_STATE(604)] = 16721,
  [SMALL_STATE(605)] = 16728,
  [SMALL_STATE(606)] = 16735,
  [SMALL_STATE(607)] = 16742,
  [SMALL_STATE(608)] = 16749,
  [SMALL_STATE(609)] = 16756,
  [SMALL_STATE(610)] = 16763,
  [SMALL_STATE(611)] = 16770,
  [SMALL_STATE(612)] = 16777,
  [SMALL_STATE(613)] = 16784,
  [SMALL_STATE(614)] = 16791,
  [SMALL_STATE(615)] = 16798,
  [SMALL_STATE(616)] = 16805,
  [SMALL_STATE(617)] = 16812,
  [SMALL_STATE(618)] = 16819,
  [SMALL_STATE(619)] = 16826,
  [SMALL_STATE(620)] = 16833,
  [SMALL_STATE(621)] = 16840,
  [SMALL_STATE(622)] = 16847,
  [SMALL_STATE(623)] = 16854,
  [SMALL_STATE(624)] = 16861,
  [SMALL_STATE(625)] = 16868,
  [SMALL_STATE(626)] = 16875,
  [SMALL_STATE(627)] = 16882,
  [SMALL_STATE(628)] = 16889,
  [SMALL_STATE(629)] = 16896,
  [SMALL_STATE(630)] = 16903,
  [SMALL_STATE(631)] = 16910,
  [SMALL_STATE(632)] = 16917,
  [SMALL_STATE(633)] = 16924,
  [SMALL_STATE(634)] = 16931,
  [SMALL_STATE(635)] = 16938,
  [SMALL_STATE(636)] = 16945,
  [SMALL_STATE(637)] = 16952,
  [SMALL_STATE(638)] = 16959,
  [SMALL_STATE(639)] = 16966,
  [SMALL_STATE(640)] = 16973,
  [SMALL_STATE(641)] = 16980,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8),
  [7] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subsection, 1, 0, 1),
  [9] = {.entry = {.count = 1, .reusable = true}}, SHIFT(468),
  [11] = {.entry = {.count = 1, .reusable = true}}, SHIFT(611),
  [13] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4),
  [15] = {.entry = {.count = 1, .reusable = true}}, SHIFT(295),
  [17] = {.entry = {.count = 1, .reusable = true}}, SHIFT(300),
  [19] = {.entry = {.count = 1, .reusable = true}}, SHIFT(569),
  [21] = {.entry = {.count = 1, .reusable = true}}, SHIFT(299),
  [23] = {.entry = {.count = 1, .reusable = true}}, SHIFT(298),
  [25] = {.entry = {.count = 1, .reusable = true}}, SHIFT(297),
  [27] = {.entry = {.count = 1, .reusable = true}}, SHIFT(88),
  [29] = {.entry = {.count = 1, .reusable = true}}, SHIFT(87),
  [31] = {.entry = {.count = 1, .reusable = true}}, SHIFT(175),
  [33] = {.entry = {.count = 1, .reusable = false}}, SHIFT(369),
  [35] = {.entry = {.count = 1, .reusable = false}}, SHIFT(370),
  [37] = {.entry = {.count = 1, .reusable = true}}, SHIFT(373),
  [39] = {.entry = {.count = 1, .reusable = true}}, SHIFT(389),
  [41] = {.entry = {.count = 1, .reusable = true}}, SHIFT(122),
  [43] = {.entry = {.count = 1, .reusable = true}}, SHIFT(123),
  [45] = {.entry = {.count = 1, .reusable = true}}, SHIFT(504),
  [47] = {.entry = {.count = 1, .reusable = true}}, SHIFT(536),
  [49] = {.entry = {.count = 1, .reusable = true}}, SHIFT(486),
  [51] = {.entry = {.count = 1, .reusable = true}}, SHIFT(499),
  [53] = {.entry = {.count = 1, .reusable = true}}, SHIFT(181),
  [55] = {.entry = {.count = 1, .reusable = true}}, SHIFT(292),
  [57] = {.entry = {.count = 1, .reusable = true}}, SHIFT(104),
  [59] = {.entry = {.count = 1, .reusable = true}}, SHIFT(105),
  [61] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9),
  [63] = {.entry = {.count = 1, .reusable = true}}, SHIFT(475),
  [65] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18),
  [67] = {.entry = {.count = 1, .reusable = true}}, SHIFT(411),
  [69] = {.entry = {.count = 1, .reusable = true}}, SHIFT(594),
  [71] = {.entry = {.count = 1, .reusable = true}}, SHIFT(98),
  [73] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subsection, 2, 0, 2),
  [75] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subsubsection, 1, 0, 1),
  [77] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subsubsection, 2, 0, 2),
  [79] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_section, 1, 0, 1),
  [81] = {.entry = {.count = 1, .reusable = true}}, SHIFT(639),
  [83] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2),
  [85] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_section, 2, 0, 2),
  [87] = {.entry = {.count = 1, .reusable = true}}, SHIFT(394),
  [89] = {.entry = {.count = 1, .reusable = true}}, SHIFT(507),
  [91] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6),
  [93] = {.entry = {.count = 1, .reusable = true}}, SHIFT(85),
  [95] = {.entry = {.count = 1, .reusable = true}}, SHIFT(78),
  [97] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_blockmeta_repeat1, 2, 0, 0),
  [99] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_blockmeta_repeat1, 2, 0, 0),
  [101] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_blockmeta_repeat1, 2, 0, 0), SHIFT_REPEAT(475),
  [104] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_blockmeta_repeat1, 2, 0, 0), SHIFT_REPEAT(18),
  [107] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_blockmeta_repeat1, 2, 0, 0), SHIFT_REPEAT(411),
  [110] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_blockmeta_repeat1, 2, 0, 0), SHIFT_REPEAT(594),
  [113] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_blockmeta, 1, 0, 0),
  [115] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_blockmeta, 1, 0, 0),
  [117] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metaval_text, 1, 0, 4),
  [119] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_metaval_text, 1, 0, 4),
  [121] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metaval_list, 1, 0, 5),
  [123] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_metaval_list, 1, 0, 5),
  [125] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metaval_any, 1, 0, 0),
  [127] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_metaval_any, 1, 0, 0),
  [129] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pair, 2, 0, 0),
  [131] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pair, 2, 0, 0),
  [133] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pair, 1, 0, 0),
  [135] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pair, 1, 0, 0),
  [137] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metaval_list, 4, 0, 0),
  [139] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_metaval_list, 4, 0, 0),
  [141] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metakey_bool, 1, 0, 0),
  [143] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_metakey_bool, 1, 0, 0),
  [145] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subsection, 2, 0, 3),
  [147] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subsection, 2, 0, 1),
  [149] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subsection, 3, 0, 6),
  [151] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subsection, 3, 0, 3),
  [153] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subsection, 4, 0, 6),
  [155] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subsection, 3, 0, 2),
  [157] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0),
  [159] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(468),
  [162] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(611),
  [165] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(4),
  [168] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(295),
  [171] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(300),
  [174] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(569),
  [177] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(299),
  [180] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(298),
  [183] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(297),
  [186] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(88),
  [189] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(87),
  [192] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(175),
  [195] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(369),
  [198] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(370),
  [201] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(373),
  [204] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(389),
  [207] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(122),
  [210] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(123),
  [213] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(504),
  [216] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(536),
  [219] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(486),
  [222] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(499),
  [225] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(181),
  [228] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(292),
  [231] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(104),
  [234] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(105),
  [237] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(9),
  [240] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsection_repeat1, 2, 0, 0), SHIFT_REPEAT(98),
  [243] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subsubsection, 3, 0, 3),
  [245] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subsubsection, 2, 0, 3),
  [247] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subsubsection, 2, 0, 1),
  [249] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subsubsection, 3, 0, 6),
  [251] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0),
  [253] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(468),
  [256] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(295),
  [259] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(300),
  [262] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(569),
  [265] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(299),
  [268] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(298),
  [271] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(297),
  [274] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(88),
  [277] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(87),
  [280] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(175),
  [283] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(369),
  [286] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(370),
  [289] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(373),
  [292] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(389),
  [295] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(122),
  [298] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(123),
  [301] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(504),
  [304] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(536),
  [307] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(486),
  [310] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(499),
  [313] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(181),
  [316] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(292),
  [319] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(104),
  [322] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(105),
  [325] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(9),
  [328] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subsubsection_repeat1, 2, 0, 0), SHIFT_REPEAT(98),
  [331] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subsubsection, 3, 0, 2),
  [333] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subsubsection, 4, 0, 6),
  [335] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0),
  [337] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(468),
  [340] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(639),
  [343] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(2),
  [346] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(295),
  [349] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(300),
  [352] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(569),
  [355] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(299),
  [358] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(298),
  [361] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(297),
  [364] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(88),
  [367] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(87),
  [370] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(175),
  [373] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(369),
  [376] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(370),
  [379] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(373),
  [382] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(389),
  [385] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(122),
  [388] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(123),
  [391] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(504),
  [394] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(536),
  [397] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(486),
  [400] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(499),
  [403] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(181),
  [406] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(292),
  [409] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(104),
  [412] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(105),
  [415] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(9),
  [418] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_section_repeat1, 2, 0, 0), SHIFT_REPEAT(98),
  [421] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_section, 3, 0, 3),
  [423] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_section, 4, 0, 6),
  [425] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_section, 2, 0, 1),
  [427] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_section, 3, 0, 2),
  [429] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_section, 3, 0, 6),
  [431] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_section, 2, 0, 3),
  [433] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0),
  [435] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(468),
  [438] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(507),
  [441] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(6),
  [444] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(85),
  [447] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(295),
  [450] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(300),
  [453] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(569),
  [456] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(299),
  [459] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(298),
  [462] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(297),
  [465] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(88),
  [468] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(87),
  [471] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(175),
  [474] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(369),
  [477] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(370),
  [480] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(373),
  [483] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(389),
  [486] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(122),
  [489] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(123),
  [492] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(504),
  [495] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(536),
  [498] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(486),
  [501] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(499),
  [504] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(181),
  [507] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(292),
  [510] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(104),
  [513] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(105),
  [516] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(9),
  [519] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(98),
  [522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(371),
  [524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(361),
  [526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(398),
  [528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(56),
  [530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(75),
  [532] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0),
  [534] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(468),
  [537] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(295),
  [540] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(300),
  [543] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(569),
  [546] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(299),
  [549] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(298),
  [552] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(297),
  [555] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(88),
  [558] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(87),
  [561] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(175),
  [564] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(369),
  [567] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(370),
  [570] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(373),
  [573] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(389),
  [576] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(122),
  [579] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(123),
  [582] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(504),
  [585] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(536),
  [588] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(486),
  [591] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(499),
  [594] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(181),
  [597] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(292),
  [600] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(104),
  [603] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(105),
  [606] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(9),
  [609] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(98),
  [612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(57),
  [614] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 5, 0, 27),
  [616] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 5, 0, 27),
  [618] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_caption, 3, 0, 0),
  [620] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_caption, 3, 0, 0),
  [622] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_item, 3, 0, 0),
  [624] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_item, 3, 0, 0),
  [626] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialblock, 3, 0, 7),
  [628] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialblock, 3, 0, 7),
  [630] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 3, 0, 12),
  [632] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 3, 0, 12),
  [634] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 3, 0, 3),
  [636] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 3, 0, 3),
  [638] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 3, 0, 13),
  [640] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 3, 0, 13),
  [642] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 3, 0, 14),
  [644] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 3, 0, 14),
  [646] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 3, 0, 3),
  [648] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 3, 0, 3),
  [650] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 3, 0, 1),
  [652] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 3, 0, 1),
  [654] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_paragraph, 2, 0, 0),
  [656] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_paragraph, 2, 0, 0),
  [658] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_paragraph, 3, 0, 0),
  [660] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_paragraph, 3, 0, 0),
  [662] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_paragraph, 4, 0, 3),
  [664] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_paragraph, 4, 0, 3),
  [666] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_paragraph, 1, 0, 0),
  [668] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_paragraph, 1, 0, 0),
  [670] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialblock, 1, 0, 0),
  [672] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialblock, 1, 0, 0),
  [674] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialblock, 3, 0, 1),
  [676] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialblock, 3, 0, 1),
  [678] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_mathblock, 4, 0, 15),
  [680] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_mathblock, 4, 0, 15),
  [682] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialblock, 4, 0, 16),
  [684] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialblock, 4, 0, 16),
  [686] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialblock, 4, 0, 3),
  [688] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialblock, 4, 0, 3),
  [690] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_caption, 4, 0, 15),
  [692] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_caption, 4, 0, 15),
  [694] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_item, 4, 0, 15),
  [696] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_item, 4, 0, 15),
  [698] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 4, 0, 19),
  [700] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 4, 0, 19),
  [702] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 4, 0, 20),
  [704] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 4, 0, 20),
  [706] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 4, 0, 21),
  [708] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 4, 0, 21),
  [710] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 4, 0, 22),
  [712] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 4, 0, 22),
  [714] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 4, 0, 23),
  [716] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 4, 0, 23),
  [718] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 4, 0, 24),
  [720] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 4, 0, 24),
  [722] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 4, 0, 3),
  [724] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 4, 0, 3),
  [726] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_paragraph, 5, 0, 3),
  [728] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_paragraph, 5, 0, 3),
  [730] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 2, 0, 1),
  [732] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 2, 0, 1),
  [734] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 2, 0, 1),
  [736] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 2, 0, 1),
  [738] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 5, 0, 28),
  [740] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 5, 0, 28),
  [742] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 5, 0, 29),
  [744] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 5, 0, 29),
  [746] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 5, 0, 30),
  [748] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 5, 0, 30),
  [750] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table, 6, 0, 31),
  [752] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table, 6, 0, 31),
  [754] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_mathblock, 3, 0, 0),
  [756] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_mathblock, 3, 0, 0),
  [758] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialblock, 2, 0, 1),
  [760] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialblock, 2, 0, 1),
  [762] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_appendix, 1, 0, 1),
  [764] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_appendix, 1, 0, 1),
  [766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(201),
  [768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(390),
  [770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(391),
  [772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(392),
  [774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(393),
  [776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(151),
  [778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(152),
  [780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(607),
  [782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(608),
  [784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(609),
  [786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(610),
  [788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(202),
  [790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(103),
  [792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(106),
  [794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(110),
  [796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(116),
  [798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(301),
  [800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(296),
  [802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(370),
  [804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(310),
  [806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(94),
  [808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(93),
  [810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(99),
  [812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(96),
  [814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(76),
  [816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(90),
  [818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(60),
  [820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(67),
  [822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(49),
  [824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(50),
  [826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(59),
  [828] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(301),
  [831] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(296),
  [834] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(175),
  [837] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(369),
  [840] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(370),
  [843] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(373),
  [846] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(389),
  [849] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(122),
  [852] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(123),
  [855] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(504),
  [858] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(536),
  [861] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(486),
  [864] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(499),
  [867] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(181),
  [870] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(104),
  [873] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(105),
  [876] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0), SHIFT_REPEAT(96),
  [879] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_paragraph_repeat1, 2, 0, 0),
  [881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(68),
  [883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(95),
  [885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(58),
  [887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(485),
  [889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(519),
  [891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(92),
  [893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(97),
  [895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(311),
  [897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(190),
  [899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(154),
  [901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(185),
  [903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(165),
  [905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(204),
  [907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(158),
  [909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(268),
  [911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(137),
  [913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(239),
  [915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(146),
  [917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(240),
  [919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(148),
  [921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(205),
  [923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(160),
  [925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(244),
  [927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(169),
  [929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(269),
  [931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(138),
  [933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(245),
  [935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(171),
  [937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(100),
  [939] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0), SHIFT_REPEAT(241),
  [942] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0), SHIFT_REPEAT(395),
  [945] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0), SHIFT_REPEAT(396),
  [948] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0), SHIFT_REPEAT(397),
  [951] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0), SHIFT_REPEAT(374),
  [954] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0), SHIFT_REPEAT(162),
  [957] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0), SHIFT_REPEAT(163),
  [960] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0), SHIFT_REPEAT(624),
  [963] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0), SHIFT_REPEAT(625),
  [966] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0), SHIFT_REPEAT(626),
  [969] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0), SHIFT_REPEAT(627),
  [972] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0), SHIFT_REPEAT(242),
  [975] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0), SHIFT_REPEAT(111),
  [978] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0), SHIFT_REPEAT(113),
  [981] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0), SHIFT_REPEAT(130),
  [984] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tdcontent, 1, 0, 0),
  [986] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tdcontent, 1, 0, 0),
  [988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(118),
  [990] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0),
  [992] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(201),
  [995] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(390),
  [998] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(391),
  [1001] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(392),
  [1004] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(393),
  [1007] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(151),
  [1010] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(152),
  [1013] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(607),
  [1016] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(608),
  [1019] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(609),
  [1022] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(610),
  [1025] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(202),
  [1028] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0),
  [1030] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(106),
  [1033] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(110),
  [1036] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(118),
  [1039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(218),
  [1041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(260),
  [1043] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(265),
  [1046] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(381),
  [1049] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(382),
  [1052] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(383),
  [1055] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(384),
  [1058] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(132),
  [1061] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(133),
  [1064] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(570),
  [1067] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(571),
  [1070] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(572),
  [1073] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(573),
  [1076] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(266),
  [1079] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(107),
  [1082] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(112),
  [1085] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(121),
  [1088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(265),
  [1090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(381),
  [1092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(382),
  [1094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(383),
  [1096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(384),
  [1098] = {.entry = {.count = 1, .reusable = false}}, SHIFT(132),
  [1100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(193),
  [1102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(133),
  [1104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(570),
  [1106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(571),
  [1108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(572),
  [1110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(573),
  [1112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(266),
  [1114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(107),
  [1116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(112),
  [1118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(127),
  [1120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(289),
  [1122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(385),
  [1124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(386),
  [1126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(387),
  [1128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(388),
  [1130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(141),
  [1132] = {.entry = {.count = 1, .reusable = false}}, SHIFT(142),
  [1134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(590),
  [1136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(591),
  [1138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(592),
  [1140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(593),
  [1142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(280),
  [1144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(108),
  [1146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(109),
  [1148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(128),
  [1150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(178),
  [1152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(179),
  [1154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(194),
  [1156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(121),
  [1158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(129),
  [1160] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(289),
  [1163] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(385),
  [1166] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(386),
  [1169] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(387),
  [1172] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(388),
  [1175] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(141),
  [1178] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(142),
  [1181] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(590),
  [1184] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(591),
  [1187] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(592),
  [1190] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(593),
  [1193] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(280),
  [1196] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(108),
  [1199] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(109),
  [1202] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(129),
  [1205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(241),
  [1207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(395),
  [1209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(396),
  [1211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(397),
  [1213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(374),
  [1215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(162),
  [1217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(163),
  [1219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(624),
  [1221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(625),
  [1223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(626),
  [1225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(627),
  [1227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(242),
  [1229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(111),
  [1231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(113),
  [1233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(131),
  [1235] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(241),
  [1238] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(395),
  [1241] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(396),
  [1244] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(397),
  [1247] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(374),
  [1250] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(162),
  [1253] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(163),
  [1256] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(624),
  [1259] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(625),
  [1262] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(626),
  [1265] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(627),
  [1268] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(242),
  [1271] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(111),
  [1274] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(113),
  [1277] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_repeat1, 2, 0, 0), SHIFT_REPEAT(131),
  [1280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(267),
  [1282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(134),
  [1284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(135),
  [1286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(273),
  [1288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(276),
  [1290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(139),
  [1292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(277),
  [1294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(279),
  [1296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(284),
  [1298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(285),
  [1300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(257),
  [1302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(143),
  [1304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(144),
  [1306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(225),
  [1308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(228),
  [1310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(149),
  [1312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(229),
  [1314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(230),
  [1316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(150),
  [1318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(231),
  [1320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(235),
  [1322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(236),
  [1324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(203),
  [1326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(155),
  [1328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(156),
  [1330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(182),
  [1332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(124),
  [1334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(188),
  [1336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(209),
  [1338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(211),
  [1340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(119),
  [1342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(212),
  [1344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(213),
  [1346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(161),
  [1348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(214),
  [1350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(219),
  [1352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(243),
  [1354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(166),
  [1356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(167),
  [1358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(189),
  [1360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(126),
  [1362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(192),
  [1364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(249),
  [1366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(252),
  [1368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(172),
  [1370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(253),
  [1372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(254),
  [1374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(120),
  [1376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(255),
  [1378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(259),
  [1380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(278),
  [1382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(140),
  [1384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(369),
  [1386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(91),
  [1388] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialinline, 1, 0, 0),
  [1390] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialinline, 1, 0, 0),
  [1392] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialinline, 3, 0, 11),
  [1394] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialinline, 3, 0, 11),
  [1396] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialinline, 4, 0, 17),
  [1398] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialinline, 4, 0, 17),
  [1400] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_construct, 4, 0, 3),
  [1402] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_construct, 4, 0, 3),
  [1404] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inline, 4, 0, 3),
  [1406] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_inline, 4, 0, 3),
  [1408] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialinline, 4, 0, 18),
  [1410] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialinline, 4, 0, 18),
  [1412] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialconstruct, 1, 0, 1),
  [1414] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialconstruct, 1, 0, 1),
  [1416] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_construct, 3, 0, 3),
  [1418] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_construct, 3, 0, 3),
  [1420] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialinline, 4, 0, 3),
  [1422] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialinline, 4, 0, 3),
  [1424] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialinline, 5, 0, 25),
  [1426] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialinline, 5, 0, 25),
  [1428] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inline, 2, 0, 1),
  [1430] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_inline, 2, 0, 1),
  [1432] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialinline, 5, 0, 26),
  [1434] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialinline, 5, 0, 26),
  [1436] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialinline, 3, 0, 9),
  [1438] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialinline, 3, 0, 9),
  [1440] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_construct, 3, 0, 1),
  [1442] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_construct, 3, 0, 1),
  [1444] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inline, 3, 0, 3),
  [1446] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_inline, 3, 0, 3),
  [1448] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_construct, 2, 0, 1),
  [1450] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_construct, 2, 0, 1),
  [1452] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialinline, 3, 0, 1),
  [1454] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialinline, 3, 0, 1),
  [1456] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inline, 3, 0, 1),
  [1458] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_inline, 3, 0, 1),
  [1460] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialinline, 2, 0, 1),
  [1462] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialinline, 2, 0, 1),
  [1464] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialinline, 3, 0, 8),
  [1466] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialinline, 3, 0, 8),
  [1468] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialinline, 3, 0, 10),
  [1470] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialinline, 3, 0, 10),
  [1472] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inlinemeta, 4, 0, 0),
  [1474] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_inlinemeta, 4, 0, 0),
  [1476] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inlinemeta, 3, 0, 0),
  [1478] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_inlinemeta, 3, 0, 0),
  [1480] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_trshort_repeat1, 2, 0, 0),
  [1482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(77),
  [1484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(89),
  [1486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(356),
  [1488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(357),
  [1490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(312),
  [1492] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_blockmeta_repeat1, 2, 0, 0), SHIFT_REPEAT(312),
  [1495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(338),
  [1497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(488),
  [1499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(337),
  [1501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(563),
  [1503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(577),
  [1505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(548),
  [1507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(333),
  [1509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(521),
  [1511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(490),
  [1513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(641),
  [1515] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_blockmeta_repeat1, 2, 0, 0), SHIFT_REPEAT(337),
  [1518] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_blockmeta_repeat1, 2, 0, 0), SHIFT_REPEAT(338),
  [1521] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_blockmeta_repeat1, 2, 0, 0), SHIFT_REPEAT(333),
  [1524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(564),
  [1526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(460),
  [1528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(588),
  [1530] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inlinemeta_repeat1, 2, 0, 0), SHIFT_REPEAT(564),
  [1533] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inlinemeta_repeat1, 2, 0, 0), SHIFT_REPEAT(312),
  [1536] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inlinemeta_repeat1, 2, 0, 0), SHIFT_REPEAT(460),
  [1539] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inlinemeta_repeat1, 2, 0, 0), SHIFT_REPEAT(588),
  [1542] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_inlinemeta_repeat1, 2, 0, 0),
  [1544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(53),
  [1546] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_thead_repeat1, 2, 0, 0),
  [1548] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_thead_repeat1, 2, 0, 0), SHIFT_REPEAT(86),
  [1551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(450),
  [1553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(86),
  [1555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(70),
  [1557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(54),
  [1559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(376),
  [1561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(549),
  [1563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(550),
  [1565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(467),
  [1567] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_tr_repeat1, 2, 0, 0),
  [1569] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_tr_repeat1, 2, 0, 0), SHIFT_REPEAT(103),
  [1572] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_bibtex_repeat1, 2, 0, 0),
  [1574] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_bibtex_repeat1, 2, 0, 0), SHIFT_REPEAT(550),
  [1577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(518),
  [1579] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 4, 0, 3),
  [1581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(354),
  [1583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(55),
  [1585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(517),
  [1587] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_bibitem_repeat1, 2, 0, 0), SHIFT_REPEAT(517),
  [1590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(470),
  [1592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(334),
  [1594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(71),
  [1596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(73),
  [1598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(315),
  [1600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(633),
  [1602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(317),
  [1604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(520),
  [1606] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 3, 0, 3),
  [1608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(471),
  [1610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(328),
  [1612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(319),
  [1614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(558),
  [1616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(543),
  [1618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(472),
  [1620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(344),
  [1622] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_thead, 3, 0, 1),
  [1624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(415),
  [1626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13),
  [1628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(417),
  [1630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(323),
  [1632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(79),
  [1634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(430),
  [1636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(429),
  [1638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(565),
  [1640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(566),
  [1642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(567),
  [1644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(568),
  [1646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(480),
  [1648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(481),
  [1650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(482),
  [1652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(483),
  [1654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(497),
  [1656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(474),
  [1658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(511),
  [1660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(512),
  [1662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(513),
  [1664] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 2, 0, 1),
  [1666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(540),
  [1668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(541),
  [1670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(542),
  [1672] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 3, 0, 1),
  [1674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(341),
  [1676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(347),
  [1678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(200),
  [1680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(509),
  [1682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(335),
  [1684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(414),
  [1686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(422),
  [1688] = {.entry = {.count = 1, .reusable = false}}, SHIFT(291),
  [1690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(326),
  [1692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14),
  [1694] = {.entry = {.count = 1, .reusable = false}}, SHIFT_EXTRA(),
  [1696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(336),
  [1698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12),
  [1700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(226),
  [1702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(600),
  [1704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(227),
  [1706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(601),
  [1708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(603),
  [1710] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metakey_list, 1, 0, 0),
  [1712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(547),
  [1714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(346),
  [1716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(433),
  [1718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(505),
  [1720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(458),
  [1722] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_td, 3, 0, 1),
  [1724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(343),
  [1726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(210),
  [1728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(617),
  [1730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(199),
  [1732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(618),
  [1734] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_trshort, 4, 0, 1),
  [1736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(585),
  [1738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(197),
  [1740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(477),
  [1742] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metaval_text_inline, 1, 0, 4),
  [1744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(622),
  [1746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(345),
  [1748] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inlinemetapair, 2, 0, 0),
  [1750] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metaval_list_inline, 1, 0, 0),
  [1752] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metaval_any_inline, 1, 0, 0),
  [1754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(325),
  [1756] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metaval_list_inline, 4, 0, 0),
  [1758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(322),
  [1760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(264),
  [1762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(250),
  [1764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(634),
  [1766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(251),
  [1768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(635),
  [1770] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_td, 4, 0, 3),
  [1772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(464),
  [1774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(263),
  [1776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(425),
  [1778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(537),
  [1780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(324),
  [1782] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inlinemetapair, 1, 0, 0),
  [1784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(528),
  [1786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(448),
  [1788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(431),
  [1790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(176),
  [1792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(484),
  [1794] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bibitem, 7, 0, 32),
  [1796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(452),
  [1798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(453),
  [1800] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tbody, 3, 0, 1),
  [1802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(401),
  [1804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(454),
  [1806] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_bibitem_repeat1, 2, 0, 0),
  [1808] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bibitem, 8, 0, 32),
  [1810] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bibitem, 9, 0, 32),
  [1812] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bibitempair, 5, 0, 0),
  [1814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(327),
  [1816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(413),
  [1818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17),
  [1820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(330),
  [1822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(274),
  [1824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(583),
  [1826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(275),
  [1828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(584),
  [1830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(427),
  [1832] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_trshort, 3, 0, 1),
  [1834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(222),
  [1836] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_metaval_list_repeat1, 2, 0, 0), SHIFT_REPEAT(505),
  [1839] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tr, 3, 0, 1),
  [1841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(443),
  [1843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(529),
  [1845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(206),
  [1847] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metakey_text, 1, 0, 0),
  [1849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(52),
  [1851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(510),
  [1853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(81),
  [1855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(82),
  [1857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(223),
  [1859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(286),
  [1861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(224),
  [1863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(562),
  [1865] = {.entry = {.count = 1, .reusable = false}}, SHIFT(424),
  [1867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(66),
  [1869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(83),
  [1871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(532),
  [1873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(538),
  [1875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(363),
  [1877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(232),
  [1879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(233),
  [1881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(234),
  [1883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(187),
  [1885] = {.entry = {.count = 1, .reusable = false}}, SHIFT(447),
  [1887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(237),
  [1889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(238),
  [1891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(438),
  [1893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(586),
  [1895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(291),
  [1897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7),
  [1899] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 5, 0, 3),
  [1901] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_metaval_list_repeat1, 2, 0, 0),
  [1903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(184),
  [1905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(207),
  [1907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(208),
  [1909] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 4, 0, 1),
  [1911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(522),
  [1913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(557),
  [1915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(527),
  [1917] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bibtex, 3, 0, 0),
  [1919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(51),
  [1921] = {.entry = {.count = 1, .reusable = false}}, SHIFT(492),
  [1923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(215),
  [1925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(216),
  [1927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(217),
  [1929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(535),
  [1931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(220),
  [1933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(221),
  [1935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(64),
  [1937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(546),
  [1939] = {.entry = {.count = 1, .reusable = false}}, SHIFT(544),
  [1941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(424),
  [1943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(246),
  [1945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(247),
  [1947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(248),
  [1949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(455),
  [1951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(606),
  [1953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(177),
  [1955] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bibtex, 2, 0, 0),
  [1957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(515),
  [1959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(69),
  [1961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(256),
  [1963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(290),
  [1965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(258),
  [1967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(180),
  [1969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(191),
  [1971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(183),
  [1973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(261),
  [1975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(262),
  [1977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(186),
  [1979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(196),
  [1981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(270),
  [1983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(271),
  [1985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(272),
  [1987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(84),
  [1989] = {.entry = {.count = 1, .reusable = false}}, SHIFT(461),
  [1991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(461),
  [1993] = {.entry = {.count = 1, .reusable = false}}, SHIFT(462),
  [1995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(638),
  [1997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(604),
  [1999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(605),
  [2001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(63),
  [2003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(616),
  [2005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(619),
  [2007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(620),
  [2009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(621),
  [2011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(487),
  [2013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(636),
  [2015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(637),
  [2017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(48),
  [2019] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metakey_any, 1, 0, 0),
  [2021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(418),
  [2023] = {.entry = {.count = 1, .reusable = false}}, SHIFT(408),
  [2025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(408),
  [2027] = {.entry = {.count = 1, .reusable = false}}, SHIFT(409),
  [2029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(493),
  [2031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(494),
  [2033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(495),
  [2035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(496),
  [2037] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [2039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(500),
  [2041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(501),
  [2043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(72),
  [2045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(198),
  [2047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(65),
  [2049] = {.entry = {.count = 1, .reusable = false}}, SHIFT(420),
  [2051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(420),
  [2053] = {.entry = {.count = 1, .reusable = false}}, SHIFT(421),
  [2055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5),
  [2057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(523),
  [2059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(524),
  [2061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(525),
  [2063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(526),
  [2065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(281),
  [2067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(530),
  [2069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(531),
  [2071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(282),
  [2073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(283),
  [2075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(74),
  [2077] = {.entry = {.count = 1, .reusable = false}}, SHIFT(436),
  [2079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(436),
  [2081] = {.entry = {.count = 1, .reusable = false}}, SHIFT(437),
  [2083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(80),
  [2085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(553),
  [2087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(554),
  [2089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(555),
  [2091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(556),
  [2093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(195),
  [2095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(560),
  [2097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(561),
  [2099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(287),
  [2101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(288),
  [2103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3),
  [2105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(559),
};

enum ts_external_scanner_symbol_identifiers {
  ts_external_token_upto_brace_or_comma_text = 0,
  ts_external_token_asis_dollar_text = 1,
  ts_external_token_asis_two_dollars_text = 2,
  ts_external_token_asis_backtick_text = 3,
  ts_external_token_asis_three_backticks_text = 4,
  ts_external_token_asis_halmos_text = 5,
  ts_external_token_text = 6,
  ts_external_token_paragraph_end = 7,
};

static const TSSymbol ts_external_scanner_symbol_map[EXTERNAL_TOKEN_COUNT] = {
  [ts_external_token_upto_brace_or_comma_text] = sym_upto_brace_or_comma_text,
  [ts_external_token_asis_dollar_text] = sym_asis_dollar_text,
  [ts_external_token_asis_two_dollars_text] = sym_asis_two_dollars_text,
  [ts_external_token_asis_backtick_text] = sym_asis_backtick_text,
  [ts_external_token_asis_three_backticks_text] = sym_asis_three_backticks_text,
  [ts_external_token_asis_halmos_text] = sym_asis_halmos_text,
  [ts_external_token_text] = sym_text,
  [ts_external_token_paragraph_end] = sym_paragraph_end,
};

static const bool ts_external_scanner_states[10][EXTERNAL_TOKEN_COUNT] = {
  [1] = {
    [ts_external_token_upto_brace_or_comma_text] = true,
    [ts_external_token_asis_dollar_text] = true,
    [ts_external_token_asis_two_dollars_text] = true,
    [ts_external_token_asis_backtick_text] = true,
    [ts_external_token_asis_three_backticks_text] = true,
    [ts_external_token_asis_halmos_text] = true,
    [ts_external_token_text] = true,
    [ts_external_token_paragraph_end] = true,
  },
  [2] = {
    [ts_external_token_text] = true,
  },
  [3] = {
    [ts_external_token_text] = true,
    [ts_external_token_paragraph_end] = true,
  },
  [4] = {
    [ts_external_token_asis_two_dollars_text] = true,
  },
  [5] = {
    [ts_external_token_asis_halmos_text] = true,
  },
  [6] = {
    [ts_external_token_asis_three_backticks_text] = true,
  },
  [7] = {
    [ts_external_token_asis_dollar_text] = true,
  },
  [8] = {
    [ts_external_token_asis_backtick_text] = true,
  },
  [9] = {
    [ts_external_token_upto_brace_or_comma_text] = true,
  },
};

#ifdef __cplusplus
extern "C" {
#endif
void *tree_sitter_rsm_external_scanner_create(void);
void tree_sitter_rsm_external_scanner_destroy(void *);
bool tree_sitter_rsm_external_scanner_scan(void *, TSLexer *, const bool *);
unsigned tree_sitter_rsm_external_scanner_serialize(void *, char *);
void tree_sitter_rsm_external_scanner_deserialize(void *, const char *, unsigned);

#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_rsm(void) {
  static const TSLanguage language = {
    .abi_version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = (const void*)ts_lex_modes,
    .lex_fn = ts_lex,
    .external_scanner = {
      &ts_external_scanner_states[0][0],
      ts_external_scanner_symbol_map,
      tree_sitter_rsm_external_scanner_create,
      tree_sitter_rsm_external_scanner_destroy,
      tree_sitter_rsm_external_scanner_scan,
      tree_sitter_rsm_external_scanner_serialize,
      tree_sitter_rsm_external_scanner_deserialize,
    },
    .primary_state_ids = ts_primary_state_ids,
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
